IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfMailItemBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfMailItemBrowse'
		DROP PROCEDURE [dbo].[adfMailItemBrowse]
	END
GO

PRINT 'Creating procedure adfMailItemBrowse'
GO

SET QUOTED_IDENTIFIER ON
GO

/******************************************************************************
**		File: adfMailItemBrowse.sql
**		Name: adfMailItemBrowse
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 10/17/2006
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [adfMailItemBrowse] 
	@Timestamp bigint, 
	@UnreadOnly bit,
	@ShowArchive bit
AS
	SET NOCOUNT ON
	

	DECLARE
		@UserID TIdentifier,
		@Class TClass,
		@Date TDate
		
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @Class = dbo.adfGetClassByName('Adf.MailItem')
	SET @Date = DATEADD(month, -1, GETDATE())

	SELECT
		[MailItem].[Class],
		[MailItem].[ID],
		[MailItem].[State],
		[MailItem].[Flag],
		[MailItem].[FileAs],
		[MailItem].[EventType],
		[MailItem].[FromID],
		[MailItem].[DocumentID],
		[MailItem].[DocumentClass],
		CAST(ISNULL([DocumentUserState].[Read], 0) as bit) as [Read],
		[MailItem].[Data],
		[MailItem].[Comments],
		[MailItem].[Created],
		[MailItem].[CreatedBy],
		[MailItem].[Modified],
		[MailItem].[ModifiedBy],
		CAST([MailItem].[Timestamp] as bigint) as [Timestamp]
	FROM
		[MailItem] LEFT OUTER JOIN [DocumentUserState]
			ON	[DocumentUserState].[UserID] = @UserID AND 
				[DocumentUserState].[DocumentID] = [MailItem].[ID] AND
				[DocumentUserState].[DocumentClass] = @Class
	WHERE
		[MailItem].[ToID] = @UserID
	AND
		CAST([MailItem].[Timestamp] as bigint) > @Timestamp
	AND
		(
			@UnreadOnly = 0 OR 
			ISNULL([DocumentUserState].[Read], 0) = 0
		)
	AND
		(
			@ShowArchive = 1 OR 
			ISNULL([DocumentUserState].[Read], 0) = 0 OR
			[MailItem].[Created] >= @Date
		)
		
GO

GRANT EXECUTE ON [adfMailItemBrowse] TO PUBLIC
GO
 