IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfHasAccessRight]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function adfHasAccessRight'
		DROP FUNCTION [dbo].[adfHasAccessRight]
	END

GO

PRINT 'Creating function adfHasAccessRight'
GO
/******************************************************************************
**		File: 
**		Name: adfHasAccessRight
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE FUNCTION adfHasAccessRight
	(@RightID INT)
RETURNS INT
AS
BEGIN
	IF IS_MEMBER('db_owner') = 1
	BEGIN
		IF EXISTS(
			SELECT 
				[Right].[ID], 
				[Right].[Name] 
			FROM 
				[Right] 
			WHERE 
				[Right].[ID] = @RightID AND
				[Right].[Name] IN ('ManageRights', 'ManageUsers', 'ManageCompanies', 'ManageOwnCompanies', 'ManageEmployees', 'ManageContacts', 'ManagePerson', 'ViewContactDetails', 'ViewEmployee', 'ViewEmployeeDetails')
			)
			RETURN 1
	END
		
	
	DECLARE @UserID INT
	SET @UserID = dbo.adfGetCurrentUserID()
	
	IF NOT EXISTS(
		SELECT 
			*
		FROM
			[AccessRight] a
		WHERE
			(
				a.[RightID] = @RightID 
				AND 			
				[a].[Allow] = 1
				AND
				(a.[TrusteeID] IN 
					(
						SELECT 
							[UserRole].[RoleID]
						FROM
							[UserRole]
						WHERE
							[UserRole].[UserID] = @UserID
					) 
					OR
					a.[TrusteeID] = @UserID
				)
			))
	BEGIN
			RETURN 0
	END
		
	RETURN 1
END
GO

GRANT EXEC ON adfHasAccessRight TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfHasAccessRightByName]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function adfHasAccessRightByName'
		DROP FUNCTION [dbo].[adfHasAccessRightByName]
	END

GO

PRINT 'Creating function adfHasAccessRightByName'
GO
/******************************************************************************
**		File: 
**		Name: adfHasAccessRightByName
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE FUNCTION adfHasAccessRightByName
	(@RightName TSysName)
RETURNS INT
AS
BEGIN
	DECLARE @UserID INT, @RightID INT
	SELECT @RightID = [ID] FROM [Right] WHERE [Name]=@RightName

	IF IS_MEMBER('db_owner') = 1
	BEGIN
		IF @RightName IN ('ManageRights', 'ManageUsers', 'ManageCompanies', 'ManageOwnCompanies', 'ManageEmployees', 'ManageContacts', 'ManagePerson', 'ViewContactDetails', 'ViewEmployee', 'ViewEmployeeDetails')
			RETURN 1
	END
	
	SET @UserID = dbo.adfGetCurrentUserID()
	IF NOT EXISTS(
		SELECT 
			*
		FROM
			[AccessRight] a
		WHERE
			(
				a.[RightID] = @RightID 
				AND 			
				[a].[Allow] = 1
				AND
				(a.[TrusteeID] IN 
					(
						SELECT 
							[UserRole].[RoleID]
						FROM
							[UserRole]
						WHERE
							[UserRole].[UserID] = @UserID
					) 
					OR
					a.[TrusteeID] = @UserID
				)
			))
	BEGIN
		RETURN 0
	END

	RETURN 1
END
GO

GRANT EXEC ON adfHasAccessRightByName TO PUBLIC
GO
