IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfTransitionTemplateCreate')
	BEGIN
		PRINT 'Dropping Procedure adfTransitionTemplateCreate'
		DROP  Procedure  adfTransitionTemplateCreate
	END

GO

PRINT 'Creating Procedure adfTransitionTemplateCreate'
GO
/******************************************************************************
**		File: 
**		Name: adfTransitionTemplateCreate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfTransitionTemplateCreate
	@Right			TSysName,
	@Class			TClass,
	@FromState		TState,
	@ToState		TState,
	@ActionID		TIdentifier,
	@Name			TName,
	@Comments		TNotes,
	@UICommandID	TIdentifier,
	@SPValidate		TSysname,
	@SPBefore		TSysname,
	@SPAfter		TSysname,
	@ConfirmationMessage TName
AS
	DECLARE @ID TIdentifier,
			@RightID TIdentifier
	SET NOCOUNT ON
	
	SET @RightID = dbo.adfGetRightID(@Right)
	
	DECLARE @Lang TLanguage
	SET @Lang = dbo.adfGetLanguage()
	
	BEGIN TRANSACTION

	INSERT INTO [TransitionTemplate]
	(
		[RightID], 
		[Class], 
		[FromState], 
		[ToState], 
		[ActionID], 
		[Name], 
		[Comments], 
		[UICommandID],
		[SPValidate],
		[SPBefore],
		[SPAfter],
		[ConfirmationMessage]
	)
	VALUES(
		@RightID, 
		@Class, 
		@FromState, 
		@ToState, 
		@ActionID, 
		@Name, 
		@Comments, 
		@UICommandID,
		@SPValidate,
		@SPBefore,
		@SPAfter,
		@ConfirmationMessage
	)
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	SET @ID = SCOPE_IDENTITY()
	
	INSERT INTO [TransitionTemplateGlobal]
		([ID], [Language], [Name], [Comments], [ConfirmationMessage])
	VALUES
		(@ID, @Lang, @Name, @Comments, @ConfirmationMessage)
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION
	
	EXEC adfTransitionTemplateGet @ID
	
	RETURN 0
GO

GRANT EXEC ON adfTransitionTemplateCreate TO PUBLIC
GO
