IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfTransitionTemplateUpdate')
	BEGIN
		PRINT 'Dropping Procedure adfTransitionTemplateUpdate'
		DROP  Procedure  adfTransitionTemplateUpdate
	END

GO

PRINT 'Creating Procedure adfTransitionTemplateUpdate'
GO
/******************************************************************************
**		File: 
**		Name: adfTransitionTemplateUpdate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfTransitionTemplateUpdate
	@ID				TIdentifier,
	@Right			TSysname,
	@Class			TClass,
	@FromState		TState,
	@ToState		TState,
	@ActionID		TIdentifier,
	@Name			TName,
	@Comments		TNotes,
	@UICommandID	TIdentifier,
	@SPValidate		TSysname,
	@SPBefore		TSysname,
	@SPAfter		TSysname,
	@ConfirmationMessage TName
AS
	DECLARE @RightID TIdentifier
	
	SET NOCOUNT ON

	SET @RightID = dbo.adfGetRightID(@Right)

	DECLARE @Lang TLanguage
	SET @Lang = dbo.adfGetLanguage()
	
	BEGIN TRANSACTION
	
	IF @Lang = 'ru'
	BEGIN
		UPDATE [TransitionTemplate]
		SET
			[TransitionTemplate].[RightID] = @RightID,
			[TransitionTemplate].[Class] = @Class,
			[TransitionTemplate].[FromState] = @FromState,
			[TransitionTemplate].[ToState] = @ToState,
			[TransitionTemplate].[ActionID] = @ActionID,
			[TransitionTemplate].[Name] = @Name,
			[TransitionTemplate].[Comments] = @Comments,
			[TransitionTemplate].[UICommandID] = @UICommandID,
			[TransitionTemplate].[SPValidate] = @SPValidate,
			[TransitionTemplate].[SPBefore] = @SPBefore,
			[TransitionTemplate].[SPAfter] = @SPAfter,
			[TransitionTemplate].[ConfirmationMessage] = @ConfirmationMessage
		WHERE
			[TransitionTemplate].[ID] = @ID
	END
	ELSE
	BEGIN
		UPDATE [TransitionTemplate]
		SET
			[TransitionTemplate].[RightID] = @RightID,
			[TransitionTemplate].[Class] = @Class,
			[TransitionTemplate].[FromState] = @FromState,
			[TransitionTemplate].[ToState] = @ToState,
			[TransitionTemplate].[ActionID] = @ActionID,
			[TransitionTemplate].[UICommandID] = @UICommandID,
			[TransitionTemplate].[SPValidate] = @SPValidate,
			[TransitionTemplate].[SPBefore] = @SPBefore,
			[TransitionTemplate].[SPAfter] = @SPAfter
		WHERE
			[TransitionTemplate].[ID] = @ID
	END	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	IF EXISTS(SELECT * FROM [TransitionTemplateGlobal] WHERE [ID] = @ID AND [Language] = @Lang)
	BEGIN
		UPDATE [TransitionTemplateGlobal]
		SET
			[Name] = @Name,
			[Comments] = @Comments,
			[ConfirmationMessage] = @ConfirmationMessage
		WHERE
			[ID] = @ID AND [Language] = @Lang
	END
	ELSE
	BEGIN
		INSERT INTO [TransitionTemplateGlobal]
			([ID], [Language], [Name], [Comments], [ConfirmationMessage])
		VALUES
			(@ID, @Lang, @Name, @Comments, @ConfirmationMessage)
	END

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION

	EXEC adfTransitionTemplateGet @ID
	
	RETURN 0
GO

GRANT EXEC ON adfTransitionTemplateUpdate TO PUBLIC
GO
