IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsAssignment') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'UniqueID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsAssignment')
		DROP TABLE [MsAssignment]
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsAssignment') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: MsAssignment                                          */
	/*==============================================================*/
	create table MsAssignment (
	   ProjectID            TIdentifier          not null,
	   TaskID               TIdentifier          not null,
	   ResourceID           TIdentifier          not null,
	   ID                   TIdentifier          identity,
	   Guid                 TGuid                not null,
	   Units                TDouble              not null,
	   Work                 TDouble              not null,
	   Cost                 TDouble              not null,
	   OvertimeWork         TDouble              not null,
	   OvertimeCost         TDouble              not null,
	   ActualWork           TDouble              not null,
	   ActualCost           TDouble              not null,
	   ActualOvertimeWork   TDouble              not null,
	   ActualOvertimeCost   TDouble              not null,
	   RemainingWork        TDouble              not null,
	   RemainingCost        TDouble              not null,
	   RemainingOvertimeWork TDouble              not null,
	   RemainingOvertimeCost TDouble              not null,
	   PercentWorkComplete  TPercent             not null,
	   UniqueID				TIdentifier			null,
	   constraint MsAssignmentPK primary key  (TaskID, ProjectID, ResourceID, ID)
	)
go

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsProject') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'UniqueID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsProject')
		DROP TABLE [MsProject]
END
GO
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsProject') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: MsProject                                             */
	/*==============================================================*/
	create table MsProject (
	   ID                   TIdentifier          identity,
	   DocumentItemID       TIdentifier          null,
	   PriorityID           TIdentifier          not null,
	   CurrencyCode         TCode3               not null,
	   Guid                 TGuid                not null,
	   ParentSummaryGuid    TGuid                null,
	   Name                 TName                not null,
	   FullName             TName                not null,
	   FileCreateDate       TDateTime            not null,
	   Notes                TNotes               null,
	   CurrencySymbol       TCode                not null,
	   CurrencyDigits       TInt16               not null,
	   CurrencySymbolPosition TInt32               not null,
	   StartWeekOn          TInt32               not null,
	   StartYearIn          TInt32               not null,
	   DaysPerMonth         TInt16               not null,
	   HoursPerDay          TDouble              not null,
	   HoursPerWeek         TDouble              not null,
	   FixedCost            TDouble              not null,
	   FixedDuration        TBool                not null,
	   Start                TDateTime            not null,
	   Finish               TDateTime            not null,
	   Duration             TInt32               not null,
	   ActualStart          TDateTime            null,
	   ActualFinish         TDateTime            null,
	   Work                 TDouble              not null,
	   Cost                 TDouble              not null,
	   OvertimeWork         TDouble              not null,
	   OvertimeCost         TDouble              not null,
	   ActualWork           TDouble              not null,
	   ActualCost           TDouble              not null,
	   ActualDuration       TInt32               not null,
	   ActualOvertimeWork   TDouble              not null,
	   ActualOvertimeCost   TDouble              not null,
	   RemainingWork        TDouble              not null,
	   RemainingCost        TDouble              not null,
	   RemainingDuration    TInt32               not null,
	   RemainingOvertimeWork TDouble              not null,
	   RemainingOvertimeCost TDouble              not null,
	   PercentComplete      TPercent             not null,
	   PercentWorkComplete  TPercent             not null,
	   UniqueID				TIdentifier		  	null,
	   LastDateSync         TDateTime            not null,
	   FileVersion          TCode                not null,
	   constraint MsProjectPK primary key  (ID)
	)
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'FileVersion' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsProject')
	ALTER TABLE [MsProject] ADD [FileVersion] TCode not null default '11.0'
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'LastDateSync' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsProject')
BEGIN
	EXEC sp_executesql N'ALTER TABLE [MsProject] ADD [LastDateSync] TDateTime null'
	EXEC sp_executesql N'UPDATE [MsProject] SET [LastDateSync] = [MsProject].[Modified] FROM [MsProject]'
	EXEC sp_executesql N'ALTER TABLE [MsProject] ALTER COLUMN [LastDateSync] TDateTime not null'
END

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsResource') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'UniqueID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsResource')
		DROP TABLE [MsResource]
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsResource') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: MsResource                                            */
	/*==============================================================*/
	create table MsResource (
	   ProjectID            TIdentifier          not null,
	   ID                   TIdentifier          identity,
	   Guid                 TGuid                not null,
	   Name                 TName                not null,
	   Code                 TCode                null,
	   Notes                TNotes               null,
	   Initials             TCode                not null,
	   Type                 TInt32               not null,
	   StandardRate         TMoney               null,
	   OvertimeRate         TMoney               null,
	   Work                 TDouble              not null,
	   Cost                 TDouble              not null,
	   CostPerUse           TDouble              not null,
	   OvertimeWork         TDouble              not null,
	   OvertimeCost         TDouble              not null,
	   ActualWork           TDouble              not null,
	   ActualCost           TDouble              not null,
	   ActualOvertimeWork   TDouble              not null,
	   ActualOvertimeCost   TDouble              not null,
	   RemainingWork        TDouble              not null,
	   RemainingCost        TDouble              not null,
	   RemainingOvertimeWork TDouble              not null,
	   RemainingOvertimeCost TDouble              not null,
	   PercentWorkComplete  TPercent             not null,
	   UniqueID				TIdentifier			null,
	   constraint MsResourcePK primary key  (ProjectID, ID),
	   constraint MsResourceAK unique (ID)
	)
go

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsTask') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'UniqueID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsTask')
		DROP TABLE [MsTask]
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsTask') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: MsTask                                                */
	/*==============================================================*/
	create table MsTask (
	   ID                   TIdentifier          identity,
	   ProjectID            TIdentifier          not null,
	   SubprojectID         TIdentifier          null,
	   ParentID             TIdentifier          null,
	   PriorityID           TIdentifier          not null,
	   Guid                 TGuid                not null,
	   Name                 TName                not null,
	   Notes                TNotes               null,
	   Start                TDateTime            not null,
	   Finish               TDateTime            not null,
	   Duration             TInt32               not null,
	   ActualStart          TDateTime            null,
	   ActualFinish         TDateTime            null,
	   Work                 TDouble              not null,
	   Cost                 TDouble              not null,
	   OvertimeWork         TDouble              not null,
	   OvertimeCost         TDouble              not null,
	   ActualWork           TDouble              not null,
	   ActualCost           TDouble              not null,
	   ActualDuration       TInt32               not null,
	   ActualOvertimeWork   TDouble              not null,
	   ActualOvertimeCost   TDouble              not null,
	   RemainingWork        TDouble              not null,
	   RemainingCost        TDouble              not null,
	   RemainingDuration    TDouble              not null,
	   RemainingOvertimeWork TDouble              not null,
	   RemainingOvertimeCost TDouble              not null,
	   PercentComplete      TPercent             not null,
	   PercentWorkComplete  TPercent             not null,
	   Milestone            TBool                not null,
	   Estimated            TBool                not null,
	   UniqueID				TIdentifier			null,
	   constraint MsTaskPK primary key  (ProjectID, ID),
	   constraint MsTaskAK unique (ID)
	)
go

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MsTimephasedData') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: MsTimephasedData                                      */
	/*==============================================================*/
	create table MsTimephasedData (
	   ProjectID            TIdentifier          not null,
	   TaskID               TIdentifier          not null,
	   ResourceID           TIdentifier          not null,
	   AssignmentID         TIdentifier          not null,
	   Type                 TInt32               not null,
	   StartDate            TDateTime            not null,
	   EndDate              TDateTime            not null,
	   Value                TDouble              not null,
	   constraint MsTimephasedDataPK primary key  (TaskID, ProjectID, ResourceID, AssignmentID, Type, StartDate)
	)
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'SubprojectID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsTask')
	ALTER TABLE [MsTask] ADD [SubprojectID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'MsResourceID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Assignment')
	ALTER TABLE [Assignment] ADD [MsResourceID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'MsProjectID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [MsProjectID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'MsTaskID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Task')
	ALTER TABLE [Task] ADD [MsTaskID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'DocumentItemID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsProject')
	ALTER TABLE [MsProject] ADD [DocumentItemID] TIdentifier NULL
GO