IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'ProjectDetail') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	DECLARE @true bit
	IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PercentComplete' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
		SET @true = 1

	EXEC sp_executesql N'
	/*==============================================================*/
	/* Table: ProjectDetail                                         */
	/*==============================================================*/
	create table ProjectDetail (
	   ID                   TIdentifier          not null,
	   DueDate              TDate                not null,
	   PercentComplete      TPercent             not null default 0,
	   PlannedBudget        TMoney               not null default 0,
	   PlannedManHour       TCount               not null default 0,
	   constraint ProjectDetailPK primary key  (ID)
	)'
	
	IF @true = 1
	BEGIN
		EXEC sp_executesql N'
		INSERT INTO [ProjectDetail] ([ID], [DueDate])
		SELECT [ID], [Date] FROM [Project]
		'

		EXEC sp_executesql N'
		WITH
		[NewProjectDueDate] ([ProjectID], [DueDate]) AS
		(
		SELECT 
			[Project].[ID],
			MAX([Task].[DueDate])
		FROM 
			[Project]
			LEFT OUTER JOIN [Task]
				ON [Task].[ProjectID] = [Project].[ID]
		GROUP BY
			[Project].[ID]
		)
		UPDATE [ProjectDetail]
		SET [DueDate] = (CASE WHEN [NewProjectDueDate].[DueDate] IS NOT NULL
										AND [NewProjectDueDate].[DueDate] >= [Project].[Date]
										THEN [NewProjectDueDate].[DueDate] ELSE [Project].[Date] END)
		FROM 
			[ProjectDetail] 
			INNER JOIN [Project]
				ON [Project].[ID] = [ProjectDetail].[ID]
			INNER JOIN [NewProjectDueDate]
				ON [NewProjectDueDate].[ProjectID] = [Project].[ID]
		'
		EXEC adfParameterSet 'MustRecalculateTasksAndProjects', 'Install', @true
	END
	ELSE
	BEGIN
		EXEC sp_executesql N'
		INSERT INTO [ProjectDetail] ([ID], [DueDate], [PercentComplete], [PlannedBudget], [PlannedManHour])
		SELECT [ID], [DueDate], [PercentComplete], [PlannedBudget], [PlannedManHour] FROM [Project]
		'
	END
	
END
go
IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Duration' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] DROP COLUMN [Duration]
GO
IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ManHour' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] DROP COLUMN [ManHour]
GO
IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'DueDate' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'DueDate' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='Project'
	SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT ' + @name
	EXEC (@sql)	
	ALTER TABLE [Project] DROP COLUMN [DueDate]
END
GO
IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PercentComplete' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'PercentComplete' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='Project'
	SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT ' + @name
	EXEC (@sql)	
	ALTER TABLE [Project] DROP COLUMN [PercentComplete]
END
GO
IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PlannedBudget' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'PlannedBudget' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='Project'
	SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT ' + @name
	EXEC (@sql)	
	ALTER TABLE [Project] DROP COLUMN [PlannedBudget]
END
GO
IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PlannedManHour' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'PlannedManHour' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='Project'
	SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT ' + @name
	EXEC (@sql)	
	ALTER TABLE [Project] DROP COLUMN [PlannedManHour]
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'PaymentPeriod') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: PaymentPeriod                                         */
	/*==============================================================*/
	create table PaymentPeriod (
	   ProjectID            TIdentifier          not null,
	   InvoicePeriodType    TCode                null,
	   InvoiceDayType       TCode                null,
	   InvoiceNextPaymentDate TDate                null,
	   CalculationPeriodType TCode                null,
	   CalculationDayType   TCode                null,
	   CalculationNextPaymentDate TDate                null,
	   StatementPeriodType  TCode                null,
	   StatementDayType     TCode                null,
	   StatementNextPaymentDate TDate                null,
	   constraint PaymentPeriodPK primary key  (ProjectID)
	)
go

INSERT INTO PaymentPeriod ([ProjectID])
SELECT 
	[ID]
FROM 
	[Project]
	LEFT OUTER JOIN [PaymentPeriod]
		ON [PaymentPeriod].[ProjectID] = [Project].[ID]
WHERE
	[PaymentPeriod].[ProjectID] IS NULL
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'AssistantRecurrencePattern') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	IF (SELECT COUNT([ID]) FROM [AssistantRecurrencePattern]) = 0
	BEGIN
		DROP TABLE [AssistantRecurrencePattern]
	END
END

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'AssistantRecurrencePattern') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
/*==============================================================*/
/* Table: AssistantRecurrencePattern                            */
/*==============================================================*/
	create table AssistantRecurrencePattern (
	   ID                   TIdentifier          identity,
	   StartDate            TDate                null,
	   EndDate              TDate                null,
	   Occurrences          TCount               null,
	   RecurrenceType       TIdentifier          not null,
	   Interval             TCount               null,
	   DayOfWeekMask        TIdentifier          not null,
	   Instance             TIdentifier          null,
	   MonthOfYear          TCount               null,
	   DayOfMonth           TCount               null,
	   DayTransferRule      TCount               null
	   constraint AssistantRecurrencePatternPK primary key  (ID)
	)
GO
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'CalculationRecurrencePatternID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [CalculationRecurrencePatternID] TIdentifier NULL

GO
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'StatementRecurrencePatternID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [StatementRecurrencePatternID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'InvoiceRecurrencePatternID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [InvoiceRecurrencePatternID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'CustomerFinanceManagerID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [CustomerFinanceManagerID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Modified' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsProject')
	ALTER TABLE [MsProject] ADD [Modified] TSysDateTime not null default GETDATE()
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ModifiedBy' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='MsProject')
BEGIN
	EXEC sp_executesql N'ALTER TABLE [MsProject] ADD [ModifiedBy] TUserID null'
	EXEC sp_executesql N'UPDATE [MsProject] SET [ModifiedBy] = 1'
	EXEC sp_executesql N'ALTER TABLE [MsProject] ALTER COLUMN [ModifiedBy] TUserID not null'
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'GroupCalculationLines' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [GroupCalculationLines] TBool not null default 0
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'EqualEmployeeFileAs' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Assignment')
	ALTER TABLE [Assignment] ADD [EqualEmployeeFileAs] TBool not null default 0
GO

DECLARE
	@value TVariant,
	@GroupCalculationLines bit
EXEC adfParameterGet @Name='GroupCalculationLines', @Group='Pjm5', @Value = @value OUTPUT
SET @GroupCalculationLines = ISNULL(CAST(@value as bit), 0)
EXEC adfParameterSet 'GroupCalculationLines', 'Pjm5', @GroupCalculationLines
GO

DECLARE
	@value TVariant,
	@ShowActivityTypes bit
EXEC adfParameterGet @Name='ShowActivityTypes', @Group='Pjm5', @Value = @value OUTPUT
SET @ShowActivityTypes = ISNULL(CAST(@value as bit), 0)
EXEC adfParameterSet 'ShowActivityTypes', 'Pjm5', @ShowActivityTypes
GO

DECLARE
	@value TVariant,
	@ShowPrice bit
EXEC adfParameterGet @Name='ShowPrice', @Group='Pjm5', @Value = @value OUTPUT
SET @ShowPrice = ISNULL(CAST(@value as bit), 0)
EXEC adfParameterSet 'ShowPrice', 'Pjm5', @ShowPrice
GO


IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'CheckTaskWorkOverdraft' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [CheckTaskWorkOverdraft] TBool not null default 0
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ContractComments' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ContractComments] TNotes null
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'ActivityTypeDefaults') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: ActivityTypeDefaults                                  */
	/*==============================================================*/
	create table ActivityTypeDefaults (
	   ActivityTypeID       TIdentifier          not null,
	   LanguageCode         TCode                not null,
	   Subject              TName                null,
	   Comments             TNotes               null,
	   constraint ActivityTypeDefaultsPK primary key  (ActivityTypeID, LanguageCode)
	)
go

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'ExpenseCodeDefaults') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: ExpenseCodeDefaults                                   */
	/*==============================================================*/
	create table ExpenseCodeDefaults (
	   ExpenseCodeID        TIdentifier          not null,
	   LanguageCode         TCode                not null,
	   Subject              TName                null,
	   Comments             TNotes               null,
	   constraint ExpenseCodeDefaultsPK primary key  (ExpenseCodeID, LanguageCode)
	)
go

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'LanguageCode') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: LanguageCode                                          */
	/*==============================================================*/
	create table LanguageCode (
	   Class                TClass               not null,
	   ID                   TIdentifier          identity,
	   State                TState               not null,
	   Flag                 TFlag                not null,
	   Code                 TCode                not null,
	   FileAs               TName                not null,
	   Comments             TNotes               null,
	   Created              TSysDateTime         not null default GETDATE(),
	   CreatedBy            TUserID              not null,
	   Modified             TSysDateTime         not null default GETDATE(),
	   ModifiedBy           TUserID              not null,
	   Timestamp            timestamp            not null,
	   constraint LanguageCodePK primary key  (Code)
	)
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ProjectLanguageCode' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ProjectLanguageCode] TCode null
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ShowActivityTypes' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ShowActivityTypes] TBool not null default 0
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ShowPrice' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ShowPrice] TBool not null default 0
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'BankAccountID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [BankAccountID] TIdentifier null
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ExchangeSystemName' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD  [ExchangeSystemName] TName null
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'GroupingAdvanceCalculations' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [GroupingAdvanceCalculations] TCount not null default 0
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'StatementCurrencyPoint' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [StatementCurrencyPoint] TIdentifier not null default 0
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'IsConsignor' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [IsConsignor] TBool not null default 0
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ConsignorID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ConsignorID] TIdentifier null
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ConsignorClass' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ConsignorClass] TClass null
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ConsignorContract' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [ConsignorContract] TName null
go

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountTypeByTime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountTypeByTime] TIdentifier not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountViewByTime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountViewByTime] TBool not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountByTime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountByTime] TMoney not null default 0
GO
IF EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountPercentByTime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'DiscountPercentByTime' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='ProjectDetail'
	SET @sql = N'ALTER TABLE [ProjectDetail] DROP CONSTRAINT ' + @name
	EXEC (@sql)	
	
	ALTER TABLE [ProjectDetail] DROP COLUMN [DiscountPercentByTime]
END
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountTypeByExpense' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountTypeByExpense] TIdentifier not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountViewByExpense' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountViewByExpense] TBool not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountByExpense' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountByExpense] TMoney not null default 0
GO
IF EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountPercentByExpense' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'DiscountPercentByExpense' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='ProjectDetail'
	SET @sql = N'ALTER TABLE [ProjectDetail] DROP CONSTRAINT ' + @name
	EXEC (@sql)

	ALTER TABLE [ProjectDetail] DROP COLUMN [DiscountPercentByExpense]
END
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountTypeByPhone' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountTypeByPhone] TIdentifier not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountViewByPhone' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountViewByPhone] TBool not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountByPhone' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountByPhone] TMoney not null default 0
GO
IF EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountPercentByPhone' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'DiscountPercentByPhone' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='ProjectDetail'
	SET @sql = N'ALTER TABLE [ProjectDetail] DROP CONSTRAINT ' + @name
	EXEC (@sql)
	
	ALTER TABLE [ProjectDetail] DROP COLUMN [DiscountPercentByPhone]
END
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountTypeByServiceRequest' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountTypeByServiceRequest] TIdentifier not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountViewByServiceRequest' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
	ALTER TABLE [ProjectDetail] ADD [DiscountViewByServiceRequest] TBool not null default 0
GO
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountByServiceRequest' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
BEGIN
	ALTER TABLE [ProjectDetail] ADD [DiscountByServiceRequest] TMoney not null default 0
	
	DECLARE @value TVariant,
			@GroupingAdvanceCalculations TCount,
			@ShowActivityTypes TBool,
			@GroupCalculationLines TBool

	EXEC adfParameterGet @Name='GroupingAdvanceCalculations', @Group='Pjm6', @Value = @value OUTPUT
	SET @GroupingAdvanceCalculations = ISNULL(CAST(@value as int), 0)

	EXEC adfParameterGet @Name='ShowActivityTypes', @Group='Pjm5', @Value = @value OUTPUT
	SET @ShowActivityTypes = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='GroupCalculationLines', @Group='Pjm5', @Value = @value OUTPUT
	SET @GroupCalculationLines = ISNULL(CAST(@value as bit), 0)

	UPDATE
		[Project]
	SET
		[GroupingAdvanceCalculations] = @GroupingAdvanceCalculations,
		[ShowActivityTypes] = @ShowActivityTypes,
		[GroupCalculationLines] = @GroupCalculationLines
	WHERE
		[State] = 5
END
GO
IF EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'DiscountPercentByServiceRequest' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectDetail')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'DiscountPercentByServiceRequest' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND OBJECT_NAME(sys.columns.object_id)='ProjectDetail'
	SET @sql = N'ALTER TABLE [ProjectDetail] DROP CONSTRAINT ' + @name
	EXEC (@sql)
	
	ALTER TABLE [ProjectDetail] DROP COLUMN [DiscountPercentByServiceRequest]
END
GO

IF NOT EXISTS (SELECT * FROM [F41AB0F8-FDF0-4FAD-9B71-8F17B4A51B53] WHERE [Group] = 'Pjm6' AND [Name]='UseSubProjects')
BEGIN
	DECLARE @value bit
	--IF EXISTS(SELECT * FROM [Task] WHERE [SubprojectID] IS NOT NULL)
		--SET @value = 1
	--ELSE
	SET @value = 0
	EXEC adfParameterSet 'UseSubProjects', 'Pjm6', @value
END
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'UseSubProjects' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [UseSubProjects] TBool not null default 0
GO

--  " "  ,   
UPDATE
	[Project]
SET
	[UseSubProjects] = 1
WHERE
	[Project].[ID] IN (SELECT DISTINCT [ProjectID] FROM [Task] WHERE [SubprojectID] IS NOT NULL)
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'NumerationCode' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [NumerationCode] TCode NULL
GO
