IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm6GetAvailableProjectsForProjectSelectorDialog]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm6GetAvailableProjectsForProjectSelectorDialog'
		DROP FUNCTION [dbo].[fnPjm6GetAvailableProjectsForProjectSelectorDialog]
	END

GO

PRINT 'Creating function fnPjm6GetAvailableProjectsForProjectSelectorDialog'
GO
/******************************************************************************
**		File:	fnPjm6GetAvailableProjectsForProjectSelectorDialog.sql
**		Name: 	fnPjm6GetAvailableProjectsForProjectSelectorDialog
**		Desc:	         
**				(, , , ) 
**			
**
**
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	24.03.09	ENB			 
**
**		27.03.09	ENB			     
**								 ,     
**								view,      .
**	
*******************************************************************************/
CREATE FUNCTION fnPjm6GetAvailableProjectsForProjectSelectorDialog (
	@EmployeeID TIdentifier,
	@OnlyActive bit,
	@ContractOnly bit,
	@OnlyProjectMember bit,
	@ProjectState int = 2,
	@ProjectSelector bit = 0,
	@SupportsRequestManagement bit
)
RETURNS @Projects TABLE ([ID] INT PRIMARY KEY)
AS 
BEGIN

	DECLARE @CurrentEmployeeID 	TIdentifier, 
		@UserID 		TIdentifier

	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @UserID = dbo.adfGetCurrentUserID()

	IF @EmployeeID IS NULL OR @EmployeeID <= 0
		SET @EmployeeID = @CurrentEmployeeID

	DECLARE
		@ViewAllProjects TBool,
		@Assistant		 TBool,
		@ExpenseSecretary TBool

	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) 
	SET @Assistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	SET @ExpenseSecretary = dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment')

--	   
	INSERT INTO @Projects ([ID])
	SELECT [Project].[ID]
	FROM   [Project]
	WHERE
		(
			[Project].[State] = 2 OR (@OnlyActive = 0 AND [Project].[State] = 4)
		) 
		AND
		(
			(@ExpenseSecretary = 1)
			OR
			(@ViewAllProjects = 1 AND @Assistant = 1)
			OR
			(@OnlyProjectMember = 0 AND 
				([Project].[ProjectManagerEmployeeID] = @EmployeeID
				    OR
				 ([Project].[ID] IN (
					SELECT
						[Assignment].[ProjectID]
					FROM
						[Assignment] 
					WHERE 	
						[Assignment].[ID] IN (
							SELECT [AssignmentEntry].[AssignmentID]
							FROM   [AssignmentEntry]
							WHERE  
								[AssignmentEntry].[EmployeeID] = @EmployeeID 
						) AND
					   ([Assignment].[State] = 1)
					)
				))
			)
			OR
			(@OnlyProjectMember = 1 
			 AND 
			 ([Project].[ID] IN (
				SELECT
					[Assignment].[ProjectID]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN (
						SELECT [AssignmentEntry].[AssignmentID]
						FROM   [AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @EmployeeID 
					) AND
				   ([Assignment].[State] = 1)
				)
			 )
			)
		) 
		AND
		(
			@ContractOnly = 0 OR [Project].[ProjectTypeID] = 1
		) 
		AND
		(
			@ProjectState = 2 
			OR
			(@ProjectState = 1 
			  AND 
			 ([Project].[ID] IN (
				SELECT [vas].[ProjectID]
				FROM	vwAssignment AS vas
				WHERE	[vas].[EmployeeID] = @EmployeeID 
				AND     [vas].[State] = 1)
			 )
			)	 
			OR
			@ProjectState = 3 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
		) 
		AND
		(
			@ProjectSelector = 0 
			OR
			(@SupportsRequestManagement = 0 AND 
				EXISTS (SELECT * FROM [CalendarProject] WHERE [UserID] = @UserID AND [ProjectID] = [Project].[ID])
			)
			OR
			(@SupportsRequestManagement = 1 AND 
				EXISTS (SELECT * FROM [IssueProject] WHERE [UserID] = @UserID AND [ProjectID] = [Project].[ID])
			)
		)
		AND
		(
			@SupportsRequestManagement = 0
			OR
			(@SupportsRequestManagement = 1 AND [SupportsRequestManagement] = 1)
		)

	RETURN

END
	
GO
