IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetTimeDurationSum]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetTimeDurationSum'
		DROP FUNCTION [dbo].[fnReportGetTimeDurationSum]
	END
GO

PRINT 'Creating function fnReportGetTimeDurationSum'
GO

/******************************************************************************
**		File: fnReportGetTimeDurationSum.sql
**		Name: fnReportGetTimeDurationSum
**
**              
**		Return values: 
**		     
**		Called by:   
**              
**		Parameters:
**		Input								Output
**      ----------							-----------
**		  
**		  
**		XML    
**		
**		Auth: MAN
**		Date: 23/08/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		23.08.2010	MAN				First Version
*******************************************************************************/
CREATE FUNCTION dbo.fnReportGetTimeDurationSum 
(
	@PeriodStart	TDateTime, 
	@PeriodEnd		TDateTime,
	@ProjectXML		XML
)
RETURNS @ResultTimeDurationSum TABLE 
(
	ProjectID		Tidentifier,
	TimeMarked		TAmount,	--  
	TimeBillable	TAmount,	--   
	TimeSold		TAmount		--   
)
AS
BEGIN
	INSERT INTO	@ResultTimeDurationSum
	(
		[ProjectID],
		[TimeMarked],
		[TimeBillable],
		[TimeSold]
	)
	SELECT  
		[vwTimeEntry].[ProjectID] AS [ProjectID],
		SUM(
			CASE 
				WHEN [State] IN (1, 2, 3, 5, 6)  --   4 ()
					THEN [vwTimeEntry].[RoundedDuration] / 60.0
				ELSE 0 
			END
			) AS [TimeMarked], -- 
		SUM(
			CASE 
				WHEN [State] IN (3, 6) AND [Billable] = 1 -- ,     
					THEN [vwTimeEntry].[RoundedDuration] / 60.0
				ELSE 0 
			END
			) AS [TimeBillable], --  
		SUM(
			CASE 
				WHEN [State] in ( 6 ) --  (   . )
					THEN [vwTimeEntry].[BillableDuration] / 60.0
				ELSE 0 
			END
			) AS [TimeSold]  --  
	FROM 
		[vwTimeEntry]
	WHERE 
		[vwTimeEntry].[ProjectID] IN 
		(
			SELECT
				Projects.value('@ProjectID','TIdentifier') AS [ProjectID]
			FROM
				@ProjectXML.nodes('/row') AS Projects(Projects)
		)
		AND
		[vwTimeEntry].[StartTime] >= @PeriodStart
		AND
		[vwTimeEntry].[StartTime] < @PeriodEnd
	GROUP BY 
		[vwTimeEntry].[ProjectID]
RETURN
END
GO