IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6CheckAssignmentsAdd]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6CheckAssignmentsAdd'
		DROP PROCEDURE [dbo].[pjm6CheckAssignmentsAdd]
	END
GO

PRINT 'Creating procedure pjm6CheckAssignmentsAdd'
GO

/******************************************************************************
**		File: pjm6CheckAssignmentsAdd.sql
**		Name: pjm6CheckAssignmentsAdd
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Yuriy.Soldatkin
**		Date: 11/3/2009
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    15.04.10		SYV				 ,    
*******************************************************************************/
CREATE PROCEDURE [pjm6CheckAssignmentsAdd]
	@Xml XML,
	@ProjectID TIdentifier
AS
SET NOCOUNT ON
	DECLARE @State TState,			
			@IsMember TBool,
			@IsAssistant TBool,
			@IsAssignmentEditor TBool,
			@MsProjectID TIdentifier,
			@IsLocalError TBool,
			@doc INT,
			@FileAs TName
	
	DECLARE @for_append TABLE ([ID] INT null, [Description] nvarchar(256) null, [FileAs] varchar(32) null)
	
	SET @State = dbo.adfwfGetInitialState('7797bd53-86ce-415e-9e13-b11bcbd52359')
	IF @State IS NULL
	BEGIN
		INSERT INTO @for_append VALUES(NULL, 'accessdenied_all', NULL)
		SELECT * FROM @for_append
		RETURN 1
	END
	
	SELECT @MsProjectID = [MsProjectID] FROM [Project] WHERE [ID] = @ProjectID
	IF @MsProjectID IS NOT NULL
	BEGIN
		INSERT INTO @for_append VALUES(NULL, 'documentfrommsproject', NULL)
		SELECT * FROM @for_append
		RETURN 1
	END


	DECLARE @CurrentEmployeeID int, 
			@ProjectState TState,
			@IsPM TBool

	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()

	IF dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID) = 0
	BEGIN
		SET @IsPM = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProjectTemplates'))
		SELECT @ProjectState = [State] FROM [Project] WHERE [ID] = @ProjectID
		
		SET @IsMember = dbo.fnPjm5IsProjectMember(@ProjectID, @CurrentEmployeeID)
		SET @IsAssistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
		SET @IsAssignmentEditor = (@IsAssistant | @IsMember) & dbo.adfHasAccessRight(dbo.adfGetRightID('EditAssignment'))
		IF (NOT (
			(@ProjectState IN (5, 6) AND @IsPM = 1) OR
			(@ProjectState NOT IN (5, 6) AND @IsAssignmentEditor = 1)
			))
		BEGIN
			INSERT INTO @for_append VALUES(NULL, 'accessdenied_all', NULL)
			SELECT * FROM @for_append
			RETURN 1
		END
	END

	IF EXISTS (SELECT * FROM [ProjectTemplate] WHERE [ID] = @ProjectID)
	BEGIN
		SET @State = 3
	END

	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml

	DECLARE @AddEmployeeID TIdentifier
	DECLARE For_Add CURSOR LOCAL FAST_FORWARD FOR 
		SELECT 
			[ID] 
		FROM
		OPENXML(@doc, '/Employee/Assignments', 2)
			WITH (
				[ID] int
				)
	OPEN For_Add
	FETCH NEXT FROM For_Add INTO @AddEmployeeID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @IsLocalError = 0
		SELECT
			@FileAs = [FileAs]
		FROM
			[Employee]
		WHERE
			[ID] = @AddEmployeeID	

		IF @AddEmployeeID IS NOT NULL AND
			EXISTS (
			SELECT 
				*
			FROM
				[vwAssignment] AS [Assignment]
			WHERE
				[Assignment].[ProjectID]  = @ProjectID AND
				[Assignment].[EmployeeID]  = @AddEmployeeID AND
				[Assignment].[State] = @State
			) 
		BEGIN
			INSERT INTO @for_append VALUES(@AddEmployeeID, 'AssignmentAlreadyExist', @FileAs) 
			SET @IsLocalError = 1
		END

		IF @AddEmployeeID IS NOT NULL AND
			EXISTS (
			SELECT 
				*
			FROM
				[Employee]
			WHERE
				[ID]  = @AddEmployeeID AND
				[State] = 2
			) 
		BEGIN
			INSERT INTO @for_append VALUES(@AddEmployeeID, 'EmployeeFire', @FileAs)
			SET @IsLocalError = 1
		END

		IF @IsLocalError = 0
		BEGIN
			INSERT INTO @for_append VALUES(@AddEmployeeID, NULL, NULL)
		END
		FETCH NEXT FROM For_Add INTO @AddEmployeeID
	END
	CLOSE For_Add
	DEALLOCATE For_Add
	EXEC sp_xml_removedocument @doc
	
	SELECT * FROM @for_append
	RETURN 0

GO

GRANT EXECUTE ON [pjm6CheckAssignmentsAdd] TO PUBLIC
GO
