IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5CalculationCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5CalculationCreate'
		DROP PROCEDURE [dbo].[pjm5CalculationCreate]
	END
GO

PRINT 'Creating procedure pjm5CalculationCreate'
GO

/******************************************************************************
**		File: pjm5CalculationCreate.sql
**		Name: pjm5CalculationCreate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 05/03/2005 11:14:48
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		30.03.11	SYV				  RatesWithVAT   
**		18.04.11	SYV				    
**		18.06.13	SOV				      
**									    
*******************************************************************************/
CREATE PROCEDURE [pjm5CalculationCreate]
	@Xml XML
AS
	DECLARE 	
			@Date TDate,
			@Number TCode,
			@FileAs TName,
			@ProjectID TIdentifier,
			@DocumentClass TClass,
			@PeriodStart TDate,
			@PeriodEnd TDate,
			@ServiceTypeID TIdentifier,
			@Description TNotes,
			@Comments TNotes,
			@State TState,
			@ID TIdentifier,
			@CurrencyCode TCode,
			@VATRate TPercent,
			@ProjectType TIdentifier,
			@doc int,
			@Scale TCount,
			@RatesWithVAT TBool,
			@Discount TAmount,
			@DiscountPC TAmount,
			@DiscountPercent TPercent,
			@DiscountView TBool,
			@DiscountType TIdentifier,
			@timeClass TClass

	SET NOCOUNT ON

	SET @State = dbo.adfwfGetInitialState('72390edf-0691-4bca-8972-77424b455803')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml
	SELECT
		@Date = CAST([XmlTable].[Date] AS datetime),
		@Number = [XmlTable].[Number],
		@FileAs = [XmlTable].[FileAs],
		@ProjectID = [XmlTable].[ProjectID],
		@DocumentClass = [XmlTable].[DocumentClass],
		@PeriodStart = CAST([XmlTable].[PeriodStart] AS datetime),
		@PeriodEnd = CAST([XmlTable].[PeriodEnd] AS datetime),
		@ServiceTypeID = [XmlTable].[ServiceTypeID],
		@CurrencyCode = [XmlTable].[CurrencyCode],
		@Description = [XmlTable].[Description],
		@Comments = [XmlTable].[Comments],
		@ProjectType = [Project].[ProjectTypeID],
		@Scale = [Project].[Scale],
		@Discount = [Discount],
		@DiscountPC = [DiscountPC],
		@DiscountPercent = [DiscountPercent],
		@DiscountView = [DiscountView],
		@DiscountType = [DiscountType]
	FROM
		OPENXML(@doc, '/pjm5CalculationGet/Calculation', 2)
			WITH (
				[Date] nvarchar(19),
				[Number] varchar(32),
				[FileAs] nvarchar(512),
				[ProjectID] int,
				[DocumentClass] int,
				[PeriodStart] nvarchar(19),
				[PeriodEnd] nvarchar(19),
				[ServiceTypeID] int,
				[CurrencyCode] varchar(32),
				[Description] nvarchar(max),
				[Comments] nvarchar(max),
				[Discount] decimal(18,4),
				[DiscountPC] decimal(18,4),
				[DiscountPercent] decimal(18,4),
				[DiscountView] bit,
				[DiscountType] int
				) AS [XmlTable]
		INNER JOIN [Project]
			ON [Project].[ID] = [XmlTable].[ProjectID]
	EXEC sp_xml_removedocument @doc
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllCalculations')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	IF @ProjectType NOT IN (1, 2)
	BEGIN
		RAISERROR('#wrongprojecttype', 18, -1)
		RETURN 1
	END
	
	DECLARE @ApplyVAT TBool
	SET @VATRate = 0
	
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')

	SELECT 
		@ApplyVAT = [ApplyVAT],
		@RatesWithVAT = CASE WHEN @DocumentClass = @timeClass THEN [RatesWithVAT] ELSE 0 END
	FROM
		[Project] 
	WHERE 
		[Project].[ID] = @ProjectID

	IF @ApplyVAT = 1
	BEGIN
		SET @VATRate = dbo.fnPjm5GetVATRate()
	END

	--      
	DECLARE @Cost TMoney,
			@CostPC TMoney,
			@Total TMoney,
			@TotalWithVAT TMoney,
			@TotalPC TMoney,
			@TotalWithVATPC TMoney

	SET @Cost = 0
	SET @CostPC = 0

	SET @Cost = dbo.fnPjm6GetCalculationTotal(@DiscountType, @DiscountView, @DiscountPercent, @Discount, @Cost)
	SET @CostPC = dbo.fnPjm6GetCalculationTotal(@DiscountType, @DiscountView, @DiscountPercent, @DiscountPC, @CostPC)

	SET @Total = (1 - @RatesWithVAT) * @Cost + @RatesWithVAT * @Cost / (1 + @VATRate)
	SET @TotalWithVAT = @RatesWithVAT * @Cost + (1 - @RatesWithVAT) * @Cost * (1 + @VATRate)
	SET @TotalPC = (1 - @RatesWithVAT) * @CostPC + @RatesWithVAT * @CostPC / (1 + @VATRate)
	SET @TotalWithVATPC = @RatesWithVAT * @CostPC + (1 - @RatesWithVAT) * @CostPC * (1 + @VATRate)

	BEGIN TRANSACTION
	INSERT INTO [Calculation]
		([Flag], [State], [Date], [Number], [FileAs], [ProjectID], [DocumentClass], [CurrencyCode], [PeriodStart], [PeriodEnd], [ServiceTypeID],
		[VATRate], [Comments],
		[TotalPC], [TotalWithVATPC], [Description],
		[Scale], [RatesWithVAT], [Discount], [DiscountPC], [DiscountPercent], [DiscountView], [DiscountType],
		[Total], [TotalWithVAT])
	VALUES
		(0, @State, @Date, @Number, @FileAs, @ProjectID, @DocumentClass, @CurrencyCode, @PeriodStart, @PeriodEnd, @ServiceTypeID,
		@VATRate, @Comments,
		@TotalPC, @TotalWithVATPC, @Description,
		@Scale, @RatesWithVAT, @Discount, @DiscountPC, @DiscountPercent, @DiscountView, @DiscountType,
		@Total, @TotalWithVAT)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()
	COMMIT TRANSACTION
	EXEC pjm5CalculationGet @ID

	RETURN 0
GO

GRANT EXECUTE ON pjm5CalculationCreate TO PUBLIC
GO
