IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6CalculationMarkUp]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6CalculationMarkUp'
		DROP PROCEDURE [dbo].[pjm6CalculationMarkUp]
	END
GO

PRINT 'Creating procedure pjm6CalculationMarkUp'
GO

/******************************************************************************
**		File: pjm6CalculationMarkUp.sql
**		Name: pjm6CalculationMarkUp
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 05/03/2005 11:14:48
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		30.03.11	SYV				    "  "   
*******************************************************************************/
CREATE PROCEDURE pjm6CalculationMarkUp
	@ID TIdentifier,
	@EmployeeID TIdentifier,
	@Value TMoney
AS
	SET NOCOUNT ON
	DECLARE 
		@ProjectID TIdentifier,
		@RoundInterval TCount,
		@VATRate TPercent
		
	IF ISNULL((SELECT [State] FROM [Calculation] WHERE [ID] = @ID), 0) = 3
	BEGIN
		RAISERROR('#TransitionTemplateCouldNotBeFound', 18, -1)
		RETURN 1
	END

	SELECT
		@ProjectID = [Project].[ID],
		@RoundInterval = [Project].[RoundingInterval],
		@VATRate = [Calculation].[VATRate]
	FROM
		[Project]
		INNER JOIN [Calculation]
			ON [Calculation].[ProjectID] = [Project].[ID]
	WHERE
		[Calculation].[ID] = @ID
		
	DECLARE @update_table TABLE ([ID] int, [Amount] decimal(18, 4), [VAT] money)
	DECLARE
		@changed TBool,
		@count TCount
	SET @count = 0	
	SET @changed = 1
	
	DECLARE lines CURSOR LOCAL FAST_FORWARD FOR
		SELECT
			[CalculationLine].[ID],
			[CalculationLine].[Amount],
			[CalculationLine].[Price]
		FROM
			[CalculationLine]
			INNER JOIN [TimeEntry]
				ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND
					[TimeEntry].[ID] = [CalculationLine].[DocumentID]
		WHERE
			[CalculationLine].[CalculationID] = @ID AND
			(
				@EmployeeID IS NULL OR
				[TimeEntry].[EmployeeID] = @EmployeeID
			) AND
			[CalculationLine].[Price] <> 0
		ORDER BY
			[CalculationLine].[Amount] DESC

	WHILE @changed = 1 AND @count < 7
	BEGIN
		DECLARE
			@PrevAmount TMoney,
			@PrevValue TMoney,
			@DiffValue TMoney,
			@Sign int

		SET @changed = 0
		SET @count = @count + 1
		DELETE FROM @update_table
		
		SELECT
			@PrevAmount = SUM([CalculationLine].[Amount]),
			@PrevValue = SUM([CalculationLine].[Amount] * [CalculationLine].[Price])
		FROM
			[Calculation]
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID] = [Calculation].[ID]
			INNER JOIN [TimeEntry]
				ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND
					[TimeEntry].[ID] = [CalculationLine].[DocumentID]
		WHERE
			[Calculation].[ID] = @ID AND
			(
				@EmployeeID IS NULL OR
				[TimeEntry].[EmployeeID] = @EmployeeID
			)
		GROUP BY
			[Calculation].[TotalWithVAT]

		SET @DiffValue = ABS(@PrevValue - @Value)
		SET @Sign = 1
		IF @PrevValue > @Value
			SET @Sign = -1

		DECLARE 
			@CalculationLineID TIdentifier,
			@Amount TAmount,
			@Price TMoney
			
		DECLARE
			@prev_line TMoney,
			@proc TAmount,
			@delta_money TMoney,
			@delta TCount,
			@delta_amount TAmount,
			@delta_vat TMoney
			
		OPEN lines
		FETCH NEXT FROM lines INTO 
			@CalculationLineID,
			@Amount,
			@Price
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @delta_amount = 0
			SET @prev_line = (@Amount * @Price)
			SET @proc = @prev_line / @PrevValue
			SET @delta_money = @proc * @DiffValue
				
			SET @delta = 60 * @delta_money / @Price
			SET @delta = dbo.fnPjm5RoundedDuration(@delta, @RoundInterval, 3)
			IF @delta > 0
			BEGIN
				SET @delta_amount = @Amount + @Sign * @delta / 60.0
				IF @delta_amount <= 0
					SET @delta_amount = @RoundInterval / 60.0
				IF @delta_amount <= 0
					SET @delta_amount = 1 / 60.0
			END
			IF @delta_amount > 0 AND @delta_amount != @Amount
			BEGIN
				SET @delta_vat = @VATRate * ROUND(@delta_amount, 2) * @Price
				INSERT INTO @update_table ([ID], [Amount], [VAT]) VALUES (@CalculationLineID, ROUND(@delta_amount, 2), ROUND(@delta_vat, 2))
				SET @changed = 1
			END
			
			FETCH NEXT FROM lines INTO
				@CalculationLineID,
				@Amount,
				@Price
		END
		CLOSE lines

		UPDATE
			[CalculationLine]
		SET
			[Amount] = T.[Amount],
			[VAT] = T.[VAT]
		FROM
			[CalculationLine]
			INNER JOIN @update_table T
				ON T.[ID] = [CalculationLine].[ID]
		IF @@error != 0
		BEGIN
			DEALLOCATE lines
			RETURN 1
		END
	END
	DEALLOCATE lines

	SELECT [TotalWithVAT] FROM [Calculation] WHERE [ID] = @ID
	RETURN 0
GO

GRANT EXECUTE ON pjm6CalculationMarkUp TO PUBLIC
GO

