IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ExportFacture')
	BEGIN
		PRINT 'Dropping Procedure ExportFacture'
		DROP  Procedure  ExportFacture
	END

GO

PRINT 'Creating Procedure ExportFacture'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
**-------------------------------------------------------------------------------------
**	DATE		Author		Comments
**  ---------   ----------  -----------------------------------------------------------
**	31.05.10	SPV			 
	31.08.11    SAM                
--------------------------------------------------------------------------------------*/
CREATE Procedure ExportFacture
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE
		@FactureClass TClass,
		@InvoiceClass TClass,
		@StatementClass TClass,
		@Value TVariant,
		@NationalCurrencyCode TCode3,
		@val TVariant,
		@State TState,
		@EmployeeClass TClass,
		@CompanyClass TClass

	IF EXISTS (
		SELECT
			[Facture].[ID]
		FROM
			[Facture]
			INNER JOIN [Project]
				ON [Project].[ID] = [Facture].[ProjectID]
		WHERE
			[Facture].[ID] = @ID AND
			[Project].[ContractDate] IS NULL AND
			[Project].[ContractNumber] IS NULL AND
			[Project].[ExchangeSystemName] IS NULL	)	
	BEGIN
		RAISERROR('#emptycontractfields', 18, -1)
		RETURN 1
	END

	
	IF EXISTS (
		SELECT
			[Facture].[ID]
		FROM
			[Facture]
			LEFT OUTER JOIN [FacturePayment]
				ON [Facture].[Advance] = 1 AND [FacturePayment].[FactureID] = [Facture].[ID]
		WHERE
			[Facture].[Advance] = 1 AND [Facture].[ID] = @ID
		GROUP BY
			[Facture].[ID]
		HAVING
			COUNT([FacturePayment].[FactureID]) <> 1 )
	BEGIN
		RAISERROR('#facturehasnotonepayment', 18, -1)
		RETURN 1
	END

		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))
	
	SET @FactureClass = dbo.adfGetClassByName('Pjm5.Facture')
	SET @InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
	SET @StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	
	SELECT @State = [State] FROM [Facture] WHERE [ID] = @ID
	
	IF @State = 3
	BEGIN
		exec pjm6ExportAnnualDocument @FactureClass, @ID
		RETURN
	END

	
	
	DECLARE @FactureStatement TABLE
	(
		[FactureID] TIdentifier,
		[StatementID] TIdentifier
	)
	--
	INSERT INTO @FactureStatement
	SELECT 
		[Facture].[ID] AS [FactureID],
		[Statement].[ID] AS [StatementID]
	FROM
		[Statement]
		INNER JOIN [Attachment]
			ON [Statement].[Class] = [Attachment].[DocumentClass]
				AND [Statement].[ID] = [Attachment].[DocumentID]
		INNER JOIN [Facture]
			ON [Facture].[Class] = [Attachment].[LinkDocumentClass]
				AND [Facture].[ID] = [Attachment].[LinkDocumentID]
	WHERE
		[Facture].[ID] = @ID
	UNION
	SELECT 
		[Facture].[ID] AS [FactureID],
		[Statement].[ID] AS [StatementID]
	FROM
		[Facture]
		INNER JOIN [Attachment]
			ON [Facture].[Class] = [Attachment].[DocumentClass]
				AND [Facture].[ID] = [Attachment].[DocumentID]
		INNER JOIN [Statement]
			ON [Statement].[Class] = [Attachment].[LinkDocumentClass]
				AND [Statement].[ID] = [Attachment].[LinkDocumentID]
	WHERE
		[Facture].[ID] = @ID
		
	DECLARE @Invoices TABLE
	(
		[InvoiceID] TIdentifier,
		[FactureID] TIdentifier
	)
	
	INSERT INTO @Invoices ([InvoiceID], [FactureID])
	SELECT 
		[Attachment].[LinkDocumentID],
		[Attachment].[DocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[DocumentClass] = @FactureClass AND
		[Attachment].[DocumentID] = @ID AND
		[Attachment].[LinkDocumentClass] = @InvoiceClass AND
		[Attachment].[LinkDocumentID] NOT IN (SELECT [InvoiceID] FROM @Invoices)
	UNION
	SELECT 
		[Attachment].[DocumentID],
		[Attachment].[LinkDocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[LinkDocumentClass] = @FactureClass AND
		[Attachment].[LinkDocumentID] = @ID AND
		[Attachment].[DocumentClass] = @InvoiceClass AND
		[Attachment].[DocumentID] NOT IN (SELECT [InvoiceID] FROM @Invoices)
		
	INSERT INTO @FactureStatement
	SELECT 
		[Invoices].[FactureID],
		[Attachment].[LinkDocumentID]
	FROM
		[Attachment]
		INNER JOIN @Invoices [Invoices]
			ON	[Invoices].[InvoiceID] = [Attachment].[DocumentID] AND
				[Attachment].[DocumentClass] = @InvoiceClass AND
				[Attachment].[LinkDocumentClass] = @StatementClass
	WHERE
		[Invoices].[FactureID] NOT IN (SELECT [FactureID] FROM @FactureStatement)
	UNION
	SELECT 
		[Invoices].[FactureID],
		[Attachment].[DocumentID]
	FROM
		[Attachment]
		INNER JOIN @Invoices [Invoices]
			ON	[Invoices].[InvoiceID] = [Attachment].[LinkDocumentID] AND
				[Attachment].[LinkDocumentClass] = @InvoiceClass AND
				[Attachment].[DocumentClass] = @StatementClass
	WHERE
		[Invoices].[FactureID] NOT IN (SELECT [FactureID] FROM @FactureStatement)
		----
		SELECT
			GETDATE() as 'Period/@StartDate',
			GETDATE() as 'Period/@EndDate',
			0 as 'Period/@PeriodType',
			(
				SELECT
					[Company].[ID] as '@SupplierID',
					[Company].[FileAs] as '@Name',
					'' as '@SupplierType',
					[Company].[LegalName] as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country]) as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostalAddress',
					[BasicPhone].[Phone] as '@BasePhone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode] as '@LegalCode',
					[Company].[KPP] as '@KPP',
				(
					SELECT
						[Facture].[ID] as '@ID',
						[Facture].[State] as '@State',
						[Facture].[Number] as '@Number',
						[Facture].[Date] as '@Date',
						ISNULL([Statement].[Number], '') as '@StatementNumber',
						ISNULL([Statement].[Date], '') as '@StatementDate',
						[Currency].[Code] as '@CurrencyCode',
						[Currency].[NumericCode] as '@CurrencyNumericCode',
						[Facture].[CurrencyRate] as '@CurrencyRate',
						dbo.pjm6fnCurrencyGetRate([Facture].[CurrencyCode], [Facture].[Date], @NationalCurrencyCode) as '@NationalCurrencyRate',
						[Facture].[Advance] as '@Advance',
						CASE [Project].[FactureCurrency]
							WHEN 0 THEN [Facture].[TotalPC]
								ELSE [Facture].[Total]
							END as '@Total',
						CASE [Project].[FactureCurrency]
							WHEN 0 THEN [Facture].[TotalWithVATPC]
								ELSE [Facture].[TotalWithVAT]
							END as '@TotalWithVAT',
						CASE [Project].[FactureCurrency]
							WHEN 0 THEN [Facture].[VATPC]
								ELSE [Facture].[VAT]
							END as '@VAT',
						[Facture].[Sender] as '@Consignor',
						[Facture].[Recipient] as '@Consignee',
						(SELECT TOP(1)[FactureLine].[VATRate] FROM [FactureLine] WHERE [FactureLine].[FactureID] = [Facture].[ID]) as '@VATRate',
						CASE WHEN (SELECT TOP(1) [FactureLine].[VATRate] FROM [FactureLine] WHERE [FactureLine].[FactureID] = [Facture].[ID]) > 0 THEN 1 ELSE 0 END as '@ApplyVAT',
						dbo.fnPjm6GetLastEditDate([Facture].[ID], [Facture].[Class]) as '@Modified',
						-----------contract
						(
						SELECT
							[Project].[ID] as '@ContractID',
							[Project].[ContractNumber] as '@ContractNumber',
							dbo.fnMask ([Project].[ExchangeSystemName], [Project].[ContractNumber],
							    [Project].[ContractDate]) as '@ExchangeSystemName',
							[Project].[ContractDate] as '@ContractDate',
							[Project].[ContractEndDate] as '@ContractEndDate',
							[Currency].[Code] as '@CurrencyCode',
							[Currency].[NumericCode] as '@CurrencyNumericCode',
							[CostCenter].[ID] as '@CostCenterID',
							[CostCenter].[Code] as '@CostCenterCode',
							[CostCenter].[FileAs] as '@CodeCenterFileAs',
							CASE
								WHEN [Project].[CurrencyCode] != @NationalCurrencyCode THEN
									CASE
										WHEN ISNULL([ContractBankAccount].[CurrencyCode], [DefaultBankAccount].[CurrencyCode]) != @NationalCurrencyCode THEN 'INT'
										ELSE 'UE'
									END
								ELSE
									'NAT'
							END as '@CurrencyContractType',
							[Project].[InvoiceExpirationPeriod] as '@InvoiceExpirationPeriod',
							[Project].[InvoiceExpirationPeriodType] as '@InvoiceExpirationPeriodType',
							[Project].[IsConsignor] as '@IsConsignor',
							[Project].[ConsignorID] as '@ConsignorID',
							CASE [Project].[ConsignorClass] WHEN @EmployeeClass THEN 'Employee' WHEN @CompanyClass THEN 'Company' ELSE 'None' END as '@ConsignorType',
							[BusinessCard].[FileAs] as '@Consignor',
							[Project].[ConsignorContract] as '@ConsignorContract'
						FROM
							[Project]
							LEFT OUTER JOIN [CostCenter]
								ON [Project].[CostCenterID] = [CostCenter].[ID]
							LEFT OUTER JOIN [Currency]
								ON [Currency].[Code] = [Project].[CurrencyCode]
							LEFT OUTER JOIN [Company]
								ON [Company].[ID] = [Project].[SupplierCompanyID]
							LEFT OUTER JOIN [BankAccount] [DefaultBankAccount]
								ON [DefaultBankAccount].[ID] = ISNULL([Company].[BankAccountID], -1)
							LEFT OUTER JOIN [BankAccount] [ContractBankAccount]
								ON [ContractBankAccount].[ID] = ISNULL([Project].[BankAccountID], -1)
							LEFT OUTER JOIN [BusinessCard]
								ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
						WHERE [Project].[ID] = [Facture].[ProjectID]
						FOR XML PATH('Contract'), TYPE
						),
						---------------Bank account
						(
						SELECT
							[BankAccount].[ID] as '@BankAccountID',
							[BankAccount].[Account] as '@BankAccount',
							[BankAccount].[BankName] as '@Bank',
							[BankAccount].[City] as '@CityBank',
							[BankAccount].[IntermediaryAccount] as '@IntermediaryAccount',
							[BankAccount].[BankCode] as '@BankCode',
							[Currency].[Code] as '@CurrencyCode',
							[Currency].[NumericCode] as '@CurrencyNumericCode'
						FROM
							[Company]
							INNER JOIN [BankAccount]
								ON [Company].[BankAccountID] = [BankAccount].[ID]
							INNER JOIN [Currency]
								ON [BankAccount].[CurrencyCode] = [Currency].[Code]
						WHERE
							[Facture].[SupplierCompanyID] = [Company].[ID]
						 FOR XML PATH('BankAccount'), TYPE
						),
						---------------Customer Bank account
						(
						SELECT
							[BankAccount].[ID] as '@BankAccountID',
							[BankAccount].[Account] as '@BankAccount',
							[BankAccount].[BankName] as '@Bank',
							[BankAccount].[City] as '@CityBank',
							[BankAccount].[IntermediaryAccount] as '@IntermediaryAccount',
							[BankAccount].[BankCode] as '@BankCode',
							[Currency].[Code] as '@CurrencyCode',
							[Currency].[NumericCode] as '@CurrencyNumericCode'
						FROM
							[Company]
							INNER JOIN [BankAccount]
								ON [Company].[BankAccountID] = [BankAccount].[ID]
							INNER JOIN [Currency]
								ON [BankAccount].[CurrencyCode] = [Currency].[Code]
						WHERE
							[Facture].[CustomerCompanyID] = [Company].[ID]
						 FOR XML PATH('ConsigneeBankAccount'), TYPE
						),
						-------------Customer
						(
							SELECT	
								[Company].[ID] as '@ID',
								[Company].[FileAs]  as '@Name',
								dbo.fnPjm6GetLegalFormType([Company].[LegalCode], ISNULL([LegalAddress].[Country], '')) as '@LegalFormType',
								[Company].[LegalName]  as '@LegalName',
								dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])  as '@LegalAddress',
								dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostAddress',
								[BasicPhone].[Phone] as '@Phone',
								[Fax].[Phone] as '@Fax',
								[Company].[LegalCode]  as '@LegalCode',
								[Company].[KPP] as '@KPP'
							FROM
								[Company]
								LEFT OUTER JOIN [Address] as [LegalAddress]
									ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
										[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
										[LegalAddress].[AddressTypeID] = 1
								LEFT OUTER JOIN [Address] as [PostalAddress]
									ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
										[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
										[PostalAddress].[AddressTypeID] = 5
								LEFT OUTER JOIN [Phone] as [BasicPhone]
									ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
										[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
										[BasicPhone].[PhoneTypeID] = 11
								LEFT OUTER JOIN [Phone] as [Fax]
									ON [Fax].[BusinessCardID] = [Company].[ID] AND 
										[Fax].[BusinessCardClass] = [Company].[Class] AND
										[Fax].[PhoneTypeID] = 8 
							WHERE [Company].[ID] = [Facture].[CustomerCompanyID]
							FOR XML PATH('Customer'), TYPE
						),
						-------------Consignee
						(
							SELECT	
								[Company].[ID] as '@ID',
								[Company].[FileAs]  as '@Name',
								dbo.fnPjm6GetLegalFormType([Company].[LegalCode], ISNULL([LegalAddress].[Country], '')) as '@LegalFormType',
								[Company].[LegalName]  as '@LegalName',
								dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])  as '@LegalAddress',
								dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostAddress',
								[BasicPhone].[Phone] as '@Phone',
								[Fax].[Phone] as '@Fax',
								[Company].[LegalCode]  as '@LegalCode',
								[Company].[KPP] as '@KPP'
							FROM
								[Company]
								LEFT OUTER JOIN [Address] as [LegalAddress]
									ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
										[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
										[LegalAddress].[AddressTypeID] = 1
								LEFT OUTER JOIN [Address] as [PostalAddress]
									ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
										[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
										[PostalAddress].[AddressTypeID] = 5
								LEFT OUTER JOIN [Phone] as [BasicPhone]
									ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
										[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
										[BasicPhone].[PhoneTypeID] = 11
								LEFT OUTER JOIN [Phone] as [Fax]
									ON [Fax].[BusinessCardID] = [Company].[ID] AND 
										[Fax].[BusinessCardClass] = [Company].[Class] AND
										[Fax].[PhoneTypeID] = 8 
							WHERE [Company].[ID] = [Facture].[CustomerCompanyID]
							FOR XML PATH('Consignee'), TYPE
						),
						------------Facture Lines
						(
							SELECT
								[FactureLine].[ID] as '@ID',
								[ServiceType].[ID] as '@ServiceTypeID',
								[ServiceType].[FileAs] as '@ServiceType',
								[ServiceType].[Code] as '@ServiceTypeCode',
								[Service].[ID] as '@ServiceID',
								[Service].[FileAs] as '@Service',
								[Service].[Code] as '@ServiceCode',
								[FactureLine].[Amount] as '@Amount',
								[FactureLine].[VATRate] as '@VATRate',
								[UOM].[FileAs] '@UOM',
								CASE 
								WHEN [FactureLine].[VATIsIncluded] = 1 AND [FactureLine].[Amount] != 0
									THEN ([FactureLine].[Price] * [FactureLine].[Amount] - [FactureLine].[VAT]) / [FactureLine].[Amount]
								ELSE [FactureLine].[Price] 
								END  as '@Price',
								[FactureLine].[Amount] * 	
									CASE 
										WHEN [FactureLine].[VATIsIncluded] = 1 AND [FactureLine].[Amount] != 0
											THEN ([FactureLine].[Price] * [FactureLine].[Amount] - [FactureLine].[VAT]) / [FactureLine].[Amount]
										ELSE [FactureLine].[Price]
									END  as '@Total',
								CASE [Project].[FactureCurrency]
									WHEN 0 THEN [FactureLine].[ExcisePC]
									ELSE [FactureLine].[Excise]
									END as '@Excise',
								CASE 
									WHEN [FactureLine].[VATIsIncluded] = 0 AND [FactureLine].[Amount] != 0
										THEN ([FactureLine].[Price] * [FactureLine].[Amount] + [FactureLine].[VAT]) / [FactureLine].[Amount]
									ELSE [FactureLine].[Price]
								END  as '@PriceWithVAT',
								[FactureLine].[Amount] * 	
								CASE 
									WHEN [FactureLine].[VATIsIncluded] = 0 AND [FactureLine].[Amount] != 0
										THEN ([FactureLine].[Price] * [FactureLine].[Amount] + [FactureLine].[VAT]) / [FactureLine].[Amount]
									ELSE [FactureLine].[Price]
								END as '@TotalWithVAT',
								[FactureLine].[VAT] as '@VAT',
								[FactureLine].[Description] as '@Description',
								[FactureLine].[CustomDeclaration] as '@CustomDeclaration',
								[FactureLine].[Country] as '@ProducerCountry'
							FROM
								[FactureLine]
								INNER JOIN [Project]
									ON [Facture].[ProjectID] = [Project].[ID]
								LEFT OUTER JOIN [UOM]
									ON [UOM].[ID] = [FactureLine].[UOMID]
								LEFT OUTER JOIN [ServiceAssignment]
									ON [ServiceAssignment].[Class] = [FactureLine].[DocumentClass]
									AND [ServiceAssignment].[ID] = [FactureLine].[DocumentID]
								LEFT OUTER JOIN [Service]
									ON [Service].[ID] = [ServiceAssignment].[ServiceID]
								LEFT OUTER JOIN [ServiceType]
									ON [Service].[ServiceTypeID] = [ServiceType].[ID]
							WHERE
								[FactureLine].[FactureID] = [Facture].[ID]
							FOR XML PATH('FactureLine'), TYPE
						),
						---------------------Payments
						(
						SELECT
							[Payment].[ID] as '@ID',
							[Payment].[Number] as '@Number',
							[Payment].[IncomingNumber] as '@SysNum',
							[Payment].[Date] as '@Date',
							[Payment].[IncomingDate] as '@DatePorucheniya',
							[Payment].[Value] as '@Sum'
						FROM
							[Payment]
							INNER JOIN [FacturePayment]
								ON [FacturePayment].[FactureID] = [Facture].[ID] AND [FacturePayment].[PaymentID] = [Payment].[ID]
						FOR XML PATH('Payment'), TYPE
						) as 'Payments'
						--------------------------------
				FROM
					[Facture] 
					INNER JOIN [Project]
						ON [Project].[ID] = [Facture].[ProjectID]
					INNER JOIN [Currency]
						ON [Currency].[Code] = [Facture].[CurrencyCode]
					LEFT OUTER JOIN @FactureStatement [FS]
						ON [Facture].ID = [FS].FactureID
					LEFT OUTER JOIN [Statement]
						ON ISNULL([FS].[StatementID], 0) = [Statement].[ID]
					WHERE
						[Facture].[State] IN (2) AND
						[Facture].[ID] = @ID
					FOR XML PATH('Facture'), TYPE
				) as 'Factures'
	FROM
		[Facture]
		INNER JOIN [Project]
			ON [Facture].[ProjectID] = [Project].[ID] AND [Facture].[ID] = @ID
		INNER JOIN [Company] 
			ON [Company].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Address] as [LegalAddress]
			ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
				[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
				[LegalAddress].[AddressTypeID] = 1
		LEFT OUTER JOIN [Address] as [PostalAddress]
			ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
				[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
				[PostalAddress].[AddressTypeID] = 5
		LEFT OUTER JOIN [Phone] as [BasicPhone]
			ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
				[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
				[BasicPhone].[PhoneTypeID] = 11
		LEFT OUTER JOIN [Phone] as [Fax]
			ON [Fax].[BusinessCardID] = [Company].[ID] AND 
				[Fax].[BusinessCardClass] = [Company].[Class] AND
				[Fax].[PhoneTypeID] = 8
	FOR XML PATH('Supplier'), TYPE) as 'Suppliers'
	FOR XML PATH('Documents')
	
	DECLARE @ExportFinanceOnce TBool
	SELECT
		@ExportFinanceOnce = [Company].[ExportFinanceOnce]
	FROM
		[Facture]
		INNER JOIN [Company]
			ON [Facture].[SupplierCompanyID] = [Company].[ID]
	WHERE
		[Facture].[ID] = @ID
	
	--    
	DECLARE @ExportItemID TIdentifier, @SupplierID TIdentifier, @Date TDate
	SELECT @SupplierID = [SupplierCompanyID], @Date = [Date] FROM [Facture] WHERE [ID] = @ID
	EXEC pjm6CreateExportItem @SupplierID, @Date, @Date, 3
	SET @ExportItemID = @@IDENTITY
	
	UPDATE
		[Facture]
	SET
		[Facture].[ExportItemID] = @ExportItemID,
		[Facture].[ExchangeBanned] = @ExportFinanceOnce 
	WHERE
		[Facture].[ID] = @ID AND [Facture].[State] = 2 AND [Facture].[ExchangeBanned] = 0
	
	RETURN 0
GO

GRANT EXEC ON ExportFacture TO PUBLIC

GO
