IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5GenerateInvoiceFromCalculation]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5GenerateInvoiceFromCalculation'
		DROP PROCEDURE [dbo].[pjm5GenerateInvoiceFromCalculation]
	END
GO

PRINT 'Creating procedure pjm5GenerateInvoiceFromCalculation'
GO

/******************************************************************************
**		File: pjm5GenerateInvoiceFromCalculation.sql
**		Name: pjm5GenerateInvoiceFromCalculation
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5GenerateInvoiceFromCalculation]
	@ID TIdentifier OUTPUT,
	@Xml XML,
	@DocumentClass TClass,
	@Number TName,
	@Date TDate,
	@FileAs TName,
	@BankAccountID TIdentifier,
	@CurrencyCode TCode3,
	@CurrencyRate TMoney,
	@Advance TBool, 
	@ServiceTypeID TIdentifier,
	@Description TNotes
AS
	SET NOCOUNT ON
	DECLARE @DocumentID TIdentifier,
			@State TState,
			@ProjectID TIdentifier,
			@DocumentCurrencyCode TCode3,
			@ProjectCurrencyCode TCode3,
			@DocumentCurrencyRate TMoney,
			@InvoiceBaseCurrencyRate TMoney,
			@ApplyVAT TBool,
			@PaymentCurrencyPoint TIdentifier,
			@InvoiceExpirationPeriod TCount,
			@InvoiceExpirationPeriodType TIdentifier,
			@VATRate TPercent,
			@VATIsIncluded TBool,
			@Amount TAmount,
			@Price TMoney,
			@VAT TMoney,
			@doc int,
			@rv int,
			@value TVariant,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@Scale TCount
	
	DECLARE
		@TotalPC TMoney,
		@TotalWithVATPC TMoney,
		@PricePC decimal(18, 4), 
		@VATPC decimal(18, 4)

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrencyCode TCode3

	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrencyCode = CAST(@value as varchar(3))

	EXEC adfParameterGet @Name='VATRate', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @VATRate = CAST(@value as decimal(18,4))
		
	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml
	SELECT
		@DocumentID = [XmlTable].[ID],
		@ProjectID = [XmlTable].[ProjectID],
		@VATIsIncluded = CASE [XmlTable].[VATIsIncluded] WHEN 'false' THEN 0 ELSE 1 END,
		@VATRate = [XmlTable].[VATRate],
		@TotalPC = [XmlTable].[TotalPC],
		@TotalWithVATPC = [XmlTable].[TotalWithVATPC],
		@VATPC = [XmlTable].[VATPC],
		@DocumentCurrencyCode = [XmlTable].[CurrencyCode],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@PaymentCurrencyPoint = [Project].[PaymentCurrencyPoint],
		@InvoiceExpirationPeriod = [Project].[InvoiceExpirationPeriod],
		@InvoiceExpirationPeriodType = [Project].[InvoiceExpirationPeriodType],
		@ApplyVAT = [Project].[ApplyVAT],
		@SupplierCompanyID = [Project].[SupplierCompanyID],
		@CustomerCompanyID = [Project].[CustomerCompanyID],
		@Scale = [Project].[Scale]
	FROM 
		OPENXML(@doc, '/pjm5CalculationGet/Calculation', 2)
			WITH (
				[ID] int,
				[ProjectID] int,
				[CurrencyCode] varchar(5),
				[VATIsIncluded] varchar(5),
				[Total] money,
				[TotalWithVAT] money,
				[VAT] money,
				[TotalPC] money,
				[TotalWithVATPC] money,
				[VATPC] money,
				[VATRate] decimal(18, 4),
				[ServiceTypeID] int
				) AS [XmlTable]
		INNER JOIN [Project]
			ON [XmlTable].[ProjectID] = [Project].[ID]
	EXEC sp_xml_removedocument @doc
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	ELSE IF @DocumentCurrencyCode = @CurrencyCode AND @DocumentCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = @CurrencyRate

	IF @ProjectCurrencyCode = @CurrencyCode
		SET @CurrencyRate = 1.0
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	DECLARE @c1 TCode3, @c2 TCode3
	IF @CurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @CurrencyCode
		BEGIN
			SET @c1 = @ProjectCurrencyCode
			SET @c2 = @CurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @ProjectCurrencyCode
			SET @c1 = @CurrencyCode
		END

		SELECT
			@CurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END
	IF @InvoiceBaseCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @ProjectCurrencyCode
		BEGIN
			SET @c1 = @BaseCurrencyCode
			SET @c2 = @ProjectCurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @BaseCurrencyCode
			SET @c1 = @ProjectCurrencyCode
		END

		SELECT
			@InvoiceBaseCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	IF @VATIsIncluded != 0
		SET @PricePC = @TotalWithVATPC
	ELSE
		SET @PricePC = @TotalPC

	IF @ProjectCurrencyCode = @CurrencyCode
		SET @Price = @PricePC
	ELSE
	BEGIN
		IF @CurrencyCode != @NationalCurrencyCode
			SET @Price = ROUND(@PricePC / @CurrencyRate, 2)
		ELSE
			SET @Price = ROUND(@PricePC * @CurrencyRate, 2)
	END
	
	DECLARE @divider decimal(18, 4)
	IF @VATIsIncluded = 1
		SET @divider = 1.0 + @VATRate
	ELSE 
		SET @divider = 1.0
		
	IF @ApplyVAT != 0
	BEGIN
		IF @ProjectCurrencyCode = @CurrencyCode
			SET @VAT = @VATPC
		ELSE 
		BEGIN
			IF @CurrencyCode != @NationalCurrencyCode
				SET @VAT = ROUND(@Price * @VATRate / @divider, 2)
			ELSE
				SET @VAT = ROUND(@Price * @VATRate / @divider, 2)
		END
	END
	ELSE 
	BEGIN
		SET @VAT = 0
		SET @VATPC = 0
		SET @VATRate = 0.0
	END
		
	IF @ApplyVAT = 0 SET @VATIsIncluded = 0
	
	DECLARE @InvoiceDueDate TDate
	
	IF @InvoiceExpirationPeriodType = 1
		SET @InvoiceDueDate = dbo.fnPjm5AddWorkingDays(@Date, @InvoiceExpirationPeriod)
	ELSE
		SET @InvoiceDueDate = DATEADD(day, @InvoiceExpirationPeriod - 1, @Date)

	INSERT INTO [Invoice]
		([Flag], [State], [Date], [Number], [FileAs],
		 [SupplierBankAccountID], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], [CurrencyCode], 
		 [PaymentCurrencyPoint], [DueDate], [InvoiceExpirationPeriodType],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale])
	VALUES(0, @State, @Date, @Number, @FileAs,
		@BankAccountID, @ProjectID,
		@CurrencyRate, @InvoiceBaseCurrencyRate, @CurrencyCode,
		@PaymentCurrencyPoint, @InvoiceDueDate, @InvoiceExpirationPeriodType,
		@SupplierCompanyID, @CustomerCompanyID,
		@Scale)
	IF @@ERROR != 0
		RETURN 1
	SET @ID = SCOPE_IDENTITY()

	DECLARE @TotalBC TMoney, @TotalWithVATBC TMoney
	SET @Amount = 1.0
	SET @TotalBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount - @VATIsIncluded * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount - @VATIsIncluded * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount - @VATIsIncluded * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)
	SET @TotalWithVATBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)

	INSERT INTO [InvoiceLine] (
		[InvoiceID], [DocumentClass], [DocumentID], [Description], [Amount], [VATIsIncluded], [VATRate], 
		[Price], [VAT], [PricePC], [VATPC], 
		[UOMID], [ServiceTypeID], [TotalBC], [TotalWithVATBC])
	VALUES (
		@ID, @DocumentClass, @DocumentID, @Description, 1, @VATIsIncluded, @VATRate, 
		@Price, @VAT, @PricePC, @VATPC, NULL, @ServiceTypeID, @TotalBC, @TotalWithVATBC)
	IF @@ERROR != 0
		RETURN 1
		
	DECLARE 
		@UserID TIdentifier,
		@InvoiceClass TClass,
		@ReminderPublishState TState,
		@ReminderPublishInterval TTimeSpan,
		@ReminderState TState,
		@ReminderInterval TTimeSpan
	
	SELECT
		@UserID = dbo.adfGetCurrentUserID(),
		@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice'),
		@ReminderPublishState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VA', @UserID),
		@ReminderPublishInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VA', @UserID),
		@ReminderState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VP', @UserID),
		@ReminderInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VP', @UserID)

	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VP',
		@InvoiceDueDate, @ReminderState, @ReminderInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END
	
	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VA',
		@Date, @ReminderPublishState, @ReminderPublishInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END

	EXEC pjm6BindInvoiceAndStatement @ID, NULL, @DocumentID

	RETURN 0
GO

GRANT EXECUTE ON pjm5GenerateInvoiceFromCalculation TO PUBLIC
GO

/*----------------------------
------------------------------*/

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5GenerateInvoiceFromExpense]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5GenerateInvoiceFromExpense'
		DROP PROCEDURE [dbo].[pjm5GenerateInvoiceFromExpense]
	END
GO

PRINT 'Creating procedure pjm5GenerateInvoiceFromExpense'
GO

/******************************************************************************
**		File: pjm5GenerateInvoiceFromExpense.sql
**		Name: pjm5GenerateInvoiceFromExpense
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5GenerateInvoiceFromExpense]
	@ID TIdentifier OUTPUT,
	@Xml XML,
	@DocumentClass TClass,
	@Number TName,
	@Date TDate,
	@FileAs TName,
	@BankAccountID TIdentifier,
	@CurrencyCode TCode3,
	@CurrencyRate TMoney,
	@Advance TBool, 
	@ServiceTypeID TIdentifier,
	@Description TNotes
AS
	SET NOCOUNT ON
	DECLARE @DocumentID TIdentifier,
			@State TState,
			@ProjectID TIdentifier,
			@DocumentCurrencyCode TCode3,
			@ProjectCurrencyCode TCode3,
			@DocumentCurrencyRate TMoney,
			@InvoiceBaseCurrencyRate TMoney,
			@ApplyVAT TBool,
			@PaymentCurrencyPoint TIdentifier,
			@InvoiceExpirationPeriod TCount,
			@InvoiceExpirationPeriodType TIdentifier,
			@VATRate TPercent,
			@VATIsIncluded TBool,
			@Amount TAmount,
			@Price TMoney,
			@VAT TMoney,
			@UOMID TIdentifier,
			@doc int,
			@rv int,
			@value TVariant,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@Scale TCount
	
	DECLARE
		@TotalPC TMoney,
		@TotalWithVATPC TMoney,
		@PricePC decimal(18, 4), 
		@VATPC decimal(18, 4),
		@t decimal(18, 4)

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrencyCode TCode3

	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrencyCode = CAST(@value as varchar(3))

	EXEC adfParameterGet @Name='VATRate', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @VATRate = CAST(@value as decimal(18,4))
		
	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml
	SELECT
		@DocumentID = [XmlTable].[ID],
		@ProjectID = [XmlTable].[ProjectID],
		@VATIsIncluded = CASE [XmlTable].[VATIsIncluded] WHEN 'false' THEN 0 ELSE 1 END,
		@VATRate = [XmlTable].[VATRate],
		@Amount = [XmlTable].[Amount],
		@Price = [XmlTable].[Price],
		@VAT = [XmlTable].[VAT],
		@VATPC = [XmlTable].[VATPC],
		@TotalPC = [XmlTable].[TotalPC],
		@TotalWithVATPC = [XmlTable].[TotalWithVATPC],
		@DocumentCurrencyCode = [XmlTable].[FromCurrencyCode],
		@DocumentCurrencyRate = [XmlTable].[CurrencyRate],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@PaymentCurrencyPoint = [Project].[PaymentCurrencyPoint],
		@InvoiceExpirationPeriod = [Project].[InvoiceExpirationPeriod],
		@InvoiceExpirationPeriodType = [Project].[InvoiceExpirationPeriodType],
		@ApplyVAT = [Project].[ApplyVAT],
		@UOMID = [XmlTable].[UOMID],
		@SupplierCompanyID = [Project].[SupplierCompanyID],
		@CustomerCompanyID = [Project].[CustomerCompanyID],
		@Scale = [Project].[Scale]
	FROM 
		OPENXML(@doc, '/pjm5ExpenseGet/Expense', 2)
			WITH (
				[ID] int,
				[ProjectID] int,
				[FromCurrencyCode] varchar(5),
				[VATIsIncluded] varchar(5),
				[Amount] decimal(18,4),
				[Price] money,
				[VAT] money,
				[TotalPC] money,
				[TotalWithVATPC] money,
				[VATPC] money,
				[CurrencyRate] money,
				[VATRate] decimal(18, 4),
				[UOMID] int
				) AS [XmlTable]
		INNER JOIN [Project]
			ON [XmlTable].[ProjectID] = [Project].[ID]
	EXEC sp_xml_removedocument @doc
			
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	ELSE IF @ProjectCurrencyCode = @CurrencyCode AND @DocumentCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = @DocumentCurrencyRate
	ELSE IF @CurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = @CurrencyRate

	IF @ApplyVAT != 0 AND @VATIsIncluded != 0
		SET @t = @TotalWithVATPC
	ELSE
	BEGIN
		SET @t = @TotalPC
		IF @VATIsIncluded != 0
			SET @Price = ROUND((@Price * @Amount - @VAT) / @Amount, 2)
	END
	IF @Amount != 0 
		SET @PricePC = ROUND(@t / @Amount, 2)
	ELSE IF @ProjectCurrencyCode = @DocumentCurrencyCode
		SET @PricePC = @Price
	SET @PricePC = ISNULL(@PricePC, 0)
		
	IF @ProjectCurrencyCode = @CurrencyCode
	BEGIN
		IF @Amount != 0 SET @Price = ROUND(@t / @Amount, 2)
	END
	ELSE IF @CurrencyCode != @DocumentCurrencyCode
	BEGIN
		IF @CurrencyCode != @NationalCurrencyCode
		BEGIN
			IF @Amount != 0
				SET @Price = ROUND(ROUND(@t / @CurrencyRate, 2) / @Amount, 2)
			ELSE	
				SET @Price = ROUND(ROUND(@t / @CurrencyRate, 2), 2)
		END
		ELSE
		BEGIN
			IF @Amount != 0
				SET @Price = ROUND(ROUND(@t * @CurrencyRate, 2) / @Amount, 2)
			ELSE
				SET @Price = ROUND(ROUND(@t * @CurrencyRate, 2), 2)
		END
	END
	
	DECLARE @divider decimal(18, 4)
	IF @VATIsIncluded = 1
		SET @divider = 1.0 + @VATRate
	ELSE 
		SET @divider = 1.0
		
	IF @ApplyVAT != 0
	BEGIN
		IF @ProjectCurrencyCode = @CurrencyCode
			SET @VAT = @VATPC
		ELSE IF @CurrencyCode != @DocumentCurrencyCode
		BEGIN
			IF @CurrencyCode != @NationalCurrencyCode
				SET @VAT = ROUND(@Price * @Amount * @VATRate / @divider, 2)
			ELSE
				SET @VAT = ROUND(@Price * @Amount * @VATRate / @divider, 2)
		END
	END
	ELSE 
	BEGIN
		SET @VAT = 0
		SET @VATPC = 0
		SET @VATRate = 0.0
	END
		
	IF @ApplyVAT = 0 SET @VATIsIncluded = 0
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @CurrencyRate = 1.0
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	DECLARE @c1 TCode3, @c2 TCode3
	IF @CurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @CurrencyCode
		BEGIN
			SET @c1 = @ProjectCurrencyCode
			SET @c2 = @CurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @ProjectCurrencyCode
			SET @c1 = @CurrencyCode
		END

		SELECT
			@CurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END
	IF @InvoiceBaseCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @ProjectCurrencyCode
		BEGIN
			SET @c1 = @BaseCurrencyCode
			SET @c2 = @ProjectCurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @BaseCurrencyCode
			SET @c1 = @ProjectCurrencyCode
		END

		SELECT
			@InvoiceBaseCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	DECLARE @InvoiceDueDate TDate
	
	IF @InvoiceExpirationPeriodType = 1
		SET @InvoiceDueDate = dbo.fnPjm5AddWorkingDays(@Date, @InvoiceExpirationPeriod)
	ELSE
		SET @InvoiceDueDate = DATEADD(day, @InvoiceExpirationPeriod - 1, @Date)

	INSERT INTO [Invoice]
		([Flag], [State], [Date], [Number], [FileAs],
		 [SupplierBankAccountID], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], [CurrencyCode], 
		 [PaymentCurrencyPoint], [DueDate], [InvoiceExpirationPeriodType],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale])
	VALUES(0, @State, @Date, @Number, @FileAs,
		@BankAccountID, @ProjectID,
		@CurrencyRate, @InvoiceBaseCurrencyRate, @CurrencyCode,
		@PaymentCurrencyPoint, @InvoiceDueDate, @InvoiceExpirationPeriodType,
		@SupplierCompanyID, @CustomerCompanyID,
		@Scale)
	IF @@ERROR != 0
		RETURN 1
	SET @ID = SCOPE_IDENTITY()

	DECLARE @TotalBC TMoney, @TotalWithVATBC TMoney
	SET @TotalBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount - @VATIsIncluded * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount - @VATIsIncluded * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount - @VATIsIncluded * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)
	SET @TotalWithVATBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)
	INSERT INTO [InvoiceLine] (
		[InvoiceID], [DocumentClass], [DocumentID], [Description], [Amount], [VATIsIncluded], [VATRate], 
		[Price], [VAT], [PricePC], [VATPC], 
		[UOMID], [ServiceTypeID], [TotalBC], [TotalWithVATBC])
	VALUES (
		@ID, @DocumentClass, @DocumentID, @Description, @Amount, @VATIsIncluded, @VATRate, 
		@Price, @VAT, @PricePC, @VATPC, @UOMID, @ServiceTypeID, @TotalBC, @TotalWithVATBC)
	IF @@ERROR != 0
		RETURN 1
		
	DECLARE 
		@UserID TIdentifier,
		@InvoiceClass TClass,
		@ReminderPublishState TState,
		@ReminderPublishInterval TTimeSpan,
		@ReminderState TState,
		@ReminderInterval TTimeSpan
	
	SELECT
		@UserID = dbo.adfGetCurrentUserID(),
		@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice'),
		@ReminderPublishState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VA', @UserID),
		@ReminderPublishInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VA', @UserID),
		@ReminderState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VP', @UserID),
		@ReminderInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VP', @UserID)

	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VP',
		@InvoiceDueDate, @ReminderState, @ReminderInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END
	
	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VA',
		@Date, @ReminderPublishState, @ReminderPublishInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END

	RETURN 0
GO

GRANT EXECUTE ON pjm5GenerateInvoiceFromExpense TO PUBLIC
GO

----------------------------------------------------------
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5GenerateInvoiceFromRequest]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5GenerateInvoiceFromRequest'
		DROP PROCEDURE [dbo].[pjm5GenerateInvoiceFromRequest]
	END
GO

PRINT 'Creating procedure pjm5GenerateInvoiceFromRequest'
GO

/******************************************************************************
**		File: pjm5GenerateInvoiceFromRequest.sql
**		Name: pjm5GenerateInvoiceFromRequest
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5GenerateInvoiceFromRequest]
	@ID TIdentifier OUTPUT,
	@Xml XML,
	@DocumentClass TClass,
	@Number TName,
	@Date TDate,
	@FileAs TName,
	@BankAccountID TIdentifier,
	@CurrencyCode TCode3,
	@CurrencyRate TMoney,
	@Advance TBool, 
	@ServiceTypeID TIdentifier,
	@Description TNotes
AS
	SET NOCOUNT ON
	DECLARE @DocumentID TIdentifier,
			@State TState,
			@ProjectID TIdentifier,
			@DocumentCurrencyCode TCode3,
			@ProjectCurrencyCode TCode3,
			@DocumentCurrencyRate TMoney,
			@InvoiceBaseCurrencyRate TMoney,
			@ApplyVAT TBool,
			@PaymentCurrencyPoint TIdentifier,
			@InvoiceExpirationPeriod TCount,
			@InvoiceExpirationPeriodType TIdentifier,
			@VATRate TPercent,
			@VATIsIncluded TBool,
			@Amount TAmount,
			@Price TMoney,
			@VAT TMoney,
			@doc int,
			@rv int,
			@value TVariant,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@Scale TCount
	
	DECLARE
		@TotalPC TMoney,
		@TotalWithVATPC TMoney,
		@PricePC decimal(18, 4), 
		@VATPC decimal(18, 4),
		@t decimal(18, 4)

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrencyCode TCode3

	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrencyCode = CAST(@value as varchar(3))

	EXEC adfParameterGet @Name='VATRate', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @VATRate = CAST(@value as decimal(18,4))
		
	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml
	SELECT
		@DocumentID = [XmlTable].[ID],
		@ProjectID = [XmlTable].[ProjectID],
		@VATIsIncluded = CASE [XmlTable].[VATIsIncluded] WHEN 'false' THEN 0 ELSE 1 END,
		@TotalPC = [XmlTable].[Total],
		@TotalWithVATPC = [XmlTable].[TotalWithVAT],
		@VATPC = [XmlTable].[VAT],
		@DocumentCurrencyCode = [Project].[CurrencyCode],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@PaymentCurrencyPoint = [Project].[PaymentCurrencyPoint],
		@InvoiceExpirationPeriod = [Project].[InvoiceExpirationPeriod],
		@InvoiceExpirationPeriodType = [Project].[InvoiceExpirationPeriodType],
		@ApplyVAT = [Project].[ApplyVAT],
		@SupplierCompanyID = [Project].[SupplierCompanyID],
		@CustomerCompanyID = [Project].[CustomerCompanyID],
		@Scale = [Project].[Scale]
	FROM 
		OPENXML(@doc, '/pjm5ServiceRequestGet/ServiceRequest', 2)
			WITH (
				[ID] int,
				[ProjectID] int,
				[Total] money,
				[TotalWithVAT] money,
				[VAT] money,
				[VATIsIncluded] varchar(5),
				[ServiceTypeID] int
				) AS [XmlTable]
		INNER JOIN [Project]
			ON [XmlTable].[ProjectID] = [Project].[ID]
	EXEC sp_xml_removedocument @doc
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @CurrencyRate = 1.0
	ELSE
		SET @CurrencyRate = @CurrencyRate
		
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	ELSE IF @CurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = @CurrencyRate

	IF @VATIsIncluded = 1
		SET @PricePC = @TotalWithVATPC
	ELSE
		SET @PricePC = @TotalPC
		
	SET @Price = @PricePC
	SET @VAT = @VATPC

	IF @CurrencyCode != @DocumentCurrencyCode
	BEGIN
		IF @CurrencyCode != @NationalCurrencyCode
			SET @Price = ROUND(@PricePC / @CurrencyRate, 2)
		ELSE
			SET @Price = ROUND(@PricePC * @CurrencyRate, 2)
	END
	
	DECLARE @divider decimal(18, 4)
	IF @VATIsIncluded = 1
		SET @divider = 1.0 + @VATRate
	ELSE 
		SET @divider = 1.0
		
	IF @ApplyVAT = 1
	BEGIN
		IF @ProjectCurrencyCode = @CurrencyCode
			SET @VAT = @VATPC
		ELSE IF @CurrencyCode != @DocumentCurrencyCode
		BEGIN
			IF @CurrencyCode != @NationalCurrencyCode
				SET @VAT = ROUND(@Price * @VATRate / @divider, 2)
			ELSE
				SET @VAT = ROUND(@Price * @VATRate / @divider, 2)
		END
	END
	ELSE 
	BEGIN
		SET @VAT = 0
		SET @VATPC = 0
		SET @VATRate = 0.0
	END
		
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @CurrencyRate = 1.0
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	DECLARE @c1 TCode3, @c2 TCode3
	IF @CurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @CurrencyCode
		BEGIN
			SET @c1 = @ProjectCurrencyCode
			SET @c2 = @CurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @ProjectCurrencyCode
			SET @c1 = @CurrencyCode
		END

		SELECT
			@CurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END
	IF @InvoiceBaseCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @ProjectCurrencyCode
		BEGIN
			SET @c1 = @BaseCurrencyCode
			SET @c2 = @ProjectCurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @BaseCurrencyCode
			SET @c1 = @ProjectCurrencyCode
		END

		SELECT
			@InvoiceBaseCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	DECLARE @InvoiceDueDate TDate
	
	IF @InvoiceExpirationPeriodType = 1
		SET @InvoiceDueDate = dbo.fnPjm5AddWorkingDays(@Date, @InvoiceExpirationPeriod)
	ELSE
		SET @InvoiceDueDate = DATEADD(day, @InvoiceExpirationPeriod - 1, @Date)

	INSERT INTO [Invoice]
		([Flag], [State], [Date], [Number], [FileAs],
		 [SupplierBankAccountID], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], [CurrencyCode], 
		 [PaymentCurrencyPoint], [DueDate], [InvoiceExpirationPeriodType],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale])
	VALUES(0, @State, @Date, @Number, @FileAs,
		@BankAccountID, @ProjectID,
		@CurrencyRate, @InvoiceBaseCurrencyRate, @CurrencyCode,
		@PaymentCurrencyPoint, @InvoiceDueDate, @InvoiceExpirationPeriodType,
		@SupplierCompanyID, @CustomerCompanyID,
		@Scale)
	IF @@ERROR != 0
		RETURN 1
	SET @ID = SCOPE_IDENTITY()

	DECLARE @TotalBC TMoney, @TotalWithVATBC TMoney
	IF @ApplyVAT = 0 SET @VATIsIncluded = 0
	SET @Amount = 1.0
	SET @TotalBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount - @VATIsIncluded * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount - @VATIsIncluded * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount - @VATIsIncluded * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)
	SET @TotalWithVATBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)

	INSERT INTO [InvoiceLine] (
		[InvoiceID], [DocumentClass], [DocumentID], [Description], [Amount], [VATIsIncluded], [VATRate], 
		[Price], [VAT], [PricePC], [VATPC], 
		[UOMID], [ServiceTypeID], [TotalBC], [TotalWithVATBC])
	VALUES (
		@ID, @DocumentClass, @DocumentID, @Description, 1, @VATIsIncluded, @VATRate, 
		@Price, @VAT, @PricePC, @VATPC, NULL, @ServiceTypeID, @TotalBC, @TotalWithVATBC)
	IF @@ERROR != 0
		RETURN 1
		
	DECLARE 
		@UserID TIdentifier,
		@InvoiceClass TClass,
		@ReminderPublishState TState,
		@ReminderPublishInterval TTimeSpan,
		@ReminderState TState,
		@ReminderInterval TTimeSpan
	
	SELECT
		@UserID = dbo.adfGetCurrentUserID(),
		@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice'),
		@ReminderPublishState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VA', @UserID),
		@ReminderPublishInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VA', @UserID),
		@ReminderState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VP', @UserID),
		@ReminderInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VP', @UserID)

	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VP',
		@InvoiceDueDate, @ReminderState, @ReminderInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END
	
	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VA',
		@Date, @ReminderPublishState, @ReminderPublishInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END

	RETURN 0
GO

GRANT EXECUTE ON pjm5GenerateInvoiceFromRequest TO PUBLIC
GO

----------------------------------------------------------
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5GenerateInvoiceFromTimeEntry]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5GenerateInvoiceFromTimeEntry'
		DROP PROCEDURE [dbo].[pjm5GenerateInvoiceFromTimeEntry]
	END
GO

PRINT 'Creating procedure pjm5GenerateInvoiceFromTimeEntry'
GO

/******************************************************************************
**		File: pjm5GenerateInvoiceFromTimeEntry.sql
**		Name: pjm5GenerateInvoiceFromTimeEntry
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5GenerateInvoiceFromTimeEntry]
	@ID TIdentifier OUTPUT,
	@Xml XML,
	@DocumentClass TClass,
	@Number TName,
	@Date TDate,
	@FileAs TName,
	@BankAccountID TIdentifier,
	@CurrencyCode TCode3,
	@CurrencyRate TMoney,
	@Advance TBool, 
	@ServiceTypeID TIdentifier,
	@Description TNotes
AS
	SET NOCOUNT ON
	DECLARE @DocumentID TIdentifier,
			@State TState,
			@ProjectID TIdentifier,
			@DocumentCurrencyCode TCode3,
			@ProjectCurrencyCode TCode3,
			@DocumentCurrencyRate TMoney,
			@InvoiceBaseCurrencyRate TMoney,
			@ApplyVAT TBool,
			@PaymentCurrencyPoint TIdentifier,
			@InvoiceExpirationPeriod TCount,
			@InvoiceExpirationPeriodType TIdentifier,
			@VATRate TPercent,
			@VATIsIncluded TBool,
			@Amount TAmount,
			@Price TMoney,
			@VAT TMoney,
			@doc int,
			@rv int,
			@value TVariant,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@Scale TCount
	
	DECLARE
		@TotalPC TMoney,
		@TotalWithVATPC TMoney,
		@PricePC decimal(18, 4), 
		@VATPC decimal(18, 4),
		@t decimal(18, 4)

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrencyCode TCode3

	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrencyCode = CAST(@value as varchar(3))

	EXEC adfParameterGet @Name='VATRate', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @VATRate = CAST(@value as decimal(18,4))
		
	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml
	SELECT
		@DocumentID = [XmlTable].[ID],
		@ProjectID = [XmlTable].[ProjectID],
		@VATIsIncluded = CASE [XmlTable].[RatesWithVAT] WHEN 'false' THEN 0 ELSE 1 END,
		@Amount = [XmlTable].[BillableHour],
		@PricePC = [XmlTable].[Rate],
		@DocumentCurrencyCode = [Project].[CurrencyCode],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@PaymentCurrencyPoint = [Project].[PaymentCurrencyPoint],
		@InvoiceExpirationPeriod = [Project].[InvoiceExpirationPeriod],
		@InvoiceExpirationPeriodType = [Project].[InvoiceExpirationPeriodType],
		@ApplyVAT = [Project].[ApplyVAT],
		@SupplierCompanyID = [Project].[SupplierCompanyID],
		@CustomerCompanyID = [Project].[CustomerCompanyID],
		@Scale = [Project].[Scale]
	FROM 
		OPENXML(@doc, '/pjm5TimeEntryGet/TimeEntry', 2)
			WITH (
				[ID] int,
				[ProjectID] int,
				[RatesWithVAT] varchar(5),
				[Rate] money,
				[BillableHour] decimal(18, 4)
				) AS [XmlTable]
		INNER JOIN [Project]
			ON [XmlTable].[ProjectID] = [Project].[ID]
	EXEC sp_xml_removedocument @doc

	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @ApplyVAT = 1 AND @VATIsIncluded = 1
		SET @VATPC = ROUND(@PricePC * @Amount * @VATRate / (1 + @VATRate), 2)
	ELSE IF @ApplyVAT = 1 AND @VATIsIncluded = 0
		SET @VATPC = ROUND(@PricePC * @Amount * @VATRate, 2)
	ELSE 
		SET @VATPC = 0.0
		
	SET @Price = @PricePC
	SET @VAT = @VATPC
	
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @CurrencyRate = 1.0
		
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	ELSE IF @CurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = @CurrencyRate

	IF @ProjectCurrencyCode = @CurrencyCode
		SET @Price = @PricePC
	ELSE IF @CurrencyCode != @DocumentCurrencyCode
	BEGIN
		IF @CurrencyCode != @NationalCurrencyCode
			SET @Price = ROUND(@PricePC / @CurrencyRate, 2)
		ELSE
			SET @Price = ROUND(@PricePC * @CurrencyRate, 2)
	END
	
	DECLARE @divider decimal(18, 4)
	IF @VATIsIncluded = 1
		SET @divider = 1.0 + @VATRate
	ELSE 
		SET @divider = 1.0
		
	IF @ApplyVAT != 0
	BEGIN
		IF @ProjectCurrencyCode = @CurrencyCode
			SET @VAT = @VATPC
		ELSE IF @CurrencyCode != @DocumentCurrencyCode
		BEGIN
			IF @CurrencyCode != @NationalCurrencyCode
				SET @VAT = ROUND(@Price * @Amount * @VATRate / @divider, 2)
			ELSE
				SET @VAT = ROUND(@Price * @Amount * @VATRate / @divider, 2)
		END
	END
	ELSE 
	BEGIN
		SET @VAT = 0
		SET @VATPC = 0
		SET @VATRate = 0.0
	END
		
	IF @ApplyVAT = 0 SET @VATIsIncluded = 0
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @CurrencyRate = 1.0
	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @InvoiceBaseCurrencyRate = 1.0
	DECLARE @c1 TCode3, @c2 TCode3
	IF @CurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @CurrencyCode
		BEGIN
			SET @c1 = @ProjectCurrencyCode
			SET @c2 = @CurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @ProjectCurrencyCode
			SET @c1 = @CurrencyCode
		END

		SELECT
			@CurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END
	IF @InvoiceBaseCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @ProjectCurrencyCode
		BEGIN
			SET @c1 = @BaseCurrencyCode
			SET @c2 = @ProjectCurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @BaseCurrencyCode
			SET @c1 = @ProjectCurrencyCode
		END

		SELECT
			@InvoiceBaseCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	DECLARE @InvoiceDueDate TDate
	
	IF @InvoiceExpirationPeriodType = 1
		SET @InvoiceDueDate = dbo.fnPjm5AddWorkingDays(@Date, @InvoiceExpirationPeriod)
	ELSE
		SET @InvoiceDueDate = DATEADD(day, @InvoiceExpirationPeriod - 1, @Date)
	
	INSERT INTO [Invoice]
		([Flag], [State], [Date], [Number], [FileAs],
		 [SupplierBankAccountID], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], [CurrencyCode], 
		 [PaymentCurrencyPoint], [DueDate], [InvoiceExpirationPeriodType],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale])
	VALUES(0, @State, @Date, @Number, @FileAs,
		@BankAccountID, @ProjectID,
		@CurrencyRate, @InvoiceBaseCurrencyRate, @CurrencyCode,
		@PaymentCurrencyPoint, @InvoiceDueDate, @InvoiceExpirationPeriodType,
		@SupplierCompanyID, @CustomerCompanyID,
		@Scale)
	IF @@ERROR != 0
		RETURN 1
	SET @ID = SCOPE_IDENTITY()

	DECLARE @TotalBC TMoney, @TotalWithVATBC TMoney
	SET @TotalBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount - @VATIsIncluded * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount - @VATIsIncluded * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount - @VATIsIncluded * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)
	SET @TotalWithVATBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) / @InvoiceBaseCurrencyRate
						ELSE (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) * @InvoiceBaseCurrencyRate
					END, 2)

	INSERT INTO [InvoiceLine] (
		[InvoiceID], [DocumentClass], [DocumentID], [Description], [Amount], [VATIsIncluded], [VATRate], 
		[Price], [VAT], [PricePC], [VATPC], 
		[UOMID], [ServiceTypeID], [TotalBC], [TotalWithVATBC])
	VALUES (
		@ID, @DocumentClass, @DocumentID, @Description, @Amount, @VATIsIncluded, @VATRate, 
		@Price, @VAT, @PricePC, @VATPC, 1, @ServiceTypeID, @TotalBC, @TotalWithVATBC)
	IF @@ERROR != 0
		RETURN 1
		
	DECLARE 
		@UserID TIdentifier,
		@InvoiceClass TClass,
		@ReminderPublishState TState,
		@ReminderPublishInterval TTimeSpan,
		@ReminderState TState,
		@ReminderInterval TTimeSpan
	
	SELECT
		@UserID = dbo.adfGetCurrentUserID(),
		@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice'),
		@ReminderPublishState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VA', @UserID),
		@ReminderPublishInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VA', @UserID),
		@ReminderState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VP', @UserID),
		@ReminderInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VP', @UserID)

	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VP',
		@InvoiceDueDate, @ReminderState, @ReminderInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END
	
	EXEC @rv = pjm5InvoiceReminderCreate @ID, 'VA',
		@Date, @ReminderPublishState, @ReminderPublishInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END

	RETURN 0
GO

GRANT EXECUTE ON pjm5GenerateInvoiceFromTimeEntry TO PUBLIC
GO
