IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5InvoiceLineUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5InvoiceLineUpdate'
	DROP PROCEDURE [dbo].[pjm5InvoiceLineUpdate]
END
GO

PRINT 'Creating procedure pjm5InvoiceLineUpdate'
GO

/******************************************************************************
**		File: pjm5InvoiceLineUpdate.sql
**		Name: pjm5InvoiceLineUpdate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5InvoiceLineUpdate]
	@ID	TIdentifier,
	@InvoiceID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@Amount TAmount,
	@UOMID TIdentifier,
	@VATIsIncluded TBool, 
	@VATRate TPercent, 
	@Price TMoney,
	@VAT TMoney,
	@PricePC TMoney,
	@VATPC TMoney,
	@Description TNotes,
	@ServiceTypeID TIdentifier,
	@BasePrice TCount,
	@SortKey TCode
AS
	SET NOCOUNT ON
	DECLARE 
		@BaseCurrencyRate TAmount, 
		@NationalCurrencyCode TCode3, 
		@BaseCurrencyCode TCode3,
		@ProjectCurrencyCode TCode3,
		@CurrencyCode TCode3,
		@value TVariant,
		@TotalBC TMoney,
		@TotalWithVATBC TMoney,
		@Scale TCount,
		@ProjectID TIdentifier
		
	SELECT
		@BaseCurrencyRate = [Invoice].[BaseCurrencyRate], 
		@CurrencyCode = [Invoice].[CurrencyCode],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@Scale = [Invoice].[Scale],
		@ProjectID = [Project].[ID]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
	WHERE
		[Invoice].[ID] = @InvoiceID

	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		


	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrencyCode = CAST(@value AS varchar(3))
	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @value OUTPUT	
	SET @BaseCurrencyCode = CAST(@value AS varchar(3))
	
	SET @TotalBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount - @VATIsIncluded * @VATPC
						WHEN @CurrencyCode = @BaseCurrencyCode
							THEN @Price * @Amount - @VATIsIncluded * @VAT
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount - @VATIsIncluded * @VATPC) / @BaseCurrencyRate
						ELSE (@PricePC * @Amount - @VATIsIncluded * @VATPC) * @BaseCurrencyRate
					END, @Scale)
	SET @TotalWithVATBC = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @BaseCurrencyCode
							THEN @PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC
						WHEN @CurrencyCode = @BaseCurrencyCode
							THEN @Price * @Amount + (1 - @VATIsIncluded) * @VAT
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) / @BaseCurrencyRate
						ELSE (@PricePC * @Amount + (1 - @VATIsIncluded) * @VATPC) * @BaseCurrencyRate
					END, @Scale)
					
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
		SET @UOMID = 1 --  Hours
	SET @Price = ISNULL(@Price, 0.0)
	SET @VAT = ISNULL(@VAT, 0.0)
	IF @ID IS NULL -- 
	BEGIN
		INSERT INTO [InvoiceLine] 
			([InvoiceID], [DocumentClass], [DocumentID], 
			[Description], [Amount], [UOMID], [Price], [VATIsIncluded], [VATRate], [VAT],
			[PricePC], [VATPC], [ServiceTypeID], [TotalBC], [TotalWithVATBC], 
			[BasePrice], [SortKey])
		VALUES 
			(@InvoiceID, @DocumentClass, @DocumentID, 
			@Description, @Amount, @UOMID, @Price, @VATIsIncluded, @VATRate, @VAT,
			@PricePC, @VATPC, @ServiceTypeID, @TotalBC, @TotalWithVATBC,
			@BasePrice, @SortKey)
		IF @@ERROR != 0
			RETURN 1
	END
	ELSE
	BEGIN
		UPDATE 
			[InvoiceLine] 
		SET
			[DocumentClass] = @DocumentClass,
			[DocumentID] = @DocumentID,
			[Description] =  @Description,
			[Amount] = @Amount,
			[UOMID] = @UOMID,
			[Price] = @Price,
			[VATIsIncluded] = @VATIsIncluded, 
			[VATRate] = @VATRate, 
			[VAT] = @VAT,
			[PricePC] = @PricePC, 
			[VATPC] = @VATPC,
			[ServiceTypeID] = @ServiceTypeID,
			[TotalBC] = @TotalBC,
			[TotalWithVATBC] = @TotalWithVATBC,
			[BasePrice] = @BasePrice, 
			[SortKey] = @SortKey
		WHERE
			[ID] = @ID
		IF @@ERROR != 0
			RETURN 1
	END
	RETURN 0
GO

GRANT EXECUTE ON pjm5InvoiceLineUpdate TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5InvoiceLineDelete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5InvoiceLineDelete'
	DROP PROCEDURE [dbo].[pjm5InvoiceLineDelete]
END
GO

PRINT 'Creating procedure pjm5InvoiceLineDelete'
GO

/******************************************************************************
**		File: pjm5InvoiceLineDelete.sql
**		Name: pjm5InvoiceLineDelete
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm5InvoiceLineDelete
	@ID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE @ProjectID TIdentifier
	SELECT @ProjectID = [Invoice].[ProjectID] 
	FROM 
		[InvoiceLine]
		INNER JOIN [Invoice] 
			ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
	WHERE 
		[InvoiceLine].[ID] = @ID
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		

	DELETE FROM [InvoiceLine] WHERE [ID] = @ID

	IF @@ERROR != 0
		RETURN 1

	RETURN 0
GO

GRANT EXECUTE ON pjm5InvoiceLineDelete TO PUBLIC
GO
