/*drop procedure if it already exists*/

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5IssueAllBrowse]') AND
           OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5IssueAllBrowse'
		DROP PROCEDURE [dbo].[pjm5IssueAllBrowse]
	END
GO

PRINT 'Creating procedure pjm5IssueAllBrowse'
GO

CREATE PROCEDURE [pjm5IssueAllBrowse]
	@StateSelector INT,
	@EmployeeOnly BIT,
	@ProjectID INT,
	@DateSelector int,
	@PeriodStart TDateTime,
	@PeriodEnd TDateTime
AS

	/*
	    @DateSelector description:
	    0 - all, 1 - today, 2 - last year,  3 - this year, 4 - period
		@StateSelector description:
		0 - all, 1 - active, 2 - closed, 3 - resolved, 4 - postponed, 5 - submited
	*/

	SET NOCOUNT ON
	
	DECLARE @EmployeeID TIdentifier
	
	DECLARE @Transition TABLE ([ID] TIdentifier)
	INSERT INTO @Transition ([ID])
	SELECT [ID] 
	FROM [TransitionTemplate] 
	WHERE [Class] = dbo.adfGetClassByName('Pjm5.Issue')
	

    /*IF @DateSelector = 0 THEN get all entries*/
	IF @DateSelector = 1
	BEGIN
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodStart)
	END

	IF @DateSelector = 2
	BEGIN
		DECLARE @CurrYear int;
	    SELECT
		    @PeriodEnd = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd),
		    @CurrYear = DATEPART(year, @PeriodEnd),
			@PeriodStart = DATEADD(year,(@CurrYear-1900), 0) + DATEADD(month, 0, 0)
	END

	IF @DateSelector = 3
	BEGIN
	    SELECT
		    @PeriodEnd = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd),
			@CurrYear = DATEPART(year, @PeriodEnd),
			@PeriodStart = DATEADD(year,(@CurrYear-1-1900), 0) + DATEADD(month, 0, 0)
	END
	IF @DateSelector = 4
	BEGIN
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd)
	END
	
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	
	DECLARE @ViewAllFinance TBool
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	
	DECLARE	@userID int
	SET	@userID = dbo.adfGetCurrentUserID()
	
	DECLARE @IssueClass TClass
	SET @IssueClass = dbo.adfGetClassByName('Pjm5.Issue')
	
	SELECT
		[Issue].[Class],
		[Issue].[ID],
		[Issue].[State],
		[Issue].[Flag],
		[Issue].[Number],
		[Issue].[FileAs],
		[Issue].[DuplicateOfIssueID],
		[Issue].[ProjectID],
		[Issue].[EmployeeID],
		[Issue].[SeverityID],
		[Issue].[PriorityID],
		[Issue].[DueDate],
		[Issue].[EndTime],
		[Issue].[ResolutionID],
		[Issue].[Resolution],
		[Issue].[SendStatusReport],
		[Issue].[WSSDocumentURL],
		[Issue].[UDF1],
		[Issue].[UDF2],
		[Issue].[UDF3],
		[Issue].[UDF4],
		[Issue].[Comments],
		[Issue].[Created],
		[Issue].[CreatedBy],
		[Issue].[Modified],
		[Issue].[ModifiedBy],
		[Issue].[Timestamp],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @EmployeeID
				THEN [Issue].[ActualBudget]
			ELSE -1
		END AS [ActualBudget],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @EmployeeID
				THEN [Issue].[Budget]
			ELSE -1
		END AS [Budget],
		[Issue].[ActualManHour],
		[Issue].[ManHour],
		CAST(ISNULL([DocumentUserState].[Read], 0) as bit) as [Read],
		[DocumentUserState].[ReadTime]
	FROM
		[Issue]
		INNER JOIN [Project] ON [Project].[ID] = [Issue].[ProjectID]
		LEFT OUTER JOIN [DocumentUserState]
			ON ([DocumentUserState].[UserID] = @UserID AND 
				[DocumentUserState].[DocumentClass] = @IssueClass AND 
				[DocumentUserState].[DocumentID] = [Issue].[ID])
	WHERE
	    (
	        (   
			    (
				    (@DateSelector = 0)
				)
				OR
				(
		            (@DateSelector in (1,2,3,4))
		            AND
		            ([Issue].[Created] BETWEEN @PeriodStart AND @PeriodEnd)
				)
		    )
			AND
			(([Issue].[State] = @StateSelector) OR (@StateSelector = 0))
		)
		AND
		(
			@EmployeeOnly = 0 
		OR 
			(@EmployeeOnly != 0 AND [Issue].[EmployeeID] = @EmployeeID)	
		)
		AND 
		(
			(@ProjectID > 0 AND [Issue].[ProjectID] = @ProjectID)
			OR 
			(@ProjectID = -1 AND [Issue].[ProjectID] IN (SELECT [ProjectID] FROM [IssueProject] WHERE [UserID] = @userId))
			OR
			(@ProjectID = -2 AND [Issue].[ProjectID] IN (SELECT [ID] FROM [Project]	WHERE
				[State] = 2 AND [Project].[SupportsRequestManagement] != 0
				AND
				([ProjectManagerEmployeeID] = @EmployeeID OR  
				dbo.fnPjm5IsProjectMember([Project].[ID], @EmployeeID) = 1 OR
				dbo.fnPjm5IsAssistant() = 1)))
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5IssueAllBrowse] TO PUBLIC
GO
 