IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5SubscriptionRuleUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5SubscriptionRuleUpdate'
		DROP PROCEDURE [dbo].[pjm5SubscriptionRuleUpdate]
	END
GO

PRINT 'Creating procedure pjm5SubscriptionRuleUpdate'
GO

/******************************************************************************
**		File: pjm5SubscriptionRuleUpdate.sql
**		Name: pjm5SubscriptionRuleUpdate
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 20/12/2005 13:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5SubscriptionRuleUpdate]
	@UserID TIdentifier,
	@Xml XML
AS
	SET NOCOUNT ON
	
	IF @UserID IS NULL
	BEGIN
		SET @UserID = dbo.adfGetCurrentUserID()
	END
	
	IF @UserID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE 
		@State				TState,
		@FileAs				TName,
		@XmlRuleID			int,
		@RuleID				TIdentifier,
		@doc int
	
	BEGIN TRANSACTION
	
	DELETE FROM [SubscriptionRule] WHERE [UserID] = @UserID AND [ExternalInitiator] = 0
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	EXEC sp_xml_preparedocument @doc OUTPUT, @Xml

	DECLARE rules CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
	SELECT
		[XmlTable].[State],
		[XmlTable].[FileAs],
		[XmlTable].[XmlRuleID]
	FROM
		OPENXML(@doc, 'pjm5SubscriptionRuleUpdate/SubscriptionRule', 1)
			WITH (
				[State] int '@State',
				[FileAs] nvarchar(512) '@Name',
				[XmlRuleID] int '@mp:id'
				) AS [XmlTable]
				
	OPEN rules

	FETCH NEXT FROM rules INTO @State, @FileAs, @XmlRuleID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		INSERT INTO [SubscriptionRule] ([State], [FileAs], [UserID], [Created], [Modified])	
			VALUES (@State, @FileAs, @UserID, GETDATE(), GETDATE())
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			EXEC sp_xml_removedocument @doc
			RETURN 1
		END
		SET @RuleID = SCOPE_IDENTITY()
		
		INSERT INTO [Subscription] ([SubscriptionTypeID], [SubscriptionRuleID])
		SELECT
			[SubscriptionTypeID],
			@RuleID
		FROM
			OPENXML(@doc, 'pjm5SubscriptionRuleUpdate/SubscriptionRule/Subscription', 1)
				WITH ([SubscriptionTypeID] int '@Type', [XmlParentID] int '@mp:parentid') AS [S]
		WHERE [XmlParentID] = @XmlRuleID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			EXEC sp_xml_removedocument @doc
			RETURN 1
		END
				
		INSERT INTO [DocumentSubscriptionRule] ([DocumentClass], [DocumentID], [SubscriptionRuleID])
		SELECT
			[DocumentClass],
			[DocumentID],
			@RuleID
		FROM
			OPENXML(@doc, 'pjm5SubscriptionRuleUpdate/SubscriptionRule/Document', 1)
				WITH ([DocumentClass] smallint '@Class', [DocumentID] int '@ID', [XmlParentID] int '@mp:parentid')
		WHERE [XmlParentID] = @XmlRuleID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			EXEC sp_xml_removedocument @doc
			RETURN 1
		END
				
		INSERT INTO [SubscriptionRuleNotificationWay] ([NotificationWayID], [SubscriptionRecurrencePatternID], [SubscriptionRuleID])
		SELECT
			[ID],
			NULL,
			@RuleID
		FROM
			OPENXML(@doc, 'pjm5SubscriptionRuleUpdate/SubscriptionRule/NotificationWay', 1)
				WITH ([ID] int '@ID', [XmlParentID] int '@mp:parentid')
		WHERE [XmlParentID] = @XmlRuleID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			EXEC sp_xml_removedocument @doc
			RETURN 1
		END
		
		FETCH NEXT FROM rules INTO @State, @FileAs, @XmlRuleID
	END

	CLOSE rules
	DEALLOCATE rules
	
	EXEC sp_xml_removedocument @doc

	COMMIT TRANSACTION
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm5SubscriptionRuleUpdate] TO PUBLIC
GO
  