IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6DismissOldEvents]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6DismissOldEvents'
		DROP PROCEDURE [dbo].[pjm6DismissOldEvents]
	END
GO

PRINT 'Creating procedure pjm6DismissOldEvents'
GO

/******************************************************************************
**		File: pjm6DismissOldEvents.sql
**		Name: pjm6DismissOldEvents
**		Desc:      , 
**		       .
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Yuriy.Soldatkin
**		Date: 13/5/2010
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm6DismissOldEvents]
	@UserID TIdentifier
AS
SET NOCOUNT ON

	DECLARE @InitialEventState TState,
			@AlertedEventState TState,
			@EventID TIdentifier
				
	SET @InitialEventState = dbo.fnPjm5GetInitialEventState()
	SET @AlertedEventState = dbo.fnPjm5GetAlertedEventState()

	DECLARE @LastEvents TABLE ([ID] INT null)

	INSERT INTO 
		@LastEvents
	SELECT
		MAX([Event].[ID]) AS [ID]
	FROM
		[Event]
		INNER JOIN [SubscriptionRule]
			ON [SubscriptionRule].[ID] = [Event].[SubscriptionRuleID]
		WHERE 
			[SubscriptionRule].[UserID] = @UserID
		GROUP BY
			[Event].[DocumentClass],
			[Event].[DocumentID],
			[Event].[NotificationWayID]
			
	DECLARE EventsForAdd CURSOR LOCAL FAST_FORWARD FOR 
		SELECT
			[Event].[ID]
		FROM
			[Event]
			INNER JOIN [SubscriptionRule]
				ON [SubscriptionRule].[ID] = [Event].[SubscriptionRuleID]
			WHERE 
				[SubscriptionRule].[UserID] = @UserID
				AND [Event].[State] IN (@AlertedEventState, @InitialEventState)
		
	OPEN EventsForAdd
	FETCH NEXT FROM EventsForAdd INTO @EventID
	WHILE @@FETCH_STATUS = 0
	BEGIN	
		IF(@EventID NOT IN (SELECT [ID] FROM @LastEvents))
		BEGIN
			EXEC pjm5EventDismiss @EventID
		END	
		FETCH NEXT FROM EventsForAdd INTO @EventID
	END	
		
	CLOSE EventsForAdd
	DEALLOCATE EventsForAdd	
	RETURN 0

GO

GRANT EXECUTE ON [pjm6DismissOldEvents] TO PUBLIC
GO