IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[PjmSyncExportContactFunction]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function PjmSyncExportContactFunction'
		DROP FUNCTION [dbo].[PjmSyncExportContactFunction]
	END

GO

PRINT 'Creating function PjmSyncExportContactFunction'
GO

CREATE FUNCTION PjmSyncExportContactFunction (
				@DeviceID varchar(40),
				@TimeStampEmployee bigint,
				@TimeStampCompany bigint,
				@ContactSelector int,
				@CreateDeleted BIT)

RETURNS @Result TABLE (
	[Class] TClass,
	[ID] TIdentifier,
	[ItemID] TCode,

	[FileAs] TName,
	[LastName] TName,
	[JobTitle] TName,
	[FirstName] TPersonName,
	[MiddleName] TPersonName,	
	[Birthday] TDate,
	[Nickname] TCode,
	[Body] TNotes,

	[CompanyName] TName,
	[Department] TName,
	[GovernmentId] TCode,
	[Manager] TName,
	
	[HomeTelephoneNumber] TPhone,
	[BusinessTelephoneNumber] TPhone,
	[Business2TelephoneNumber] TPhone,
	[MobileTelephoneNumber] TPhone,
	[BusinessFaxNumber] TPhone,
	[HomeFaxNumber] TPhone,
	[CompanyTelephoneNumber] TPhone,
	[AssistantTelephoneNumber] TPhone,

	[HomeAddressStreet] TName,
	[HomeAddressCity] TCity,
	[HomeAddressState] TName,
	[HomeAddressPostalCode] TPostalCode,
	[HomeAddressCountry] TName,

	[BusinessAddressStreet] TName,
	[BusinessAddressCity] TCity,
	[BusinessAddressState] TName,
	[BusinessAddressPostalCode] TPostalCode,
	[BusinessAddressCountry] Tname,	

	[OtherAddressStreet] TName,
	[OtherAddressCity] TCity,
	[OtherAddressState] TName,
	[OtherAddressPostalCode] TPostalCode,
	[OtherAddressCountry] TName,

	[Email1Address] THref,
	[Email2Address] Thref,
	[Email3Address] THref,
	[WebPage] THref,

	[Categories] TNotes,
	[TimeStampEmployee] bigint,
	[TimeStampCompany] bigint
)
AS
BEGIN

DECLARE @EmployeeID Tidentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

DECLARE @t TABLE
(
	[Class] TClass,
	[ID] TIdentifier,
	[ItemID] TCode,

	[FileAs] TName,
	[LastName] TName,
	[JobTitle] TName,
	[FirstName] TPersonName,
	[MiddleName] TPersonName,	
	[Birthday] TDate,
	[Nickname] TCode,
	[Body] TNotes,

	[CompanyName] TName,
	[Department] TName,
	[GovernmentId] TCode,
	[Manager] TName,
	
	[HomeTelephoneNumber] TPhone,
	[BusinessTelephoneNumber] TPhone,
	[Business2TelephoneNumber] TPhone,
	[MobileTelephoneNumber] TPhone,
	[BusinessFaxNumber] TPhone,
	[HomeFaxNumber] TPhone,
	[CompanyTelephoneNumber] TPhone,
	[AssistantTelephoneNumber] TPhone,

	[HomeAddressStreet] TName,
	[HomeAddressCity] TCity,
	[HomeAddressState] TName,
	[HomeAddressPostalCode] TPostalCode,
	[HomeAddressCountry] TName,

	[BusinessAddressStreet] TName,
	[BusinessAddressCity] TCity,
	[BusinessAddressState] TName,
	[BusinessAddressPostalCode] TPostalCode,
	[BusinessAddressCountry] Tname,	

	[OtherAddressStreet] TName,
	[OtherAddressCity] TCity,
	[OtherAddressState] TName,
	[OtherAddressPostalCode] TPostalCode,
	[OtherAddressCountry] TName,

	[Email1Address] THref,
	[Email2Address] Thref,
	[Email3Address] THref,
	[WebPage] THref,

	[Categories] TNotes,
	[TimeStampEmployee] bigint,
	[TimeStampCompany] bigint
)

INSERT INTO @t

SELECT 
	[Employee].[Class],
	[Employee].[ID],
	[ExternalLink].[ItemID],

	[Employee].[FileAs],
	[Employee].[LastName],
	[Position].[FileAs] AS [JobTitle],
	[Employee].[FirstName],
	[Employee].[MiddleName],	
	[Employee].[BirthDate] AS [Birthday],
	[Employee].[Initials] AS [Nickname],
	REPLACE(REPLACE([Employee].[Comments], CHAR(13) + CHAR(10), CHAR(10)), CHAR(10), CHAR(13) + CHAR(10)) AS [Body],

	[Company].[FileAs] AS [CompanyName],
	[Division].[FileAs] AS [Department],
	NULL as [GovernmentId],
	NULL as [Manager],
	
	[vwPhone].[#PhoneType#2] AS [HomeTelephoneNumber],
	[vwPhone].[#PhoneType#1] AS [BusinessTelephoneNumber],
	[vwPhone].[#PhoneType#6] AS [Business2TelephoneNumber],
	[vwPhone].[#PhoneType#3] AS [MobileTelephoneNumber],
	[vwPhone].[#PhoneType#8] AS [BusinessFaxNumber],
	[vwPhone].[#PhoneType#9] AS [HomeFaxNumber],
	[vwPhone].[#PhoneType#7] AS [CompanyTelephoneNumber],
	[vwPhone].[#PhoneType#5] AS [AssistantTelephoneNumber],

	CASE WHEN [Home].[AddressTypeID] IS NULL THEN [Legal].[Street] ELSE [Home].[Street] END AS [HomeAddressStreet],
	CASE WHEN [Home].[AddressTypeID] IS NULL THEN [Legal].[City] ELSE [Home].[City] END AS [HomeAddressCity],
	CASE WHEN [Home].[AddressTypeID] IS NULL THEN [Legal].[Region] ELSE [Home].[Region] END AS [HomeAddressState],
	CASE WHEN [Home].[AddressTypeID] IS NULL THEN [Legal].[PostalCode] ELSE [Home].[PostalCode] END AS [HomeAddressPostalCode],
	CASE WHEN [Home].[AddressTypeID] IS NULL THEN [Legal].[Country] ELSE [Home].[Country] END AS [HomeAddressCountry],

	NULL AS [BusinessAddressStreet],
	NULL AS [BusinessAddressCity],
	NULL AS [BusinessAddressState],
	NULL AS [BusinessAddressPostalCode],
	NULL AS [BusinessAddressCountry],	

	[Other].[Street] AS [OtherAddressStreet],
	[Other].[City] AS [OtherAddressCity],
	[Other].[Region] AS [OtherAddressState],
	[Other].[PostalCode] AS [OtherAddressPostalCode],
	[Other].[Country] AS [OtherAddressCountry],

	[Email].[Email] AS [Email1Address],
	[Email2].[Email] AS [Email2Address],
	[Email3].[Email] AS [Email3Address],
	[WebPage].[Email] AS [WebPage],

	ISNULL([dbo].[fnPjm5CategoriesConcat] ([Employee].[Class], [Employee].[ID])+', ','')+ 'PjmSync' AS [Categories],
	CAST([Employee].[TimeStamp] as bigint) AS [TimeStampEmployee],
	0 AS [TimeStampCompany]
	
FROM
	[Employee] 
	LEFT OUTER JOIN [Position]
		ON [Employee].[PositionID] = [Position].[ID]
	INNER JOIN [Company]
		ON [Company].[ID] = [Employee].[CompanyID]
	LEFT OUTER JOIN [Division]
		ON [Employee].[DivisionID] = [Division].[ID]
	LEFT OUTER JOIN [vwPhone]
		ON [vwPhone].[BusinessCardClass] = [Employee].[Class] AND
			[vwPhone].[BusinessCardID] = [Employee].[ID]
	LEFT OUTER JOIN [Address] AS [Home]
		ON [Home].[BusinessCardClass] = [Employee].[Class] AND
			[Home].[BusinessCardID] = [Employee].[ID] AND
			[Home].[AddressTypeID] = 3
	LEFT OUTER JOIN [Address] AS [Legal]
		ON [Legal].[BusinessCardClass] = [Employee].[Class] AND
			[Legal].[BusinessCardID] = [Employee].[ID] AND
			[Legal].[AddressTypeID] = 2
	LEFT OUTER JOIN [Address] AS [Other]
		ON [Other].[BusinessCardClass] = [Employee].[Class] AND
			[Other].[BusinessCardID] = [Employee].[ID] AND
			[Other].[AddressTypeID] = 4
	LEFT OUTER JOIN [Email]
		ON [Email].[BusinessCardClass] = [Employee].[Class] AND
			[Email].[BusinessCardID] = [Employee].[ID] AND
			[Email].[EmailTypeID] = 1
	LEFT OUTER JOIN [Email] AS [Email2]
		ON [Email2].[BusinessCardClass] = [Employee].[Class] AND
			[Email2].[BusinessCardID] = [Employee].[ID] AND
			[Email2].[EmailTypeID] = 2
	LEFT OUTER JOIN [Email] AS [Email3]
		ON [Email3].[BusinessCardClass] = [Employee].[Class] AND
			[Email3].[BusinessCardID] = [Employee].[ID] AND
			[Email3].[EmailTypeID] = 3
	LEFT OUTER JOIN [Email] AS [WebPage]
		ON [WebPage].[BusinessCardClass] = [Employee].[Class] AND
			[WebPage].[BusinessCardID] = [Employee].[ID] AND
			[WebPage].[EmailTypeID] = 4
	INNER JOIN [UserContact]
		ON [Employee].[ID] = [UserContact].[BusinessCardID] AND
			[UserContact].[BusinessCardClass] = [Employee].[Class] AND 
			[UserContact].[UserID] = dbo.adfGetCurrentUserID()
	LEFT OUTER JOIN [ExternalLink]
		ON [ExternalLink].[DeviceID] = @DeviceID AND
			[ExternalLink].[DocumentID] = [Employee].[ID] AND
			 [ExternalLink].[DocumentClass] = [Employee].[Class]
	WHERE 
		[UserContact].[BusinessCardID] IS NOT NULL	AND
		(@ContactSelector =0 OR @ContactSelector=2)
		
	UNION 

SELECT 
	[Company].[Class],
	[Company].[ID],
	[ExternalLink].[ItemID],

	[Company].[FileAs],
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	REPLACE(REPLACE([Company].[Comments], CHAR(13) + CHAR(10), CHAR(10)), CHAR(10), CHAR(13) + CHAR(10)) AS [Body],
	
	[Company].[LegalName] AS [CompanyName],
	NULL,
	[Company].[LegalCode] AS [GovernmentId],
	[Employee].[FileAs] AS [Manager],

	[vwPhone].[#PhoneType#2] AS [HomeTelephoneNumber],
	[vwPhone].[#PhoneType#1] AS [BusinessTelephoneNumber],
	[vwPhone].[#PhoneType#6] AS [Business2TelephoneNumber],
	[vwPhone].[#PhoneType#3] AS [MobileTelephoneNumber],
	[vwPhone].[#PhoneType#8] AS [BusinessFaxNumber],
	[vwPhone].[#PhoneType#9] AS [HomeFaxNumber],
	[vwPhone].[#PhoneType#7] AS [CompanyTelephoneNumber],
	[vwPhone].[#PhoneType#5] AS [AssistantTelephoneNumber],

	[Home].[Street] AS [HomeAddressStreet],
	[Home].[City] AS [HomeAddressCity],
	[Home].[Region] AS [HomeAddressState],
	[Home].[PostalCode] AS [HomeAddressPostalCode],
	[Home].[Country] AS [HomeAddressCountry],

	[Business].[Street] AS [BusinessAddressStreet],
	[Business].[City] AS [BusinessAddressCity],
	[Business].[Region] AS [BusinessAddressState],
	[Business].[PostalCode] AS [BusinessAddressPostalCode],
	[Business].[Country] AS [BusinessAddressCountry],	

	[Other].[Street] AS [OtherAddressStreet],
	[Other].[City] AS [OtherAddressCity],
	[Other].[Region] AS [OtherAddressState],
	[Other].[PostalCode] AS [OtherAddressPostalCode],
	[Other].[Country] AS [OtherAddressCountry],

	[Email].[Email] AS [Email1Address],
	[Email2].[Email] AS [Email2Address],
	[Email3].[Email] AS [Email3Address],
	[WebPage].[Email] AS [WebPage],

	ISNULL([dbo].[fnPjm5CategoriesConcat] ([Company].[Class], [Company].[ID])+', ','')+ 'PjmSync' AS [Categories],
	0 AS [TimeStampEmployee],
	CAST([Company].[TimeStamp] as bigint) AS [TimeStampCompany]
FROM
	[Company]
	LEFT OUTER JOIN [vwPhone]
		ON [vwPhone].[BusinessCardClass] = [Company].[Class] AND
			[vwPhone].[BusinessCardID] = [Company].[ID]
	LEFT OUTER JOIN [Employee]
		ON [Employee].[ID] = [Company].[ExecutiveEmployeeID]
	LEFT OUTER JOIN [Address] AS [Home]
		ON [Home].[BusinessCardClass] = [Company].[Class] AND
			[Home].[BusinessCardID] = [Company].[ID] AND
			[Home].[AddressTypeID] = 3
	LEFT OUTER JOIN [Address] AS [Business]
		ON [Business].[BusinessCardClass] = [Company].[Class] AND
			[Business].[BusinessCardID] = [Company].[ID] AND
			[Business].[AddressTypeID] = 1
	LEFT OUTER JOIN [Address] AS [Other]
		ON [Other].[BusinessCardClass] = [Company].[Class] AND
			[Other].[BusinessCardID] = [Company].[ID] AND
			[Other].[AddressTypeID] = 4
	LEFT OUTER JOIN [Email]
		ON [Email].[BusinessCardClass] = [Company].[Class] AND
			[Email].[BusinessCardID] = [Company].[ID] AND
			[Email].[EmailTypeID] = 1
	LEFT OUTER JOIN [Email] AS [Email2]
		ON [Email2].[BusinessCardClass] = [Company].[Class] AND
			[Email2].[BusinessCardID] = [Company].[ID] AND
			[Email2].[EmailTypeID] = 2
	LEFT OUTER JOIN [Email] AS [Email3]
		ON [Email3].[BusinessCardClass] = [Company].[Class] AND
			[Email3].[BusinessCardID] = [Company].[ID] AND
			[Email3].[EmailTypeID] = 3
	LEFT OUTER JOIN [Email] AS [WebPage]
		ON [WebPage].[BusinessCardClass] = [Company].[Class] AND
			[WebPage].[BusinessCardID] = [Company].[ID] AND
			[WebPage].[EmailTypeID] = 4
	INNER JOIN [UserContact]
		ON [Company].[ID] = [UserContact].[BusinessCardID] AND
			[UserContact].[BusinessCardClass] = [Company].[Class] AND 
			[UserContact].[UserID] = dbo.adfGetCurrentUserID()
	LEFT OUTER JOIN [ExternalLink]
		ON [ExternalLink].[DeviceID] = @DeviceID AND
			[ExternalLink].[DocumentID] = [Company].[ID] AND
			 [ExternalLink].[DocumentClass] = [Company].[Class]
	WHERE 
		[UserContact].[BusinessCardID] IS NOT NULL AND
		@ContactSelector IN (1,2);
		

INSERT INTO @Result
(
	[Class],
	[ID],
	[ItemID],

	[FileAs],
	[LastName],
	[JobTitle],
	[FirstName],
	[MiddleName],	
	[Birthday],
	[Nickname],
	[Body],

	[CompanyName],
	[Department],
	[GovernmentId],
	[Manager],
	
	[HomeTelephoneNumber],
	[BusinessTelephoneNumber],
	[Business2TelephoneNumber],
	[MobileTelephoneNumber],
	[BusinessFaxNumber],
	[HomeFaxNumber],
	[CompanyTelephoneNumber],
	[AssistantTelephoneNumber],

	[HomeAddressStreet],
	[HomeAddressCity] ,
	[HomeAddressState],
	[HomeAddressPostalCode],
	[HomeAddressCountry],

	[BusinessAddressStreet],
	[BusinessAddressCity],
	[BusinessAddressState],
	[BusinessAddressPostalCode],
	[BusinessAddressCountry],	

	[OtherAddressStreet],
	[OtherAddressCity],
	[OtherAddressState],
	[OtherAddressPostalCode],
	[OtherAddressCountry],

	[Email1Address],
	[Email2Address],
	[Email3Address],
	[WebPage],

	[Categories],
	[TimeStampEmployee],
	[TimeStampCompany]
)
SELECT
	[Class],
	[ID],
	[ItemID],

	[FileAs],
	[LastName],
	[JobTitle],
	[FirstName],
	[MiddleName],	
	[Birthday],
	[Nickname],
	[Body],

	[CompanyName],
	[Department],
	[GovernmentId],
	[Manager],
	
	[HomeTelephoneNumber],
	[BusinessTelephoneNumber],
	[Business2TelephoneNumber],
	[MobileTelephoneNumber],
	[BusinessFaxNumber],
	[HomeFaxNumber],
	[CompanyTelephoneNumber],
	[AssistantTelephoneNumber],

	[HomeAddressStreet],
	[HomeAddressCity],
	[HomeAddressState],
	[HomeAddressPostalCode],
	[HomeAddressCountry],

	[BusinessAddressStreet],
	[BusinessAddressCity],
	[BusinessAddressState],
	[BusinessAddressPostalCode],
	[BusinessAddressCountry],	

	[OtherAddressStreet],
	[OtherAddressCity],
	[OtherAddressState],
	[OtherAddressPostalCode],
	[OtherAddressCountry],

	[Email1Address],
	[Email2Address],
	[Email3Address],
	[WebPage],

	[Categories],
	[TimeStampEmployee],
	[TimeStampCompany]
FROM @t AS [Table]
WHERE 
	   ([TimeStampEmployee] > @TimeStampEmployee)  
	OR ([TimeStampCompany] > @TimeStampCompany)
	OR [ItemID] IS NULL 
	OR @CreateDeleted=1

UNION ALL

SELECT 
	[ExternalLink].[DocumentClass],
	-[ExternalLink].[DocumentID],
	[ExternalLink].[ItemID],

	NULL,
	NULL,
	NULL,
	NULL,
	NULL,	
	NULL,
	NULL,
	NULL,

	NULL,
	NULL,
	NULL,
	NULL,
	
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,

	NULL,
	NULL,
	NULL,
	NULL,
	NULL,

	NULL,
	NULL,
	NULL,
	NULL,
	NULL,	

	NULL,
	NULL,
	NULL,
	NULL,
	NULL,

	NULL,
	NULL,
	NULL,
	NULL,

	NULL,
	NULL,
	NULL
FROM [ExternalLink]
	LEFT OUTER JOIN @t AS [Table]
	ON [Table].[Class]=[ExternalLink].[DocumentClass] AND
		[Table].[ID]=[ExternalLink].[DocumentID]
WHERE [Table].[ItemID] IS NULL AND 
		[ExternalLink].[DeviceID] = @DeviceID AND
	[ExternalLink].[DocumentClass] IN (dbo.adfGetClassByName('Adf.Employee'),dbo.adfGetClassByName('Adf.Company'))





	RETURN
END
GO
