IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5CreateProjectByTemplate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5CreateProjectByTemplate'
		DROP PROCEDURE [dbo].[pjm5CreateProjectByTemplate]
	END
GO

PRINT 'Creating procedure pjm5CreateProjectByTemplate'
GO

/******************************************************************************
**		File: ProjectCreateByTemplate.sql
**		Name: pjm5CreateProjectByTemplate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		26.03.10	SYV				  EnabledTasks
**		21.05.10	SYV		          [ExchangeSystemName]   	
**		15.06.10	KOV				  [FolderID]
**		13.11.10	SYV				  [GroupingAdvanceCalculations]
**		24.11.10	SYV				  [StatementCurrencyPoint]
**		22.04.11	SYV				    GroupCalculationLines, ShowActivityTypes
**									GroupingAdvanceCalculations  
**		14.07.11	SYV				 UseSubProjects
*******************************************************************************/
CREATE PROCEDURE [pjm5CreateProjectByTemplate]
	@ID	TIdentifier,
	@StartDate TDateTime,
	@SupplierID TIdentifier,
	@ManagerID TIdentifier,
	@CustomerID TIdentifier,
	@PersonID TIdentifier,
	@BookingXml XML,
	@EnabledTasks TBool,
	@CopyDataFromBudget		TBool		= 0,
	@Forced					TBool		= 1
AS
	SET NOCOUNT ON
	
	DECLARE @State TState,
			@NewProjectID TIdentifier,
			@CurrencyCode TCode3,
			@AssignmentState TState,
			@ServiceAssignmentState TState,
			@TaskState TState,
			@InvoiceState TState,
			@BaseDate TDateTime,
			@EmployeeName TName,
			@QualificationID TIdentifier,
			@StandardRate TMoney,
			@OvertimeRate TMoney,
			@ManagerAssignmentID TIdentifier,
			@ApplyVat int,
			@rv int,
			@doc int,
			@InvoicePeriodType TCode,
			@InvoiceDayType TCode,
			@InvoiceNextPaymentDate TDate,
			@StatementPeriodType TCode,
			@StatementDayType TCode,
			@StatementNextPaymentDate TDate,
			@CalculationPeriodType TCode,
			@CalculationDayType TCode,
			@CalculationNextPaymentDate TDate,
			@CheckTaskWorkOverdraft TBool,
			@value TVariant,
			@InvoiceExpirationPeriodType TIdentifier,
			@InvoiceExpirationPeriod TCount,
			@StatementCurrencyPoint TIdentifier,
			@BudgetTemplateID TIdentifier,
			@UseBudgetPlanning TBool

			
			
	SET @State = dbo.adfwfGetInitialState('e64c30d7-1ade-4f9e-8bde-c35357ea6e8a')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SET @AssignmentState = dbo.adfwfGetInitialState('7797bd53-86ce-415e-9e13-b11bcbd52359')
	IF @AssignmentState IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SET @ServiceAssignmentState = dbo.adfwfGetInitialState('8cece7ca-a901-42cc-bdb8-60b87a26cd1d')
	IF @ServiceAssignmentState IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF(@EnabledTasks = 1)
	BEGIN
		SET @TaskState = 8 --dbo.adfwfGetInitialState('1b62b9f6-1e1c-4f4d-95bc-41484b45741c')
		IF @TaskState IS NULL
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END
	END
	
	SET @InvoiceState = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	EXEC sp_xml_preparedocument @doc OUTPUT, @BookingXml
	
	IF(@EnabledTasks = 1)
	BEGIN
		DECLARE @busyEntry TABLE ([TaskID] int, [AssignmentID] int, [Date] datetime, [Planned] int)
		INSERT INTO @busyEntry ([TaskID], [AssignmentID], [Date], [Planned])
		SELECT
			[TaskID], 
			[AssignmentID], 
			CAST([Date] AS datetime), 
			[Planned]
		FROM
			OPENXML(@doc, '/Booking/BusyEntry', 2)
				WITH (
					[TaskID] int,
					[AssignmentID] int,
					[Date] varchar(19),
					[Planned] int
					)
		EXEC sp_xml_removedocument @doc
	END

	SELECT
		@CurrencyCode = [Project].[CurrencyCode],
		@BaseDate = [Project].[Date],
		@InvoicePeriodType = [PaymentPeriod].[InvoicePeriodType],
		@InvoiceDayType = [PaymentPeriod].[InvoiceDayType],
		@InvoiceNextPaymentDate = [PaymentPeriod].[InvoiceNextPaymentDate],
		@StatementPeriodType = [PaymentPeriod].[StatementPeriodType],
		@StatementDayType = [PaymentPeriod].[StatementDayType],
		@StatementNextPaymentDate = [PaymentPeriod].[StatementNextPaymentDate],
		@CalculationPeriodType = [PaymentPeriod].[CalculationPeriodType],
		@CalculationDayType = [PaymentPeriod].[CalculationDayType],
		@CalculationNextPaymentDate = [PaymentPeriod].[CalculationNextPaymentDate],
		@BudgetTemplateID = [ProjectTemplate].[BudgetTemplateID]
	FROM
		[Project]
		INNER JOIN [PaymentPeriod]
			ON [PaymentPeriod].[ProjectID] = [Project].[ID]
		INNER JOIN [ProjectTemplate]
			ON [ProjectTemplate].[ID] = [Project].[ID]
	WHERE
		[Project].[ID] = @ID
		
	DECLARE 
		@ShiftDays TCount,
		@VatRate TAmount
	SELECT 
		@ShiftDays = DATEDIFF(day, @BaseDate, @StartDate),
		@VatRate = CASE @ApplyVat
			WHEN 1 THEN dbo.fnPjm5GetVATRate()
			ELSE 0
			END

	EXEC adfParameterGet 'InvoiceExpirationPeriodType', 'Pjm5', @Value = @value OUTPUT
	SET @InvoiceExpirationPeriodType = ISNULL(CAST(@value as int), 0)
	
	EXEC adfParameterGet 'InvoiceExpirationPeriod', 'Pjm5', @Value = @value OUTPUT
	SET @InvoiceExpirationPeriod = ISNULL(CAST(@value as int), 0)

	EXEC adfParameterGet @Name='CheckTaskWorkOverdraft', @Group='Pjm6', @Value = @value OUTPUT
	SET @CheckTaskWorkOverdraft = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='StatementCurrencyPoint', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @StatementCurrencyPoint = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='UseBudgetPlanning', @Group='Pjm6', @Value = @value OUTPUT
	SET @UseBudgetPlanning = CAST(@value as bit)

	BEGIN TRANSACTION
	
	
	INSERT INTO [Project]
		([State], [Flag], [Date], [Number], [FileAs], [ProjectTypeID],
		[SupplierCompanyID], [ProjectManagerEmployeeID], [CustomerCompanyID],
		[CustomerFinanceManagerID], [ResponsiblePersonEmployeeID],
		[PriorityID], 
		[ProjectLanguageCode],
		[CurrencyCode], [CostCenterID], [Budget],
		[ContractNumber], [ContractDate], [ContractEndDate], [ContractSubject], [ApplyVAT],
		[InvoiceExpirationPeriod], [InvoiceExpirationPeriodType],
		[WSSDocumentsURL], [Comments],[ContractComments], [RoundingInterval], [RoundingMode], [Billable],
		[SupportsRequestManagement], [RatesWithVAT],
		[PaymentCurrencyPoint], [InitialBalance], [BaseInitialBalance],
		[InvoiceCurrency], [StatementCurrency], [FactureCurrency], [Scale], [FolderID], [GroupCalculationLines],
		[CheckTaskWorkOverdraft], [ShowActivityTypes], [ExchangeSystemName],
		[GroupingAdvanceCalculations],
		[StatementCurrencyPoint], [ShowPrice], [UseSubProjects]
		)
	SELECT
		@State,
		0,
		@StartDate,
		[Number],
		[FileAs],
		[ProjectTypeID],
		@SupplierID,
		@ManagerID,
		@CustomerID,
		[CustomerFinanceManagerID],
		@PersonID,
		[PriorityID],
		[ProjectLanguageCode],
		[CurrencyCode],
		[CostCenterID],
		[Budget],
		[ContractNumber],
		dbo.fnPjm5ShiftDate([ContractDate], @ShiftDays),
		CASE
			WHEN [ContractEndDate] IS NOT NULL THEN
				dbo.fnPjm5ShiftDate([ContractEndDate], @ShiftDays)
			ELSE [ContractEndDate]
		END,
		[ContractSubject],
		[ApplyVAT],
		@InvoiceExpirationPeriod,
		@InvoiceExpirationPeriodType,
		[WSSDocumentsURL],
		[Comments],
		[ContractComments],
		[RoundingInterval],
		[RoundingMode],
		[Billable],
		[SupportsRequestManagement],
		[RatesWithVAT],
		[PaymentCurrencyPoint],
		[InitialBalance],
		[BaseInitialBalance],
		[InvoiceCurrency],
		[StatementCurrency],
		[FactureCurrency], 
		[Scale],
		[FolderID],
		[GroupCalculationLines],
		@CheckTaskWorkOverdraft,
		[ShowActivityTypes],
		[ExchangeSystemName],
		[GroupingAdvanceCalculations],
		@StatementCurrencyPoint,
		[ShowPrice],
	    [UseSubProjects]
	FROM
		[Project]
	WHERE
		[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @NewProjectID = SCOPE_IDENTITY()

	INSERT INTO [ProjectDetail] 
		([ID], [DueDate],
		
		[DiscountTypeByTime],
		[DiscountViewByTime],
		[DiscountByTime],
				
		[DiscountTypeByExpense],
		[DiscountViewByExpense],
		[DiscountByExpense],
				
		[DiscountTypeByPhone],
		[DiscountViewByPhone],
		[DiscountByPhone],	
				
		[DiscountTypeByServiceRequest],
		[DiscountViewByServiceRequest],
		[DiscountByServiceRequest])
	SELECT
		@NewProjectID, 
		@StartDate,
		
		[DiscountTypeByTime],
		[DiscountViewByTime],
		[DiscountByTime],
				
		[DiscountTypeByExpense],
		[DiscountViewByExpense],
		[DiscountByExpense],
				
		[DiscountTypeByPhone],
		[DiscountViewByPhone],
		[DiscountByPhone],	
				
		[DiscountTypeByServiceRequest],
		[DiscountViewByServiceRequest],
		[DiscountByServiceRequest]
	FROM
		[ProjectDetail]
	WHERE
		[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	UPDATE
		[PaymentPeriod]
	SET
		[InvoicePeriodType] = @InvoicePeriodType,
		[InvoiceDayType] = @InvoiceDayType,
		[StatementPeriodType] = @StatementPeriodType,
		[StatementDayType] = @StatementDayType,
		[CalculationPeriodType] = @CalculationPeriodType,
		[CalculationDayType] = @CalculationDayType
	WHERE
		[ProjectID] = @NewProjectID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	INSERT INTO [ProjectActivityType] ([ProjectID], [ActivityTypeID], [Billable], [Actively])
	SELECT @NewProjectID, [ActivityTypeID], [Billable], [Actively]
	FROM [ProjectActivityType] 
	WHERE[ProjectID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	INSERT INTO [ProjectExpenseCode] ([ProjectID], [ExpenseCodeID], [Billable], [Actively])
	SELECT @NewProjectID, [ExpenseCodeID], [Billable], [Actively]
	FROM [ProjectExpenseCode]
	WHERE [ProjectID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DECLARE @inTemplateID INT, @inProjectID INT

	-- Assignments
	DECLARE @assignmenttable TABLE ([InTemplateID] int, [InProjectID] int)
	DECLARE assignments CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT
			[ID],
			[Flag],
			[FileAs],
			[EmployeeID],
			[QualificationID],
			[StandardRate],
			[OvertimeRate],
			[RateVisible],
			[Approver],
			[Administrator],
			[AlwaysUseRate],
			[ReceiveTaskStatusReports],
			[ReceiveIssueStatusReports],
			[Comments]
		FROM
			[vwAssignment]
		WHERE
			[ProjectID] = @ID

	OPEN assignments
	DECLARE 
		@assflag TFlag,
		@assfileas TName, @assemployeeID TIdentifier,
		@assqualificationID TIdentifier, @assstandardRate TMoney,
		@assovertimeRate TMoney, @assratevisible TBool,
		@assapprover TBool,	@assadministrator TBool, @taskreport TBool,
		@issuereport TBool, @asscomments TNotes, @AlwaysUseRate TBool
	
	FETCH NEXT FROM assignments INTO @inTemplateID, @assflag, @assfileas, @assemployeeID,
		@assqualificationID, @assstandardRate, @assovertimeRate, @assratevisible,
		@assapprover, @assadministrator, @AlwaysUseRate, @taskreport, @issuereport, @asscomments
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC @rv = pjm5AssignmentCreateInternal
			@ID = @inProjectID OUTPUT,
			@Flag = @assflag,
			@State = @AssignmentState,
			@FileAs = @assfileas,
			@EmployeeID = @assemployeeid,
			@ProjectID = @NewProjectID,
			@QualificationID = @assqualificationID,
			@StandardRate = @assstandardRate,
			@OvertimeRate = @assovertimeRate,
			@RateVisible = @assratevisible,
			@Approver = @assapprover,
			@Administrator = @assadministrator,
			@TaskReport = @taskreport,
			@IssueReport = @issuereport,
			@Comments = @asscomments,
			@AlwaysUseRate = @AlwaysUseRate
			
		IF @@ERROR != 0 OR @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		INSERT INTO @assignmenttable ([InTemplateID], [InProjectID]) VALUES(@inTemplateID, @inProjectID)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		FETCH NEXT FROM assignments INTO @inTemplateID, @assflag, @assfileas, @assemployeeID,
			@assqualificationID, @assstandardRate, @assovertimeRate, @assratevisible,
			@assapprover, @assadministrator, @AlwaysUseRate, @taskreport, @issuereport, 
			@asscomments
	END
	CLOSE assignments
	DEALLOCATE assignments
	
	-- ServiceAssignments
	DECLARE @services TABLE ([InTemplateID] int, [InProjectID] int)
	DECLARE service CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT [ID] 
		FROM [ServiceAssignment] 
		WHERE [ServiceAssignment].[ProjectID] = @ID
	OPEN service
	FETCH NEXT FROM service INTO @inTemplateID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		INSERT INTO [ServiceAssignment]
			([Flag], [State], [FileAs], 
			[ProjectID], [ServiceID], 
			[RateMultiplier], [Price], [VATIsIncluded],
			[PaymentTermID],
			[Comments], [ContractAddendumID],
			[ServiceTypeID])
		SELECT
			[Flag],
			@ServiceAssignmentState,
			[FileAs],
			@NewProjectID,
			[ServiceID],
			[RateMultiplier],
			[Price],
			[VATIsIncluded],
			[PaymentTermID],
			[Comments],
			[ContractAddendumID],
			[ServiceTypeID]
		FROM
			[ServiceAssignment]
		WHERE
			[ID] = @inTemplateID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		SET @inProjectID = SCOPE_IDENTITY()

		INSERT INTO @services ([InTemplateID], [InProjectID]) 
		VALUES (@inTemplateID, @inProjectID)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		FETCH NEXT FROM service INTO @inTemplateID
	END
	CLOSE service
	DEALLOCATE service

	-- Invoices
	DECLARE @invoices TABLE ([InTemplateID] int,[InProjectID] int)
	DECLARE invoice CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT [ID] FROM [Invoice] WHERE [Invoice].[ProjectID] = @ID

	OPEN invoice
	FETCH NEXT FROM invoice INTO @inTemplateID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		INSERT INTO [Invoice]
			([Flag], [State], [Date], [Number], [FileAs], 
			[ProjectID], 
			[SupplierBankAccountID],
			[CurrencyRate], [CurrencyCode], [Comments])
		SELECT
			[Flag],
			@InvoiceState,
			dbo.fnPjm5ShiftDate([Date], @ShiftDays),
			[Number],
			[FileAs],
			@NewProjectID,
			[SupplierBankAccountID],
			[CurrencyRate],
			[CurrencyCode],
			[Comments]
		FROM
			[Invoice]
		WHERE
			[ID] = @inTemplateID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		SET @InProjectID = SCOPE_IDENTITY()

		INSERT INTO @invoices ([InTemplateID], [InProjectID]) VALUES(@inTemplateID, @inProjectID)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		FETCH NEXT FROM invoice INTO @inTemplateID
	END
	CLOSE invoice
	DEALLOCATE invoice
	
	INSERT INTO [InvoiceLine] (
		[InvoiceID], 
		[DocumentClass], 
		[DocumentID], 
		[Description], 
		[Amount], 
		[Price],
		[VAT],
		[VATRate],
		[VATIsIncluded])
	SELECT
		t.[InProjectID],
		l.[DocumentClass],
		s.[InProjectID],
		l.[Description],
		l.[Amount],
		l.[Price],
		l.[VAT],
		l.[VATRate],
		l.[VATIsIncluded]
	FROM
		[Invoice] i
		INNER JOIN [InvoiceLine] l
			ON i.[ID] = l.[InvoiceID]
		INNER JOIN @invoices t
			ON l.[InvoiceID] = t.[inTemplateID]
		LEFT OUTER JOIN [ServiceAssignment]
			ON [ServiceAssignment].[Class] = l.[DocumentClass] AND [ServiceAssignment].[ID] = l.[DocumentID]
		LEFT OUTER JOIN @services s
			ON [ServiceAssignment].[ID] = s.[InTemplateID]
	WHERE
		i.[ProjectID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	IF @UseBudgetPlanning = 1 AND @BudgetTemplateID IS NOT NULL
	BEGIN
		DECLARE
			@BudgetType			TIdentifier,
			@PeriodStart		TDate,
			@PeriodEnd			TDate,
			@Now				TDate

		SELECT
			@BudgetType = [BudgetTypeID]
		FROM
			[Budget]
		WHERE
			[Budget].[ID] = @BudgetTemplateID

		IF @BudgetType = 1
		BEGIN
			EXEC @rv = pjm6BudgetCreateByTemplate @NewProjectID, @BudgetTemplateID, 0, 0, NULL, NULL, NULL, NULL, NULL, @CopyDataFromBudget, @Forced
			IF @@ERROR != 0 OR @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
		ELSE
		BEGIN
			SET @Now = GETDATE()
			EXEC @rv = Pjm6GetCurrentPeriod @Now, @BudgetType, @PeriodStart = @PeriodStart OUTPUT, @PeriodEnd = @PeriodEnd OUTPUT
			IF @@ERROR != 0 OR @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
			EXEC @rv = pjm6BudgetCreateByTemplate @NewProjectID, @BudgetTemplateID, 0, 0, @PeriodStart, @PeriodEnd, @BudgetType, NULL, 0, @CopyDataFromBudget, @Forced
			IF @@ERROR != 0 OR @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END
	-- Tasks
	IF(@EnabledTasks = 1 AND (@UseBudgetPlanning = 0 OR (@UseBudgetPlanning = 1 AND @BudgetTemplateID IS NULL)))
	BEGIN
		DECLARE @inProjectTaskStartDate datetime,
				@inProjectTaskDueDate datetime,
				@TaskDuration TAmount
		DECLARE tasks CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT [ID], CAST([Duration] as decimal(18,4)) FROM [Task] WHERE [Task].[ProjectID] = @ID

		OPEN tasks
		FETCH NEXT FROM tasks INTO @inTemplateID, @TaskDuration
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SELECT @inProjectTaskStartDate = MIN([Date]) FROM @busyEntry WHERE [TaskID] = @inTemplateID
			IF @inProjectTaskStartDate IS NULL
				SELECT @inProjectTaskStartDate = dbo.fnPjm5ShiftDate([StartDate], @ShiftDays) FROM [Task] WHERE [ID] = @inTemplateID
			SELECT @inProjectTaskDueDate = dbo.fnPjm5AddWorkingDays(@inProjectTaskStartDate, @TaskDuration)
			
			INSERT INTO [Task]
				([State], [Flag], [FileAs], [ProjectID], 
				[PriorityID], 
				[StartDate], [DueDate], [EndDate], [Duration], 
				[ManHour], [Budget],
				[PercentComplete], 
				[Milestone], [SendStatusReport], 
				[Comments])
			SELECT
				@TaskState,
				[Flag],
				[FileAs],
				@NewProjectID,
				[PriorityID], 
				@inProjectTaskStartDate, @inProjectTaskDueDate, NULL, [Duration],
				[ManHour], [Budget],
				CAST([PercentComplete] as decimal(5, 2)) / CAST(100 as decimal(5, 2)),
				[Milestone], [SendStatusReport],
				[Comments] 
			FROM
				[Task]
			WHERE
				[ID] = @inTemplateID
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
			SET @inProjectID = SCOPE_IDENTITY()
			
			DECLARE @TaskIndex TCount, @Wbs TName
			SELECT @TaskIndex =	[TaskIndex], @Wbs = [Wbs] FROM [TaskWbs] WHERE [TaskID] = @inTemplateID
			UPDATE [TaskWbs] SET [TaskIndex] = @TaskIndex, [Wbs] = @Wbs WHERE [TaskID] = @inProjectID
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
				
			
			INSERT INTO [TaskAssignment] ([TaskID], [AssignmentID], [Units], [Work], [RemainingWork])
			SELECT  @inProjectID, [A].[InProjectID],
					[TaskAssignment].[Units],
					[TaskAssignment].[Work],
					[TaskAssignment].[Work]
			FROM
				[TaskAssignment]
				INNER JOIN @assignmenttable AS [A]
					ON [TaskAssignment].[AssignmentID] = [A].[InTemplateID]
			WHERE
				[TaskAssignment].[TaskID] = @inTemplateID
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
			
			INSERT INTO [BusyEntry] ([ProjectID], [TaskID], [AssignmentID], [Date], [EmployeeID], [Planned], [Committed])
			SELECT
				@NewProjectID,
				@inProjectID,
				[a].[InProjectID],
				[b].[Date],
				[vwAssignment].[EmployeeID],
				[b].[Planned],
				0
			FROM 
				@busyEntry AS [b]
				INNER JOIN @assignmenttable [a]
					ON [a].[InTemplateID] = [b].[AssignmentID]
				LEFT OUTER JOIN [vwAssignment]
					ON [vwAssignment].[ID] = [a].[InProjectID]
			WHERE
				[b].[TaskID] = @inTemplateID
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END

			FETCH NEXT FROM tasks INTO @inTemplateID, @TaskDuration
		END

		CLOSE tasks
		DEALLOCATE tasks
	END
	
	COMMIT TRANSACTION
	
	SELECT @NewProjectID AS [ID]
	RETURN 0
GO

GRANT EXECUTE ON pjm5CreateProjectByTemplate TO PUBLIC
GO
 
