IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectTemplateGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectTemplateGet'
		DROP PROCEDURE [dbo].[pjm5ProjectTemplateGet]
	END
GO

PRINT 'Creating procedure pjm5ProjectTemplateGet'
GO

/******************************************************************************
**		File: pjm5ProjectTemplateBrowse.sql
**		Name: pjm5ProjectTemplateBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		26.03.10	SYV				   [ExchangeSystemName]
**									 
**		15.03.10	KOV				  [FolderID]
**		19.04.11	SYV				  [StatementCurrency]  [BankAccountDefault]
**		22.04.11	SYV				   
**		14.07.11	SYV				 UseSubProjects
*******************************************************************************/
CREATE PROCEDURE [pjm5ProjectTemplateGet]
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE @TemplateClass TClass,
			@CurrentUserID TIdentifier,
			@ExistsTasks	TBool
	SET @TemplateClass = dbo.adfGetClassByName('Pjm5.ProjectTemplate')
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
		
	--    
	SET @ExistsTasks = 0
	IF (EXISTS(SELECT *FROM [Task] WHERE [ProjectID] = @ID AND [SubprojectID] IS NULL AND [State] = 7))
		SET @ExistsTasks = 1
	
	SELECT
		@TemplateClass AS [Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[T].[EndDate] AS [DueDate],
		[Project].[EndDate],
		dbo.fnPjm5GetWorkingDays([Project].[Date], [T].[EndDate]) AS [Duration],
		[T].[EndDate] AS [PlanEndDate],
		[Project].[ProjectLanguageCode],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[Budget],
		ISNULL([T].[ManHour], 0) AS [PlannedManHour],
		ISNULL([T].[Budget], 0) AS [PlannedBudget],
		0 AS [RealManHour],
		0 AS [RealBudget],
		0 AS [EstimatedManHour],
		0 AS [EstimatedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[RatesWithVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[SupportsRequestManagement],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		-1 AS [BudgetIndicator],
		-1 AS [DateIndicator],
		[Project].[PaymentCurrencyPoint],
		[Project].[InitialBalance],
		[Project].[BaseInitialBalance],
		[Project].[InvoiceCurrency],
		[Project].[StatementCurrency],
		[Project].[FactureCurrency],
		[Project].[Scale],
		[Project].[FolderID],
		dbo.fnFolderHasRightAccess([Project].[FolderID], @CurrentUserID, 'FOLDERVISIBLE') AS [FolderVisible],
		[PaymentPeriod].[InvoicePeriodType],
		[PaymentPeriod].[InvoiceDayType],
		[PaymentPeriod].[InvoiceNextPaymentDate],
		[PaymentPeriod].[StatementPeriodType],
		[PaymentPeriod].[StatementDayType],
		[PaymentPeriod].[StatementNextPaymentDate],
		[PaymentPeriod].[CalculationPeriodType],
		[PaymentPeriod].[CalculationDayType],
		[PaymentPeriod].[CalculationNextPaymentDate],
		[Project].[ContractComments],
		[Project].[ExchangeSystemName],
		@ExistsTasks AS [ExistsTasks],
		[ProjectTemplate].[BudgetTemplateID],
		0 AS [StatementCurrency], --
		0 AS [BankAccountDefault], --

		[ProjectDetail].[DiscountTypeByTime],
		[ProjectDetail].[DiscountViewByTime],
		[ProjectDetail].[DiscountByTime],
		[ProjectDetail].[DiscountByTime] AS [DiscountPercentByTime],
		
		[ProjectDetail].[DiscountTypeByExpense],
		[ProjectDetail].[DiscountViewByExpense],
		[ProjectDetail].[DiscountByExpense],
		[ProjectDetail].[DiscountByExpense] AS [DiscountPercentByExpense],

		[ProjectDetail].[DiscountTypeByPhone],
		[ProjectDetail].[DiscountViewByPhone],
		[ProjectDetail].[DiscountByPhone],
		[ProjectDetail].[DiscountByPhone] AS [DiscountPercentByPhone],

		[ProjectDetail].[DiscountTypeByServiceRequest],
		[ProjectDetail].[DiscountViewByServiceRequest],
		[ProjectDetail].[DiscountByServiceRequest],
		[ProjectDetail].[DiscountByServiceRequest] AS [DiscountPercentByServiceRequest],
		[GroupingAdvanceCalculations],
		[ShowActivityTypes],
		[GroupCalculationLines],
		[ShowPrice],
		[UseSubProjects],
		[Project].[NumerationCode]
	FROM
		[Project] 
		INNER JOIN [PaymentPeriod]
			ON [PaymentPeriod].[ProjectID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		INNER JOIN [ProjectTemplate]
			ON [ProjectTemplate].[ID] = [Project].[ID] 
		LEFT OUTER JOIN 
			(SELECT
				[Task].[ProjectID] AS [ProjectID],
				MAX([DueDate]) AS [EndDate],
				ISNULL(SUM([ManHour]), 0) / 60.0 AS [ManHour],
				(SELECT
					ISNULL(SUM([TaskAssignment].[Work] * [Assignment].[StandardRate]), 0) / 60.0
				FROM 
					[Task] t
					INNER JOIN [TaskAssignment]
						ON [TaskAssignment].[TaskID] = t.[ID]
					INNER JOIN [Assignment]
						ON [TaskAssignment].[AssignmentID] = [Assignment].[ID]
				WHERE 
					t.[State] IN (7) AND
					[Assignment].[ProjectID] = [Task].[ProjectID]
				) AS [Budget]
			FROM 
				[Task]
			WHERE
				[Task].[State] IN (7)
			GROUP BY
				[Task].[ProjectID]
			) AS T
			ON ([Project].[ID] = [T].[ProjectID])
	WHERE
		[Project].[ID] = @ID
		
	SELECT
		[ProjectActivityType].[ActivityTypeID] AS [ID],
		[ActivityType].[FileAs] AS [Name],
		[ProjectActivityType].[Billable],
		[ProjectActivityType].[Actively]
	FROM
		[ProjectActivityType]
		INNER JOIN [ActivityType]
			ON [ActivityType].[ID] = [ProjectActivityType].[ActivityTypeID] 
	WHERE
		[ProjectActivityType].[ProjectID] = @ID
		
	SELECT
		[ProjectExpenseCode].[ExpenseCodeID] AS [ID],
		[ExpenseCode].[FileAs] AS [Name],
		[ProjectExpenseCode].[Billable],
		[ProjectExpenseCode].[Actively]
	FROM
		[ProjectExpenseCode]
		INNER JOIN [ExpenseCode]
			ON [ExpenseCode].[ID] = [ProjectExpenseCode].[ExpenseCodeID] 
	WHERE
		[ProjectExpenseCode].[ProjectID] = @ID
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5ProjectTemplateGet] TO PUBLIC
GO  