IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRateByProject')
	BEGIN
		PRINT 'Dropping Procedure ReportRateByProject'
		DROP  Procedure ReportRateByProject
	END

GO

PRINT 'Creating Procedure ReportRateByProject'
GO

CREATE Procedure ReportRateByProject
		@ProjectID TIdentifier,
		@DateSelector int,
		@PeriodStart TDate,
		@PeriodEnd TDate
				
AS
	SET NOCOUNT ON
	

	IF @ProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE
		@UserID TIdentifier,
		@UserName TName,
		@Multiplier decimal(18,8),
		@BillableMultiplier decimal(18,8),
		@SumProffit money,
		@Loss money,
		@BillableLoss money
		
	
	IF @DateSelector = 0
		BEGIN
			SELECT
				@PeriodStart = [StartDate],
				@PeriodEnd = [EndDate]
			FROM	
				dbo.adfGetDateInterval(3, GETDATE(), GETDATE(), GETDATE())
		END
	ELSE IF @DateSelector = 1
		BEGIN
			SELECT
				@PeriodStart = [StartDate],
				@PeriodEnd = [EndDate]
			FROM	
				dbo.adfGetDateInterval(4, GETDATE(), GETDATE(), GETDATE())
		END
	ELSE
		BEGIN
			SET @PeriodEnd = DATEADD(day, 1, @PeriodEnd)
		END				
	
		SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	SELECT 
		@UserName AS [UserName],
		[Project].[FileAs] AS [ProjectName],
		GETDATE() AS [Date],
		[Project].[CurrencyCode] AS [CurrencyCode],
		@PeriodStart AS [PeriodStart],
		DATEADD(day, -1, @PeriodEnd) AS [PeriodEnd]		
	FROM  
		[Project]
	WHERE
		[Project].[ID] = @ProjectID			
	
	SELECT
		@SumProffit = SUM([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATIsIncluded] * [InvoiceLine].[VATPC])
	FROM 
		[Invoice]
		INNER JOIN [InvoiceLine]
			ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
		INNER JOIN [ServiceType]
			ON [ServiceType].[ID] = [InvoiceLine].[ServiceTypeID]
		LEFT OUTER JOIN [AdvanceInvoice]
			ON [AdvanceInvoice].[AdvanceInvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [Invoice] AS [Base]
			ON [AdvanceInvoice].[InvoiceID] = [Base].[ID]
	WHERE
		([Base].[State] NOT IN (2,5) OR [Base].[State] IS NULL) AND
		[Invoice].[ProjectID] = @ProjectID AND
		[Invoice].[Date] >= @PeriodStart AND [Invoice].[Date] < @PeriodEnd AND
		[Invoice].[State] IN (2,5) AND
		[ServiceType].[RatesDepended] = 1 

	SELECT 
		@Loss = SUM(([EntryAmount].[Price] / (1 + [VATRate]*[Project].[RatesWithVAT]))*[EntryAmount].[Amount]),
		@BillableLoss = SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE ([EntryAmount].[Price] / (1 + [VATRate]*[Project].[RatesWithVAT]))*[EntryAmount].[Amount]*[TimeEntry].[Billable] END)
	FROM
		[TimeEntry]
	INNER JOIN [Project]
		ON [TimeEntry].[ProjectID] = [Project].[ID]
	INNER JOIN [EntryAmount]
		ON [EntryAmount].[ID] = [TimeEntry].[ID]
	WHERE		 
		[TimeEntry].[ProjectID] = @ProjectID AND
		[TimeEntry].[State] IN (3,4,6) AND
		[TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd

	SET @SumProffit = ISNULL(@SumProffit, 0)
	
	IF @Loss != 0
		SET @Multiplier = CAST(@SumProffit AS decimal(18,8))/CAST(@Loss AS decimal(18,8))
	
    IF @BillableLoss!=0
		SET @BillableMultiplier = CAST(@SumProffit AS decimal(18,8))/CAST(@BillableLoss AS decimal(18,8))
		
		
	DECLARE @Table TABLE ([QualificationID] TIdentifier, [TimeRate] money, [SumDuration] decimal(18), [TimeRateBillable] money, [SumDurationBillable] decimal(18))
	INSERT INTO @Table 
		SELECT 
			[vwAssignment].[QualificationID],			
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE [Rate]*[TimeEntry].[Duration] END),
			SUM([TimeEntry].[Duration]),
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE [Rate] * [TimeEntry].[Duration] * [TimeEntry].[Billable] END),
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE [TimeEntry].[Duration]* [TimeEntry].[Billable] END)	
		FROM
			[TimeEntry]
			INNER JOIN [vwAssignment]
				ON [TimeEntry].[AssignmentID] = [vwAssignment].[ID] AND
					[TimeEntry].[ProjectID] = [vwAssignment].[ProjectID]
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]		
		WHERE 
			[TimeEntry].[ProjectID] = @ProjectID AND
			[TimeEntry].[State] IN (3,4,6) AND
			[TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd
		GROUP BY 
			[vwAssignment].[QualificationID]

	SELECT 
		[Table].[QualificationID],
		ISNULL([Qualification].[FileAs],'( )') AS [QualificationFileAs],
		[QualificationRate].[Standard] AS [CurrentRate], 
		CASE WHEN @Loss = 0 OR [SumDuration] = 0  THEN 0 ELSE @Multiplier*[TimeRate]/[SumDuration] END AS [Rate],
		CASE WHEN @BillableLoss = 0 OR [SumDurationBillable] = 0 THEN 0 ELSE @BillableMultiplier*[TimeRateBillable]/[SumDurationBillable] END AS [BillableRate]        
	FROM 
		@Table AS [Table]
		LEFT OUTER JOIN [Qualification]
			ON [Qualification].[ID] = [Table].[QualificationID]	
		LEFT OUTER JOIN [QualificationRate]
			ON [QualificationRate].[QualificationID] = 	[Table].[QualificationID] AND
			[QualificationRate].[CurrencyCode] = (SELECT [CurrencyCode] FROM [Project] WHERE [ID]=@ProjectID)	
	ORDER BY 
		[CurrentRate] DESC
	  

RETURN 0

GO

GRANT EXEC ON ReportRateByProject TO PUBLIC

GO
