IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectByEstimator')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectByEstimator'
		DROP  Procedure  ReportProjectByEstimator
	END

GO

PRINT 'Creating Procedure ReportProjectByEstimator'
GO

--------------------------------------------------------------------------------------
CREATE Procedure ReportProjectByEstimator
			@DateSelector int,
			@StartDate TDate,
			@EndDate TDate,
			@CompanyID TIdentifier,
			@DivisionID TIdentifier,
			@EstimatorEmployeeID TIdentifier
			
 
AS
	SET NOCOUNT ON

------------------------------------------------
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END

	IF @DivisionID IS NULL 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END
 
	SET DATEFIRST 1	
	DECLARE
		@UserID TIdentifier,
		@UserName TName,
		@DivisionFileAs TName

	SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
			
	IF @DateSelector = 1 -- current month
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
			END
		ELSE IF @DateSelector = 0 --last month
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@StartDate = DATEADD(month, -1, @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		END
		ELSE --Period
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime),
				@EndDate = CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime)
		END

	DECLARE @EstimatorEmployeeFileAs TName
	SELECT @EstimatorEmployeeFileAs = [FileAS] FROM [Employee]
						WHERE [Employee].[ID] = @EstimatorEmployeeID
					
	DECLARE @DivisionManager TName
	SELECT	@DivisionManager = [Value] 
	FROM [PropertyValue]
		INNER JOIN [Property]
			ON [Property].[ID] = [PropertyValue].[PropertyID]
			AND [Property].[Name] = ' '
	WHERE   [PropertyValue].[DocumentClass] = dbo.adfGetClassByName('Adf.Division') AND 
			[PropertyValue].[DocumentID] = @DivisionID
	
	SELECT 
		@UserName AS [UserName],
		GETDATE() AS [Date],
		@StartDate AS [PeriodStart],
		@EndDate AS [PeriodEnd],
		ISNULL(@EstimatorEmployeeFileAs, '()') AS [Estimator],
		[Company].[FileAs] AS [Company],
		[Division].[FileAs] AS [Division],
		@DivisionManager AS [DivisionManager]
	FROM [Company]
		INNER JOIN [Division]
			ON [Division].[ID] = @DivisionID
	WHERE [Company].[ID]= @CompanyID	
	
	DECLARE @TaskClass Int
	SET @TaskClass = dbo.adfGetClassByName('Pjm5.Task')

	DECLARE @FareIndex Int
	SELECT @FareIndex = [ID] FROM [Property] 
						WHERE [Property].[Name] = ''

	DECLARE @FeeIndex Int
	SELECT @FeeIndex = [ID] FROM [Property] 
						WHERE [Property].[Name] = ''

	SELECT 
		[Employee].[FileAs] AS [Estimator],
		[Company].[FileAs] AS [Customer],
		[CostCenter].[Code] AS [Bank],
		[Project].[ContractNumber] AS [ReportNumber],
		[Task].[FileAs] AS [Task],
		CONVERT(Decimal(38,3), ISNULL([Fare].[Value], 0)) AS [Fare],
		CONVERT(Decimal(38,3), ISNULL([Fee].[Value], 0)) AS [Fee]
	FROM [Task]
		INNER JOIN [Project]
			ON [Project].[ID] = [Task].[ProjectID]
		LEFT OUTER JOIN [Company]
			ON [Company].[ID] = [Project].[CustomerCompanyID]
		INNER JOIN [CostCenter]
			ON [CostCenter].[ID] = [Project].[CostCenterID]
		LEFT OUTER JOIN [PropertyValue] as [Fare]
			ON [Fare].[DocumentClass] = @TaskClass
			AND [Fare].[DocumentID] = [Task].[ID]
			AND [Fare].[PropertyID] = @FareIndex
		LEFT OUTER JOIN [PropertyValue] as [Fee]
			ON [Fee].[DocumentClass] = @TaskClass
			AND [Fee].[DocumentID] = [Task].[ID]
			AND [Fee].[PropertyID] = @FeeIndex
		INNER JOIN [TaskAssignment]
			ON [TaskAssignment].[TaskID] = [Task].[ID]
		INNER JOIN [vwAssignment]
			ON [vwAssignment].[ID] = [TaskAssignment].[AssignmentID]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [vwAssignment].[EmployeeID]
	WHERE
		CAST(CONVERT(varchar(8), [Task].[DueDate], 112) AS datetime) >= @StartDate AND
		CAST(CONVERT(varchar(8), [Task].[DueDate], 112) AS datetime) <= @EndDate AND
		((@EstimatorEmployeeID IS NULL AND [Employee].[DivisionID] = @DivisionID)
			OR
		(@EstimatorEmployeeID > 0) AND ([vwAssignment].[EmployeeID] = @EstimatorEmployeeID))
	ORDER BY
		[vwAssignment].[FileAs],
		[CostCenter].[FileAS],
		[Project].[ContractNumber] ASC
	RETURN 0
GO

GRANT EXEC ON ReportProjectByEstimator TO PUBLIC
GO  