IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeTimeAllocationByProject')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeTimeAllocationByProject'
		DROP  Procedure  ReportEmployeeTimeAllocationByProject
	END

GO

PRINT 'Creating Procedure ReportEmployeeTimeAllocationByProject'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
   
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**	--------		--------			-------------------------------------------
**  18.01.10		SYV					
--------------------------------------------------------------------------------------*/
CREATE PROCEDURE [dbo].[ReportEmployeeTimeAllocationByProject]
        @CompanyID TIdentifier,
        @DivisionSelector int,
        @DivisionID TIdentifier,
        @DateSelector int,
        @Date TDate,
        @PeriodStart TdateTime,
		@PeriodEnd	TdateTime
		
AS

SET NOCOUNT ON

	DECLARE 

        @TimeEntryClass as TClass
	
	SET @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	
	IF @DivisionID IS NULL AND @DivisionSelector=2 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 2
	END

EXEC ReportEmployeeTimeAllocationByProjectHeader @CompanyID,
                                                 @DivisionSelector,
                                                 @DivisionID,
                                                 @DateSelector,
                                                 @Date, 
                                                 @PeriodStart = @PeriodStart OUTPUT,
                                                 @PeriodEnd = @PeriodEnd OUTPUT                          

DECLARE @Columns TABLE(Number int)


DECLARE @EmployeeTimeAllocation TABLE(
                                     TimeEntryState TIdentifier,
                                     EmployeeID TIdentifier,
                                     EmployeeName TName,
                                     ProjectID TIdentifier,
                                     ProjectName TName,
                                     Duration TMoney)

DECLARE @TimeEntries TABLE(
					[EmployeeID] TIdentifier,
					[EmployeeFileAs] TName,
				    [Working] TState,
					[ProjectID] TIdentifier, 
					[ProjectCode] TCode, 
					[State] TState,
					[Duration] TMoney,
					[BillableDuration] TMoney)


INSERT INTO @TimeEntries(
					[EmployeeID],
					[EmployeeFileAs],
				    [Working],
					[ProjectID], 
					[ProjectCode], 
					[State],
					[Duration],
					[BillableDuration])
SELECT
	[Employee].[ID],
	[Employee].[FileAs],
	[Employee].[State],
	[TimeEntry].[ProjectID],
	[Project].[Number],
	[TimeEntry].[State],
	SUM([TimeEntry].[Duration]/60.0) as [Duration],
	CASE [TimeEntry].[Billable] WHEN 1 THEN 
		SUM([EntryAmount].[Amount]) ELSE NULL END as [BillableDuration]
FROM
	[Employee]
	LEFT OUTER JOIN [TimeEntry]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
		AND [TimeEntry].[StartTime] BETWEEN @PeriodStart AND @PeriodEnd
	LEFT OUTER JOIN [EntryAmount]
		ON [EntryAmount].[ID] = [TimeEntry].[ID]
	LEFT OUTER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[TimeEntry].[ProjectID] IS NOT NULL AND	
	(
		[Project].[SupplierCompanyID] = @CompanyID OR
		@CompanyID IS NULL
	) AND
	(
		(@DivisionSelector = 2 AND [Employee].[DivisionID] = @DivisionID) OR
		(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
		(@DivisionSelector = 0)
	)
GROUP BY
	[Employee].[ID],
	[Employee].[FileAs],
	[Employee].[State],
	[TimeEntry].[ProjectID],
	[Project].[Number],
	[TimeEntry].[State],
	[TimeEntry].[Billable]


-- ,   ""
INSERT INTO @EmployeeTimeAllocation(TimeEntryState,
                                   EmployeeID, EmployeeName,
                                   ProjectID, ProjectName,
                                   Duration)
SELECT 
	4 AS [ColumnNumbers],
	[TimeEntries].[EmployeeID],
	[TimeEntries].[EmployeeFileAs],
	[TimeEntries].[ProjectID],
	[TimeEntries].[ProjectCode],
	CASE WHEN [TimeEntries].[State] IN (2,3, 6)
		THEN ISNULL([TimeEntries].[Duration], 0) 
		ELSE 0 
	END
FROM 
	@TimeEntries AS [TimeEntries]
WHERE
	[TimeEntries].[Working] = 1 OR [TimeEntries].[Duration] > 0
GROUP BY
	[TimeEntries].[State],
	[TimeEntries].[EmployeeID],
	[TimeEntries].[EmployeeFileAs],
	[TimeEntries].[ProjectID],
	[TimeEntries].[ProjectCode],
	[TimeEntries].[Duration],
	[TimeEntries].[BillableDuration]

-- ,   ""
INSERT INTO @EmployeeTimeAllocation(TimeEntryState,
                                   EmployeeID, EmployeeName,
                                   ProjectID, ProjectName,
                                   Duration)
SELECT 
	6 AS [ColumnNumbers],
	[TimeEntries].[EmployeeID],
	[TimeEntries].[EmployeeFileAs],
	[TimeEntries].[ProjectID],
	[TimeEntries].[ProjectCode],
	CASE WHEN [TimeEntries].[State] IN (3, 6) AND [TimeEntries].[BillableDuration] IS NOT NULL
		THEN ISNULL([TimeEntries].[BillableDuration], 0) 
	ELSE 0 END
FROM 
	@TimeEntries AS [TimeEntries]

WHERE
	[TimeEntries].[Working] = 1 OR [TimeEntries].[Duration] > 0
GROUP BY
	[TimeEntries].[State],

	[TimeEntries].[EmployeeID],
	[TimeEntries].[EmployeeFileAs],
	[TimeEntries].[ProjectID],
	[TimeEntries].[ProjectCode],
	[TimeEntries].[Duration],
	[TimeEntries].[BillableDuration]

SELECT 
	[TE].* 
FROM 
	@EmployeeTimeAllocation AS [TE]
INNER JOIN [Project]
		ON [Project].[ID] = [TE].[ProjectID]
ORDER BY
	[TE].[TimeEntryState],
	[Project].[ProjectTypeID],
	[Project].[CostCenterID],
	[TE].[ProjectName]


SELECT 
	EmployeeID as EmpID, 
	EmployeeName as EmpName,
	TimeEntryState TimeState,
	ISNULL(SUM(Duration), 0) as TotalDuration
FROM @EmployeeTimeAllocation
GROUP BY TimeEntryState, EmployeeID, EmployeeName



RETURN 0

GO

GRANT EXEC ON ReportEmployeeTimeAllocationByProject TO PUBLIC

GO

