﻿IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeTimeByActivity')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeTimeByActivity'
		DROP  Procedure  ReportEmployeeTimeByActivity
	END
GO
PRINT 'Creating Procedure ReportEmployeeTimeByActivity'
GO

CREATE PROCEDURE [dbo].[ReportEmployeeTimeByActivity]
		@CompanyID		TIdentifier, -- ID компании
        @DivisionID		TIdentifier, -- ID подразделения
        @DateSelector	TIdentifier, -- Тип выбранной даты (SelectedIndex на фильтре)
        @PeriodStart	TdateTime,	 -- Дата начала периода
		@PeriodEnd		TdateTime,	 -- Дата конца периода
		@RoundedType	TIdentifier  -- Как округлять время : 0 - настройки проекта, 1 - не округлять
AS
SET NOCOUNT ON

-- Проверка на права
IF  dbo.adfHasAccessRightByName('ViewEmployeeTimeByActivityTypesReport') = 0 
BEGIN
      RAISERROR('#NotEnoughPermissions', 18, -1)
      RETURN 1
END

DECLARE
	@PeriodName TName -- Название периода
-- Определение периодов
EXEC ReportGetPeriod 
	@DateSelector,			-- Тип выбранного периода
	@PeriodStart OUTPUT,	-- Начало периода
	@PeriodEnd	 OUTPUT,	-- Конец периода
	@PeriodName  OUTPUT		-- Название периода
	
DECLARE @Result TABLE        
(
	EmployeeName	TName,		 -- Наименование сотрудника
	ActivityType	TName,		 -- Вид деятельности
	ProjectType		TName,		 -- Порядок вида деятельности для отображения
	TimeDuration	TAmount,	 -- Время
	ActivityTypeFileAs TName
)

INSERT INTO @Result
(
	EmployeeName,
	ActivityType,
	ProjectType,
	TimeDuration,
	ActivityTypeFileAs
)
SELECT
	ISNULL( [Employee].[LastName],[Employee].[FileAs] ) AS [EmployeeName], -- Если нет Фамилии, показать поле "Хранить как"
	CASE 
		WHEN [ActivityType].[Code] = [ActivityType].[FileAs] THEN [ActivityType].[Code]
		ELSE ([ActivityType].[Code] + ' \ ' + [ActivityType].[FileAs])
	END AS [ActivityType],
	CASE [Project].[ProjectTypeID]
		WHEN 1 THEN 'Работа по договорам'
		ELSE 'Прочие работы'
	END AS [ProjectType],
	CASE @RoundedType
		WHEN 0 THEN
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration]
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration],
	ISNULL([ActivityType].[FileAs],' ') AS [ActivityTypeFileAs]
FROM
	[TimeEntry]
	INNER JOIN [Employee]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
	INNER JOIN [ActivityType]
		ON [ActivityType].[ID] = [TimeEntry].[ActivityTypeID]
WHERE
	[TimeEntry].[State] IN (2,3,6) -- Отправлена на утверждение, Утверждена, Учтена
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND -- Сотрудник требуемой компании
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND -- Сотрудник требуемого подразделения
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)
	
SELECT 
	[@Result].[EmployeeName],
	[@Result].[ActivityType],
	[@Result].[ProjectType],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration],
	(SUM([@Result].[TimeDuration])/(SELECT SUM([@Result].[TimeDuration]) FROM @Result WHERE [@Result].[ProjectType] = 'Работа по договорам')*100) AS [Percent],
	[@Result].[ActivityTypeFileAs]
FROM 
	@Result
WHERE
	[@Result].[ProjectType] = 'Работа по договорам'
GROUP BY 
	[@Result].[EmployeeName],
	[@Result].[ProjectType],
	[@Result].[ActivityType],
	[@Result].[ActivityTypeFileAs]
UNION
SELECT 
	[@Result].[EmployeeName],
	[@Result].[ActivityType],
	[@Result].[ProjectType],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration],
	(SUM([@Result].[TimeDuration])/(SELECT SUM([@Result].[TimeDuration]) FROM @Result WHERE [@Result].[ProjectType] = 'Прочие работы')*100) AS [Percent],
	[@Result].[ActivityTypeFileAs]
FROM 
	@Result
WHERE
	[@Result].[ProjectType] = 'Прочие работы'
GROUP BY 
	[@Result].[EmployeeName],
	[@Result].[ProjectType],
	[@Result].[ActivityType],
	[@Result].[ActivityTypeFileAs]
UNION
SELECT
	ISNULL( [Employee].[LastName],[Employee].[FileAs] ) AS [EmployeeName],
	'',
	'',
	NULL,
	NULL,
	''
FROM
	[Employee]
WHERE
	[Employee].[State] = 1
	AND -- Сотрудник требуемой компании
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND -- Сотрудник требуемого подразделения
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)

------------------------------------------------------------------------------------------------------------

-- Заполнение шапки
EXEC ReportProjectTimeAllocationByEmployeeHeader
	    @CompanyID,
        @DivisionID ,
        @PeriodName,
        @PeriodStart,
        @PeriodEnd,
        @RoundedType

RETURN 0
GO

GRANT EXEC ON ReportEmployeeTimeByActivity TO PUBLIC
GO