IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployment')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployment'
		DROP  Procedure  ReportEmployment
	END

GO

PRINT 'Creating Procedure ReportEmployment'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportEmployment
	@EmployeeID		TIdentifier
AS
	SET NOCOUNT ON
	DECLARE
		@TodayDate			datetime,
		@curentyear			int,
		@YearEnd			datetime,
		@PlanMonthEnd		datetime,
		@ActualMonthStart	datetime
		
	SET @TodayDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	SET @curentyear = DATEPART(yyyy, @TodayDate)
	SET @YearEnd = CAST(CONVERT(varchar(8), Str(@curentyear, 4, 0) + '1231', 112) AS datetime )
	SET @PlanMonthEnd = DATEADD(month, 12, @TodayDate)
	SET @ActualMonthStart = DATEADD(month, -12, @TodayDate)	

	SELECT 
		@EmployeeID = [ID]
	FROM 
		[Employee] 
	WHERE 
		([Employee].[ID] = @EmployeeID) OR
		(@EmployeeID IS NULL AND [UserID] = dbo.adfGetCurrentUserID())
		
	EXECUTE ReportEmploymentHeader @EmployeeID, @TodayDate, @YearEnd, @PlanMonthEnd, @ActualMonthStart
	
	SELECT
	1 AS [Table],
	[ProjectType].[ID] AS [ProjectTypeID],
	[ProjectType].[FileAs] AS [ProjectType],
	SUM(CASE
		WHEN [BusyEntry].[Date] > @TodayDate AND CAST(CONVERT(varchar(8), [BusyEntry].[Date], 112) AS DATETIME) <= @YearEnd 
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled])/ 60.00
		ELSE 0 END) AS [Hours]
	FROM
		[ProjectType]
		LEFT OUTER JOIN [Project]
			ON [Project].[ProjectTypeID] = [ProjectType].[ID]
		LEFT OUTER JOIN [BusyEntry]
			ON [BusyEntry].[ProjectID] = [Project].[ID] AND
				 [BusyEntry].[EmployeeID] = @EmployeeID
	WHERE [Project].[State] in(1,2,3,4)	 AND ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) != 0		 	
	GROUP BY
		[ProjectType].[ID],
		[ProjectType].[FileAs]	
	UNION ALL
	SELECT
	2 AS [Table],
	[ProjectType].[ID],
	[ProjectType].[FileAs],
	SUM(CASE
		WHEN [BusyEntry].[Date] > @TodayDate AND CAST(CONVERT(varchar(8), [BusyEntry].[Date], 112) AS DATETIME) <= @PlanMonthEnd 
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0 END)
	FROM
		[ProjectType]
		LEFT OUTER JOIN [Project]
			ON [Project].[ProjectTypeID] = [ProjectType].[ID]
		LEFT OUTER JOIN [BusyEntry]
			ON [BusyEntry].[ProjectID] = [Project].[ID] AND
				 [BusyEntry].[EmployeeID] = @EmployeeID
	WHERE [Project].[State] in(1,2,3,4)	 AND ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) != 0				 	
	GROUP BY
		[ProjectType].[ID],
		[ProjectType].[FileAs]		
	UNION ALL
	SELECT
	3 AS [Table],
	[ProjectType].[ID],
	[ProjectType].[FileAs] AS [ProjectType],
	SUM(CASE
		WHEN CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) AS DATETIME) >= @ActualMonthStart AND CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @TodayDate
		THEN [TimeEntry].[Duration] / 60.00
		ELSE 0 END) AS [Actual12month]
	FROM
		[ProjectType]
		LEFT OUTER JOIN [Project]
			ON [Project].[ProjectTypeID] = [ProjectType].[ID]
		LEFT OUTER JOIN [TimeEntry]
			ON ([Project].[ID] = [TimeEntry].[ProjectID] AND [TimeEntry].[State]in(3,6))
			
	WHERE [Project].[State] in(1,2,3,4) AND [TimeEntry].[EmployeeID] = @EmployeeID 	
	GROUP BY
		[ProjectType].[ID],
		[ProjectType].[FileAs]	
		

RETURN 0
GO

GRANT EXEC ON ReportEmployment TO PUBLIC

GO
