IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmploymentHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportEmploymentHeader'
		DROP  Procedure  ReportEmploymentHeader
	END

GO

PRINT 'Creating Procedure ReportEmploymentHeader'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportEmploymentHeader
	@EmployeeID			TIdentifier,
	@TodayDate			datetime,
	@YearEnd			datetime,
	@PlanMonthEnd		datetime,
	@ActualMonthStart	datetime
AS
	SET NOCOUNT ON
	DECLARE
		@UserID			TIdentifier,
		@UserName		TName,
		@EmployeeName	TName,
		@DimensionID	TIdentifier,
		@CompanyName	TName,
		@CompanyID		TIdentifier,
		@Qualification	TName
							
	SET @UserID = dbo.adfGetCurrentUserID()
			
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	SELECT
		@DimensionID = [Employee].[ID],
		@EmployeeName = [Employee].[FileAs],
		@CompanyName = [Company].[FileAs],
		@CompanyID = [Company].[ID],
		@Qualification = [Qualification].[FileAs],
		@ActualMonthStart = CASE
								WHEN ([Employee].[HireDate] IS NOT NULL AND [Employee].[HireDate] > @ActualMonthStart)
								THEN [Employee].[HireDate]
								WHEN ([Employee].[HireDate] IS NOT NULL AND CAST(CONVERT(varchar(8), [Employee].[HireDate], 112) AS DATETIME) <= @ActualMonthStart)
								THEN @ActualMonthStart
								WHEN [Employee].[HireDate] IS NULL
								THEN @ActualMonthStart
							END	
	FROM 
		[Employee]
		LEFT OUTER JOIN [Company]
			ON [Employee].[CompanyID] = [Company].[ID]
		LEFT OUTER JOIN [Qualification]
			ON [Employee].[QualificationID]	= [Qualification].[ID]
	WHERE
		[Employee].[ID] = @EmployeeID 
	
	SELECT
		@EmployeeName AS [Name],
		@DimensionID AS [DimensionID],
		@CompanyName AS [CompanyName],
		@Qualification AS [Qualification],
		@TodayDate AS [TodayDate],
		(SUM(CASE 
			WHEN [CompanyCalendar].[Date] > @TodayDate AND [CompanyCalendar].[Date] <= @YearEnd
			THEN [CompanyCalendar].[Working]
			ELSE 0 END) / 60) AS [PlanYearHours],
		(SUM(CASE 
			WHEN [CompanyCalendar].[Date] > @TodayDate AND [CompanyCalendar].[Date] <= @PlanMonthEnd 
			THEN [CompanyCalendar].[Working]
			ELSE 0 END) / 60) AS [Plan12monthHours],
		(SUM(CASE 
			WHEN [CompanyCalendar].[Date] >= @ActualMonthStart AND [CompanyCalendar].[Date] <= @TodayDate
			THEN [CompanyCalendar].[Working]
			ELSE 0 END) / 60) AS [Actual12monthHours],
		@UserName AS [UserName]		
	FROM
		[CompanyCalendar]
	WHERE
		[CompanyCalendar].[CompanyID] =	@CompanyID	

RETURN 0
GO

GRANT EXEC ON ReportEmploymentHeader TO PUBLIC

GO
