IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportIssue')
	BEGIN
		PRINT 'Dropping Procedure ReportIssue'
		DROP  Procedure  ReportIssue
	END

GO

PRINT 'Creating Procedure ReportIssue'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportIssue
	@ID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE
		@ProjectID TIdentifier,
		@UserID			TIdentifier,
		@UserName		TName,
		@current		int,
		@IsFinanceEnable	bit,
		@ViewAllFinance TBool,
		@ViewFinance TBool,
		@CurrentEmployeeID TIdentifier,
		@IsPM TBool,
		@IsMember TBool,
		@AdvancedTimeExpenses bit,
		@value TVariant
		
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @IsPM = dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID)
	SET @IsMember = @IsPM | dbo.fnPjm5IsProjectMember(@ProjectID, @CurrentEmployeeID)
	
	SET @IsFinanceEnable = @IsMember & @ViewFinance
	SET @IsFinanceEnable = @IsFinanceEnable | @ViewAllFinance | @IsPM
	
	EXEC adfParameterGet 'AdvancedTimeExpensesForm', 'Pjm5', @value OUTPUT
	SET @AdvancedTimeExpenses = ISNULL(CAST(@value AS BIT), 0)
	
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID		
		
	SELECT
		[Issue].[Number],
		[Issue].[Created],
		[Issue].[State],
		[Project].[Number] AS [ProjectName],
		NULL AS [TaskName],
		dbo.fnPjm5GetContactList([Issue].[ID], [Issue].[Class]) AS [Contacts],
		dbo.fnPjm5GetCategoryList([Issue].[ID], [Issue].[Class]) AS [Categories],
		[Employee].[FileAs] AS [Assignment],
		[Priority].[FileAs] AS [Priority],
		[Severity].[FileAs] AS [Severity],
		[Issue].[DueDate],
		[Issue].[UDF1],
		[Issue].[UDF2],
		[Issue].[UDF3],
		[Issue].[UDF4],
		[Resolution].[FileAs] AS [Resolution],
		[Issue].[EndTime],
		[Issue].[FileAs] AS [Subject],
		[Issue].[Comments],
		dbo.fnPjm5GetAttachmentList([Issue].[ID], [Issue].[Class]) AS [AttachmentList],
		@UserName AS [UserName],
		(SELECT
			CASE 
				WHEN [NamedListBinding].[UDFCaption] IS NOT NULL
				THEN CASE 
						WHEN RIGHT(RTRIM([NamedListBinding].[UDFCaption]),1) != ':'
						THEN ([NamedListBinding].[UDFCaption] + N':')
						ELSE [NamedListBinding].[UDFCaption]
					END	
				ELSE NULL		
			END
		FROM
			[NamedList]
			INNER JOIN [NamedListBinding]
				ON [NamedList].[ID] = [NamedListBinding].[NamedListID]
		WHERE
			[NamedList].[ProjectID] = [Project].[ID] AND [NamedListBinding].[UDFIndex] = 1) AS [UDF1Caption],
		(SELECT
			CASE 
				WHEN [NamedListBinding].[UDFCaption] IS NOT NULL
				THEN CASE 
						WHEN RIGHT(RTRIM([NamedListBinding].[UDFCaption]),1) != ':'
						THEN ([NamedListBinding].[UDFCaption] + N':')
						ELSE [NamedListBinding].[UDFCaption]
					END	
				ELSE NULL		
			END
		FROM
			[NamedList]
			INNER JOIN [NamedListBinding]
				ON [NamedList].[ID] = [NamedListBinding].[NamedListID]
		WHERE
			[NamedList].[ProjectID] = [Project].[ID] AND [NamedListBinding].[UDFIndex] = 2) AS [UDF2Caption],
		(SELECT
			CASE 
				WHEN [NamedListBinding].[UDFCaption] IS NOT NULL
				THEN CASE 
						WHEN RIGHT(RTRIM([NamedListBinding].[UDFCaption]),1) != ':'
						THEN ([NamedListBinding].[UDFCaption] + N':')
						ELSE [NamedListBinding].[UDFCaption]
					END	
				ELSE NULL		
			END
		FROM
			[NamedList]
			INNER JOIN [NamedListBinding]
				ON [NamedList].[ID] = [NamedListBinding].[NamedListID]
		WHERE
			[NamedList].[ProjectID] = [Project].[ID] AND [NamedListBinding].[UDFIndex] = 3) AS [UDF3Caption],
		(SELECT
			CASE 
				WHEN [NamedListBinding].[UDFCaption] IS NOT NULL
				THEN CASE 
						WHEN RIGHT(RTRIM([NamedListBinding].[UDFCaption]),1) != ':'
						THEN ([NamedListBinding].[UDFCaption] + N':')
						ELSE [NamedListBinding].[UDFCaption]
					END	
				ELSE NULL		
			END
		FROM
			[NamedList]
			INNER JOIN [NamedListBinding]
				ON [NamedList].[ID] = [NamedListBinding].[NamedListID]
		WHERE
			[NamedList].[ProjectID] = [Project].[ID] AND [NamedListBinding].[UDFIndex] = 4) AS [UDF4Caption],
		[Issue].[ManHour],
		[Issue].[ActualManHour],
		[Issue].[Budget],
		[Issue].[ActualBudget],
		ISNULL([Project].[CurrencyCode], 'RUB') AS [CurrencyCode],
		@IsFinanceEnable AS [HasFinanceAccess],
		@AdvancedTimeExpenses AS [AdvancedTimeExpenses]
	FROM
		[Issue]
		INNER JOIN [Project]
			ON [Issue].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [Employee]
			ON [Issue].[EmployeeID] = [Employee].[ID]
		INNER JOIN [Priority]
			ON [Issue].[PriorityID] = [Priority].[ID]
		INNER JOIN [Severity]
			ON [Issue].[SeverityID] = [Severity].[ID]
		LEFT OUTER JOIN [Resolution]
			ON [Issue].[ResolutionID] = [Resolution].[ID]
		
	WHERE
		[Issue].[ID] = @ID
	
	SELECT
		2								AS [Table],
		[TransitionTemplate].[Name]		AS [TransitionName],
		[FromState].[Name]				AS [FromStateName],
		[ToState].[Name]				AS [ToStateName],
		[Transition].[Created]			AS [Time],
		[Action].[Name]					AS [ActionName],
		[Trustee].[DisplayName]			AS [TrusteeName],
		0								AS [Level]
	FROM
		[Issue]
		INNER JOIN [Transition]
			ON [Issue].[Class] = [Transition].[Class] AND
				[Issue].[ID] = [Transition].[DocumentID]
		INNER JOIN [TransitionTemplate]
			ON	(	[TransitionTemplate].[ID] = [Transition].[TransitionTemplateID])
		LEFT OUTER JOIN [State] AS [FromState]
			ON	(	[FromState].[State] = [TransitionTemplate].[FromState]
				AND	[FromState].[Class] = [Transition].[Class])
		LEFT OUTER JOIN [State] AS [ToState]
			ON	(	[ToState].[State] = [TransitionTemplate].[ToState]
				AND	[ToState].[Class] = [Transition].[Class])
		INNER JOIN [Action]
			ON	(	[Action].[ID] = [TransitionTemplate].[ActionID])
		INNER JOIN [Trustee]
			ON	(	[Trustee].[ID] = [Transition].[UserID])
			
	WHERE
		[Issue].[ID] = @ID
	
	UNION ALL	
	SELECT
		1,
		[Issue].[Comments],
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		0
	FROM
		[Issue]
	WHERE
		[Issue].[ID] = @ID		
		
	UNION ALL
	SELECT
		3,
		NULL,
		NULL,
		NULL,
		[Note].[Created],
		[Note].[Text],
		[Trustee].[DisplayName],
		0
	FROM
		[Issue]
		INNER JOIN [Note]
			ON [Issue].[ID] = [Note].[DocumentID] AND
			   [Issue].[Class] = [Note].[DocumentClass]
		INNER JOIN [Trustee]
			ON ([Note].[CreatedBy] = [Trustee].[ID])
	WHERE
		[Issue].[ID] = @ID 
	ORDER BY 
		5 ASC

RETURN 0
GO

GRANT EXEC ON ReportIssue TO PUBLIC

GO
