IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportPortfolioOfProjects')
	BEGIN
		PRINT 'Dropping Procedure ReportPortfolioOfProjects'
		DROP  Procedure  ReportPortfolioOfProjects
	END

GO

PRINT 'Creating Procedure ReportPortfolioOfProjects'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportPortfolioOfProjects
	@StateSelector	int,
	@BillSelector   int,
	@CompanyID		TIdentifier,
	@ManagerID		TIdentifier,
	@DivisionSelector int,
	@DivisionID		TIdentifier
AS
	SET NOCOUNT ON
	IF @DivisionID IS NULL AND @DivisionSelector=2 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END
	
		
	EXECUTE ReportPortfolioOfProjectsHeader @CompanyID, @StateSelector, @ManagerID, @BillSelector, @DivisionID, @DivisionSelector
	
	DECLARE
		@t	TABLE(
			[ProjectID]		int,
			[WorkingDays]	int
		)

	INSERT INTO @t(
		[ProjectID],		
		[WorkingDays]
	)
	
	SELECT
		[Project].[ID],
		dbo.fnPjm5GetWorkingDays([Project].[Date], GETDATE())
	FROM [Project]
		INNER JOIN [Company] AS [SupplierCompany]
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]	
	WHERE
	
		(@StateSelector = 0 OR [Project].[State] = @StateSelector) AND
		([SupplierCompany].[ID] = @CompanyID OR @CompanyID IS NULL) AND
		(
		@BillSelector = 0 OR 
		(@BillSelector = 1 AND [Project].[ProjectTypeID] = 1) OR 
		(@BillSelector = 2 AND [Project].[ProjectTypeID] = 2) OR 
		(@BillSelector = 3 AND [Project].[ProjectTypeID] NOT IN (1, 2))
		) AND
		[Project].[State] NOT IN (5, 6)
		
		
	SELECT
		[Priority].[FileAs] AS [Priority],
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectCode],
		[CustomerCompany].[FileAs] AS [CustomerCompanyName],
		[Employee].[FileAs] AS [ManagerName],
		[Project].[State] AS [State],
		[Project].[Budget] AS [Budget],
		[Project].[CurrencyCode] AS [CurrencyCode]		
	FROM 
		@t tb
		INNER JOIN [Project]
			ON tb.[ProjectID] = [Project].[ID]
		INNER JOIN [Company] AS [SupplierCompany]
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Employee]
			ON [Project].[ProjectManagerEmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Division] 
				ON [Employee].[DivisionID] = [Division].[ID]
		LEFT OUTER JOIN [Priority]
			ON [Project].[PriorityID] = [Priority].[ID]	
	WHERE
		([Project].[ProjectManagerEmployeeID] = @ManagerID OR @ManagerID IS NULL)
		AND
		(
			@DivisionSelector = 0 OR 
			(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
			(@DivisionSelector = 2 AND ([Employee].[DivisionID] = @DivisionID OR (@DivisionID IS NULL AND [Employee].[DivisionID] IS NOT NULL)))
		)		
				   		
	RETURN 0
GO

GRANT EXEC ON ReportPortfolioOfProjects TO PUBLIC

GO
