IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProject')
	BEGIN
		PRINT 'Dropping Procedure ReportProject'
		DROP  Procedure  ReportProject
	END

GO

PRINT 'Creating Procedure ReportProject'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportProject
	@ID TIdentifier
AS

	SET NOCOUNT ON
	DECLARE
		@UserID			TIdentifier,
		@UserName		TName
		
	SET @UserID = dbo.adfGetCurrentUserID()
		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID

	SELECT
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectCode],
		[SupplierCompany].[FileAs] AS [SupplierCompanyName],
		[CostCenter].[FileAs] AS [CostCenter],
		[Employee].[FileAs] AS [ManagerName],
		[CustomerCompany].[FileAs] AS [CustomerCompanyName],
		[ResponsiblePerson].[FileAs] AS [ResponsiblePerson],
		[Project].[Date] AS [StartDate],
		ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) AS [EndDate],
		CASE
			WHEN ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) IS NOT NULL
			THEN dbo.fnPjm5GetWorkingDays(GETDATE(), ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]))
			ELSE NULL
		END AS [Remains],
		CASE
			WHEN ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) IS NOT NULL
			THEN dbo.fnPjm5GetWorkingDays(ISNULL(DATEADD(day, 1, [Project].[EndDate]), DATEADD(day, 1, [ProjectDetail].[DueDate])), GETDATE())
			ELSE NULL
		END AS [Exceed], 
		[Project].[State] AS [State],
		@UserName AS [UserName],
		[ProjectType].[FileAs] AS [ProjectType],
		[Currency].[FileAs] AS [CurrencyName],
		[Project].[CurrencyCode] AS [CurrencyCode],
		[Priority].[FileAs] AS [Priority],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		dbo.fnPjm5GetContactList([Project].[ID], [Project].[Class]) AS [Contacts],
		dbo.fnPjm5GetCategoryList([Project].[ID], [Project].[Class]) AS [Categories],
		dbo.fnPjm5GetActivityTypeListByProject([Project].[ID]) AS [ActivityType],
		dbo.fnPjm5GetAttachmentList([Project].[ID], [Project].[Class]) AS [AttachmentList]
	FROM 
		[Project]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		INNER JOIN [ProjectType]
			ON [Project].[ProjectTypeID] = [ProjectType].[ID]
		INNER JOIN [Currency]
			ON [Project].[CurrencyCode] = [Currency].[Code]
		INNER JOIN [Priority]
			ON [Project].[PriorityID] = [Priority].[ID]		
		LEFT OUTER JOIN [Company] AS [CustomerCompany]
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]	
		LEFT OUTER JOIN [Employee]
			ON [Project].[ProjectManagerEmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [CostCenter]
			ON [Project].[CostCenterID] = [CostCenter].[ID]
		LEFT JOIN [Employee] AS [ResponsiblePerson]
			ON [Project].[ResponsiblePersonEmployeeID] = [ResponsiblePerson].[ID]				
	WHERE
		[Project].[ID] = @ID
		
	SELECT
		1 AS [Table],
		[Assignment].[FileAs] AS [Name], --
		[Qualification].[FileAs] AS [Qualification], --
		[Assignment].[State] AS [State],-- (/)
		NULL AS [Date],
		dbo.fnPjm5GetTaskListByAssignment([Assignment].[ID]) AS [List]		
	FROM
		[Assignment]
		LEFT OUTER JOIN [Qualification]
			ON [Assignment].[QualificationID] = [Qualification].[ID]		
	WHERE
		[Assignment].[ProjectID] = @ID 
	UNION ALL
	SELECT NULL, NULL, NULL, 0, NULL, NULL		  	
	UNION ALL
	SELECT
		2,
		[Task].[FileAs],--
		NULL,
		[Task].[State],-- 
		[Task].[DueDate],--		
		dbo.fnPjm5GetAssignmentListByTask([Task].[ID])
	FROM
		[Task]
	WHERE
		[Task].[ProjectID] = @ID
	ORDER BY 3
			

RETURN 0
GO

GRANT EXEC ON ReportProject TO PUBLIC

GO
