IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectReport')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectReport'
		DROP  Procedure  ReportProjectReport
	END

GO

PRINT 'Creating Procedure ReportProjectReport'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportProjectReport
	@ProjectSelector INT,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier
	
AS
	SET NOCOUNT ON
		
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE 
		@ProjectID TIdentifier
		
	SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END	
			
	SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED		
	SET NOCOUNT ON
	DECLARE @value TVariant,
			@WorkTime decimal(18,2),
			@Counter  decimal(18,2)
		
			
	EXECUTE ReportProjectReportHeader @ProjectID
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
	SET @WorkTime = @WorkTime / 60.00
	
	DECLARE
		@f	table(
			[ID]   int,
			[Fact] decimal(18,2)
		)
	INSERT INTO @f(
		[ID],
		[Fact]
		)
			
	SELECT
		[Assignment].[ID],
		SUM([TimeEntry].[Duration]) / 60.0
	FROM
		[Assignment]
		LEFT OUTER JOIN [TimeEntry]
			ON [TimeEntry].[AssignmentID] = [Assignment].[ID] AND
				[TimeEntry].[State]in(2,3,6)
	WHERE
		[Assignment].[ProjectID] = @ProjectID
	GROUP BY 
		[Assignment].[ID]	
		
	
	DECLARE
		@t	table(
			[Table]		int,
			[String1]	varchar(256),
			[String2]	varchar(256),
			[String3]	varchar(256),
			[State]		int,
			[Data1]		decimal(18,2),
			[Data2]		decimal(18,2),
			[Data3]		decimal(18,2),
			[Data4]		decimal(18,2),
			[Data5]		decimal(18,2),
			[Data6]		decimal(18,2),
			[Data7]		decimal(18,2),
			[Date1]		datetime,
			[Date2]		datetime
		)
	;WITH [SummaryTask] ([ID], [SubCount]) AS
	(
		SELECT
			[Parent].[ID],
			COUNT([Child].[ID]) 
		FROM 
			[Task] AS [Parent] 
			LEFT OUTER JOIN [Task] AS [Child] 
				ON [Child].[ParentID] = [Parent].[ID]
		WHERE
			[Parent].[ProjectID] = @ProjectID
		GROUP BY
			[Parent].[ID]
	)	
	INSERT INTO @t(
		[Table],
		[String1],
		[String2],
		[String3],
		[State],
		[Data1],
		[Data2],
		[Data3],
		[Data4],
		[Data5],
		[Data6],
		[Data7],
		[Date1],
		[Date2]
	)
	
	SELECT
		1, --   
		[Assignment].[FileAs], --
		[Qualification].[FileAs], --
		NULL,
		[Assignment].[State],-- (/)
		SUM(([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00), -- 
		[FactTable].[Fact], --   
		SUM(CASE WHEN [BusyEntry].[Date] <= CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
			THEN (([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
			ELSE 0 END
		),--   
		0,
		0,
		0,
		0,
		NULL,
		NULL
	FROM
		[vwAssignment] AS [Assignment]
		LEFT OUTER JOIN [Qualification]
			ON [Assignment].[QualificationID] = [Qualification].[ID]
		LEFT OUTER JOIN [BusyEntry]
			ON [Assignment].[ID] = [BusyEntry].[AssignmentID] AND
			   [BusyEntry].[ProjectID]	= @ProjectID
		LEFT OUTER JOIN @f as [FactTable]
			ON [Assignment].[ID] = [FactTable].[ID]
	WHERE
		[Assignment].[ProjectID] = @ProjectID AND
		(([FactTable].[Fact] IS NOT NULL AND [Assignment].[State] = 2) OR ([Assignment].[State] = 1))	
	GROUP BY
		[Assignment].[FileAs],
		[Qualification].[FileAs],
		[Assignment].[State],
		[FactTable].[Fact]
		
		
	UNION
	SELECT
		2, --    
		CASE WHEN
			[Task].[SubprojectID] IS NULL
			THEN
				[Task].[FileAs]
			ELSE
				[Project].[FileAs]
		END, -- 
		NULL,
		NULL,
		[Task].[State],-- 
		[Task].[Duration],--    
		CASE
			WHEN [Task].[ManHour] IS NULL OR [Task].[ManHour] = 0
			THEN 0
		ELSE [Task].[PlannedManHour] / ([Task].[ManHour] / 60.00) * 100
		END, -- %  
		CASE
			WHEN [Task].[ManHour] IS NULL OR [Task].[ManHour] = 0
			THEN 0
		ELSE [Task].[RealManHourNullable] / ([Task].[ManHour] / 60.00) * 100
		END, -- %  	
		[Task].[RealManHourNullable] AS [RealManHour1],--  
		[Task].[PlannedManHour],--  
		[Task].[ManHour] / 60.00, --  
		[Task].[PercentComplete] * 100,--, %
		[Task].[DueDate],--
		[Task].[StartDate]-- 
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN [SummaryTask] ON
		(
			[SummaryTask].[ID] = [Task].[ID]
			AND
			[SummaryTask].[SubCount] = 0
		)
		LEFT OUTER JOIN [Project]
			ON [Project].[ID] = [Task].[SubprojectID]
	WHERE
		[Task].[ProjectID] = @ProjectID
	
	UNION
	SELECT
		3, --  
		CASE WHEN
			[Task].[SubprojectID] IS NULL
			THEN
				[Task].[FileAs]
			ELSE
				[SubProject].[FileAs]
		END, -- 
		NULL, 
		[Project].[CurrencyCode],
		[Task].[State],
		0,
		[Task].[Budget], --  
		CASE
			WHEN [Task].[Budget] IS NULL OR [Task].[Budget] = 0
			THEN 0
		ELSE ISNULL(([Task].[PlannedBudget] / [Task].[Budget] * 100), 0)
		END, -- %  
		CASE
			WHEN [Task].[Budget] IS NULL OR [Task].[Budget] = 0
			THEN 0
		ELSE ISNULL((([Task].[TimeRealBudget] + [Task].[ExpenseRealBudget]) / [Task].[Budget] * 100), 0)
		END, -- %  	
		[Task].[TimeRealBudget] + [Task].[ExpenseRealBudget],--  
		0,
		[Task].[PlannedBudget],--  	
    	NULL,
    	NULL
	FROM 
		[pjm5vwTask] AS [Task]
		INNER JOIN [Project]
			ON 	[Task].[ProjectID] = [Project].[ID]
		INNER JOIN [SummaryTask] ON
		(
			[SummaryTask].[ID] = [Task].[ID]
			AND
			[SummaryTask].[SubCount] = 0
		)
		LEFT OUTER JOIN [Project] AS [SubProject]
			ON [SubProject].[ID] = [Task].[SubprojectID]
	WHERE
		[Task].[ProjectID] = @ProjectID
				
	SELECT
		[Table],
		[String1],
		[String2],
		[String3],
		[State],
		[Data1],
		[Data2],
		[Data3],
		[Data4],
		[Data5],
		[Data6],
		[Data7],
		[Date1],
		[Date2]
	FROM
		@t
	UNION
	SELECT
		0,
		NULL,
		NULL,
		NULL,
		0,
		0,
		0,
		0,
		0,
		0,
		0,
		0,
		NULL,
		NULL	

RETURN 0
GO

GRANT EXEC ON ReportProjectReport TO PUBLIC

GO
