IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectTimeAllocationByEmployee')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectTimeAllocationByEmployee'
		DROP  Procedure  ReportProjectTimeAllocationByEmployee
	END
GO
PRINT 'Creating Procedure ReportProjectTimeAllocationByEmployee'
GO
/******************************************************************************
**		File: ReportProjectTimeAllocationByEmployee.sql
**		Name: ReportProjectTimeAllocationByEmployee
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 18/11/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		18.11.2010	MAN				First Version
*******************************************************************************/

CREATE PROCEDURE [dbo].[ReportProjectTimeAllocationByEmployee]
        @CompanyID		TIdentifier, -- ID 
        @DivisionID		TIdentifier, -- ID 
        @DateSelector	TIdentifier, --    (SelectedIndex  )
        @PeriodStart	TdateTime,	 --   
		@PeriodEnd		TdateTime,	 --   
		@RoundedType	TIdentifier  --    : 0 -  , 1 -  
AS
SET NOCOUNT ON

--  
IF  dbo.adfHasAccessRightByName('ViewProjectTimeAllocationByEmployeeReport') = 0 
BEGIN
      RAISERROR('#NotEnoughPermissions', 18, -1)
      RETURN 1
END

DECLARE
	@PeriodName TName --  
-- 
EXEC ReportGetPeriod 
	@DateSelector,			--   
	@PeriodStart OUTPUT,	--  
	@PeriodEnd	 OUTPUT,	--  
	@PeriodName  OUTPUT		--  
-- 	
DECLARE @Result TABLE        
(
	EmployeeName	TName,		 --  
	ProjectNumber	TName,		 --  
	ProjectOrder	TIdentifier, --    
	TimeDuration	TAmount		 -- 
)
--   (  )
INSERT INTO @Result
(
	EmployeeName,
	ProjectNumber,
	ProjectOrder,
	TimeDuration
)
SELECT
	ISNULL( [Employee].[LastName],[Employee].[FileAs] ) AS [EmployeeName], --   ,   " "
	'', --   (  )
	0, --     
	CASE @RoundedType --    
		WHEN 0 THEN --   
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration] 
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration] 
FROM
	[TimeEntry]
	INNER JOIN [Employee]  --         
		ON [TimeEntry].[EmployeeID] = [Employee].[ID] 
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[TimeEntry].[State] IN (2,3,6) --   , , 
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND --   
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND --   
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)
--  ""   
INSERT INTO @Result
(
	EmployeeName,
	ProjectNumber,
	ProjectOrder,
	TimeDuration
)
SELECT
	ISNULL( [Employee].[LastName],[Employee].[FileAs] ) AS [EmployeeName],
	CASE [Project].[ProjectTypeID] --   
		WHEN 1 THEN '  '
		WHEN 2 THEN ' '
		WHEN 3 THEN ' '
		WHEN 4 THEN ''
		WHEN 5 THEN ''
		WHEN 6 THEN ''
	END AS [ProjectNumber],
	[Project].[ProjectTypeID], --        
	CASE @RoundedType
		WHEN 0 THEN
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration]
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration]
FROM
	[TimeEntry]
	INNER JOIN [Employee]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[TimeEntry].[State] IN (2,3,6) --   , , 
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND --   
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND --   
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)
--  ""   
INSERT INTO @Result
(
	EmployeeName,
	ProjectNumber,
	ProjectOrder,
	TimeDuration
)
SELECT
	ISNULL( [Employee].[LastName],[Employee].[FileAs] ) AS [EmployeeName],
	[Project].[Number] AS [ProjectNumber],
	7, --  :   
	CASE @RoundedType
		WHEN 0 THEN
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration]
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration]
FROM
	[TimeEntry]
	INNER JOIN [Employee]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[Project].[ProjectTypeID] = 1 --   
	AND
	[TimeEntry].[State] IN (2,3,6) --   , , 
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND --   
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND --   
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)

--  
SELECT
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]

SELECT
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
		
--  
EXEC ReportProjectTimeAllocationByEmployeeHeader
	    @CompanyID,
        @DivisionID ,
        @PeriodName,
        @PeriodStart,
        @PeriodEnd,
        @RoundedType
        
RETURN 0
GO

GRANT EXEC ON ReportProjectTimeAllocationByEmployee TO PUBLIC
GO

