IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRevenueAnalysisByClients')
	BEGIN
		PRINT 'Dropping Procedure ReportRevenueAnalysisByClients'
		DROP  Procedure  ReportRevenueAnalysisByClients
	END

GO

PRINT 'Creating Procedure ReportRevenueAnalysisByClients'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE PROCEDURE [dbo].[ReportRevenueAnalysisByClients]
      @CompanyID TIdentifier,
      @CurrencySelector int,
      @ManagerID TIdentifier,
      @CostCenterID TIdentifier,
	  @CompanyManagerSelector int,
	  @CostCenterSelector int,
      @ServiceTypeID TIdentifier,
      @ServiceTypeSelector int,
      @InvoiceSelector int,
      @DateSelector int,
      @CountSelector int,
      @Count	int
AS

SET NOCOUNT ON

   DECLARE 
          @PeriodStart TDate,
          @PeriodEnd TDate,
          @CurrencyCode TCode3,
          @Value TVariant,
          @TotalRevenue float,
          @Rate float,
          @Prefix varchar(5),
          @ToCurrencyCode TCode3

   
  DECLARE @RevenueHeader Table(CompanyName TName,
                               CurrencyCode nvarchar(32),
                               ManagerName TName,
                               CostCenterName TName,
                               ServiceTypeName TName,
                               SeriveIncludedName  TName,
                               InvoiceState TName,
                               DatePeriod TName, 
                               UserName TName,
                               [Count] TName)
  INSERT INTO @RevenueHeader(CompanyName, 
                             CurrencyCode,
                             ManagerName,
                             CostCenterName,
                             ServiceTypeName,
                             SeriveIncludedName,
                             InvoiceState,
                             DatePeriod, 
                             UserName,
                             [Count])
	EXEC ReportRevenueAnalysisByClientsHeader
              @CompanyID, @CurrencySelector, @ManagerID, @CompanyManagerSelector, @CostCenterID, @CostCenterSelector, 
			  @ServiceTypeID, @ServiceTypeSelector, @InvoiceSelector, @DateSelector,
              @CountSelector, @Count
   
   EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @CurrencyCode = CAST(@Value AS nvarchar(32))
   
    
   EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @ToCurrencyCode = CAST(@Value AS nvarchar(32))
   

   SET @PeriodEnd = GETDATE()

   IF @DateSelector = 0
           SET @PeriodStart = DATEADD(year, 0, GETDATE())
   IF @DateSelector = 1
           SET @PeriodStart = DATEADD(year, -1, GETDATE())
   IF @DateSelector = 2
           SET @PeriodStart = DATEADD(year, -2, GETDATE())

   SET @PeriodStart = convert(char(8),dateadd(day,1-datepart(dayofyear,@PeriodStart),@PeriodStart),112)
   
   
   DECLARE @CustomerRevenue TABLE (CompanyName TName, Manager TName,
                                   ProjectCount int, ActiveProjectCount int,
                                   AverageSum float, InvoiceCount int,
                                   Debt float, Revenue float,
                                   PayTerm int, Percentage float)
INSERT INTO @CustomerRevenue 
(	
	CompanyName, 
	Manager,
    ProjectCount, 
	ActiveProjectCount,
    AverageSum, 
	InvoiceCount,
    Debt, 
	Revenue,
    PayTerm
)
SELECT 
	[CustomerCompany].[FileAs] AS CompanyName,
    (CASE  WHEN [ManagerEmployee].[FileAs] IS NOT NULL THEN [ManagerEmployee].[FileAs] ELSE '( )' END)  AS Manager,
    COUNT(DISTINCT [Projects].[ID]) AS AllCount,
    COUNT(DISTINCT CASE Projects.[State] WHEN 2 THEN [Projects].[ID] ELSE NULL END) AS ActiveCount,
    ISNULL(AVG([Invoices].[Revenue]),0) AS AverageSum,
    COUNT(DISTINCT [Invoices].[ID]) AS InvoiceCount,
    CASE @CurrencySelector
		WHEN 0 THEN 
			SUM(CASE[Invoices].[State] 
					WHEN 2 THEN [Invoices].[TotalWithVATBC] - ISNULL(Payments.PaySum,0) 
					ELSE 0 END)
        WHEN 1 THEN 
			SUM(CASE[Invoices].[State] 
					WHEN 2 THEN [Invoices].[TotalWithVATBC] - 
					ISNULL(Payments.PaySum*dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoices].[Date], @ToCurrencyCode),0) 
					ELSE 0 END) 
	END AS Debt,
    ISNULL(SUM([Invoices].[Revenue]),0) AS Revenue,
    ISNULL(AVG(DATEDIFF(day,[Invoices].[Date],[Payments].[PayDate])+1),0) as PayTerm
FROM (	SELECT 
			[Invoice].[ID],
			[Invoice].[State],
			CASE @CurrencySelector 
				WHEN 0 THEN SUM([InvoiceLine].[TotalWithVATBC])
				WHEN 1 THEN SUM([InvoiceLine].[TotalWithVATBC])*
					dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoice].[Date], @ToCurrencyCode)
			END AS Revenue,
			CASE @CurrencySelector
				WHEN 0 THEN [Invoice].[TotalWithVATBC]
				WHEN 1 THEN [Invoice].[TotalWithVATBC] *
					dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoice].[Date], @ToCurrencyCode) 
			END AS TotalWithVATBC,
			[Invoice].[Date],
			[Invoice].[ProjectID]
		FROM 
			[InvoiceLine]
			LEFT OUTER JOIN ServiceType
				ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
			INNER JOIN [Invoice]
				ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
        WHERE 
		(
			(@InvoiceSelector = 0 AND [Invoice].[State] = 5) 
			OR 
			(@InvoiceSelector = 1 AND [Invoice].[State] IN (2,5))			
		) 
		AND
		(
			@DateSelector = 3 
			OR 
			(@DateSelector IN (0, 1, 2) AND [Invoice].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
		) 
		AND 
		(
			@ServiceTypeSelector = 0 
			OR
			@ServiceTypeSelector = 1 AND (([InvoiceLine].[ServiceTypeID] IS NOT NULL AND [ServiceType].[RatesDepended] = 1) OR [InvoiceLine].[ServiceTypeID] IS NULL)
			OR
			@ServiceTypeSelector = 2 AND [ServiceType].[RatesDepended] = 0 
			OR
			@ServiceTypeSelector = 3 AND ISNULL(@ServiceTypeID, 0) = ISNULL([InvoiceLine].[ServiceTypeID], 0)
		) 
		GROUP BY 
			[Invoice].[ID], 
			[Invoice].[State],
			[Invoice].[TotalWithVATBC],
			[Invoice].[Date], 
			[Invoice].[ProjectID], 
			[Invoice].[BaseCurrencyRate],
			[Invoice].[CurrencyRate] 
		) AS Invoices

LEFT JOIN (	SELECT 
				[PaymentDetail].[InvoiceID],
                SUM([Payment].[TotalWithVATBC]) AS PaySum,
                MAX([Payment].[Date]) AS PayDate
			FROM 
				[Payment]
				INNER JOIN [PaymentDetail] 
					ON [PaymentDetail].[PaymentID] = [Payment].[ID]
			GROUP BY 
				[PaymentDetail].[InvoiceID]) AS Payments
	ON [Payments].[InvoiceID] = [Invoices].[ID]
RIGHT JOIN [Project] AS Projects
	ON [Invoices].[ProjectID] = [Projects].[ID]
INNER JOIN [Company] CustomerCompany
	ON [Projects].[CustomerCompanyID] = [CustomerCompany].[ID]
LEFT OUTER JOIN [Employee] ManagerEmployee 
	ON [CustomerCompany].[ManagerEmployeeID] = [ManagerEmployee].[ID]
WHERE 
(
	/*[CustomerCompany].[ManagerEmployeeID] = @ManagerID 
	OR 
	@ManagerID IS NULL*/
	@CompanyManagerSelector = 0
	OR
	(@CompanyManagerSelector = 1 AND ISNULL([CustomerCompany].[ManagerEmployeeID], 0) = ISNULL(@ManagerID, 0)) 
)
AND
(
	[Projects].[SupplierCompanyID] = @CompanyID 
	OR 
	@CompanyID IS NULL
) 
AND
(
	@CostCenterSelector = 0
	OR
	(@CostCenterSelector = 1 AND ISNULL([Projects].[CostCenterID], 0) = ISNULL(@CostCenterID, 0)) 
)
GROUP BY 
	[CustomerCompany].[ID], 
	[CustomerCompany].[FileAs], 
	[ManagerEmployee].[FileAs]
ORDER by 
	[Revenue]  DESC,
	[Manager]	ASC

   SELECT @TotalRevenue = SUM([Revenue]) FROM @CustomerRevenue
       
   SET @Rate = CASE  
                 WHEN @TotalRevenue<1000 THEN 1
                 WHEN @TotalRevenue>=1000 and @TotalRevenue<10000000 THEN 0.001
                 WHEN @TotalRevenue>=10000000 and @TotalRevenue<10000000000 THEN 0.000001
                 WHEN @TotalRevenue>=10000000000 THEN 0.000000001
               END
   SET @Prefix = CASE  
                 WHEN @TotalRevenue<1000 THEN ''
                 WHEN @TotalRevenue>=1000 and @TotalRevenue<10000000 THEN '.'
                 WHEN @TotalRevenue>=10000000 and @TotalRevenue<10000000000 THEN '.'
                 WHEN @TotalRevenue>=10000000000 THEN '.'
               END


   UPDATE @CustomerRevenue
   SET Percentage = CASE WHEN @TotalRevenue = 0 THEN 0
                         ELSE Revenue*100/@TotalRevenue
                    END,
       AverageSum = AverageSum * @Rate,
       Debt = Debt * @Rate,
       Revenue = Revenue * @Rate

   UPDATE @RevenueHeader
   SET CurrencyCode = @Prefix + CurrencyCode    
   
   SELECT * FROM  @RevenueHeader

   IF @CountSelector = 3
      SELECT * 
      FROM @CustomerRevenue
   ELSE
      SELECT TOP(CASE @CountSelector WHEN 0 THEN 5 
                                     WHEN 1 THEN 10 
                                     WHEN 2 THEN @Count
                 END) *
      FROM @CustomerRevenue
    

RETURN 0
GO

GRANT EXEC ON ReportRevenueAnalysisByClients TO PUBLIC

GO

