IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTotalOfEmployees')
	BEGIN
		PRINT 'Dropping Procedure ReportTotalOfEmployees'
		DROP  Procedure  ReportTotalOfEmployees
	END

GO

PRINT 'Creating Procedure ReportTotalOfEmployees'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportTotalOfEmployees
	@DateSelector	int,
	@PeriodStart	TDateTime,
	@PeriodEnd		TDateTime
	
AS
	SET NOCOUNT ON
	SET DATEFIRST 1
    DECLARE 
		@Date datetime,
		@DayCount int,
		@MonthCount int,
		@QuarterCount int		
	
	SELECT 
		@Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME),
		@DayCount = DATEPART(day,@Date),
		@MonthCount = DATEPART(month,@Date),
		@QuarterCount = DATEPART(quarter,@Date)
		
	SET	@PeriodStart = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1 - DATEPART(weekday, @Date), @Date)
			WHEN 1 THEN DATEADD(week, -1, DATEADD(day, 1 - DATEPART(weekday, @Date), @Date))
			WHEN 2 THEN DATEADD(day, 1 - @DayCount, @Date)
			WHEN 3 THEN DATEADD(month, -1, DATEADD(day, 1 - @DayCount, @Date))
			WHEN 4 THEN DATEADD(quarter,@QuarterCount-1,DATEADD(month, 1 - @MonthCount, DATEADD(day, 1 - @DayCount, @Date)))
			WHEN 5 THEN DATEADD(quarter,@QuarterCount-2,DATEADD(month, 1 - @MonthCount, DATEADD(day, 1 - @DayCount, @Date)))
			ELSE CAST(CONVERT(varchar(8), @PeriodStart, 112) AS DATETIME)
	END
	SET	@PeriodEnd = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1, @Date)
			WHEN 1 THEN DATEADD(week, 1, @PeriodStart)
			WHEN 2 THEN DATEADD(day, 1, @Date)
			WHEN 3 THEN DATEADD(month, 1, @PeriodStart)
			WHEN 4 THEN DATEADD(day, 1, @Date)	    
			WHEN 5 THEN DATEADD(quarter, 1, @PeriodStart)
			ELSE CASE
				WHEN @PeriodEnd > @PeriodStart THEN DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS DATETIME))
				ELSE DATEADD(day, 1, @PeriodStart)
			END
	END
	
	IF @PeriodStart > GETDATE()
	BEGIN
		RAISERROR('#CannotGetFutureReport', 16, -1)
		RETURN 1
	END	
	
	EXECUTE ReportTotalOfEmployeesHeader @DateSelector, @PeriodStart, @PeriodEnd 
	
	SELECT
		[Employee].[FileAs] AS [EmployeeName],
		[Qualification].[FileAs] AS [Qualification],
		SUM(CASE WHEN [TimeEntry].[State]in(2,3,5,6) 
				THEN [TimeEntry].[RoundedDuration] / 60.0
			ELSE 0 END) AS [Total],
		SUM(CASE WHEN [TimeEntry].[State]in(3,6) 
				THEN [TimeEntry].[RoundedDuration] / 60.0
			ELSE 0 END) AS [Approved],
		SUM(CASE WHEN [TimeEntry].[State]in(3,6) 
				THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
			ELSE 0 END) AS [Calculation]		
	FROM
		[Employee]
		LEFT OUTER JOIN [Qualification]
			ON [Employee].[QualificationID] = [Qualification].[ID]
		INNER JOIN [vwTimeEntry] as [TimeEntry]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
	WHERE
		[TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd
	GROUP BY
		[Employee].[FileAs],
		[Qualification].[FileAs] 

RETURN 0
GO

GRANT EXEC ON ReportTotalOfEmployees TO PUBLIC

GO
