IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordCalculation')
	BEGIN
		PRINT 'Dropping Procedure ReportWordCalculation'
		DROP  Procedure  ReportWordCalculation
	END

GO

PRINT 'Creating Procedure ReportWordCalculation'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**
*******************************************************************************/
CREATE Procedure ReportWordCalculation
	@ID int,
	@Version TName,
	@Language TName = NULL
AS
	IF @Version = '5.5'
	BEGIN
		EXEC ReportCalculation @ID, @Language
		RETURN 0
	END
	
	EXEC ReportWordCalculationV2 @ID, @Language
	RETURN 0
GO

GRANT EXEC ON ReportWordCalculation TO PUBLIC
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordCalculationV2')
	BEGIN
		PRINT 'Dropping Procedure ReportWordCalculationV2'
		DROP  Procedure  ReportWordCalculationV2
	END

GO

PRINT 'Creating Procedure ReportWordCalculationV2'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		29.10.09	PAM		             
**									 
**      13.11.09	SPV				     .
**		13.11.09	SPV				          .  
**		12.11.10	SYV				 AdvanceLine  AdvanceLine by activityType,
**									 PrintOptions
**		01.12.10	SYV				  [CurrencySymbol]
**		03.12.10	SYV				  CustomerContactEmployeeID, CustomerContactName
**									CustomerContactFileAs, CustomerContactPositionID,
**									CustomerContactPositionFileAs
**		03.12.10	SYV				  CustomerAddress, CustomerPhone, ContactAddress,
**									ContactPhone, ContactEmail
**		08.04.11	SYV				    //
**		16.06.11	SPV				    
**		20.09.11	PAM				     
**		02.11.12	SAP				  ProjectLanguage
**		12.11.12	SAP				   
**		11.04.13	SOV				     2- 
*******************************************************************************/
CREATE Procedure ReportWordCalculationV2
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@timeClass TClass,
		@expenseClass TClass,
		@phoneClass TClass,
		@requestClass TClass,
		@calculationClass TClass,
		@DocumentCalculationClass TClass,
		@TotalAmount TAmount,
		
		@TotalLines TMoney,
		@TotalLinesVAT TMoney,
		
		@TotalWithoutDiscount TMoney,
		@TotalLinesWithoutDiscount	TMoney,
		@TotalLinesVATWithoutDiscount TMoney,

		@TotalAdvanceWithoutDiscountPC TMoney,
		@TotalAdvanceVATWithoutDiscountPC TMoney,
		@TotalAdvanceWithVATWithoutDiscountPC TMoney,

		@TotalAdvance TMoney,
		@TotalAdvanceVAT TMoney,
		@TotalAdvanceWithVAT TMoney,

		@Discount TMoney,
		@DiscountType TIdentifier,

		@VATRate TMoney,
		@RatesWithVAT TBool,		
		@VATIsIncluded TBool,
		@AdvanceDiscountPC TMoney,
		@AdvanceDiscountType TIdentifier,

		@Code TName,
		@GroupTimeEntry TBool,
		@ShowActivityTypes TBool,
		@ShowPrice TBool,
		@GroupingAdvanceCalculations TCount,
		@NationalCurrencyCode TCode3,
		@val TVariant,
		@ContactID TIdentifier,
		@CustomerID TIdentifier,
		@CompanyClass TClass,
		@EmployeeClass TClass,
		@Date DateTime,
		@EmployeeID TIdentifier,
		@Price TMoney,
		@Description nvarchar(max),

		@Flag int,
		@Rate decimal(18,4),
		@TypeID int,
		@EmployeeFileAs nvarchar(256)

	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @Code = CASE WHEN @Language = 'en' THEN 'Calculation; ' ELSE '; ' END
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET	@expenseClass = dbo.adfGetClassByName('Pjm5.Expense')
	SET	@phoneClass = dbo.adfGetClassByName('Pjm5.PhoneCall')
	SET	@calculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET @requestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))

	SELECT
		@DocumentCalculationClass = [Calculation].[DocumentClass],
		@RatesWithVAT = [Calculation].[RatesWithVAT],
		@VATRate = [Calculation].[VATRate],
		@GroupTimeEntry = [Project].[GroupCalculationLines],
		@ShowActivityTypes = [Project].[ShowActivityTypes],
		@ShowPrice = [Project].[ShowPrice],
		@GroupingAdvanceCalculations = [Project].[GroupingAdvanceCalculations],
		@ContactID = [Project].[ResponsiblePersonEmployeeID],
		@CustomerID = [Project].[CustomerCompanyID],
		@Discount = [Discount],
		@DiscountType = [DiscountType]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Calculation].[ID] = @ID
		
	IF (@DocumentcalculationClass = @TimeClass AND @ShowActivityTypes = 0)
		SET @ShowActivityTypes = 0
	ELSE
		SET @ShowActivityTypes = 1

	IF (@DocumentcalculationClass = @TimeClass AND @ShowPrice = 1)
		SET @ShowPrice = 1
	ELSE
		SET @ShowPrice = 0
			
	SET @VATIsIncluded = 0
	IF @DocumentCalculationClass = @timeClass
		SET @VATIsIncluded = @RatesWithVAT
	
	DECLARE @t TABLE(
		[ID] int,
		[Date] datetime,
		[EmployeeID] int,
		[EmployeeFileAs] nvarchar(256),
		[DivisionID] int,
		[PositionID] int,
		[QualificationID] int,
		[TypeID] int,
		[Description] nvarchar(max),
		[Price] money,
		[Amount] decimal(18,4),
		[Total] money,
		[VAT] money
	)
	
	DECLARE @tt TABLE(
		[EmployeeInitials] nvarchar(32) null,
		[EmployeeFileAs] nvarchar(256) not null,
		[EmployeeFirst] nvarchar(50) null,
		[EmployeeMiddle] nvarchar(50) null,
		[EmployeeLast] nvarchar(50) null,
		[Date] DateTime not null,
		[EmployeeID] int null,
		[TypeID] int null,
		[TypeCode] nvarchar(32) null,
		[TypeFileAs] nvarchar(2000) null,
		[Description] nvarchar(max) null,
		[Amount] decimal(18,4) not null,
		[Price] decimal(18,4) not null,
		[Total] decimal(18,4) not null
		
	)

	DECLARE @empGroup TABLE(
		[Flag] int not null,
		[EmployeeInitials] nvarchar(32) null,
		[EmployeeFileAs] nvarchar(256) not null,
		[EmployeeFirst] nvarchar(50) null,
		[EmployeeMiddle] nvarchar(50) null,
		[EmployeeLast] nvarchar(50) null,
		[Date] DateTime not null,
		[EmployeeID] int null,
		[TypeID] int null,
		[TypeCode] nvarchar(32) null,
		[TypeFileAs] nvarchar(2000) null,
		[Description] nvarchar(max) null,
		[Amount] decimal(18,4) not null,
		[Price] decimal(18,4) not null,
		[Total] decimal(18,4) not null,
		[Rate] decimal(18,4)
	)
	
	IF @DocumentCalculationClass = @timeClass
	BEGIN
		INSERT INTO @t
			([ID],
			[Date],
			[EmployeeID],
			[EmployeeFileAs],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[TypeID],
			[Description],
			[Amount],
			[Price],
			[Total],
			[VAT])
		SELECT
			[CalculationLine].[ID],
			[TimeEntry].[StartTime],
			[TimeEntry].[EmployeeID],
			[Employee].[FileAs],
			[Employee].[DivisionID],
			[Employee].[PositionID],
			[Assignment].[QualificationID],
			[TimeEntry].[ActivityTypeID],
			[CalculationLine].[Description],
			[CalculationLine].[Amount],
			[CalculationLine].[Price],
			[CalculationLine].[Amount] * [CalculationLine].[Price],
			[CalculationLine].[VAT]
		FROM
			[CalculationLine]
			INNER JOIN [TimeEntry]
				ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND
					[TimeEntry].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [TimeEntry].[EmployeeID]
			LEFT OUTER JOIN [Assignment]
				ON [TimeEntry].[AssignmentID] = [Assignment].[ID]
		WHERE 
			[CalculationLine].[CalculationID] = @ID
	END
	ELSE
	BEGIN
		INSERT INTO @t
		(
			[ID],
			[Date],
			[EmployeeID],
			[EmployeeFileAs],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[TypeID],
			[Description],
			[Price],
			[Amount],
			[Total],
			[VAT]
		)
		SELECT
			[pjm5vwCalculationLine].[ID],
			[pjm5vwCalculationLine].[Date], 
			[Employee].[ID],
			[Employee].[FileAs],
			[Employee].[DivisionID],
			[Employee].[PositionID],
			[pjm5vwCalculationLine].[QualificationID],
			[pjm5vwCalculationLine].[TypeID],
			[pjm5vwCalculationLine].[Description],
			CASE 
				WHEN [pjm5vwCalculationLine].[VATIsIncluded] = 1 AND [pjm5vwCalculationLine].[Amount] != 0
					THEN [pjm5vwCalculationLine].[Price] - [pjm5vwCalculationLine].[VAT] / [pjm5vwCalculationLine].[Amount]
				ELSE [pjm5vwCalculationLine].[Price]
			END AS [Price],
			[pjm5vwCalculationLine].[Amount],
			CASE 
				WHEN [pjm5vwCalculationLine].[VATIsIncluded] = 1
					THEN ([pjm5vwCalculationLine].[Amount] * [pjm5vwCalculationLine].[Price] - [pjm5vwCalculationLine].[VAT])
				ELSE [pjm5vwCalculationLine].[Amount] * [pjm5vwCalculationLine].[Price]
			END AS [Total],
			[pjm5vwCalculationLine].[VAT]
		FROM
			[pjm5vwCalculationLine]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [pjm5vwCalculationLine].[EmployeeID]
		WHERE 
			[pjm5vwCalculationLine].[CalculationID] = @ID
	END
	
	--      
	SELECT
		@TotalWithoutDiscount = SUM([Total]),
		@TotalLinesWithoutDiscount = SUM([Total] - [VAT] * @VATIsIncluded),
		@TotalLinesVATWithoutDiscount = 
			SUM([Total] + [VAT] * (1 - @VATIsIncluded)) - SUM([Total] - [VAT] * @VATIsIncluded)
	FROM @t

	SET @TotalWithoutDiscount = ISNULL(@TotalWithoutDiscount, 0)
	SET @TotalLinesWithoutDiscount = ISNULL(@TotalLinesWithoutDiscount, 0)
	SET @TotalLinesVATWithoutDiscount = ISNULL(@TotalLinesVATWithoutDiscount, 0)
	
	SELECT
		--     
		@TotalLines = CASE
			WHEN [DiscountType] = 3 AND @TotalWithoutDiscount <= [Discount]
				THEN @TotalWithoutDiscount - @TotalLinesVATWithoutDiscount * @VATIsIncluded
			WHEN [DiscountType] = 3 AND @TotalWithoutDiscount > [Discount]
				THEN [Discount] - ([Discount] / (1 + [VATRate])) * @VATIsIncluded * [VATRate]
			WHEN [DiscountType] = 0
				THEN @TotalWithoutDiscount - @TotalLinesVATWithoutDiscount * @VATIsIncluded
			ELSE
				@TotalWithoutDiscount + (CASE
					WHEN [DiscountType] = 1 
						THEN -1
					ELSE 1 END) * CASE 
						WHEN [DiscountView] = 0
							THEN ROUND(@TotalWithoutDiscount * [DiscountPercent], 2)
						ELSE dbo.fnPjm6GetCalculationDiscount([ID], 0) END
				- ((@TotalWithoutDiscount + (CASE
					WHEN [DiscountType] = 1 
						THEN -1
					ELSE 1 END) * CASE 
						WHEN [DiscountView] = 0
							THEN ROUND(@TotalWithoutDiscount * [DiscountPercent], 2)
						ELSE dbo.fnPjm6GetCalculationDiscount([ID], 0) END) / (1 + [VATRate])) * @VATIsIncluded * [VATRate]
			END,
		--     
		@TotalLinesVAT = CASE
			WHEN [DiscountType] = 3 AND @TotalWithoutDiscount <= [Discount]
				THEN @TotalLinesVATWithoutDiscount
			WHEN [DiscountType] = 3 AND @TotalWithoutDiscount > [Discount]
				THEN [Discount] * [VATRate] / (1 + @VATIsIncluded * [VATRate])
			WHEN [DiscountType] = 0
				THEN @TotalLinesVATWithoutDiscount
			ELSE
				(@TotalWithoutDiscount + (CASE
					WHEN [DiscountType] = 1 
						THEN -1
					ELSE 1 END) * CASE 
						WHEN [DiscountView] = 0
							THEN ROUND(@TotalWithoutDiscount * [DiscountPercent], 2)
						ELSE dbo.fnPjm6GetCalculationDiscount([ID], 0) END) 
				* [VATRate] / (1 + @VATIsIncluded * [VATRate])
			END
	FROM
		[Calculation]
	WHERE
		[Calculation].[ID] = @ID

	SELECT @TotalAmount = ROUND(SUM([Amount]), 2) FROM @t

	SET @TotalLines = ISNULL(@TotalLines, 0)
	SET @TotalLinesVAT = ISNULL(@TotalLinesVAT, 0)
	SET @TotalAmount = ISNULL(@TotalAmount, 0)

	IF @TotalLines < 0
		SET @TotalLines = 0
	IF @TotalLinesVAT < 0
		SET @TotalLinesVAT = 0
	SET @TotalAmount = ISNULL(@TotalAmount, 0)

	DECLARE @AdvanceFlag TBool
	IF EXISTS(SELECT * FROM [CalculationAdvance] WHERE [CalculationID] = @ID)
		SET @AdvanceFlag = 1
	ELSE
		SET @AdvanceFlag = 0
		
	--  /     
	SELECT 
		@AdvanceDiscountPC = SUM(
			(CASE 
				WHEN [DiscountType] = 0
					THEN 0
				WHEN [DiscountType] = 2
					THEN 1
				ELSE -1
			END) * 
				CASE
					WHEN [DiscountType] != 3 
						THEN CASE
							WHEN [DiscountType] = 1 
								THEN CASE 
										WHEN [TotalWithoutDiscountPC] > [DiscountPC]
											THEN [DiscountPC]
										ELSE 0
									END
							ELSE [DiscountPC] END
					ELSE 
						CASE 
							WHEN [TotalWithoutDiscountPC] > [DiscountPC]
								THEN [TotalWithoutDiscountPC] - [DiscountPC]
							ELSE 0
						END	
				END),
		@TotalAdvanceWithoutDiscountPC = SUM([TotalWithoutDiscountPC]),
		@TotalAdvanceWithVATWithoutDiscountPC  = SUM([TotalWithVATWithoutDiscountPC]),
		@TotalAdvance = SUM([TotalPC]),
		@TotalAdvanceWithVAT = SUM([TotalWithVATPC])
	FROM
		[Calculation]
		INNER JOIN [CalculationAdvance]
			ON [CalculationAdvance].[AdvanceCalculationID] = [Calculation].[ID]
	WHERE 
		[CalculationID] = @ID

	SET @TotalAdvanceVAT = @TotalAdvanceWithVAT - @TotalAdvance
	SET @TotalAdvanceVAT = ISNULL(@TotalAdvanceVAT, 0)
	SET @TotalAdvance = ISNULL(@TotalAdvance, 0)
	SET @TotalAdvanceWithVAT = ISNULL(@TotalAdvanceWithVAT, 0)
	SET @AdvanceDiscountPC = ISNULL(@AdvanceDiscountPC, 0)
	SET @TotalAdvanceWithoutDiscountPC = ISNULL(@TotalAdvanceWithoutDiscountPC, 0)
	SET	@TotalAdvanceWithVATWithoutDiscountPC  = ISNULL(@TotalAdvanceWithVATWithoutDiscountPC, 0)
	SET @TotalAdvanceVATWithoutDiscountPC = @TotalAdvanceWithVATWithoutDiscountPC - @TotalAdvanceWithoutDiscountPC

	SET @AdvanceDiscountType = CASE 
			WHEN @AdvanceDiscountPC > 0 THEN 2
			WHEN @AdvanceDiscountPC < 0 THEN 1
			ELSE 0
		END
	SET @AdvanceDiscountPC = ABS(@AdvanceDiscountPC)
	SET @Discount = ISNULL(@Discount, 0)

	IF (@VATIsIncluded = 0 AND @TotalLinesWithoutDiscount < @Discount AND @DiscountType = 3)
		OR (@VATIsIncluded = 1 AND (@TotalLinesWithoutDiscount + @TotalLinesVATWithoutDiscount) < @Discount AND @DiscountType = 3)
	BEGIN
		SET @DiscountType = 0
	END

	--------------Calculation-------------
	SELECT
		[Calculation].[ID],
		CASE @DocumentCalculationClass
				WHEN @timeClass THEN 0
				WHEN @expenseClass THEN 1
				WHEN @phoneClass THEN 2
				ELSE 3
		END AS [CalculationType],
		[Calculation].[Number],
		[Calculation].[Date],
		[Calculation].[FileAs],
		[Calculation].[PeriodStart],
		[Calculation].[PeriodEnd],
		[Calculation].[Description],

		[Calculation].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		
		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],
		
		[SupplierCompany].[ExecutiveEmployeeID],
		[SupplierEmployee].[LastName] + 
			ISNULL(' ' + [SupplierEmployee].[FirstName], '') + 
				ISNULL(' ' + [SupplierEmployee].[MiddleName], '') AS [ExecutiveName],
		[SupplierEmployee].[FileAs] AS [ExecutiveFileAs],
		[SupplierEmployeePosition].[ID] AS [ExecutivePositionID],
		[SupplierEmployeePosition].[FileAs] AS [ExecutivePositionFileAs],
		[CustomerCompany].[ExecutiveEmployeeID] AS [CustomerExecutiveEmployeeID],
		[CustomerExecutive].[LastName] + 
			ISNULL(' ' + [CustomerExecutive].[FirstName], '') + 
				ISNULL(' ' + [CustomerExecutive].[MiddleName], '') AS [CustomerExecutiveName],
		[CustomerExecutive].[FileAs] AS [CustomerExecutiveFileAs],
		[CustomerExecutivePosition].[ID] AS [CustomerExecutivePositionID],
		[CustomerExecutivePosition].[FileAs] AS [CustomerExecutivePositionFileAs],
		[Calculation].[Total],
		[Calculation].[VATRate] * 100 AS [VATRate],
		[Calculation].[VAT],
		[Calculation].[TotalWithVAT],
		CASE
			WHEN [Calculation].[VATRate] != 0 THEN @VATIsIncluded
			ELSE 2
		END AS [VATFlag],
		@TotalAmount AS [TotalAmount],
		ROUND(@TotalLines, 2) AS [TotalLines],
		ROUND(@TotalLinesVAT, 2) AS [TotalLinesVAT],
		ROUND(@TotalLines + @TotalLinesVAT, 2) AS [TotalLinesWithVAT],
		@AdvanceFlag AS [AdvanceFlag],
		@TotalAdvance AS [TotalAdvance],
		@TotalAdvanceVAT AS [TotalAdvanceVAT],
		@TotalAdvanceWithVAT AS [TotalAdvanceWithVAT],
		[Currency].[ID] AS [CurrencyID],
		[Currency].[FileAs] AS [CurrencyFileAs],
		[Currency].[Code] AS [CurrencyCode],
		CASE 
			WHEN dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		[Currency].[Symbol] AS [CurrencySymbol],
		[CustomerContact].[ID] AS [CustomerContactEmployeeID],
		[CustomerContact].[LastName] + 
			ISNULL(' ' + [CustomerContact].[FirstName], '') + 
				ISNULL(' ' + [CustomerContact].[MiddleName], '') AS [CustomerContactName],
		[CustomerContact].[FileAs] AS [CustomerContactFileAs],
		[CustomerContactPosition].[ID] AS [CustomerContactPositionID],
		[CustomerContactPosition].[FileAs] AS [CustomerContactPositionFileAs],
		[Calculation].[TotalWithoutDiscount],
		[Calculation].[TotalWithVATWithoutDiscount],
		[Calculation].[VATWithoutDiscount],
		[Calculation].[TotalWithoutDiscountPC],
		[Calculation].[TotalWithVATWithoutDiscountPC],
		[Calculation].[VATWithoutDiscountPC],
		[Calculation].[DiscountView],
		CASE WHEN @VATIsIncluded = 1
			THEN dbo.fnPjm6GetCalculationDiscount(@ID, 1) / (1 + [Calculation].[VATRate])
			ELSE dbo.fnPjm6GetCalculationDiscount(@ID, 1)
		END AS [DiscountPC],
		[Calculation].[DiscountPercent] * 100 AS [DiscountPercent],
		CASE WHEN @VATIsIncluded = 1
			THEN dbo.fnPjm6GetCalculationDiscount(@ID, 0) / (1 + [Calculation].[VATRate])
			ELSE dbo.fnPjm6GetCalculationDiscount(@ID, 0)
		END AS [Discount],
		@DiscountType AS [DiscountType],
		ROUND(@TotalLinesWithoutDiscount, 2) AS [TotalLinesWithoutDiscount],
		ROUND(@TotalLinesVATWithoutDiscount, 2) AS [TotalLinesVATWithoutDiscount],
		ROUND(@TotalLinesWithoutDiscount + @TotalLinesVATWithoutDiscount, 2) AS [TotalLinesWithVATWithoutDiscount],
		CASE WHEN @VATIsIncluded = 0
			THEN dbo.fnPjm6GetCalculationDiscount(@ID, 1) * (1 + [Calculation].[VATRate])
			ELSE dbo.fnPjm6GetCalculationDiscount(@ID, 1)
		END AS [DiscountWithVATPC],
		CASE WHEN @VATIsIncluded = 0
			THEN dbo.fnPjm6GetCalculationDiscount(@ID, 0) * (1 + [Calculation].[VATRate])
			ELSE dbo.fnPjm6GetCalculationDiscount(@ID, 0)
		END AS [DiscountWithVAT],
		@AdvanceDiscountPC AS [AdvanceDiscountPC],
		@AdvanceDiscountType AS [AdvanceDiscountType],
		@TotalAdvanceWithoutDiscountPC AS [TotalAdvanceWithoutDiscountPC],
		@TotalAdvanceWithVATWithoutDiscountPC AS [TotalAdvanceWithVATWithoutDiscountPC],
		@TotalAdvanceVATWithoutDiscountPC AS [TotalAdvanceVATWithoutDiscountPC],
		--   
		[CustomerCompany].[AccountantEmployeeID] AS [CustomerAccountantEmployeeID],
		[CustomerAccountant].[LastName] + 
			ISNULL(' ' + [CustomerAccountant].[FirstName], '') + 
				ISNULL(' ' + [CustomerAccountant].[MiddleName], '') AS [CustomerAccountantName],
		[CustomerAccountant].[FileAs] AS [CustomerAccountantFileAs],
		[CustomerAccountantPosition].[ID] AS [CustomerAccountantPositionID],
		[CustomerAccountantPosition].[FileAs] AS [CustomerAccountantPositionFileAs],
		--   
		[SupplierCompany].[AccountantEmployeeID] AS [SupplierAccountantEmployeeID],
		[SupplierAccountant].[LastName] + 
			ISNULL(' ' + [SupplierAccountant].[FirstName], '') + 
				ISNULL(' ' + [SupplierAccountant].[MiddleName], '') AS [SupplierAccountantName],
		[SupplierAccountant].[FileAs] AS [SupplierAccountantFileAs],
		[SupplierAccountantPosition].[ID] AS [SupplierAccountantPositionID],
		[SupplierAccountantPosition].[FileAs] AS [SupplierAccountantPositionFileAs],
		[SupplierCompany].[Number] as [SupplierCode],
		[CustomerCompany].[Number] as [CustomerCode],
		[Project].[NumerationCode] as [ProjectNumerationCode],
		[Project].[ProjectLanguageCode] AS [ProjectLanguage],
		[Project].[PaymentCurrencyPoint]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [CustomerExecutive]
			ON [CustomerCompany].[ExecutiveEmployeeID] = [CustomerExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerExecutivePosition]
			ON [CustomerExecutive].[PositionID] = [CustomerExecutivePosition].[ID]
		INNER JOIN [Currency]
			ON [Calculation].[CurrencyCode] = [Currency].[Code]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierEmployeePosition]
			ON [SupplierEmployee].[PositionID] = [SupplierEmployeePosition].[ID]
		LEFT OUTER JOIN [vwEmployeeWithEP] AS [CustomerContact]
			ON [Project].[ResponsiblePersonEmployeeID] = [CustomerContact].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerContactPosition]
			ON [CustomerContact].[PositionID] = [CustomerContactPosition].[ID]
		LEFT OUTER JOIN [Employee] AS [CustomerAccountant]
			ON [CustomerCompany].[AccountantEmployeeID] = [CustomerAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerAccountantPosition]
			ON [CustomerAccountant].[PositionID] = [CustomerAccountantPosition].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierAccountant]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierAccountantPosition]
			ON [SupplierAccountant].[PositionID] = [SupplierAccountantPosition].[ID]
	WHERE 
		[Calculation].[ID] = @ID
--------------Line-------------
	IF @GroupTimeEntry = 0
		SELECT
			[ID],
			CONVERT(datetime,CONVERT(varchar(8),[Date],112),112) AS [Date],
			[Date] as [StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[Description],
			[Amount],		
			[Price],
			[Total],
			[VAT]
		FROM @t
	ELSE
	BEGIN
		DECLARE tCursor CURSOR FOR
			SELECT [Date], [EmployeeID], [Description], [Price] FROM @t

		OPEN tCursor
		FETCH NEXT FROM tCursor INTO @Date, @EmployeeID, @Description, @Price
		WHILE @@fetch_status = 0 
		BEGIN
			UPDATE @t
			SET [Date] = 
			(	SELECT min([Date])
				FROM @t 
				GROUP BY
					CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112),
					[EmployeeID],
					[Description],
					[Price]
				HAVING
					CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112) = CONVERT(datetime, CONVERT(varchar(8), @Date, 112), 112) AND
					[EmployeeID] = @EmployeeID AND
					[Description] = @Description AND
					[Price] = @Price)
			WHERE
				CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112) = CONVERT(datetime, CONVERT(varchar(8), @Date, 112), 112) AND
				[EmployeeID] = @EmployeeID AND
				[Description] = @Description AND
				[Price] = @Price
			FETCH NEXT FROM tCursor INTO @Date, @EmployeeID, @Description, @Price
		END
		CLOSE tCursor
		DEALLOCATE tCursor
		SELECT
			ROW_NUMBER() OVER(ORDER BY [Date], [EmployeeFileAs]) AS [ID],
			CONVERT(datetime,CONVERT(varchar(8),[Date],112),112) AS [Date],
			[Date] AS [StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[Description],
			SUM([Amount]) AS [Amount],		
			[Price],
			SUM([Total]) AS[Total],
			SUM([VAT]) AS [VAT]
		FROM @t
		GROUP BY
			[Date],
			[EmployeeID],
			[EmployeeFileAs],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[Description],
			[Price]
		ORDER BY [Date]
	END
--------------advance------------
	SELECT
		[Calculation].[ID],
		[Calculation].[Date],
		[Calculation].[FileAs],
		ISNULL([Calculation].[Description], [Calculation].[FileAs]) AS [Description],
		[Calculation].[TotalPC],
		[Calculation].[TotalWithVATPC],
		[Calculation].[DiscountType],
		[Calculation].[DiscountView],
		CASE WHEN [DocumentClass] = @timeClass AND [RatesWithVAT] = 1
			THEN dbo.fnPjm6GetCalculationDiscount(@ID, 1) / (1 + [VATRate])
			ELSE dbo.fnPjm6GetCalculationDiscount(@ID, 1)
		END AS [DiscountPC],
		[Calculation].[DiscountPercent] * 100 AS [DiscountPercent],
		[Calculation].[TotalWithoutDiscountPC],
		[Calculation].[TotalWithVATWithoutDiscountPC],
		[Calculation].[VATWithoutDiscountPC],
		CASE WHEN @VATIsIncluded = 0
			THEN dbo.fnPjm6GetCalculationDiscount(@ID, 1) * (1 + [VATRate])
			ELSE dbo.fnPjm6GetCalculationDiscount(@ID, 1)
		END AS [DiscountWithVATPC]
	FROM
		[CalculationAdvance]
		INNER JOIN [Calculation]
			ON [Calculation].[ID] = [CalculationAdvance].[AdvanceCalculationID]
	WHERE
		[CalculationAdvance].[CalculationID] = @ID
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()

--------------AdvanceLine------------	
	DECLARE @advT TABLE(
		[ID] int,
		[Date] datetime,
		[StartTime] datetime,
		[EmployeeID] int,
		[EmployeeFileAs] nvarchar(256),
		[EmployeeInitials] varchar(32),
		[DivisionID] int,
		[PositionID] int,
		[QualificationID] int,
		[TypeID] int,
		[Description] nvarchar(max),
		[Price] money,
		[Amount] decimal(18,4),
		[Total] money,
		[VAT] money
	)

	IF @DocumentCalculationClass = @timeClass OR @DocumentCalculationClass = @requestClass
	BEGIN
		INSERT INTO @advT
			([ID], [Date], [StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[EmployeeInitials],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[TypeID],
			[Description], [Price], [Amount], [Total], [VAT])
		SELECT
			[CalculationLine].[ID],
			CAST(CONVERT(varchar(8), [Expense].[Date], 112) as datetime) AS [Date],
			[Expense].[Date] AS [StartTime],
			[Employee].[ID] AS [EmployeeID],
			[Employee].[FileAs] AS [EmployeeFileAs],
			[Employee].[Initials] AS [EmployeeInitials],
			[Employee].[DivisionID],
			[Employee].[PositionID],
			[Assignment].[QualificationID],
			[Expense].[ExpenseCodeID],
			[CalculationLine].[Description],
			CASE
				WHEN [Expense].[FromCurrencyCode] != [Expense].[ToCurrencyCode]
					THEN 	
						CASE 
							WHEN @NationalCurrencyCode = [Expense].[FromCurrencyCode]
							THEN 
								([Expense].[Price] / (1 + [Expense].[VATRate] * [Expense].[VATisIncluded]))
								/
								[Expense].[CurrencyRate]
							ELSE 
								([Expense].[Price] / (1 + [Expense].[VATRate] * [Expense].[VATisIncluded]))
								*
								[Expense].[CurrencyRate]
						END
				ELSE ([Expense].[Price] / (1 + [Expense].[VATRate] * [Expense].[VATisIncluded]))
			END AS [Price],
			[Expense].[Amount],
			[Expense].[TotalPC],
			[Expense].[VATPC]
		FROM
			[CalculationAdvance]
			INNER JOIN [Calculation]
				ON [Calculation].[ID] = [CalculationAdvance].[AdvanceCalculationID]
			INNER JOIN [CalculationLine]
				ON [Calculation].[ID] = [CalculationLine].[CalculationID]
			INNER JOIN [Expense]
				ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
				[Expense].[ID] = [CalculationLine].[DocumentID]
			LEFT OUTER JOIN
			(
				[Assignment]
				INNER JOIN [AssignmentEntry]
					ON [Assignment].[ID] = [AssignmentEntry].[AssignmentID]
			)
				ON [Expense].[EmployeeID] = [AssignmentEntry].[EmployeeID]
			AND [Expense].[ProjectID] = [Assignment].[ProjectID]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [Expense].[EmployeeID]
		WHERE
			[CalculationAdvance].[CalculationID] = @ID
			AND
			(
				[Assignment].[State] = 1 
				OR
				(
					[Assignment].[State] = 2
					AND
					-- 
					[Assignment].[Modified] = 
					(
						SELECT 
							MAX([Modified]) 
						FROM
							[Assignment]
							INNER JOIN [AssignmentEntry]
								ON [Assignment].[ID] = [AssignmentEntry].[AssignmentID]
						WHERE
							[Expense].[EmployeeID] = [AssignmentEntry].[EmployeeID]
							AND 
							[Expense].[ProjectID] = [Assignment].[ProjectID]
					) 
				)
			)
	END

	IF @GroupTimeEntry = 0
		SELECT
			[ID], 
			[Date], 
			[StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[EmployeeInitials],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[TypeID],
			[Description], 
			[Price], 
			[Amount], 
			[Total], 
			[VAT]
		FROM 
			@advT
	ELSE
		SELECT
			ROW_NUMBER() OVER(ORDER BY [Date], [EmployeeFileAs]) AS [ID],
			[Date],
			[Date] AS [StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[EmployeeInitials],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[Description],
			[Price],
			SUM([Amount]) AS [Amount],		
			SUM([Total]) AS [Total],
			SUM([VAT]) AS [VAT]
		FROM @advT
		GROUP BY
			[Date],
			[EmployeeID],
			[EmployeeFileAs],
			[EmployeeInitials],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[Description],
			[Price]
	
	-- AdvanceLine by activityType
	SELECT
		[ExpenseCode].[ID] AS [TypeID],
		[ExpenseCode].[Code] AS [TypeCode],
		[ExpenseCode].[FileAs] AS [TypeFileAs],
		SUM([advT].[Total]) AS [Total],
		[PropertyValue].[Value] AS [Addlang]
	FROM 
		@advT AS [advT]
		INNER JOIN [ExpenseCode]
			ON [advT].[TypeID] = [ExpenseCode].[ID]
		LEFT OUTER JOIN [Property]
			ON [Property].[Class] = [ExpenseCode].[Class]
		LEFT OUTER JOIN [PropertyValue]
			ON [PropertyValue].[PropertyID] = [Property].[ID] AND
			[PropertyValue].[DocumentID] = [ExpenseCode].[ID]
	WHERE		
		[Property].[Guid] = '00000001-0000-0000-0000-000000000000'		
	GROUP BY
		[ExpenseCode].[ID],
		[ExpenseCode].[Code],
		[ExpenseCode].[FileAs],
		[PropertyValue].[Value]
	ORDER BY [TypeCode] ASC
			
------------Document Properties----------
	SELECT
      [Calculation].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @calculationClass) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Calculation].[ID] = @ID

-- PrintOptions

SELECT 
	@ShowActivityTypes AS [ShowActivityTypes],
	@GroupingAdvanceCalculations AS [DisplayTypeAdvanceCalculation],
	@ShowPrice as [ShowPrice]

/*
	BEGIN NEW BLOCK (    )
*/
-- by date
insert into @tt
	SELECT
		[Employee].[Initials],	
		[Employee].[FileAs],
		[Employee].[FirstName],
		[Employee].[MiddleName],
		[Employee].[LastName],
		[Date],
		[EmployeeID],
		[TypeID],
		[TypeCode],
		[TypeFileAs],
		[Description],
		[Amount],
		CASE 
			WHEN @ShowPrice = 0 THEN 0.0
			--WHEN [pjm5vwReportCalculationLine].[VATIsIncluded] = 1 AND [pjm5vwReportCalculationLine].[Amount] != 0
			--	THEN [pjm5vwReportCalculationLine].[Price] - [pjm5vwReportCalculationLine].[VAT] / [pjm5vwReportCalculationLine].[Amount]
			ELSE [pjm5vwReportCalculationLine].[Price]
		END AS [Price],
		CASE 
			WHEN @ShowPrice = 0 THEN 0.0
			--WHEN [pjm5vwReportCalculationLine].[VATIsIncluded] = 1
			--	THEN ([pjm5vwReportCalculationLine].[Amount] * [pjm5vwReportCalculationLine].[Price] - [pjm5vwReportCalculationLine].[VAT])
			ELSE [pjm5vwReportCalculationLine].[Amount] * [pjm5vwReportCalculationLine].[Price]
		END AS [Total]
	FROM
		[pjm5vwReportCalculationLine]
		LEFT OUTER JOIN [Employee]
			ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
	WHERE
		[pjm5vwReportCalculationLine].[CalculationID] = @ID AND
		[pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass
	ORDER BY
		CASE WHEN @DocumentCalculationClass = @TimeClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @TimeClass THEN [Price] END Desc,
		CASE WHEN @DocumentCalculationClass = @ExpenseClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @ExpenseClass THEN [Amount] END DESC,
		CASE WHEN @DocumentCalculationClass = @PhoneClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @PhoneClass THEN [Amount] END ASC,
		CASE WHEN @DocumentCalculationClass = @RequestClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @RequestClass THEN [Employee].[Initials] END ASC

IF @GroupTimeEntry = 0
	(SELECT
		[EmployeeInitials],	
		[EmployeeFileAs],
		[EmployeeFirst],
		[EmployeeMiddle],
		[EmployeeLast],
		CONVERT(datetime,CONVERT(varchar(8),[Date],112),112) AS [Date],
		[EmployeeID],
		[TypeID],
		[TypeCode],
		[TypeFileAs],
		[Description],
		[Amount],
		[Price],
		[Total]
	FROM @tt)
ELSE
	BEGIN
		DECLARE ttCursor CURSOR FOR
			SELECT [Date], [EmployeeID],[Description], [Price] FROM @tt
		OPEN ttCursor
		FETCH NEXT FROM ttCursor INTO @Date, @EmployeeID, @Description, @Price
		WHILE @@fetch_status = 0 
		BEGIN
			UPDATE @tt 
			SET [Date] = 
			(
				SELECT min([Date])
				FROM @tt 
				GROUP BY
					CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112),
					[EmployeeID],
					[Description],
					[Price]
				HAVING
					CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112) = CONVERT(datetime, CONVERT(varchar(8), @Date, 112), 112) AND
					[EmployeeID] = @EmployeeID AND
					[Description] = @Description AND
					[Price] = @Price)
			WHERE
				CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112) = CONVERT(datetime, CONVERT(varchar(8), @Date, 112), 112) AND
				[EmployeeID] = @EmployeeID AND
				[Description] = @Description AND
				[Price] = @Price
			FETCH NEXT FROM ttCursor INTO @Date, @EmployeeID, @Description, @Price
		END
		CLOSE ttCursor
		DEALLOCATE ttCursor
		IF (@ShowActivityTypes = 0)
			SELECT
				CONVERT(datetime,CONVERT(varchar(8),[Date],112),112) AS [Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[Description],
				SUM([Amount]) AS [Amount],
				[Price],
				SUM([Total]) as [Total]
			FROM @tt
			GROUP BY	
				[Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[Description],
				[Price]
			ORDER BY
				[Date]
		ELSE
			SELECT
				CONVERT(datetime,CONVERT(varchar(8),[Date],112),112) AS [Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[TypeID],
				[TypeCode],
				[TypeFileAs],
				[Description],
				SUM([Amount]) AS [Amount],
				[Price],
				SUM([Total]) as [Total]
			FROM @tt
			GROUP BY	
				[Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[TypeID],
				[TypeCode],
				[TypeFileAs],
				[Description],
				[Price]
			ORDER BY
				[Date]
			
	END
-- by employee
	SELECT
		[Employee].[Initials] as [EmployeeInitials],	
		[Employee].[FileAs] as [EmployeeFileAs],
		[Employee].[FirstName] as [EmployeeFirst],
		[Employee].[MiddleName] as [EmployeeMiddle],
		[Employee].[LastName] as [EmployeeLast],
		[pjm5vwReportCalculationLine].[QualificationID] AS [QualificationID],
		[Qualification].[Code] AS [QualificationCode],
		[Qualification].[FileAs] AS [QualificationFileAs],
		[EmployeeID],
		SUM([pjm5vwReportCalculationLine].[Amount]) AS [Amount],
		[pjm5vwReportCalculationLine].[Price],
		SUM([pjm5vwReportCalculationLine].[Total]) AS [Total]
	FROM [pjm5vwReportCalculationLine]
		LEFT OUTER JOIN [Employee]
			ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Qualification]
			ON [pjm5vwReportCalculationLine].[QualificationID] = [Qualification].[ID]
	WHERE
		[pjm5vwReportCalculationLine].[CalculationID] = @ID AND
		[pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass
	GROUP BY
		[Employee].[Initials],	
		[Employee].[FileAs],
		[Employee].[FirstName],
		[Employee].[MiddleName],
		[Employee].[LastName],
		[pjm5vwReportCalculationLine].[QualificationID],
		[Qualification].[Code],
		[Qualification].[FileAs],
		[EmployeeID],
		[Price]
	ORDER BY
		[Price] DESC, [Employee].[Initials]
-- by activityType
	IF(@DocumentCalculationClass = @expenseClass)
		SELECT
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			SUM([pjm5vwReportCalculationLine].[Amount]) AS [Amount],
			[pjm5vwReportCalculationLine].[Price],
			SUM([pjm5vwReportCalculationLine].[Total]) AS [Total],
			[PropertyValue].[Value] AS [Addlang]
		FROM [pjm5vwReportCalculationLine]
		LEFT OUTER JOIN [Employee]
			ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
		INNER JOIN [Expense]
			ON [Expense].[Class] = [pjm5vwReportCalculationLine].[DocumentClass] AND
			[Expense].[ID] = [pjm5vwReportCalculationLine].[DocumentID]
		INNER JOIN [ExpenseCode]
			ON [ExpenseCode].[ID] = [Expense].[ExpenseCodeID]
		LEFT OUTER JOIN [Property]
			ON [Property].[Class] = [ExpenseCode].[Class]
		LEFT OUTER JOIN [PropertyValue]
			ON [PropertyValue].[PropertyID] = [Property].[ID] AND
			[PropertyValue].[DocumentID] = [ExpenseCode].[ID]			
		WHERE
			[pjm5vwReportCalculationLine].[CalculationID] = @ID
			AND [pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass
			AND [Property].[Guid] = '00000001-0000-0000-0000-000000000000'
		GROUP BY
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			[pjm5vwReportCalculationLine].[Price],
			[PropertyValue].[Value]
		ORDER BY [TypeCode] ASC
	ELSE IF (@DocumentCalculationClass = @phoneClass)
		SELECT
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			SUM([pjm5vwReportCalculationLine].[Amount]) AS [Amount],
			[pjm5vwReportCalculationLine].[Price],
			SUM([pjm5vwReportCalculationLine].[Total]) AS [Total],
			[PropertyValue].[Value] AS [Addlang]
		FROM [pjm5vwReportCalculationLine]
		LEFT OUTER JOIN [Employee]
			ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
		INNER JOIN [PhoneCall]
			ON [PhoneCall].[Class] = [pjm5vwReportCalculationLine].[DocumentClass] AND
			[PhoneCall].[ID] = [pjm5vwReportCalculationLine].[DocumentID]
		INNER JOIN [PhoneCallCode]
			ON [PhoneCallCode].[ID] = [PhoneCall].[PhoneCallCodeID]
		LEFT OUTER JOIN [Property]
			ON [Property].[Class] = [PhoneCallCode].[Class]
		LEFT OUTER JOIN [PropertyValue]
			ON [PropertyValue].[PropertyID] = [Property].[ID] AND
			[PropertyValue].[DocumentID] = [PhoneCallCode].[ID]			
		WHERE
			[pjm5vwReportCalculationLine].[CalculationID] = @ID
			AND [pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass
			AND [Property].[Guid] = '00000001-0000-0000-0000-000000000000'
		GROUP BY
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			[pjm5vwReportCalculationLine].[Price],
			[PropertyValue].[Value]
		ORDER BY [TypeCode] ASC
	ELSE IF (@DocumentCalculationClass = @requestClass)
		SELECT
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			SUM([pjm5vwReportCalculationLine].[Amount]) AS [Amount],
			[pjm5vwReportCalculationLine].[Price],
			SUM([pjm5vwReportCalculationLine].[Total]) AS [Total],
			[PropertyValue].[Value] AS [Addlang]
		FROM [pjm5vwReportCalculationLine]
			LEFT OUTER JOIN [Employee]
				ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
			INNER JOIN [ServiceRequest]
				ON [ServiceRequest].[Class] = [pjm5vwReportCalculationLine].[DocumentClass] AND
				[ServiceRequest].[ID] = [pjm5vwReportCalculationLine].[DocumentID]
			INNER JOIN [ServiceAssignment]
				ON [TypeID] = [ServiceAssignment].[ID]
			LEFT OUTER JOIN [Property]
				ON [Property].[Class] = [ServiceAssignment].[Class]
			LEFT OUTER JOIN [PropertyValue]
				ON [PropertyValue].[PropertyID] = [Property].[ID] AND
				[PropertyValue].[DocumentID] = [ServiceAssignment].[ID]
		WHERE
			[pjm5vwReportCalculationLine].[CalculationID] = @ID AND
			[pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass AND
			[Property].[Guid] = '00000001-0000-0000-0000-000000000000'
		GROUP BY
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			[pjm5vwReportCalculationLine].[Price],
			[PropertyValue].[Value]
		ORDER BY [TypeCode] ASC
	ELSE
		SELECT
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			SUM([pjm5vwReportCalculationLine].[Amount]) AS [Amount],
			--[pjm5vwReportCalculationLine].[Price],
			1 AS [Price],
			SUM([pjm5vwReportCalculationLine].[Total]) AS [Total],
			' ' AS [Value]
		FROM [pjm5vwReportCalculationLine]
			LEFT OUTER JOIN [Employee]
				ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
			WHERE
				[pjm5vwReportCalculationLine].[CalculationID] = @ID AND
				[pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass
		GROUP BY
			[TypeID],
			[TypeCode],
			[TypeFileAs]
		ORDER BY [TypeCode] ASC

/*
	END OF NEW BLOCK
*/

-- CustomerAddress
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @CustomerID AND 
		[Address].[BusinessCardClass] = @CompanyClass

-- CustomerPhone
	SELECT
			[Phone].[PhoneTypeID],
			[Phone].[Phone]
		FROM
			[Phone]	
		WHERE
			[Phone].[BusinessCardID] = @CustomerID AND 
			[Phone].[BusinessCardClass] = @CompanyClass

-- ContactAddress	
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @ContactID AND 
		[Address].[BusinessCardClass] = @EmployeeClass

-- ContactPhone
	SELECT
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]	
	WHERE
		[Phone].[BusinessCardID] = @ContactID AND 
		[Phone].[BusinessCardClass] = @EmployeeClass

-- ContactEmail
	SELECT
		[Email].[EmailTypeID],
		[Email].[Email]
	FROM
		[Email]	

	WHERE
		[Email].[BusinessCardID] = @ContactID AND 
		[Email].[BusinessCardClass] = @EmployeeClass

-- GroupByEmployee
	insert into @empGroup			
	SELECT
		0,
		[Employee].[Initials],	
		[Employee].[FileAs],
		[Employee].[FirstName],
		[Employee].[MiddleName],
		[Employee].[LastName],
		[pjm5vwReportCalculationLine].[Date],
		[pjm5vwReportCalculationLine].[EmployeeID],
		[pjm5vwReportCalculationLine].[TypeID],
		[pjm5vwReportCalculationLine].[TypeCode],
		[pjm5vwReportCalculationLine].[TypeFileAs],
		[pjm5vwReportCalculationLine].[Description],
		[pjm5vwReportCalculationLine].[Amount],
		--[pjm5vwReportCalculationLine].[Price] AS [Price]
		CASE 
			WHEN @ShowPrice = 0 THEN 0.0
			--WHEN [pjm5vwReportCalculationLine].[VATIsIncluded] = 1 AND [pjm5vwReportCalculationLine].[Amount] != 0
			--	THEN [pjm5vwReportCalculationLine].[Price] - [pjm5vwReportCalculationLine].[VAT] / [pjm5vwReportCalculationLine].[Amount]
			ELSE [pjm5vwReportCalculationLine].[Price]
		END AS [Price],
		CASE 
			WHEN @ShowPrice = 0 THEN 0.0
			--WHEN [pjm5vwReportCalculationLine].[VATIsIncluded] = 1
			--	THEN ([pjm5vwReportCalculationLine].[Amount] * [pjm5vwReportCalculationLine].[Price] - [pjm5vwReportCalculationLine].[VAT])
			ELSE [pjm5vwReportCalculationLine].[Amount] * [pjm5vwReportCalculationLine].[Price]
		END AS [Total],
		[vwAssignment].[StandardRate]
	FROM
		[pjm5vwReportCalculationLine]
		LEFT OUTER JOIN [Employee]
			ON [pjm5vwReportCalculationLine].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Calculation]		-- -> [ProjectID]
			ON [pjm5vwReportCalculationLine].[CalculationID] = [Calculation].[ID]
		LEFT OUTER JOIN [vwAssignment]		-- -> [StandardRate]
				ON [Calculation].[ProjectID] = [vwAssignment].[ProjectID]	AND [Employee].[ID] = [vwAssignment].[EmployeeID]  
																			AND		(
																					[vwAssignment].[State] = 1 
																					OR
																					([vwAssignment].[Modified] = 
																										(SELECT max([Modified]) 
																										FROM [vwAssignment]
																										GROUP BY [EmployeeID], [ProjectID]
																										HAVING [EmployeeID] = [Employee].[ID] AND [ProjectID] = [Calculation].[ProjectID]
																										) 
																					AND [vwAssignment].[State] = 2)
																					)
	WHERE
		[pjm5vwReportCalculationLine].[CalculationID] = @ID AND
		[pjm5vwReportCalculationLine].[DocumentClass] = @DocumentCalculationClass
	ORDER BY
		CASE WHEN @DocumentCalculationClass = @TimeClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @TimeClass THEN [Price] END Desc,
		CASE WHEN @DocumentCalculationClass = @ExpenseClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @ExpenseClass THEN [Amount] END DESC,
		CASE WHEN @DocumentCalculationClass = @PhoneClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @PhoneClass THEN [Amount] END ASC,
		CASE WHEN @DocumentCalculationClass = @RequestClass THEN [pjm5vwReportCalculationLine].[Date] END ASC,
		CASE WHEN @DocumentCalculationClass = @RequestClass THEN [Employee].[Initials] END ASC

IF @GroupTimeEntry = 0							--   
	BEGIN
		DECLARE tCursor CURSOR FOR				--  
			SELECT [Flag], [Date], [EmployeeID], [Description], [Price], [Rate], [EmployeeFileAs] FROM @empGroup
		OPEN tCursor
		FETCH NEXT FROM tCursor INTO @Flag, @Date, @EmployeeID, @Description, @Price, @Rate, @EmployeeFileAs
		WHILE @@fetch_status = 0 
		BEGIN
			IF @Date IN (
							SELECT min([Date])
							FROM @empGroup
							GROUP BY [EmployeeID]
							HAVING [EmployeeID] = @EmployeeID AND SUM([Flag]) < 1
						 )
			BEGIN
				UPDATE TOP(1) @empGroup
				SET [Flag] = 1				--       (   ).	[Flag = 1]
				WHERE
				[Date] = @Date AND
				[EmployeeID] = @EmployeeID AND
				[Description] = @Description AND
				[Rate] = @Rate
			
				INSERT INTO @empGroup 		--        .	[Flag = 2]
				SELECT
					2,[EmployeeInitials],[EmployeeFileAs],'','','',DateAdd(year,99,Getdate()),[EmployeeID],0,0,'','',Sum([Amount]),0,Sum([Total]),[Rate]
				FROM @empGroup
				GROUP BY [EmployeeID], [EmployeeInitials], [EmployeeFileAs], [Rate]
				HAVING [EmployeeID] = @EmployeeID

				/*INSERT INTO @empGroup 		--    -.							[Flag = 3]
				SELECT
					3,[EmployeeInitials],'','','','',DateAdd(year,100,Getdate()),[EmployeeID],0,0,'','',0,[Price],0
				FROM @empGroup
				GROUP BY [EmployeeID], [EmployeeInitials], [Price]
				HAVING [EmployeeID] = @EmployeeID*/

				INSERT INTO @empGroup 		--        .	[Flag = 4]
				SELECT
					4,[EmployeeInitials],[EmployeeFileAs],'','','',DateAdd(year,-99,Getdate()),[EmployeeID],0,0,'','',0,0,0,[Rate]
				FROM @empGroup
				GROUP BY [EmployeeID], [EmployeeInitials], [EmployeeFileAs], [Rate]
				HAVING [EmployeeID] = @EmployeeID
				
			END
			FETCH NEXT FROM tCursor INTO @Flag, @Date, @EmployeeID, @Description, @Price, @Rate, @EmployeeFileAs
		END
		CLOSE tCursor
		DEALLOCATE tCursor

		SELECT
			[Flag],
			[EmployeeInitials],	
			[EmployeeFileAs],
			[EmployeeFirst],
			[EmployeeMiddle],
			[EmployeeLast],
			[Date],
			[EmployeeID],
			[TypeID],
			[TypeCode],
			[TypeFileAs],
			[Description],
			[Amount],
			[Price],
			[Total],
			[Rate]
		FROM @empGroup
		ORDER BY [Rate] DESC, [EmployeeInitials], [EmployeeFileAs], [Date], [Flag] DESC
	END
ELSE			--   
	BEGIN
		DECLARE ttCursor CURSOR FOR														--,       ()
		SELECT [Date], [EmployeeID], [Description], [Price] FROM @empGroup
		OPEN ttCursor
		FETCH NEXT FROM ttCursor INTO @Date, @EmployeeID, @Description, @Price
		WHILE @@fetch_status = 0 
		BEGIN
			UPDATE @empGroup
			SET [Date] = 
			(
				SELECT min([Date])
				FROM @empGroup
				GROUP BY
					CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112),
					[EmployeeID],
					[Description],
					[Price]
				HAVING
					CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112) = CONVERT(datetime, CONVERT(varchar(8), @Date, 112), 112) AND
					[EmployeeID] = @EmployeeID AND
					[Description] = @Description AND
					[Price] = @Price)
			WHERE
				CONVERT(datetime, CONVERT(varchar(8), [Date], 112), 112) = CONVERT(datetime, CONVERT(varchar(8), @Date, 112), 112) AND
				[EmployeeID] = @EmployeeID AND
				[Description] = @Description AND
				[Price] = @Price
			FETCH NEXT FROM ttCursor INTO @Date, @EmployeeID, @Description, @Price
		END
		CLOSE ttCursor
		DEALLOCATE ttCursor

		IF (@ShowActivityTypes = 0)
		BEGIN
			DECLARE tCursor CURSOR FOR														--  
				SELECT [Flag], [Date], [EmployeeID], [Description], [Price], [Rate], [EmployeeFileAs] FROM @empGroup
			OPEN tCursor
			FETCH NEXT FROM tCursor INTO @Flag, @Date, @EmployeeID, @Description, @Price, @Rate, @EmployeeFileAs
			WHILE @@fetch_status = 0 
			BEGIN
				IF @Date IN (
								SELECT min([Date])
								FROM @empGroup
								GROUP BY [EmployeeID]
								HAVING [EmployeeID] = @EmployeeID AND SUM([Flag]) < 1
							 )
				BEGIN
					UPDATE @empGroup
					SET [Flag] = 1				--       (   ).	[Flag = 1]
					WHERE
					[Date] = @Date AND
					[EmployeeID] = @EmployeeID AND
					[Description] = @Description AND
					[Rate] = @Rate
			
					INSERT INTO @empGroup 		--        .	[Flag = 2]
					SELECT
						2,[EmployeeInitials],[EmployeeFileAs],'','','',DateAdd(year,99,Getdate()),[EmployeeID],0,0,'','',Sum([Amount]),0,Sum([Total]),[Rate]
					FROM @empGroup
					GROUP BY [EmployeeID], [EmployeeInitials], [EmployeeFileAs], [Rate]
					HAVING [EmployeeID] = @EmployeeID

					/*INSERT INTO @empGroup 		--    -.							[Flag = 3]
					SELECT
						3,[EmployeeInitials],'','','','',DateAdd(year,100,Getdate()),[EmployeeID],0,0,'','',0,[Price],0
					FROM @empGroup
					GROUP BY [EmployeeID], [EmployeeInitials], [Price]
					HAVING [EmployeeID] = @EmployeeID*/

					INSERT INTO @empGroup 		--        .	[Flag = 4]
					SELECT
						4,[EmployeeInitials],[EmployeeFileAs],'','','',DateAdd(year,-99,Getdate()),[EmployeeID],0,0,'','',0,0,0,[Rate]
					FROM @empGroup
					GROUP BY [EmployeeID], [EmployeeInitials], [EmployeeFileAs], [Rate]
					HAVING [EmployeeID] = @EmployeeID
				
				END
				FETCH NEXT FROM tCursor INTO @Flag, @Date, @EmployeeID, @Description, @Price, @Rate, @EmployeeFileAs
			END
			CLOSE tCursor
			DEALLOCATE tCursor

			SELECT
				[Flag],
				[Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[Description],
				SUM([Amount]) AS [Amount],
				[Price],
				SUM([Total]) AS [Total],
				[Rate]
			FROM @empGroup
			GROUP BY	
				[Flag],
				[Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[Description],
				[Price],
				[Rate]
			ORDER BY
				[Rate] DESC, [EmployeeInitials], [EmployeeFileAs], [Date], [Flag] DESC
		END
		ELSE		--@ShowActivityTypes = 1
		BEGIN
			DECLARE tCursor CURSOR FOR														--  
				SELECT [Flag], [Date], [EmployeeID], [Description], [Price], [Rate], [TypeID], [EmployeeFileAs] FROM @empGroup
			OPEN tCursor
			FETCH NEXT FROM tCursor INTO @Flag, @Date, @EmployeeID, @Description, @Price, @Rate, @TypeID, @EmployeeFileAs
			WHILE @@fetch_status = 0 
			BEGIN
				IF @Date IN (
								SELECT min([Date])
								FROM @empGroup
								GROUP BY [EmployeeID]
								HAVING [EmployeeID] = @EmployeeID AND SUM([Flag]) < 1
							 )
					/*AND @TypeID IN (
								SELECT min([TypeID])
								FROM @empGroup
								GROUP BY [EmployeeID]
								HAVING [EmployeeID] = @EmployeeID AND SUM([Flag]) < 1
							)*/
				BEGIN
					UPDATE @empGroup
					SET [Flag] = 1				--       (   ).	[Flag = 1]
					WHERE
					[Date] = @Date AND
					[EmployeeID] = @EmployeeID AND
					[Description] = @Description AND
					[Rate] = @Rate AND
					[TypeID] = @TypeID
			
					INSERT INTO @empGroup 		--        .	[Flag = 2]
					SELECT
						2,[EmployeeInitials],[EmployeeFileAs],'','','',DateAdd(year,99,Getdate()),[EmployeeID],0,0,'','',Sum([Amount]),0,Sum([Total]),[Rate]
					FROM @empGroup
					GROUP BY [EmployeeID], [EmployeeInitials], [EmployeeFileAs], [Rate]
					HAVING [EmployeeID] = @EmployeeID

					/*INSERT INTO @empGroup 		--    -.							[Flag = 3]
					SELECT
						3,[EmployeeInitials],'','','','',DateAdd(year,100,Getdate()),[EmployeeID],0,0,'','',0,[Price],0
					FROM @empGroup
					GROUP BY [EmployeeID], [EmployeeInitials], [Price]
					HAVING [EmployeeID] = @EmployeeID*/

					INSERT INTO @empGroup 		--        .	[Flag = 4]
					SELECT
						4,[EmployeeInitials],[EmployeeFileAs],'','','',DateAdd(year,-99,Getdate()),[EmployeeID],0,0,'','',0,0,0,[Rate]
					FROM @empGroup
					GROUP BY [EmployeeID], [EmployeeInitials], [EmployeeFileAs], [Rate]
					HAVING [EmployeeID] = @EmployeeID
				
				END
				FETCH NEXT FROM tCursor INTO @Flag, @Date, @EmployeeID, @Description, @Price, @Rate, @TypeID, @EmployeeFileAs
			END
			CLOSE tCursor
			DEALLOCATE tCursor
			SELECT
				[Flag],
				[Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[TypeID],
				[TypeCode],
				[TypeFileAs],
				[Description],
				SUM([Amount]) AS [Amount],
				[Price],
				SUM([Total]) AS [Total],
				[Rate]
			FROM @empGroup
			GROUP BY	
				[Flag],
				[Date],
				[EmployeeInitials],	
				[EmployeeFileAs],
				[EmployeeFirst],
				[EmployeeMiddle],
				[EmployeeLast],
				[EmployeeID],
				[TypeID],
				[TypeCode],
				[TypeFileAs],
				[Description],
				[Price],
				[Rate]
			ORDER BY
				[Rate] DESC, [EmployeeInitials], [EmployeeFileAs], [Date], [Flag] DESC
	END			
	END

	SELECT
		dbo.pjm6fnCurrencyGetRate([Calculation].[CurrencyCode], [Calculation].[Date], @NationalCurrencyCode) as [NationalCurrencyRate]
	FROM
		[Calculation]
	WHERE
		[Calculation].[ID] = @ID

	RETURN 0
GO

GRANT EXEC ON ReportWordCalculationV2 TO PUBLIC
GO
