IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordInvoice')
	BEGIN
		PRINT 'Dropping Procedure ReportWordInvoice'
		DROP  Procedure  ReportWordInvoice
	END

GO

PRINT 'Creating Procedure ReportWordInvoice'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportWordInvoice
	@ID int,
	@Version TName,
	@Language TName = NULL	
AS
	IF @Version = '5.5'
	BEGIN
		EXEC ReportInvoice @ID, @Language
		RETURN 0
	END
	
	EXEC ReportWordInvoiceV2 @ID, @Language
	RETURN 0
GO

GRANT EXEC ON ReportWordInvoice TO PUBLIC
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordInvoiceV2')
	BEGIN
		PRINT 'Dropping Procedure ReportWordInvoiceV2'
		DROP  Procedure  ReportWordInvoiceV2
	END

GO

PRINT 'Creating Procedure ReportWordInvoiceV2'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------
*******************************************************************************
**		Change History
*******************************************************************************
**		01.12.10	SYV				  [CurrencySymbol]
**		03.12.10	SYV				  [PaymentCurrencyPoint]
**		13.07.11	SYV				  SupplierCompanyID, CustomerCompanyID  
**      13.02.12    DAV               [BankCurrencyCode]
**		20.09.12	SAP				  [TotalWithVATFract], [VATFract], [PaymentValueFract], 
**									[PaymentVATFract],  [RemainValueFract], [RemainVATFract], 
**									[AdvanceValueFract], [AdvanceVATFract]
**		02.11.12	SAP				  ProjectLanguage
**		28.06.13	SAP				   InvoiceLine  ServiceAssignmentFileAs
**									 ServiceTypeRatesDepended
*******************************************************************************/
CREATE Procedure ReportWordInvoiceV2
	@ID int,
	@Language Tname = NULL	
AS
	SET NOCOUNT ON
	DECLARE
		@Total money,
		@TotalWithVAT money,
		@VAT money	,
		@TotalCount int,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@Currency TName,
		@AdvanceValue TMoney,
		@AdvanceVAT TMoney,
		@PaymentValue TMoney,
		@PaymentVAT TMoney,
		@RemainValue TMoney,
		@RemainVAT TMoney,
		@Class TClass,
		@Code TName,
		@CompanyClass TClass,
		@EmployeeClass TClass,
		@ProjectID TIdentifier,
		@ContactID TIdentifier,
		@SupplierID TIdentifier,
		@CustomerID TIdentifier,
		@CurrencyCode TCode
		
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')

	DECLARE
		@TimeEntryClass TClass,
		@ExpenseClass TClass,
		@PhoneCallClass TClass,
		@ServiceRequestClass TClass,
		@StatementClass TClass,
		@InvoiceClass TClass

	SET @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET @ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')
	SET @PhoneCallClass = dbo.adfGetClassByName('Pjm5.PhoneCall')
	SET @ServiceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
	SET @StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET @InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')

	SET @Code = CASE WHEN @Language = 'en' THEN 'Invoice; ' ELSE '; ' END
	SELECT
		@ProjectID = [Project].[ID],
		@ContactID = [Project].[ResponsiblePersonEmployeeID],
		@Currency = CASE [Project].[InvoiceCurrency] WHEN 0 THEN 'Project' ELSE 'Payment' END,
		@CurrencyCode = CASE [Project].[InvoiceCurrency] WHEN 0 THEN [Project].[CurrencyCode] ELSE [Invoice].[CurrencyCode] END,
		@Class = [Invoice].[Class],
		@Total = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[TotalPC]
			ELSE [Invoice].[Total]
		END,
		@VAT = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[VATPC]
			ELSE [Invoice].[VAT]
		END,
		@TotalWithVAT = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[TotalWithVATPC]
			ELSE [Invoice].[TotalWithVAT]
		END,
		@SupplierID = [Invoice].[SupplierCompanyID],
		@CustomerID = [Invoice].[CustomerCompanyID]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
	WHERE
		[Invoice].[ID] = @ID	
		
	SELECT 
		@AdvanceValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[TotalWithVAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalWithVATPC]
			END, 0.0)),
		@AdvanceVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[VAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[VATPC]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
		
	SELECT 
		@PaymentValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [PaymentDetail].[PaymentValue]
				WHEN @Currency = 'Project'
					THEN [PaymentDetail].[Value]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
		INNER JOIN [PaymentDetail]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	SET @PaymentValue = ISNULL(@PaymentValue, 0)
	
	SET @RemainValue =
		CASE 
			WHEN @TotalWithVAT > ISNULL(@AdvanceValue, 0.0) THEN @TotalWithVAT - ISNULL(@AdvanceValue, 0.0) 
			ELSE 0.0
		END
	SET @RemainVAT =
		CASE
			WHEN @VAT > ISNULL(@AdvanceVAT, 0.0) THEN @VAT - ISNULL(@AdvanceVAT, 0.0) 
			ELSE 0.0
		END

	DECLARE @t TABLE(
		[ID] int,
		[Description] nvarchar(max),
		[Amount] decimal(18,4),
		[Price] money,
		[Total] money,
		[VATRate] decimal(18,4),
		[VAT] money,
		[PriceWithVAT] money,
		[TotalWithVAT] money,
		[UOMID] int,
		[ServiceTypeID] int,
		[ServiceTypeFileAs] nvarchar(max),
		[ServiceTypeRatesDepended] bit,
		[DocumentClass] TClass null,
		[DocumentID] TIdentifier null,
		[ServiceAssignmentFileAs] nvarchar(max)
	)
	IF @Currency = 'Payment'
	BEGIN
		INSERT INTO @t
			([ID],
			[Description],
			[Amount],[Price],[Total],
			[VATRate],[VAT],
			[PriceWithVAT],[TotalWithVAT],
			[UOMID],[ServiceTypeID],[ServiceTypeFileAs],[ServiceTypeRatesDepended], 
			[DocumentClass],[DocumentID],[ServiceAssignmentFileAs])
		SELECT
			[InvoiceLine].[ID],
			[InvoiceLine].[Description],
			[InvoiceLine].[Amount],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
				ELSE [InvoiceLine].[Price]
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
					ELSE [InvoiceLine].[Price]
				END,
			[InvoiceLine].[VATRate],
			[InvoiceLine].[VAT],		
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
				ELSE [InvoiceLine].[Price]
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
					ELSE [InvoiceLine].[Price]
				END,
			[InvoiceLine].[UOMID],
			[ServiceType].[ID],
			[ServiceType].[FileAs],
			[ServiceType].[RatesDepended],
			[InvoiceLine].[DocumentClass],
			[InvoiceLine].[DocumentID],
			[ServiceAssignment].[FileAs]
		FROM
			[InvoiceLine]
			LEFT OUTER JOIN [ServiceType]
				ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
			LEFT JOIN [ServiceAssignment]
				ON [ServiceAssignment].[Class] = [InvoiceLine].[DocumentClass]
					AND [ServiceAssignment].[ID] = [InvoiceLine].[DocumentID]
		WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	END
	ELSE
	BEGIN
		INSERT INTO @t
			([ID],
			[Description],
			[Amount],[Price],[Total],
			[VATRate],[VAT],
			[PriceWithVAT],[TotalWithVAT],
			[UOMID],[ServiceTypeID],[ServiceTypeFileAs],[ServiceTypeRatesDepended],
			[DocumentClass],[DocumentID],[ServiceAssignmentFileAs])
		SELECT
			[InvoiceLine].[ID],
			[InvoiceLine].[Description],
			[InvoiceLine].[Amount],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
				ELSE [InvoiceLine].[PricePC] 	 
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
					ELSE [InvoiceLine].[PricePC] 
				END,
			[InvoiceLine].[VATRate],
			[InvoiceLine].[VATPC],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] + [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
				ELSE [InvoiceLine].[PricePC] 	 
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] + [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
					ELSE [InvoiceLine].[PricePC] 
				END,
			[InvoiceLine].[UOMID],
			[ServiceType].[ID],
			[ServiceType].[FileAs],
			[ServiceType].[RatesDepended],
			[InvoiceLine].[DocumentClass],
			[InvoiceLine].[DocumentID],
			[ServiceAssignment].[FileAs]
		FROM
			[InvoiceLine]
			LEFT OUTER JOIN [ServiceType]
				ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
			LEFT JOIN [ServiceAssignment]
				ON [ServiceAssignment].[Class] = [InvoiceLine].[DocumentClass]
					AND [ServiceAssignment].[ID] = [InvoiceLine].[DocumentID]
		WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	END	
	SELECT
		@TotalCount = COUNT(*),
		@VATRate = MAX([VATRate]),
		@VATRateCount = COUNT(DISTINCT [VATRate])
	FROM
		@t
		
	SELECT
		[Invoice].[ID],
		[Invoice].[FileAs],
		[Invoice].[Number],
		[Invoice].[Date],
		(CASE WHEN [Invoice].[InvoiceExpirationPeriodType] = 1 THEN
			dbo.fnPjm5GetWorkingDays([Invoice].[Date], [Invoice].[DueDate]) 
		ELSE
			DATEDIFF(day, [Invoice].[Date], [Invoice].[DueDate]) + 1
		END)  AS [ExpirationPeriod],
		[Invoice].[InvoiceExpirationPeriodType] as [ExpirationPeriodType],
		[Invoice].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Invoice].[SupplierCompanyID],
		[Invoice].[CustomerCompanyID],

		[BankAccount].[ID] AS [BankAccountID],
		[BankAccount].[BankName] AS [BankName],
		[BankAccount].[City] AS [BankCity],
		[BankAccount].[Address] AS [BankAddress],
		[BankAccount].[BankCode] AS [BankCode],
		[BankAccount].[Account] AS [CAccount],
		[BankAccount].[IntermediaryBank] AS [SBankName],
		[BankAccount].[IntermediaryAccount] AS [SAccount],
		[BankAccount].[IntermediaryAddress] AS [SBankAddress],
		[BankAccount].[SWIFT] AS [SWIFT],
		[BankAccount].[IntermediarySWIFT] AS [SSWIFT],
		[BankAccount].[CurrencyCode] AS [BankCurrencyCode],

		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],

		[SupplierCompany].[LegalCode] AS [SupplierCompanyLegalCode],
		[SupplierCompany].[KPP] AS [SupplierCompanyKPP],

		[CustomerCompany].[LegalCode] AS [CustomerCompanyLegalCode],
		[CustomerCompany].[KPP] AS [CustomerCompanyKPP],

		[CustomerCompany].[ExecutiveEmployeeID] AS [CustomerExecutiveEmployeeID],
		[CustomerExecutive].[LastName] + 
			ISNULL(' ' + [CustomerExecutive].[FirstName], '') + 
				ISNULL(' ' + [CustomerExecutive].[MiddleName], '') AS [CustomerExecutiveName],
		[CustomerExecutive].[FileAs] AS [CustomerExecutiveFileAs],
		[CustomerExecutivePosition].[ID] AS [CustomerExecutivePositionID],
		[CustomerExecutivePosition].[FileAs] AS [CustomerExecutivePositionFileAs],

		[CustomerContact].[ID] AS [CustomerContactEmployeeID],
		[CustomerContact].[LastName] + 
			ISNULL(' ' + [CustomerContact].[FirstName], '') + 
				ISNULL(' ' + [CustomerContact].[MiddleName], '') AS [CustomerContactName],
		[CustomerContact].[FileAs] AS [CustomerContactFileAs],
		[CustomerContactPosition].[ID] AS [CustomerContactPositionID],
		[CustomerContactPosition].[FileAs] AS [CustomerContactPositionFileAs],

		[SupplierCompany].[ExecutiveEmployeeID] AS [SupplierExecutiveEmployeeID],
		[SupplierExecutive].[LastName] + 
			ISNULL(' ' + [SupplierExecutive].[FirstName], '') + 
				ISNULL(' ' + [SupplierExecutive].[MiddleName], '') AS [SupplierExecutiveName],
		[SupplierExecutive].[FileAs] AS [SupplierExecutiveFileAs],
		[SupplierExecutivePosition].[ID] AS [SupplierExecutivePositionID],
		[SupplierExecutivePosition].[FileAs] AS [SupplierExecutivePositionFileAs],

		[SupplierCompany].[AccountantEmployeeID] AS [SupplierAccountantEmployeeID],
		[SupplierAccountant].[LastName] + 
			ISNULL(' ' + [SupplierAccountant].[FirstName], '') + 
				ISNULL(' ' + [SupplierAccountant].[MiddleName], '') AS [SupplierAccountantName],
		[SupplierAccountant].[FileAs] AS [SupplierAccountantFileAs],
		[SupplierAccountantPosition].[ID] AS [SupplierAccountantPositionID],
		[SupplierAccountantPosition].[FileAs] AS [SupplierAccountantPositionFileAs],

		@Total AS [Total],
		@VAT AS [VAT],
		CAST(REPLACE(CAST(ROUND(@VAT,2,1) - ROUND(ROUND(@VAT,2,1),0,1) AS varchar),'0.','') AS int) AS [VATFract],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN @Total
			ELSE @Total + @VAT
		END AS [TotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 
				THEN CAST(REPLACE(CAST(ROUND(@Total,2,1) - ROUND(ROUND(@Total,2,1),0,1) AS varchar),'0.','') AS int)
			ELSE CAST(REPLACE(CAST(ROUND(@Total + @VAT,2,1) - ROUND(ROUND(@Total + @VAT,2,1),0,1) AS varchar),'0.','') AS int)
		END AS [TotalWithVATFract],
		CASE
			WHEN @Total IS NULL THEN 0
			ELSE 1
		END	AS [TotalFlag],
		
		dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode) AS [TotalCurrencyCode],
		dbo.fnPjm5CurrencyToString(@VAT, @CurrencyCode) AS [VATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString((@Total + @VAT), @CurrencyCode)
		END AS [TotalWithVATCurrencyCode],

		@AdvanceValue AS [AdvanceValue],
		CAST(REPLACE(CAST(ROUND(@AdvanceValue,2,1) - ROUND(ROUND(@AdvanceValue,2,1),0,1) AS varchar),'0.','') AS int)  AS [AdvanceValueFract],
		@AdvanceVAT AS [AdvanceVAT],
		CAST(REPLACE(CAST(ROUND(@AdvanceVAT,2,1) - ROUND(ROUND(@AdvanceVAT,2,1),0,1) AS varchar),'0.','') AS int)  AS [AdvanceVATFract],
		CASE
			WHEN ISNULL(@AdvanceValue, 0.0) = 0 THEN 0
			ELSE 1 
		END	AS [AdvanceFlag],
		dbo.fnPjm5CurrencyToString(@AdvanceValue, @CurrencyCode) AS [AdvanceValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@AdvanceVAT, @CurrencyCode) AS [AdvanceVATCurrencyCode],

		@PaymentValue AS [PaymentValue],
		CAST(REPLACE(CAST(ROUND(@PaymentValue,2,1) - ROUND(ROUND(@PaymentValue,2,1),0,1) AS varchar),'0.','') AS int) AS [PaymentValueFract],
		@PaymentVAT AS [PaymentVAT],
		CAST(REPLACE(CAST(ROUND(@PaymentVAT,2,1) - ROUND(ROUND(@PaymentVAT,2,1),0,1) AS varchar),'0.','') AS int) AS [PaymentVATFract],
		CASE
			WHEN ISNULL(@PaymentValue, 0.0) = 0 THEN 0
			ELSE 1 
		END	AS [PaymentFlag],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentValue, 0.0), @CurrencyCode) AS [PaymentValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentVAT, 0.0), @CurrencyCode) AS [PaymentVATCurrencyCode],

		@RemainValue AS [RemainValue],
		CAST(REPLACE(CAST(ROUND(@RemainValue,2,1)- ROUND(ROUND(@RemainValue,2,1),0,1) AS varchar),'0.','') AS int) AS [RemainValueFract],
		@RemainVAT AS [RemainVAT],
		CAST(REPLACE(CAST(ROUND(@RemainVAT,2,1)- ROUND(ROUND(@RemainVAT,2,1),0,1) AS varchar),'0.','') AS int) AS [RemainVATFract],
		CASE
			WHEN ISNULL(@RemainValue, 0.0) = 0 THEN 0
			ELSE 1
		END	AS [RemainFlag],
		dbo.fnPjm5CurrencyToString(@RemainValue, @CurrencyCode) AS [RemainValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@RemainVAT, @CurrencyCode) AS [RemainVATCurrencyCode],
		
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN (@VATRate * 100)
			ELSE NULL
		END AS [VATRate],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN 1
			ELSE 0
		END AS [VATFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			ELSE 1
		END	AS [VATRateFlag],
		@TotalCount AS [TotalCount],

		CASE @Currency WHEN 'Payment' THEN [Currency].[ID] ELSE [ProjectCurrency].[ID] END AS [CurrencyID],
		CASE @Currency WHEN 'Payment' THEN [Currency].[FileAs] ELSE [ProjectCurrency].[FileAs] END AS [CurrencyFileAs],
		CASE @Currency WHEN 'Payment' THEN [Currency].[Code] ELSE [ProjectCurrency].[Code] END AS [CurrencyCode],
		CASE 
			WHEN @Currency = 'Payment' AND
				dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			WHEN @Currency != 'Payment' AND
				dbo.adfPropertyValueGetText([ProjectCurrency].[Class], [ProjectCurrency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		[CustomerExecutive].[Gender] as [CustomerExecutiveGender],
		[CustomerContact].[Gender] as [CustomerContactGender],
		[Statement].[PeriodStart],
		[Statement].[PeriodEnd],
		CASE @Currency WHEN 'Payment' THEN [Currency].[Symbol] ELSE [ProjectCurrency].[Symbol] END AS [CurrencySymbol],
		[Invoice].[PaymentCurrencyPoint],
		[Invoice].[Advance],
		[SupplierCompany].[Number] as [SupplierCode],
		[CustomerCompany].[Number] as [CustomerCode],
		[Project].[NumerationCode] as [ProjectNumerationCode],
		[Project].[ProjectLanguageCode] AS [ProjectLanguage]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Invoice].[CurrencyCode] = [Currency].[Code]
		INNER JOIN [Currency] AS [ProjectCurrency]
			ON [Project].[CurrencyCode] = [ProjectCurrency].[Code]
			
		INNER JOIN [Company] AS [SupplierCompany]	
			ON [Invoice].[SupplierCompanyID] = [SupplierCompany].[ID]
		INNER JOIN [Company] AS [CustomerCompany]	
			ON [Invoice].[CustomerCompanyID] = [CustomerCompany].[ID]
			
		LEFT OUTER JOIN [Employee] AS [SupplierExecutive]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierExecutivePosition]
			ON [SupplierExecutive].[PositionID] = [SupplierExecutivePosition].[ID]

		LEFT OUTER JOIN [Employee] AS [SupplierAccountant]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierAccountantPosition]
			ON [SupplierAccountant].[PositionID] = [SupplierAccountantPosition].[ID]

		LEFT OUTER JOIN [vwEmployeeWithEP] AS [CustomerExecutive]
			ON [CustomerCompany].[ExecutiveEmployeeID] = [CustomerExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerExecutivePosition]
			ON [CustomerExecutive].[PositionID] = [CustomerExecutivePosition].[ID]

		LEFT OUTER JOIN [vwEmployeeWithEP] AS [CustomerContact]
			ON [Project].[ResponsiblePersonEmployeeID] = [CustomerContact].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerContactPosition]
			ON [CustomerContact].[PositionID] = [CustomerContactPosition].[ID]
		LEFT OUTER JOIN [BankAccount]
			ON [Invoice].[SupplierBankAccountID] = [BankAccount].[ID]
			
		LEFT OUTER JOIN [Attachment]
			ON [Attachment].[DocumentClass] = [Invoice].[Class] 
				AND [Attachment].[DocumentID] = @ID AND [Attachment].[LinkDocumentClass] = @StatementClass
		LEFT OUTER JOIN [Statement]
			ON [Attachment].[LinkDocumentClass] = [Statement].[Class] AND [Attachment].[LinkDocumentID] = [Statement].[ID]
	WHERE 
		[Invoice].[ID] = @ID		

	SELECT
		[Lines].[ID],
		[Lines].[DocumentID],
		[Lines].[Description],
		[Lines].[Amount],
		[Lines].[Price],
		[Lines].[Total],
		[Lines].[VAT],
		[Lines].[PriceWithVAT],
		[Lines].[TotalWithVAT],
		[Lines].[UOMID],
		[Lines].[ServiceTypeID],
		[Lines].[ServiceTypeFileAs],
		ISNULL([Lines].[ServiceTypeRatesDepended],1) AS [ServiceTypeRatesDepended],
		[Calculation].[Number] as [CalculationNumber],
		[Calculation].[Date] as [CalculationDate],
		[Calculation].[PeriodStart] as [CalculationPeriodStart],
		[Calculation].[PeriodEnd] as [CalculationPeriodEnd],
		CASE [Calculation].[DocumentClass]
			WHEN @TimeEntryClass THEN 0
			WHEN @ExpenseClass THEN 1
			WHEN @PhoneCallClass THEN 2
			WHEN @ServiceRequestClass THEN 3
			ELSE NULL
		END as [CalculationType],
		[Class].[Code] as [LineClass],
		[Lines].[ServiceAssignmentFileAs] AS [ServiceAssignmentFileAs]
	FROM
		@t [Lines]
		LEFT OUTER JOIN [Calculation]
			ON [Lines].[DocumentClass] = [Calculation].[Class] AND [Lines].[DocumentID] = [Calculation].[ID]
		LEFT OUTER JOIN [Class]
			ON [Class].[Class] = [Lines].[DocumentClass]
	ORDER BY
		[ServiceTypeFileAs] ASC,
		[Description] ASC
	
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString],
		@SupplierID AS [SupplierCompanyID]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @SupplierID AND 
		[Address].[BusinessCardClass] = @CompanyClass  

	SELECT
		[T].[PhoneTypeID],
		[T].[Phone]
	FROM
	(
	SELECT
		0 as [Chapter],
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]	
	WHERE
		[Phone].[BusinessCardID] = @SupplierID AND 
		[Phone].[BusinessCardClass] = @CompanyClass AND
		[Phone].[PhoneTypeID] IN (7, 11)
	UNION ALL
	SELECT
		1 as [Chapter],
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]		
	WHERE
		[Phone].[BusinessCardID] = @SupplierID AND 
		[Phone].[BusinessCardClass] = @CompanyClass AND
		[Phone].[PhoneTypeID] NOT IN (7, 11)) as [T]
	ORDER BY
		[Chapter], [PhoneTypeID]

		
		
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString],
		@CustomerID AS [CustomerCompanyID]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @CustomerID AND 
		[Address].[BusinessCardClass] = @CompanyClass

	SELECT
			[Phone].[PhoneTypeID],
			[Phone].[Phone]
		FROM
			[Phone]	
		WHERE
			[Phone].[BusinessCardID] = @CustomerID AND 
			[Phone].[BusinessCardClass] = @CompanyClass
	
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @ContactID AND 
		[Address].[BusinessCardClass] = @EmployeeClass

	SELECT
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]	
	WHERE
		[Phone].[BusinessCardID] = @ContactID AND 
		[Phone].[BusinessCardClass] = @EmployeeClass
	
	SELECT
		[Email].[EmailTypeID],
		[Email].[Email]
	FROM
		[Email]	
	WHERE
		[Email].[BusinessCardID] = @ContactID AND 
		[Email].[BusinessCardClass] = @EmployeeClass
	
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
      [Invoice].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @Class) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Invoice].[ID] = @ID
		
	SELECT
		[BankAccount].[ID] AS [BankAccountID],
		[BankAccount].[BankName] AS [BankName],
		[BankAccount].[City] AS [BankCity],
		[BankAccount].[Address] AS [BankAddress],
		[BankAccount].[BankCode] AS [BankCode],
		[BankAccount].[Account] AS [CAccount],
		[BankAccount].[IntermediaryBank] AS [SBankName],
		[BankAccount].[IntermediaryAccount] AS [SAccount],
		[BankAccount].[IntermediaryAddress] AS [SBankAddress],
		[BankAccount].[SWIFT] AS [SWIFT],
		[BankAccount].[IntermediarySWIFT] AS [SSWIFT]
	FROM
		[Invoice]
		LEFT OUTER JOIN [Company]
			ON [Invoice].[CustomerCompanyID] = [Company].[ID]
		LEFT OUTER JOIN [BankAccount]
			ON [Company].[BankAccountID] = [BankAccount].[ID]
	WHERE
		[Invoice].[ID] = @ID
		
	DECLARE
		@NationalCurrencyCode TCode3,
		@val TVariant

	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))

	SELECT
		[Invoice].[CurrencyRate],
		[Invoice].[BaseCurrencyRate],
		dbo.pjm6fnCurrencyGetRate([Invoice].[CurrencyCode], [Invoice].[Date], @NationalCurrencyCode) as [NationalCurrencyRate]
	FROM
		[Invoice]
	WHERE
		[Invoice].[ID] = @ID

	SELECT DISTINCT [Statement].[Number], [Statement].[Date], [Statement].[PeriodStart], [Statement].[PeriodEnd] FROM
	(
		--  -
		SELECT
			[Attachment].[LinkDocumentID] AS [ID]
		FROM
			[Attachment]
		WHERE
			[Attachment].[DocumentClass] = @InvoiceClass AND [Attachment].[DocumentID] = @ID AND [Attachment].[LinkDocumentClass] = @StatementClass
		--  -
		UNION
		SELECT
			[Attachment].[DocumentID]
		FROM
			[Attachment]
		WHERE
			[Attachment].[LinkDocumentClass] = @InvoiceClass AND [Attachment].[LinkDocumentID] = @ID AND [Attachment].[DocumentClass] = @StatementClass
		--
		UNION
		SELECT
			[StatementID]
		FROM
			[StatementAdvanceInvoice]
		WHERE
			[AdvanceInvoiceID] = @ID
	) AS [S]
	INNER JOIN [Statement]
		ON [Statement].[ID] = [S].[ID]

RETURN 0

GO

GRANT EXEC ON ReportWordInvoiceV2 TO PUBLIC
GO
