IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordStatement')
	BEGIN
		PRINT 'Dropping Procedure ReportWordStatement'
		DROP  Procedure  ReportWordStatement
	END

GO

PRINT 'Creating Procedure ReportWordStatement'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportWordStatement
	@ID int,
	@Version TName,
	@Language TName = NULL	
AS
	IF @Version = '5.5'
	BEGIN
		EXEC ReportStatement @ID, @Language
		RETURN 0
	END
	
	EXEC ReportWordStatementV2 @ID, @Language
	RETURN 0
GO

GRANT EXEC ON ReportWordStatement TO PUBLIC
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordStatementV2')
	BEGIN
		PRINT 'Dropping Procedure ReportWordStatementV2'
		DROP  Procedure  ReportWordStatementV2
	END

GO

PRINT 'Creating Procedure ReportWordStatementV2'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2011 by Avicom
/******************************************************************************
**		Change History
*******************************************************************************
**		Date		Author		Description
**		01.12.10	SYV			  [CurrencySymbol], [PCCurrencySymbol],
**								[StatementCurrencySymbol]
**		03.12.10	SYV			  [PaymentCurrencyPoint]
**		23.06.11	SPV			  CalculationType  Lines
**		18.09.12	SAP			  [TotalWithVATFract], [VATFract], [PaymentValueFract],
**								[PaymentVATFract], [RemainValueFract], [RemainVATFract],
**								[StatementTotalWithVATFract], [StatementVATFract], 
**								[StatementPaymentValueFract], [StatementPaymentVATFract],
**								[StatementRemainValueFract], [StatementRemainVATFract]
**		01.10.12	SAP			  Calculation   [TotalWithoutDiscount],
**								[TotalWithVATWithoutDiscount], [VATWithoutDiscount],
**								[TotalWithoutDiscountPC], [TotalWithVATWithoutDiscountPC],
**								[VATWithoutDiscountPC], [DiscountView], [DiscountPC],
**								[DiscountPercent], [Discount], [DiscountType],
**								[TotalLinesWithoutDiscount], [TotalLinesVATWithoutDiscount],
**								[TotalLinesWithVATWithoutDiscount], [DiscountWithVATPC],
**								[DiscountWithVAT]
**		02.11.12	SAP			  ProjectLanguage
**		19.11.12	SAP			     DiscountPercent  Calculation
**		28.06.13	SAP			   InvoiceLine  ServiceAssignmentFileAs
**								 ServiceTypeRatesDepended
*******************************************************************************/
CREATE Procedure ReportWordStatementV2
	@ID int,
	@Language TName
AS
	SET NOCOUNT ON
	DECLARE
		@Total money,
		@TotalWithVAT money,
		@VAT money,
		@TotalCount int,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@Currency TName,
		@AdvanceValue TMoney,
		@AdvanceVAT TMoney,
		@PaymentValue TMoney,
		@PaymentVAT TMoney,
		@Class TClass,
		@Code TName,
		@CompanyClass TClass,
		@SupplierID TIdentifier,
		@CustomerID TIdentifier,
		@CurrencyCode TCode,
		@StatementTotal money,
		@StatementVAT money,
		@StatementCurrencyCode TCode,
		@NationalCurrencyCode TCode3,
		@val TVariant,
		@StatementPaymentValue TMoney,
		@StatementPaymentVAT TMoney,
		@StatementTotalWithVAT money,
		@TimeEntryClass TClass,
		@ExpenseClass TClass,
		@PhoneCallClass TClass,
		@calculationClass TClass,
		@RatesWithVAT TBool,
		@GroupTimeEntry TBool,
		@ProjectID TIdentifier,
		@CurrencyRate TMoney,
		@ApplyVAT TBool,
		@ProjectCurrencyCode TCode3,
		@CalculationCurrencyCode TCode3,
		@PrimaryCurrencyCode TCode3,
		@ServiceRequestClass TClass,
		
		@TotalLinesWithoutDiscount TMoney,
		@TotalLinesVATWithoutDiscount TMoney,
		@TotalLinesWithVATWithoutDiscount TMoney,
		@DiscountWithVATPC TMoney,
		@DiscountWithVAT TMoney,
		
		@CalcID int
	
	SET @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET	@ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')
	SET	@PhoneCallClass = dbo.adfGetClassByName('Pjm5.PhoneCall')
	SET @ServiceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
	SET	@calculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))
	
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @Code = CASE WHEN @Language = 'en' THEN 'Act; ' ELSE '; ' END
	SELECT
		@Currency = CASE [Project].[StatementCurrency] WHEN 0 THEN 'Project' ELSE 'Payment' END,
		@CurrencyCode = CASE [Project].[StatementCurrency] WHEN 0 THEN [Project].[CurrencyCode] ELSE [Statement].[CurrencyCode] END,
		@Class = [Statement].[Class],
		@Total = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Statement].[TotalPC]
			ELSE [Statement].[Total]
		END,
		@VAT = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Statement].[VATPC]
			ELSE [Statement].[VAT]
		END,
		@TotalWithVAT = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Statement].[TotalWithVATPC]
			ELSE [Statement].[TotalWithVAT]
		END,
		@SupplierID = [Statement].[SupplierCompanyID],
		@CustomerID = [Statement].[CustomerCompanyID],
		
		@StatementTotalWithVAT = [Statement].[TotalWithVAT],
		@StatementTotal = [Statement].[Total],
		@StatementCurrencyCode = [Statement].[CurrencyCode],
		@StatementVAT = [Statement].[VAT]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
	WHERE
		[Statement].[ID] = @ID	
		
	SELECT 
		@AdvanceValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[TotalWithVAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalWithVATPC]
			END, 0.0)),
		@AdvanceVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[VAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[VATPC]
			END, 0.0))
	FROM
		[StatementAdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [StatementAdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[StatementAdvanceInvoice].[StatementID] = @ID
		
	SELECT 
		@PaymentValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [StatementAdvanceInvoice].[StatementPaymentValue]
				WHEN @Currency = 'Project'
					THEN [StatementAdvanceInvoice].[StatementPaymentValuePC]
			END, 0.0)),
		@PaymentVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [StatementAdvanceInvoice].[StatementPaymentVAT]
				WHEN @Currency = 'Project'
					THEN [StatementAdvanceInvoice].[StatementPaymentVATPC]
			END, 0.0)),	
		@StatementPaymentValue = SUM(ISNULL([StatementAdvanceInvoice].[StatementPaymentValue], 0.0)),
		@StatementPaymentVAT = SUM(ISNULL([StatementAdvanceInvoice].[StatementPaymentVAT], 0.0))
	FROM
		[StatementAdvanceInvoice] 
	WHERE
		[StatementAdvanceInvoice].[StatementID] = @ID
	
	DECLARE @t TABLE(
		[ID] int,
		[Description] nvarchar(max),
		[Amount] decimal(18,4),
		[Price] money,
		[Total] money,
		[VATRate] decimal(18,4),
		[VAT] money,
		[PriceWithVAT] money,
		[TotalWithVAT] money,
		[UOMID] int,
		[ServiceTypeID] int,
		[ServiceTypeFileAs] nvarchar(max),
		[ServiceTypeRatesDepended] bit,
		[DocumentClass] int,
		[DocumentID] int,
		[ServiceAssignmentFileAs] nvarchar(max)
	)
	IF @Currency = 'Payment'
	BEGIN
		INSERT INTO @t
			([ID],
			[Description],
			[Amount],[Price],[Total],
			[VATRate],[VAT],
			[PriceWithVAT],[TotalWithVAT],
			[UOMID],[ServiceTypeID],[ServiceTypeFileAs],[ServiceTypeRatesDepended],
			[DocumentClass], [DocumentID],[ServiceAssignmentFileAs])
		SELECT
			[StatementLine].[ID],
			[StatementLine].[Description],
			[StatementLine].[Amount],
			CASE 
				WHEN [StatementLine].[VATIsIncluded] = 1 AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[Price] * [StatementLine].[Amount] - [StatementLine].[VAT]) / [StatementLine].[Amount]
				ELSE [StatementLine].[Price]
			END,
			[StatementLine].[Amount] * 
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 1 AND [StatementLine].[Amount] != 0
						THEN ([StatementLine].[Price] * [StatementLine].[Amount] - [StatementLine].[VAT]) / [StatementLine].[Amount]
					ELSE [StatementLine].[Price]
				END,
			[StatementLine].[VATRate],
			[StatementLine].[VAT],
			CASE 
				WHEN [StatementLine].[VATIsIncluded] = 0 AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[Price] * [StatementLine].[Amount] + [StatementLine].[VAT]) / [StatementLine].[Amount]
				ELSE [StatementLine].[Price]
			END,
			[StatementLine].[Amount] * 
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 0 AND [StatementLine].[Amount] != 0
						THEN ([StatementLine].[Price] * [StatementLine].[Amount] + [StatementLine].[VAT]) / [StatementLine].[Amount]
					ELSE [StatementLine].[Price]
				END,
			[StatementLine].[UOMID],
			[ServiceType].[ID],
			[ServiceType].[FileAs],
			[ServiceType].[RatesDepended],
			[StatementLine].[DocumentClass],
			[StatementLine].[DocumentID],
			[ServiceAssignment].[FileAs]
		FROM
			[StatementLine]
			LEFT OUTER JOIN [ServiceType]
				ON [StatementLine].[ServiceTypeID] = [ServiceType].[ID]
			LEFT JOIN [ServiceAssignment]
				ON [ServiceAssignment].[Class] = [StatementLine].[DocumentClass]
					AND [ServiceAssignment].[ID] = [StatementLine].[DocumentID]
		WHERE 
			[StatementLine].[StatementID] = @ID
	END
	ELSE
	BEGIN
		INSERT INTO @t
			([ID],
			[Description],
			[Amount],[Price],[Total],
			[VATRate],[VAT],
			[PriceWithVAT],[TotalWithVAT],
			[UOMID],[ServiceTypeID],[ServiceTypeFileAs],[ServiceTypeRatesDepended], 
			[DocumentClass], [DocumentID],[ServiceAssignmentFileAs])
		SELECT
			[StatementLine].[ID],
			[StatementLine].[Description],
			[StatementLine].[Amount],
			CASE 
				WHEN [StatementLine].[VATIsIncluded] = 1 AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] - [StatementLine].[VATPC]) / [StatementLine].[Amount]	
				ELSE [StatementLine].[PricePC] 
			END,
			[StatementLine].[Amount] * 
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 1 AND [StatementLine].[Amount] != 0
						THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] - [StatementLine].[VATPC]) / [StatementLine].[Amount]	
					ELSE [StatementLine].[PricePC] 
				END,
			[StatementLine].[VATRate],
			[StatementLine].[VATPC],
			CASE 
				WHEN [StatementLine].[VATIsIncluded] = 0 AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] + [StatementLine].[VATPC]) / [StatementLine].[Amount]	
				ELSE [StatementLine].[PricePC] 	 
			END,
			[StatementLine].[Amount] * 
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 0 AND [StatementLine].[Amount] != 0
						THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] + [StatementLine].[VATPC]) / [StatementLine].[Amount]	
					ELSE [StatementLine].[PricePC] 
				END,
			[StatementLine].[UOMID],
			[ServiceType].[ID],
			[ServiceType].[FileAs],
			[ServiceType].[RatesDepended],
			[StatementLine].[DocumentClass],
			[StatementLine].[DocumentID],
			[ServiceAssignment].[FileAs]
		FROM
			[StatementLine]
			LEFT OUTER JOIN [ServiceType]
				ON [StatementLine].[ServiceTypeID] = [ServiceType].[ID]
			LEFT JOIN [ServiceAssignment]
				ON [ServiceAssignment].[Class] = [StatementLine].[DocumentClass]
					AND [ServiceAssignment].[ID] = [StatementLine].[DocumentID]
		WHERE 
			[StatementLine].[StatementID] = @ID
	END	
	SELECT
		@TotalCount = COUNT(*),
		@VATRate = MAX([VATRate]),
		@VATRateCount = COUNT(DISTINCT [VATRate])
	FROM
		@t

	SELECT
		[Statement].[ID],
		[Statement].[FileAs],
		[Statement].[Number],
		[Statement].[Date],
		[Statement].[PeriodStart],
		[Statement].[PeriodEnd],
		[Statement].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Statement].[SupplierCompanyID],
		[Statement].[CustomerCompanyID],
		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],
		[SupplierCompany].[LegalCode] AS [SupplierCompanyLegalCode],
		[SupplierCompany].[KPP] AS [SupplierCompanyKPP],
		[CustomerCompany].[LegalCode] AS [CustomerCompanyLegalCode],
		[CustomerCompany].[KPP] AS [CustomerCompanyKPP],
		[CustomerCompany].[ExecutiveEmployeeID] AS [CustomerExecutiveEmployeeID],
		[CustomerExecutive].[LastName] + 
			ISNULL(' ' + [CustomerExecutive].[FirstName], '') + 
				ISNULL(' ' + [CustomerExecutive].[MiddleName], '') AS [CustomerExecutiveName],
		[CustomerExecutive].[FileAs] AS [CustomerExecutiveFileAs],
		[CustomerExecutivePosition].[ID] AS [CustomerExecutivePositionID],
		[CustomerExecutivePosition].[FileAs] AS [CustomerExecutivePositionFileAs],
		[CustomerExecutiveExtended].[ExtendedProperties].value('(/ExtendedProperties/Values/Gender)[1]', 'int') AS [CustomerExecutiveEmployeeGender],
		
		[CustomerCompany].[AccountantEmployeeID] AS [CustomerAccountantEmployeeID],
		[CustomerAccountant].[LastName] + 
			ISNULL(' ' + [CustomerAccountant].[FirstName], '') + 
				ISNULL(' ' + [CustomerAccountant].[MiddleName], '') AS [CustomerAccountantName],
		[CustomerAccountant].[FileAs] AS [CustomerAccountantFileAs],
		[CustomerAccountantPosition].[ID] AS [CustomerAccountantPositionID],
		[CustomerAccountantPosition].[FileAs] AS [CustomerAccountantPositionFileAs],
		[CustomerAccountantExtended].[ExtendedProperties].value('(/ExtendedProperties/Values/Gender)[1]', 'int') AS [CustomerAccountantEmployeeGender], 

		[SupplierCompany].[ExecutiveEmployeeID] AS [SupplierExecutiveEmployeeID],
		[SupplierExecutive].[LastName] + 
			ISNULL(' ' + [SupplierExecutive].[FirstName], '') + 
				ISNULL(' ' + [SupplierExecutive].[MiddleName], '') AS [SupplierExecutiveName],
		[SupplierExecutive].[FileAs] AS [SupplierExecutiveFileAs],
		[SupplierExecutivePosition].[ID] AS [SupplierExecutivePositionID],
		[SupplierExecutivePosition].[FileAs] AS [SupplierExecutivePositionFileAs],
		[SupplierExecutiveExtended].[ExtendedProperties].value('(/ExtendedProperties/Values/Gender)[1]', 'int') AS [SupplierExecutiveEmployeeGender], 

		[SupplierCompany].[AccountantEmployeeID] AS [SupplierAccountantEmployeeID],
		[SupplierAccountant].[LastName] + 
			ISNULL(' ' + [SupplierAccountant].[FirstName], '') + 
				ISNULL(' ' + [SupplierAccountant].[MiddleName], '') AS [SupplierAccountantName],
		[SupplierAccountant].[FileAs] AS [SupplierAccountantFileAs],
		[SupplierAccountantPosition].[ID] AS [SupplierAccountantPositionID],
		[SupplierAccountantPosition].[FileAs] AS [SupplierAccountantPositionFileAs],
		[SupplierAccountantExtended].[ExtendedProperties].value('(/ExtendedProperties/Values/Gender)[1]', 'int') AS [SupplierAccountantEmployeeGender],
		
		@Total AS [Total],
		@VAT AS [VAT],
		CAST(REPLACE(CAST(ROUND(@VAT,2,1) - ROUND(ROUND(@VAT,2,1),0,1) AS varchar),'0.','') AS int) AS [VATFract],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN @Total
			ELSE @Total + @VAT
		END AS [TotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN CAST(REPLACE(CAST(ROUND(@Total,2,1) - ROUND(ROUND(@Total,2,1),0,1) AS varchar),'0.','') AS int)
			ELSE CAST(REPLACE(CAST(ROUND(@Total + @VAT,2,1)- ROUND(ROUND(@Total + @VAT,2,1),0,1) AS varchar),'0.','') AS int)
		END	AS [TotalWithVATFract],
		CASE
			WHEN @Total IS NULL THEN 0
			ELSE 1
		END	AS [TotalFlag],
		dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode) AS [TotalCurrencyCode],
		dbo.fnPjm5CurrencyToString(@VAT, @CurrencyCode) AS [VATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString((@Total + @VAT), @CurrencyCode)
		END AS [TotalWithVATCurrencyCode],
		@AdvanceValue AS [AdvanceValue],
		@AdvanceVAT AS [AdvanceVAT],
		CASE
			WHEN ISNULL(@AdvanceValue, 0) = 0 THEN 0
			ELSE 1 
		END	AS [AdvanceFlag],
		dbo.fnPjm5CurrencyToString(@AdvanceValue, @CurrencyCode) AS [AdvanceValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@AdvanceVAT, @CurrencyCode) AS [AdvanceVATCurrencyCode],

		@PaymentValue AS [PaymentValue],
		CAST(REPLACE(CAST(ROUND(@PaymentValue,2,1) - ROUND(ROUND(@PaymentValue,2,1),0,1) AS varchar),'0.','') AS int) AS [PaymentValueFract],
		@PaymentVAT AS [PaymentVAT],
		CAST(REPLACE(CAST(ROUND(@PaymentVAT,2,1) - ROUND(ROUND(@PaymentVAT,2,1),0,1) AS varchar),'0.','') AS int) AS [PaymentVATFract],
		CASE
			WHEN ISNULL(@PaymentValue, 0) = 0 THEN 0
			ELSE 1 
		END	AS [PaymentFlag],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentValue, 0.0), @CurrencyCode) AS [PaymentValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentVAT, 0.0), @CurrencyCode) AS [PaymentVATCurrencyCode],
		CASE 
			WHEN @TotalWithVAT > ISNULL(@PaymentValue, 0.0) THEN @TotalWithVAT - ISNULL(@PaymentValue, 0.0) 
			ELSE 0.0
		END AS [RemainValue],
		CASE 
			WHEN @TotalWithVAT > ISNULL(@PaymentValue, 0.0) THEN CAST(REPLACE(CAST(ROUND(@TotalWithVAT - ISNULL(@PaymentValue, 0.0),2,1) - ROUND(ROUND(@TotalWithVAT - ISNULL(@PaymentValue, 0.0),2,1),0,1) AS varchar),'0.','') AS int)
			ELSE 0
		END AS [RemainValueFract],
		CASE
			WHEN @VAT > ISNULL(@PaymentVAT, 0.0) THEN @VAT - ISNULL(@PaymentVAT, 0.0) 
			ELSE 0.0
		END AS [RemainVAT],
		CASE
			WHEN @VAT > ISNULL(@PaymentVAT, 0.0) THEN CAST(REPLACE(CAST(ROUND(@VAT - ISNULL(@PaymentVAT, 0.0),2,1) - ROUND(ROUND(@VAT - ISNULL(@PaymentVAT, 0.0),2,1),0,1) AS varchar),'0.','') AS int)
			ELSE 0
		END AS [RemainVATFract],
		CASE
			WHEN ISNULL(@PaymentValue, 0.0) > 0 AND ISNULL(@PaymentValue, 0.0) < @TotalWithVAT THEN 1
			WHEN ISNULL(@PaymentValue, 0.0) > 0 AND ISNULL(@PaymentValue, 0.0) >= @TotalWithVAT THEN 2
			ELSE 0
		END	AS [RemainFlag],
		CASE
			WHEN @TotalWithVAT > ISNULL(@PaymentValue, 0.0) THEN dbo.fnPjm5CurrencyToString(@TotalWithVAT - ISNULL(@PaymentValue, 0.0), @CurrencyCode) 
			ELSE dbo.fnPjm5CurrencyToString(0.0, @CurrencyCode) 
		END AS [RemainValueCurrencyCode],
		CASE
			WHEN @VAT > ISNULL(@PaymentVAT, 0.0) THEN dbo.fnPjm5CurrencyToString(@VAT - ISNULL(@PaymentVAT, 0.0), @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString(0.0, @CurrencyCode)
		END AS [RemainVATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN (@VATRate * 100)
			ELSE NULL
		END AS [VATRate],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN 1
			ELSE 0
		END AS [VATFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			ELSE 1
		END	AS [VATRateFlag],
		CASE @Currency WHEN 'Payment' THEN [Currency].[ID] ELSE [ProjectCurrency].[ID] END AS [CurrencyID],
		CASE @Currency WHEN 'Payment' THEN [Currency].[FileAs] ELSE [ProjectCurrency].[FileAs] END AS [CurrencyFileAs],
		CASE @Currency WHEN 'Payment' THEN [Currency].[Code] ELSE [ProjectCurrency].[Code] END AS [CurrencyCode],
		CASE 
			WHEN @Currency = 'Payment' AND
				dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			WHEN @Currency != 'Payment' AND
				dbo.adfPropertyValueGetText([ProjectCurrency].[Class], [ProjectCurrency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm6ExtraCurrencyToString(@StatementTotal, @StatementCurrencyCode)
			ELSE dbo.fnPjm6ExtraCurrencyToString((@StatementTotal + @StatementVAT), @StatementCurrencyCode)
		END AS [StatementTotalWithVATCurrencyCode],
		dbo.fnPjm6ExtraCurrencyToString((@StatementVAT), @StatementCurrencyCode) AS [StatementVATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN @StatementTotal
			ELSE @StatementTotal + @StatementVAT
		END AS [StatementTotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN CAST(REPLACE(CAST(ROUND(@StatementTotal,2,1) - ROUND(ROUND(@StatementTotal,2,1),0,1) AS varchar),'0.','') AS int)
			ELSE CAST(REPLACE(CAST(ROUND(@StatementTotal + @StatementVAT,2,1) - ROUND(ROUND(@StatementTotal + @StatementVAT,2,1),0,1) AS varchar),'0.','') AS int)
		END AS [StatementTotalWithVATFract],
		@StatementVAT AS [StatementVAT],
		CAST(REPLACE(CAST(ROUND(@StatementVAT,2,1) - ROUND(ROUND(@StatementVAT,2,1),0,1) AS varchar),'0.','') AS int) AS [StatementVATFract],
		[Statement].[CurrencyRate],
		CASE WHEN @NationalCurrencyCode = @StatementCurrencyCode
			THEN dbo.fnPjm6ExtraCurrencyToString([Statement].[CurrencyRate], @StatementCurrencyCode)
			ELSE dbo.fnPjm6ExtraCurrencyToString(1, @StatementCurrencyCode)
		END	AS [StatementRateCurrencyCode],
		CASE WHEN @NationalCurrencyCode = @StatementCurrencyCode
			THEN dbo.fnPjm6ExtraCurrencyToString(1, [ProjectCurrency].[Code]) 
			ELSE dbo.fnPjm6ExtraCurrencyToString([Statement].[CurrencyRate], [ProjectCurrency].[Code])
		END AS [ProjectRateCurrencyCode],
		CASE WHEN @NationalCurrencyCode = @StatementCurrencyCode
			THEN 1 ELSE 0 END AS [CurrencyFlag],
		@StatementPaymentValue AS [StatementPaymentValue],	
		CAST(REPLACE(CAST(ROUND(@StatementPaymentValue,2,1) - ROUND(ROUND(@StatementPaymentValue,2,1),0,1) AS varchar),'0.','') AS int) AS [StatementPaymentValueFract],
		@StatementPaymentVAT AS [StatementPaymentVAT],	
		CAST(REPLACE(CAST(ROUND(@StatementPaymentVAT,2,1) - ROUND(ROUND(@StatementPaymentVAT,2,1),0,1) AS varchar),'0.','') AS int) AS [StatementPaymentVATFract],
		dbo.fnPjm6ExtraCurrencyToString(ISNULL(@StatementPaymentValue, 0.0), @StatementCurrencyCode) AS [StatementPaymentValueCurrencyCode],
		dbo.fnPjm6ExtraCurrencyToString(ISNULL(@StatementPaymentVAT, 0.0), @StatementCurrencyCode) AS [StatementPaymentVATCurrencyCode],
		CASE 
			WHEN @StatementTotalWithVAT > ISNULL(@StatementPaymentValue, 0.0) THEN @StatementTotalWithVAT - ISNULL(@StatementPaymentValue, 0.0) 
			ELSE 0.0
		END AS [StatementRemainValue],
		CASE 
			WHEN @StatementTotalWithVAT > ISNULL(@StatementPaymentValue, 0.0) 
				THEN CAST(REPLACE(CAST(ROUND(@StatementTotalWithVAT - ISNULL(@StatementPaymentValue, 0.0),2,1) - ROUND(ROUND(@StatementTotalWithVAT - ISNULL(@StatementPaymentValue, 0.0),2,1),0,1) AS varchar),'0.','') AS int)
			ELSE 0
		END AS [StatementRemainValueFract],
		CASE
			WHEN @StatementVAT > ISNULL(@StatementPaymentVAT, 0.0) THEN @StatementVAT - ISNULL(@StatementPaymentVAT, 0.0) 
			ELSE 0.0
		END AS [StatementRemainVAT],
		CASE
			WHEN @StatementVAT > ISNULL(@StatementPaymentVAT, 0.0) 
				THEN CAST(REPLACE(CAST(ROUND(@StatementVAT - ISNULL(@StatementPaymentVAT, 0.0),2,1) - ROUND(ROUND(@StatementVAT - ISNULL(@StatementPaymentVAT, 0.0),2,1),0,1) AS varchar),'0.','') AS int)			 
			ELSE 0
		END AS [StatementRemainVATFract],
		CASE
			WHEN @StatementTotalWithVAT > ISNULL(@StatementPaymentValue, 0.0) THEN dbo.fnPjm6ExtraCurrencyToString(@StatementTotalWithVAT - ISNULL(@StatementPaymentValue, 0.0), @StatementCurrencyCode) 
			ELSE dbo.fnPjm6ExtraCurrencyToString(0.0, @StatementCurrencyCode) 
		END AS [StatementRemainValueCurrencyCode],
		CASE
			WHEN @StatementVAT > ISNULL(@StatementPaymentVAT, 0.0) THEN dbo.fnPjm6ExtraCurrencyToString(@StatementVAT - ISNULL(@StatementPaymentVAT, 0.0), @StatementCurrencyCode)
			ELSE dbo.fnPjm6ExtraCurrencyToString(0.0, @StatementCurrencyCode)
		END AS [StatementRemainVATCurrencyCode],
		CASE @Currency WHEN 'Payment' THEN [Currency].[Symbol] ELSE [ProjectCurrency].[Symbol] END AS [CurrencySymbol],
		[Currency].[Symbol] AS [StatementCurrencySymbol],
		[Project].[PaymentCurrencyPoint],
		[SupplierBankAccount].[Account] AS [SupplierAccount],
		[SupplierBankAccount].[ID] AS [SupplierAccountID],
		[CustomerBankAccount].[Account] AS [CustomerAccount],
		[CustomerBankAccount].[ID] AS [CustomerAccountID],
		[SupplierCompany].[Number] AS [SupplierCode],
		[CustomerCompany].[Number] AS [CustomerCode],
		[Project].[NumerationCode] AS [ProjectNumerationCode],
		[SupplierBankAccount].[CurrencyCode] AS [BankCurrencyCode],
		[Project].[ProjectLanguageCode] AS [ProjectLanguage]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Statement].[CurrencyCode] = [Currency].[Code]
		INNER JOIN [Currency] AS [ProjectCurrency]
			ON [Project].[CurrencyCode] = [ProjectCurrency].[Code]
		INNER JOIN [Company] AS [SupplierCompany]	
			ON [Statement].[SupplierCompanyID] = [SupplierCompany].[ID]
		INNER JOIN [Company] AS [CustomerCompany]	
			ON [Statement].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierExecutive]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierExecutivePosition]
			ON [SupplierExecutive].[PositionID] = [SupplierExecutivePosition].[ID]
		LEFT OUTER JOIN [Employee] AS [CustomerExecutive]
			ON [CustomerCompany].[ExecutiveEmployeeID] = [CustomerExecutive].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierAccountant]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierAccountantPosition]
			ON [SupplierAccountant].[PositionID] = [SupplierAccountantPosition].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerExecutivePosition]
			ON [CustomerExecutive].[PositionID] = [CustomerExecutivePosition].[ID]
		LEFT OUTER JOIN [BankAccount] [SupplierBankAccount]
			ON [SupplierBankAccount].[ID] = ISNULL([Project].[BankAccountID], [SupplierCompany].[BankAccountID])
		LEFT OUTER JOIN [BankAccount] [CustomerBankAccount]
			ON [CustomerBankAccount].[ID] = [CustomerCompany].[BankAccountID]
		LEFT OUTER JOIN [Employee] AS [CustomerAccountant]
			ON [CustomerCompany].[AccountantEmployeeID] = [CustomerAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerAccountantPosition]
			ON [CustomerAccountant].[PositionID] = [CustomerAccountantPosition].[ID]

		LEFT OUTER JOIN [ExtendedProperties] AS [SupplierExecutiveExtended]
			ON [SupplierExecutive].[ID] = [SupplierExecutiveExtended].[ID] AND [SupplierExecutiveExtended].[Class] = [SupplierExecutive].[Class]
		LEFT OUTER JOIN [ExtendedProperties] AS [SupplierAccountantExtended]
			ON [SupplierAccountant].[ID] = [SupplierAccountantExtended].[ID] AND [SupplierAccountantExtended].[Class] = [SupplierAccountant].[Class]
		LEFT OUTER JOIN [ExtendedProperties] AS [CustomerAccountantExtended]
			ON [CustomerAccountant].[ID] = [CustomerAccountantExtended].[ID] AND [CustomerAccountantExtended].[Class] = [CustomerAccountant].[Class]
		LEFT OUTER JOIN [ExtendedProperties] AS [CustomerExecutiveExtended]
			ON [CustomerExecutive].[ID] = [CustomerExecutiveExtended].[ID] AND [CustomerExecutiveExtended].[Class] = [CustomerExecutive].[Class]
	WHERE 
		[Statement].[ID] = @ID		

	SELECT
		[Lines].[ID],
		[Lines].[DocumentID],
		[Lines].[Description],
		[Lines].[Amount],
		[Lines].[Price],
		[Lines].[Total],
		[Lines].[VAT],
		[Lines].[PriceWithVAT],
		[Lines].[TotalWithVAT],
		[Lines].[UOMID],
		[Lines].[ServiceTypeID],
		[Lines].[ServiceTypeFileAs],
		ISNULL([Lines].[ServiceTypeRatesDepended],1) AS [ServiceTypeRatesDepended],
		CASE [Calculation].[DocumentClass]
			WHEN @TimeEntryClass THEN 0
			WHEN @ExpenseClass THEN 1
			WHEN @PhoneCallClass THEN 2
			WHEN @ServiceRequestClass THEN 3
			ELSE NULL
		END as [CalculationType],
		[Class].[Code] as [LineClass],
		[Lines].[ServiceAssignmentFileAs] AS [ServiceAssignmentFileAs]
	FROM
		@t [Lines]
		LEFT OUTER JOIN [Calculation]
			ON [Lines].[DocumentClass] = [Calculation].[Class] AND [Lines].[DocumentID] = [Calculation].[ID]
		LEFT OUTER JOIN [Class]
			ON [Class].[Class] = [Lines].[DocumentClass]
	ORDER BY
		[ServiceTypeFileAs] ASC,
		[Description] ASC
	
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @SupplierID AND 
		[Address].[BusinessCardClass] = @CompanyClass  
		
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @CustomerID AND 
		[Address].[BusinessCardClass] = @CompanyClass

	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
	  [Statement].[FileAs] AS [Title],
	  [Project].[FileAs] AS [Subject],
	  @author AS [Author],
	  [Employee].[FileAs] AS [Manager],
	  [Company].[FileAs] AS [Company],
	  dbo.fnPjm5GetCategoryList(@ID, @Class) AS [Category],
	  @Code + [Project].[Number] AS [Keywords],
	  dbo.fnPjm5CurrencyToString(1, [Project].[CurrencyCode]) AS [PCCurrencyCode],
	  (SELECT [Symbol] FROM [Currency] WHERE [Currency].[Code] = [Project].[CurrencyCode]) AS [PCCurrencySymbol]
	 FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
	 WHERE
		[Statement].[ID] = @ID

	/**********************************************************
					   
	**********************************************************/

	SELECT 
		@ApplyVAT = [ApplyVAT],
		@ProjectCurrencyCode = [Project].[CurrencyCode]
	FROM 
		[Project]
		INNER JOIN [Statement]
			ON [Project].[ID] = [Statement].[ProjectID]
		WHERE
			[Statement].[ID] = @ID

	

	DECLARE @CalculationInLine TABLE([ID] int, [DocumentClass] int)
	
	--    ( )
	INSERT INTO @CalculationInLine
		([ID],
		[DocumentClass])
	SELECT
		TOP(1)
		[StatementLine].[DocumentID],
		[Calculation].[DocumentClass]
	FROM
		[StatementLine]
		INNER JOIN [Calculation]
			ON [StatementLine].[DocumentID] = [Calculation].[ID]
	WHERE
		[StatementLine].[StatementID] = @ID
		AND
		[StatementLine].[DocumentClass] = @calculationClass
		AND
		[Calculation].[DocumentClass] = @TimeEntryClass
	
	--    ( )	
	INSERT INTO @CalculationInLine
		([ID],
		[DocumentClass])
	SELECT
		TOP(1)
		[StatementLine].[DocumentID],
		[Calculation].[DocumentClass]
	FROM
		[StatementLine]
		INNER JOIN [Calculation]
			ON [StatementLine].[DocumentID] = [Calculation].[ID]
	WHERE
		[StatementLine].[StatementID] = @ID
		AND
		[StatementLine].[DocumentClass] = @calculationClass
		AND
		[Calculation].[DocumentClass] = @ExpenseClass
		
	SELECT
		@RatesWithVAT = [Project].[RatesWithVAT],
		@GroupTimeEntry = [Project].[GroupCalculationLines]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Calculation].[ID] IN (SELECT TOP(1) [ID] FROM @CalculationInLine)
	
	SET @CurrencyRate = (SELECT [CurrencyRate] FROM [Statement] WHERE [ID] = @ID)

	SELECT
		@CalculationCurrencyCode = [CurrencyCode]
	FROM
		[Calculation]
	WHERE
		[Calculation].[ID] IN (SELECT [ID] FROM @CalculationInLine WHERE [DocumentClass] = @ExpenseClass)

	IF @CalculationCurrencyCode = @StatementCurrencyCode
		SET @PrimaryCurrencyCode = @StatementCurrencyCode
	ELSE
		SET @PrimaryCurrencyCode = @ProjectCurrencyCode

	IF (@PrimaryCurrencyCode = @NationalCurrencyCode) 
		OR 
		(@PrimaryCurrencyCode != @StatementCurrencyCode AND @StatementCurrencyCode != @NationalCurrencyCode)
	BEGIN
		SET @CurrencyRate = 1.0000000000000000000000000000 / @CurrencyRate
	END

	DECLARE @calculationT TABLE(
		[ID] int,
		[Date] datetime,
		[StartTime] datetime,
		[EmployeeID] int,
		[EmployeeFileAs] nvarchar(256),
		[EmployeeInitials]varchar(32),
		[DivisionID] int,
		[PositionID] int,
		[QualificationID] int,
		[TypeID] int,
		[Description] nvarchar(max),
		[Price] money,
		[Amount] decimal(18,4),
		[Total] money,
		[VAT] money,
		[TotalPC] money,
		[VATPC] money,
		[CalculationID] int
	)
	
	--     
	--  [CalculationLine]      
	IF EXISTS (SELECT * FROM @CalculationInLine WHERE [DocumentClass] = @TimeEntryClass)
	BEGIN
		INSERT INTO @calculationT
			([ID], [Date], [StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[EmployeeInitials],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[TypeID],
			[Description], [Amount], [Price], [Total], [VAT],
			[TotalPC], [VATPC],
			[CalculationID])
		SELECT
			[CalculationLine].[ID], CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) as datetime), [TimeEntry].[StartTime],
			[TimeEntry].[EmployeeID],
			[Employee].[FileAs],
			[Employee].[Initials],
			[Employee].[DivisionID],
			[Employee].[PositionID],
			[Employee].[QualificationID],
			[TimeEntry].[ActivityTypeID],
			[CalculationLine].[Description],
			[CalculationLine].[Amount],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [CalculationLine].[Amount] != 0
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT]) / [CalculationLine].[Amount]
				ELSE [CalculationLine].[Price]
			END,
			NULL,
			NULL,
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
				ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]
			END,
			[CalculationLine].[VAT],
			[CalculationLine].[CalculationID]
		FROM
			[CalculationLine]
			INNER JOIN [TimeEntry]
				ON [TimeEntry].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		WHERE 
			[CalculationLine].[CalculationID] IN (SELECT [ID] FROM @CalculationInLine WHERE [DocumentClass] = @TimeEntryClass)	
	END

	--     
	IF EXISTS (SELECT * FROM @CalculationInLine WHERE [DocumentClass] = @ExpenseClass)
	BEGIN
		INSERT INTO @calculationT
			([ID], [Date], [StartTime],
			[EmployeeID],
			[EmployeeFileAs],
			[EmployeeInitials],
			[DivisionID],
			[PositionID],
			[QualificationID], 
			[TypeID],
			[Description], [Price], [Amount], [Total], [VAT],
			[TotalPC], [VATPC],
			[CalculationID])
		SELECT
			[CalculationLine].[ID], CAST(CONVERT(varchar(8), [Expense].[Date], 112) as datetime),
			[Expense].[Date], 
			[Employee].[ID],
			[Employee].[FileAs],
			[Employee].[Initials],
			[Employee].[DivisionID],
			[Employee].[PositionID],
			[Employee].[QualificationID],
			[Expense].[ExpenseCodeID],
			[CalculationLine].[Description],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [CalculationLine].[Amount] != 0
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT]) / [CalculationLine].[Amount]
				ELSE [CalculationLine].[Price]
			END,
			[CalculationLine].[Amount],
			
			--[Total]
			CASE WHEN @StatementCurrencyCode != [Expense].[FromCurrencyCode] AND @StatementCurrencyCode != @ProjectCurrencyCode
			THEN
				[Expense].[TotalPC] * @CurrencyRate		
			ELSE
				(CASE WHEN [CalculationLine].[VATIsIncluded] = 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
					ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]
				END)
			END,
			
			--[VAT]
			CASE WHEN @StatementCurrencyCode != [Expense].[FromCurrencyCode] AND @StatementCurrencyCode != @ProjectCurrencyCode
			THEN
				[Expense].[VATPC] * @CurrencyRate	
			ELSE
				[Expense].[VAT]
			END,
					
			--[TotalPC]
			CASE WHEN @StatementCurrencyCode = [Expense].[FromCurrencyCode] AND @StatementCurrencyCode != @ProjectCurrencyCode
				THEN	--   
					(CASE WHEN [CalculationLine].[VATIsIncluded] = 1
						THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
						ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]
					END)
					* 
					@CurrencyRate
				ELSE
					[Expense].[TotalPC]
			END,
			
			--[VATPC]
			CASE WHEN @StatementCurrencyCode = [Expense].[FromCurrencyCode] AND @StatementCurrencyCode != @ProjectCurrencyCode
				THEN	--   
					[Expense].[VAT] * @CurrencyRate
				ELSE
					[Expense].[VATPC]
			END,
			
			[CalculationLine].[CalculationID]
		FROM
			[CalculationLine]
			INNER JOIN [Expense]
			ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
				[Expense].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [Expense].[EmployeeID]
		WHERE 
			[CalculationLine].[CalculationID] IN (SELECT [ID] FROM @CalculationInLine WHERE [DocumentClass] = @ExpenseClass)	
	END

	SELECT @CalcID = [CalculationID] FROM @calculationT
	
	EXEC ReportWordStatementTotalCalc @ID = @CalcID, @Language = NULL, @TotalLinesWithoutDiscount = @TotalLinesWithoutDiscount OUTPUT, 
									@TotalLinesVATWithoutDiscount = @TotalLinesVATWithoutDiscount OUTPUT,
									 @TotalLinesWithVATWithoutDiscount = @TotalLinesWithVATWithoutDiscount OUTPUT, 
									 @DiscountWithVATPC = @DiscountWithVATPC OUTPUT, 
									 @DiscountWithVAT = @DiscountWithVAT OUTPUT
	
--------------Calculation-------------
	SELECT
		[Calculation].[ID],
		CASE [Calculation].[DocumentClass]
				WHEN @TimeEntryClass THEN 0
				WHEN @ExpenseClass THEN 1
				WHEN @PhoneCallClass THEN 2
				ELSE 3
		END AS [CalculationType],
		[Calculation].[Number],
		[Calculation].[Date],
		[Calculation].[FileAs],
		[Calculation].[PeriodStart],
		[Calculation].[PeriodEnd],
		[Calculation].[Description],
		[Calculation].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],
		[SupplierCompany].[ExecutiveEmployeeID],
		[SupplierEmployee].[LastName] + 
			ISNULL(' ' + [SupplierEmployee].[FirstName], '') + 
				ISNULL(' ' + [SupplierEmployee].[MiddleName], '') AS [ExecutiveName],
		[SupplierEmployee].[FileAs] AS [ExecutiveFileAs],
		[SupplierEmployeePosition].[ID] AS [ExecutivePositionID],
		[SupplierEmployeePosition].[FileAs] AS [ExecutivePositionFileAs],
		CASE WHEN [StatementLine].[VATIsIncluded] = 1
			THEN ([StatementLine].[Amount] * [StatementLine].[PricePC] - [StatementLine].[VATPC])
			ELSE [StatementLine].[Amount] * [StatementLine].[PricePC]
		END AS [TotalPC],
		[Calculation].[VATRate] * 100 AS [VATRate],
		[StatementLine].[VATPC],
		CASE WHEN [StatementLine].[VATIsIncluded] = 0
			THEN ([StatementLine].[Amount] * [StatementLine].[PricePC] + [StatementLine].[VATPC])
			ELSE [StatementLine].[Amount] * [StatementLine].[PricePC]
		END AS [TotalWithVATPC],

		CASE
			WHEN [Project].[ApplyVAT] = 1 THEN CASE WHEN [Calculation].[DocumentClass] =  @TimeEntryClass THEN @RatesWithVAT ELSE 0 END
			ELSE 2
		END AS [VATFlag],
		[Currency].[ID] AS [CurrencyID],
		[Currency].[FileAs] AS [CurrencyFileAs],
		[Currency].[Code] AS [CurrencyCode],
		CASE 
			WHEN dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		CASE WHEN @StatementCurrencyCode = @ProjectCurrencyCode
			THEN
				dbo.fnPjm5CurrencyToString(1, [Currency].[Code])
			ELSE
				dbo.fnPjm5CurrencyToString(1, @StatementCurrencyCode)
		END AS [PayCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm6ExtraCurrencyToString([Calculation].[TotalPC], [Project].[CurrencyCode])
			ELSE dbo.fnPjm6ExtraCurrencyToString([Calculation].[TotalWithVATPC], [Project].[CurrencyCode])
		END AS [TotalWithVATPCCurrencyCode],
		[StatementLine].[VAT],
		CASE WHEN [StatementLine].[VATIsIncluded] = 0
			THEN ([StatementLine].[Amount] * [StatementLine].[Price] + [StatementLine].[VAT])
			ELSE [StatementLine].[Amount] * [StatementLine].[Price]
		END AS [TotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm6ExtraCurrencyToString([Calculation].[Total], @StatementCurrencyCode)
			ELSE dbo.fnPjm6ExtraCurrencyToString([Calculation].[TotalWithVAT], @StatementCurrencyCode)
		END AS [TotalWithVATCurrencyCode],
		dbo.fnPjm6ExtraCurrencyToString([StatementLine].[VAT], @StatementCurrencyCode) AS [VATCurrencyCode],
		CASE 
			WHEN @StatementCurrencyCode = [Project].[CurrencyCode] 
				THEN 1 
				ELSE 0 
		END AS [CurrencyFlag],
		[Currency].[Symbol] AS [CurrencySymbol],
		[Calculation].[TotalWithoutDiscount],
		[Calculation].[TotalWithVATWithoutDiscount],	
		[Calculation].[VATWithoutDiscount],
		[Calculation].[TotalWithoutDiscountPC],
		[Calculation].[TotalWithVATWithoutDiscountPC],
		[Calculation].[VATWithoutDiscountPC],
		[Calculation].[DiscountView],
		[Calculation].[DiscountPC],
		[Calculation].[DiscountPercent] * 100 AS DiscountPercent,
		[Calculation].[Discount],
		[Calculation].[DiscountType],
		@TotalLinesWithoutDiscount AS [TotalLinesWithoutDiscount],
		@TotalLinesVATWithoutDiscount AS [TotalLinesVATWithoutDiscount],
		@TotalLinesWithVATWithoutDiscount AS [TotalLinesWithVATWithoutDiscount],
		@DiscountWithVATPC AS [DiscountWithVATPC],
		@DiscountWithVAT AS [DiscountWithVAT]
	FROM
		[Calculation]
		INNER JOIN
			[StatementLine]
			ON [StatementLine].[DocumentClass] = [Calculation].[Class]
				AND
				[StatementLine].[DocumentID] = [Calculation].[ID]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Calculation].[CurrencyCode] = [Currency].[Code]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierEmployeePosition]
			ON [SupplierEmployee].[PositionID] = [SupplierEmployeePosition].[ID]
	WHERE 
		[Calculation].[ID] IN (SELECT [ID] FROM @CalculationInLine)	

--------------Calculation Line-------------
	IF @GroupTimeEntry = 0
		SELECT
			[@calculationT].[ID],
			[@calculationT].[Date],
			[@calculationT].[StartTime],
			[@calculationT].[EmployeeID],
			[@calculationT].[EmployeeFileAs],
			[@calculationT].[EmployeeInitials],
			[@calculationT].[DivisionID],
			[@calculationT].[PositionID],
			[@calculationT].[QualificationID], 
			[@calculationT].[Description],
			[@calculationT].[Amount],		
			[@calculationT].[Price],
			CASE WHEN @ApplyVAT = 0
				THEN [@calculationT].[Total]
				ELSE [@calculationT].[Total] + [@calculationT].[VAT]
			END 
			AS [TotalWithVAT],
			[@calculationT].[VAT],
			CASE WHEN @ApplyVAT = 0
				THEN [@calculationT].[TotalPC]
				ELSE [@calculationT].[TotalPC] + [@calculationT].[VATPC]
			END
			AS [TotalWithVATPC],
			[@calculationT].[VATPC],
			CASE [Calculation].[DocumentClass]
				WHEN @TimeEntryClass THEN 0
				WHEN @ExpenseClass THEN 1
				WHEN @PhoneCallClass THEN 2
				ELSE 3
			END AS [DocumentClass],
			[@calculationT].[CalculationID]
		FROM @calculationT
		INNER JOIN [Calculation]
				ON [Calculation].[ID] = [@calculationT].[CalculationID]
	ELSE
		SELECT
			ROW_NUMBER() OVER(ORDER BY [@calculationT].[Date], [@calculationT].[EmployeeFileAs]) AS [ID],
			[@calculationT].[Date],
			[@calculationT].[Date] AS [StartTime],
			[@calculationT].[EmployeeID],
			[@calculationT].[EmployeeFileAs],
			[@calculationT].[EmployeeInitials],
			[@calculationT].[DivisionID],
			[@calculationT].[PositionID],
			[@calculationT].[QualificationID], 
			[@calculationT].[Description],
			SUM([@calculationT].[Amount]) AS [Amount],		
			[@calculationT].[Price],
			CASE WHEN @ApplyVAT = 0
				THEN SUM([@calculationT].[Total])
				ELSE SUM([@calculationT].[Total]) + SUM([@calculationT].[VAT])
			END 
			AS [TotalWithVAT],
			SUM([@calculationT].[VAT]) AS [VAT],
			CASE WHEN @ApplyVAT = 0
				THEN SUM([@calculationT].[TotalPC])
				ELSE SUM([@calculationT].[TotalPC]) + SUM([@calculationT].[VATPC])
			END 
			AS [TotalWithVATPC],
			
			SUM([@calculationT].[VATPC]) AS [VATPC],
			CASE [Calculation].[DocumentClass]
				WHEN @TimeEntryClass THEN 0
				WHEN @ExpenseClass THEN 1
				WHEN @PhoneCallClass THEN 2
				ELSE 3
			END AS [DocumentClass],
			[CalculationID]
		FROM @calculationT
		INNER JOIN
			[Calculation]
				ON [Calculation].[ID] = [@calculationT].[CalculationID]
		GROUP BY
			[@calculationT].[Date],
			[@calculationT].[EmployeeID],
			[@calculationT].[EmployeeFileAs],
			[@calculationT].[EmployeeInitials],
			[@calculationT].[DivisionID],
			[@calculationT].[PositionID],
			[@calculationT].[QualificationID], 
			[@calculationT].[Description],
			[@calculationT].[Price],
			[Calculation].[DocumentClass],
			[@calculationT].[CalculationID]
		
		/**********************************************************
		**********************************************************/		
		
	--  	
	DECLARE @Factures TABLE
	(
		[ID] TIdentifier
	)
	
	DECLARE
		@FactureClass TClass,
		@InvoiceClass TClass,
		@StatementClass TClass
	
	-- Linked Invoices
	SET @FactureClass = dbo.adfGetClassbyName('Pjm5.Facture')
	SET @InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
	SET @StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	
	
	INSERT INTO @Factures ([ID])
	SELECT
		[Attachment].[LinkDocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[DocumentClass] = @StatementClass AND [Attachment].[DocumentID] = @ID AND [Attachment].[LinkDocumentClass] = @FactureClass
	UNION
	SELECT
		[Attachment].[DocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[LinkDocumentClass] = @StatementClass AND [Attachment].[LinkDocumentID] = @ID AND [Attachment].[DocumentClass] = @FactureClass
	
	SELECT DISTINCT [Invoice].[Number], [Invoice].[Date], [Invoice].[Advance] FROM
	(
	--  -
	SELECT
		[Attachment].[LinkDocumentID] AS [ID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[DocumentClass] = @StatementClass AND [Attachment].[DocumentID] = @ID AND [Attachment].[LinkDocumentClass] = @InvoiceClass
	--  -
	UNION
	SELECT
		[Attachment].[DocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[LinkDocumentClass] = @StatementClass AND [Attachment].[LinkDocumentID] = @ID AND [Attachment].[DocumentClass] = @InvoiceClass
	--
	UNION
	--    -
	SELECT
		[Attachment].[LinkDocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[DocumentClass] = @FactureClass AND [Attachment].[DocumentID] IN (SELECT [ID] FROM @Factures) AND [Attachment].[LinkDocumentClass] = @InvoiceClass
	UNION
	SELECT
		[Attachment].[DocumentID]
	FROM
		[Attachment]
	WHERE
		[Attachment].[LinkDocumentClass] = @FactureClass AND [Attachment].[LinkDocumentID] IN (SELECT [ID] FROM @Factures) AND [Attachment].[DocumentClass] = @InvoiceClass
	UNION
	SELECT
		[AdvanceInvoiceID]
	FROM
		[StatementAdvanceInvoice]
	WHERE
		[StatementID] = @ID
	) AS [Invoices]
	INNER JOIN [Invoice]
		ON [invoice].[ID] = [Invoices].[ID]
		
	
	SELECT
		[Statement].[CurrencyRate],
		[Statement].[BaseCurrencyRate],
		dbo.pjm6fnCurrencyGetRate([Statement].[CurrencyCode], [Statement].[Date], @NationalCurrencyCode) as [NationalCurrencyRate]
	FROM
		[Statement]
	WHERE
		[Statement].[ID] = @ID

	SELECT
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]
	WHERE
		[Phone].[BusinessCardID] = @SupplierID AND 
		[Phone].[BusinessCardClass] = @CompanyClass


	SELECT
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]
	WHERE
		[Phone].[BusinessCardID] = @CustomerID AND 
		[Phone].[BusinessCardClass] = @CompanyClass


	SELECT
		[Email].[EmailTypeID],
		[Email].[Email]
	FROM
		[Email]
	WHERE
		[Email].[BusinessCardID] = @SupplierID AND 
		[Email].[BusinessCardClass] = @CompanyClass


	SELECT
		[Email].[EmailTypeID],
		[Email].[Email]
	FROM
		[Email]
	WHERE
		[Email].[BusinessCardID] = @CustomerID AND 
		[Email].[BusinessCardClass] = @CompanyClass
		

RETURN 0
GO

GRANT EXEC ON ReportWordStatementV2 TO PUBLIC

GO
