IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5GenerateStatementFromCalculation]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5GenerateStatementFromCalculation'
		DROP PROCEDURE [dbo].[pjm5GenerateStatementFromCalculation]
	END
GO

PRINT 'Creating procedure pjm5GenerateStatementFromCalculation'
GO

/******************************************************************************
**		File: pjm5GenerateStatementFromCalculation.sql
**		Name: pjm5GenerateStatementFromCalculation
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5GenerateStatementFromCalculation]
	@ID TIdentifier,
	@Number TCode,
	@Date TDate,
	@FileAs TName,
	@PeriodStart TDate,
	@PeriodEnd TDate,
	@CurrencyCode TCode3,
	@CurrencyRate TMoney
AS
	DECLARE @State TState,
			@StatementID TIdentifier,
			@Class TClass,
			@CalculationState TClass,
			@Guid TGuid,
			@ProjectID TIdentifier,
			@ProjectCurrencyCode TCode3,
			@CalculationCurrencyCode TCode3,
			@StatementCurrencyRate TMoney,
			@StatementBaseCurrencyRate TMoney,
			@CalculationClass TClass,
			@ApplyVAT TBool,
			@value TVariant,
			@rv int,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@ServiceTypeID TIdentifier,
			@VATIsIncluded TBool
	
	SET NOCOUNT ON
	
	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	SET @Class = dbo.adfGetClassByName('Pjm5.Statement')
	SET @CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrencyCode TCode3
	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrencyCode = CAST(@value as varchar(3))

	DECLARE
		@description nvarchar(max),
		@vatRate decimal(18, 4),
		@total money, @totalPC money, @totalWithVAT money, @totalWithVATPC money, 
		@price money, @vat money, @pricePC money, @vatPC money, 
		@basePrice int

	SELECT
		@ProjectID = [Calculation].[ProjectID],
		@CalculationCurrencyCode = [Calculation].[CurrencyCode],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@ApplyVAT = [Project].[ApplyVAT],
		@CalculationState = [Calculation].[State],
		@SupplierCompanyID = [Project].[SupplierCompanyID],
		@CustomerCompanyID = [Project].[CustomerCompanyID],
		
		@description = ISNULL([Calculation].[Description], [Calculation].[FileAs]),
		@vatRate = [Calculation].[VATRate],
		@total = [Calculation].[Total],
		@totalPC = [Calculation].[TotalPC],
		@totalWithVAT = [Calculation].[TotalWithVAT],
		@totalWithVATPC = [Calculation].[TotalWithVATPC],
		@vat = [Calculation].[VAT],
		@vatPC = [Calculation].[VATPC],
		@ServiceTypeID = [Calculation].[ServiceTypeID],
		@VATIsIncluded = CASE
			WHEN [Calculation].[DocumentClass] = dbo.adfGetClassByName('Pjm5.TimeEntry') THEN [Project].[RatesWithVAT]
			ELSE 0
		END
	FROM 
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
	WHERE
		[Calculation].[ID] = @ID
		
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllStatements')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END	
		
	SET @StatementCurrencyRate = @CurrencyRate
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @StatementCurrencyRate = 1.0

	IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @StatementBaseCurrencyRate = 1.0
	ELSE IF @CalculationCurrencyCode = @BaseCurrencyCode
		SET @StatementBaseCurrencyRate = @CurrencyRate
		
	DECLARE @c1 TCode3, @c2 TCode3
	IF @StatementCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @CurrencyCode
		BEGIN
			SET @c1 = @ProjectCurrencyCode
			SET @c2 = @CurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @ProjectCurrencyCode
			SET @c1 = @CurrencyCode
		END

		SELECT
			@StatementCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	IF @StatementBaseCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @ProjectCurrencyCode
		BEGIN
			SET @c1 = @BaseCurrencyCode
			SET @c2 = @ProjectCurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @BaseCurrencyCode
			SET @c1 = @ProjectCurrencyCode
		END

		SELECT
			@StatementBaseCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	IF @ApplyVAT = 0 OR @VATIsIncluded = 0
	BEGIN
		SET @price = @total 
		SET @pricePC = @totalPC
	END
	ELSE 
	BEGIN
		SET @price = @totalWithVAT
		SET @pricePC = @totalWithVATPC
	END
	
	IF @ApplyVAT = 0
	BEGIN
		SET @vat = 0.0
		SET @vatPC = 0.0
	END

	SET @basePrice = 1
	IF @ProjectCurrencyCode = @CurrencyCode
	BEGIN
		SET @price = @pricePC
		SET @vat = @vatPC
	END
	ELSE 
	BEGIN
		IF @CalculationCurrencyCode != @CurrencyCode
		BEGIN
			IF @CurrencyCode != @NationalCurrencyCode
				SET @price = ROUND(@pricePC / @CurrencyRate, 2)
			ELSE
				SET @price = ROUND(@pricePC * @CurrencyRate, 2)
				
			IF @ApplyVAT = 1 
			BEGIN
				IF @VATIsIncluded = 0
					SET @vat = ROUND(@price * @vatRate, 2)
				ELSE
					SET @vat = ROUND(@price * @vatRate / (1.0 + @vatRate), 2)
			END
		END
		ELSE
		BEGIN
			SET @basePrice = 0
		END
	END

	BEGIN TRANSACTION
	INSERT INTO [Statement]
		([Flag], [State], [Date], [Number], [FileAs], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], [CurrencyCode],
		 [Periodical], 
		 [PeriodStart], [PeriodEnd],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale])
	VALUES(0, @State, @Date, @Number, @FileAs, @ProjectID,
		@StatementCurrencyRate, @StatementBaseCurrencyRate, @CurrencyCode,
		0,
		@PeriodStart, @PeriodEnd,
		@SupplierCompanyID, @CustomerCompanyID,
		2)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @StatementID = SCOPE_IDENTITY()

	INSERT INTO [StatementLine] (
		[StatementID], [DocumentClass], [DocumentID], [Description], [Amount], [VATIsIncluded], [VATRate], 
		[PricePC], [VATPC],
		[Price], [VAT], 
		[UOMID], [ServiceTypeID],
		[BasePrice])
	VALUES( 
		@StatementID, 
		@CalculationClass, @ID, @description, 1.0, @VATIsIncluded, @vatRate, 
		@pricePC, @vatPC,
		@price, @vat,
		NULL, @ServiceTypeID, @basePrice
	)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	COMMIT TRANSACTION
	
	SELECT
		@Class			AS [Class],
		@StatementID	AS [ID],
		@State			AS [State],
		@FileAs			AS [FileAs]

	EXEC pjm6BindInvoiceAndStatement NULL, @StatementID, @ID
		
	RETURN 0
GO

GRANT EXECUTE ON pjm5GenerateStatementFromCalculation TO PUBLIC
GO
 