IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'TaskAssignmentsBrowse')
	BEGIN
		PRINT 'Dropping Procedure TaskAssignmentsBrowse'
		DROP  Procedure  TaskAssignmentsBrowse
	END

GO

PRINT 'Creating Procedure TaskAssignmentsBrowse'
GO
/******************************************************************************
**		File: 
**		Name: TaskAssignmentsBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure TaskAssignmentsBrowse
	@TaskID TIdentifier,
	@StateSelector INT
AS
	SET NOCOUNT ON
	
	SELECT
		[T].[TaskID],
		[T].[AssignmentID],
		[T].[TaskName],
		[T].[AssignmentName],
		[T].[Units],
		[T].[Work],
		COALESCE([T].[WorkStartDate], [T].[StartDate]) as [StartDate],
		COALESCE([T].[WorkDueDate], [T].[DueDate]) as [DueDate],
		[T].[FromMsProject],
		[T].[MsAvailable],
		[T].[RemainingWork],
		[T].[RemainingOvertimeWork],
		[T].[ActualWork],
		[T].[State]
	FROM
		(SELECT
			[TaskAssignment].[TaskID]	as [TaskID],
			[Assignment].[ID]			as [AssignmentID],
			[Task].[FileAs]				as [TaskName],
			[Assignment].[FileAs]		as [AssignmentName],
			[Units],
			CAST([Work]/60.0 as decimal(18,4)) as [Work],
			(SELECT MIN([Date]) FROM [BusyEntry] WHERE [TaskID] = @TaskID AND [AssignmentID] = [Assignment].[ID]) as [WorkStartDate],
			(SELECT MAX([Date]) FROM [BusyEntry] WHERE [TaskID] = @TaskID AND [AssignmentID] = [Assignment].[ID]) as [WorkDueDate],
			[Task].[StartDate],
			[Task].[DueDate],
			CASE WHEN [Task].[MsTaskID] IS NULL THEN 0 ELSE 1 END		as [FromMsProject],
			[TaskAssignment].[MsAvailable]								as [MsAvailable],
			[TaskAssignment].[RemainingWork]/60							as [RemainingWork],
			[TaskAssignment].[RemainingOvertimeWork]/60					as [RemainingOvertimeWork],
			ISNULL((SELECT SUM([BusyEntry].[ActualWork] + ISNULL([BusyEntry].[ActualOvertimeWork],0)) FROM [BusyEntry] 
			WHERE [BusyEntry].[TaskID] = [TaskAssignment].[TaskID] 
				AND [BusyEntry].[AssignmentID] = [TaskAssignment].[AssignmentID]
				) / 60.0 , 0) 			as [ActualWork],
			[TaskAssignment].[State] as [State]
		FROM
			[TaskAssignment] INNER JOIN [Assignment]
				ON ([TaskAssignment].[AssignmentID] = [Assignment].[ID])
			INNER JOIN [Task]
				ON ([TaskAssignment].[TaskID] = [Task].[ID])
		WHERE
			[TaskAssignment].[TaskID] = @TaskID AND
			((@StateSelector = 0) OR (@StateSelector != 0 AND [TaskAssignment].[State] = @StateSelector))
		) T
	ORDER BY
		[T].[AssignmentName]	
	
		
	
	SELECT
		[TaskAssignment].[TaskID],
		[TaskAssignment].[AssignmentID],
		[Date],
		CAST([Planned]/60.0 as decimal(18,4)) as [Value],
		[Committed]
	FROM
		[BusyEntry]
		INNER JOIN [TaskAssignment]
			ON [TaskAssignment].[TaskID] = [BusyEntry].[TaskID]
			AND [TaskAssignment].[AssignmentID] = [BusyEntry].[AssignmentID]
	WHERE
		[BusyEntry].[TaskID] = @TaskID	AND
		((@StateSelector = 0) OR (@StateSelector != 0 AND [TaskAssignment].[State] = @StateSelector))
	
	RETURN 0
GO

GRANT EXEC ON TaskAssignmentsBrowse TO PUBLIC
GO
