IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowseByEmployee]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskBrowseByEmployee'
		DROP PROCEDURE [dbo].[pjm5TaskBrowseByEmployee]
	END
GO

PRINT 'Creating procedure pjm5TaskBrowseByEmployee'
GO

/******************************************************************************
**		File: pjm5TaskBrowseByEmployee.sql
**		Name: pjm5TaskBrowseByEmployee
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowseByEmployee]
	@StateSelector	INT,
	@DateSelector	INT,
	@EmployeeID	TIdentifier = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@PeriodStart datetime,
		@PeriodEnd datetime,
		@ViewAllTasks bit,
		@today datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @today = GETDATE()	
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))

	IF @DateSelector = 1 -- today
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodStart)
	
	IF @DateSelector = 2 -- next seven days
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)
	
	SELECT DISTINCT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		dbo.fnPjm5GetWorkingDays(@today, [Task].[DueDate]) AS [RestDays],
		[Task].[PlanPercent],
		[Task].[ManHour] / 60.0 AS [ManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[Budget]
			ELSE -1
		END AS [Budget],
		[Task].[RealManHour],
		CASE
			WHEN [Task].[ManHour] != 0 THEN
				CAST([Task].[RealManHour] as decimal(18,2))/[Task].[ManHour]
			ELSE 0
		END AS [RealManHourPercent],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[TimeRealBudget]+[Task].[ExpenseRealBudget]
			ELSE -1
		END AS [RealBudget],
		CASE
			WHEN [Task].[Budget] != 0 THEN
				CAST([Task].[TimeRealBudget]+[Task].[ExpenseRealBudget] as decimal(18,2))/[Task].[Budget]
			ELSE 0
		END AS [RealBudgetPercent],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [TaskAssignment]
			ON [TaskAssignment].[TaskID] = [Task].[ID]
		LEFT OUTER JOIN [vwAssignment] AS [Assignment]
			ON [Assignment].[ID] = [TaskAssignment].[AssignmentID]
	WHERE
		(
			(IsNull([Assignment].[EmployeeID], -1) = IsNull(@EmployeeID, -1)) OR (@EmployeeID IS NULL)
		) AND
		(
			@ViewAllTasks = 1 OR
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
			dbo.fnPjm5IsProjectMember([Task].[ProjectID], @CurrentEmployeeID) = 1
		) AND
		(
			(@StateSelector = 0 AND [Task].[State] != 7) OR 
			(@StateSelector = 1 AND [Task].[State] IN (1, 2, 8)) OR
			(@StateSelector = 2 AND [Task].[State] IN (4, 5)) OR
			(@StateSelector = 3 AND [Task].[State] = 3) OR
			(@StateSelector = 4 AND [Task].[State] = 6)
		) AND [Task].[SubprojectID] IS NULL
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowseByEmployee] TO PUBLIC
GO
  