IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trTaskIU')
	BEGIN
		PRINT 'Dropping Trigger pjm6trTaskIU'
		DROP  Trigger pjm6trTaskIU
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trTaskIU
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trTaskIU'
GO
CREATE TRIGGER pjm6trTaskIU ON [Task] FOR INSERT, UPDATE
AS
	IF @@rowcount = 0 
		RETURN

	SET NOCOUNT ON
	DECLARE @ProjectID TIdentifier
	DECLARE data CURSOR LOCAL FAST_FORWARD FOR 
		SELECT DISTINCT [ProjectID] FROM [inserted] WHERE [ProjectID] IS NOT NULL
	OPEN data
	FETCH NEXT FROM data INTO @ProjectID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		;WITH result ([ProjectID], [DueDate], [PlannedManHour], [PlannedBudget], [PercentComplete]) AS
		(
			SELECT
				[ProjectID], 
				MAX([DueDate]), 
				SUM(ISNULL([ManHour], 0)), 
				SUM(ISNULL([Budget], 0)),
				SUM(
					CASE WHEN [Task].[State] IN (2, 3) AND [Task].[Duration] = 0 
							THEN [Task].[PercentComplete]
						 WHEN [Task].[State] IN (2, 3) AND [Task].[Duration] > 0
							THEN [Task].[PercentComplete] *  [Task].[Duration]
					ELSE 0
					END
					) / 
					SUM(CASE WHEN [Task].[State] IN (2, 3) AND [Task].[Duration] > 0 
							THEN [Task].[Duration] ELSE 1 END
				)
			FROM
				[Task]
			WHERE
				[Task].[ProjectID] = @ProjectID AND
				[Task].[State] IN (2, 3, 5, 8) AND
				[Task].[MsTaskID] IS NULL
			GROUP BY 
				[ProjectID]
		)
		UPDATE
			[ProjectDetail]
		SET
			[DueDate] = result.[DueDate],
			[PercentComplete] = ISNULL(result.[PercentComplete], 0),
			[PlannedManHour] = ISNULL(result.[PlannedManHour], 0),
			[PlannedBudget] = ISNULL(result.[PlannedBudget], 0)
		FROM
			[ProjectDetail]
			INNER JOIN result
				ON result.[ProjectID] = [ProjectDetail].[ID]
		IF @@error != 0
		BEGIN
			CLOSE data
			DEALLOCATE data
			ROLLBACK TRANSACTION
			RETURN
		END
		FETCH NEXT FROM data INTO @ProjectID
	END
	CLOSE data
	DEALLOCATE data
	
	RETURN
GO

  