IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TimeEntryCreateInternal]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TimeEntryCreateInternal'
		DROP PROCEDURE [dbo].[pjm5TimeEntryCreateInternal]
	END
GO

PRINT 'Creating procedure pjm5TimeEntryCreateInternal'
GO

/******************************************************************************
**		File: pjm5TimeEntryCreateInternal.sql
**		Name: pjm5TimeEntryCreateInternal
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TimeEntryCreateInternal]
	@ID TIdentifier		OUTPUT,
	@FileAs TName,
	@ActivityTypeID TIdentifier,
	@EmployeeID TIdentifier,
	@ProjectID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@TaskID TIdentifier,
	@StartTime TDateTime,
	@Duration TCount,
	@Billable TBool,
	@Overtime TBool,
	@Color TColor,
	@Comments TNotes,
	@RecurrenceID TIdentifier = NULL
AS
	DECLARE @State TState,
			@RoundedDuration TCount,
			@ProjectState TState,
			@Rate TMoney,
			@ActivityTypeIsMandatory bit,
			@CurrencyCode TCode3,
			@VATRate TPercent,
			@rv int,
			@value TVariant,
			@CurrentEmployeeID TIdentifier,
			@DivisionID TIdentifier
	
	SET NOCOUNT ON
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	IF @EmployeeID IS NULL
		SET @EmployeeID = @CurrentEmployeeID
		
	IF @EmployeeID IS NULL
	BEGIN
		RAISERROR('#assignmentnotfound', 18, -1)
		RETURN 1
	END

	IF dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	
	IF (@DocumentID IS NOT NULL 
		AND @DocumentClass IS NOT NULL
		AND NOT EXISTS(SELECT TOP(1) [ID] FROM [Document] WHERE [Class] = @DocumentClass AND [ID] = @DocumentID))
	BEGIN
		RAISERROR('#CannotRetrieveDeletedDocument', 18, -1)
		RETURN 1
	END


	IF @Duration IS NULL OR @Duration < 0
	BEGIN
		RAISERROR('#DurationIsInvalid', 18, -1)
		RETURN 1
	END
	
	SET @State = dbo.adfwfGetInitialState('6719512d-42ee-4848-a57e-f76500e67ee7')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE	@AssignmentID TIdentifier
	IF @ProjectID IS NOT NULL
	BEGIN
		SELECT @AssignmentID = dbo.fnPjm5GetProjectAssignment(@ProjectID, @EmployeeID)
		IF @AssignmentID IS NULL
		BEGIN
			IF EXISTS(	SELECT [ID] 
						FROM vwAssignment 
						WHERE [ProjectID] = @ProjectID AND [EmployeeID] = @EmployeeID 
							AND [State] = 3)
			BEGIN
				RAISERROR('#wrongprojecttype', 18, -1)
				RETURN 1
			END
			ELSE
			BEGIN
				RAISERROR('#assignmentnotfound', 18, -1)
				RETURN 1
			END
		END

		SELECT
			@ProjectState = [State],
			@CurrencyCode = [CurrencyCode],
			@RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, [RoundingInterval], [RoundingMode])
		FROM
			[Project]
		WHERE 
			[ID] = @ProjectID

		IF @ProjectState != 2
		BEGIN
			RAISERROR('#ProjectIsNotActive', 18, -1)
			RETURN 1
		END

		IF @TaskID IS NOT NULL 
		BEGIN
			IF NOT EXISTS (SELECT * FROM [Task] WHERE [ID] = @TaskID AND [ProjectID] = @ProjectID)
			BEGIN
				RAISERROR('#TaskFromAnotherProject', 18, -1)
				RETURN 1
			END
			IF NOT EXISTS (SELECT * FROM [Task] WHERE [ID] = @TaskID AND [State] = 2)
			BEGIN
				RAISERROR('#TaskIsDraft', 18, -1)
				RETURN 1
			END
			IF dbo.fnPjm5IsTaskAssigned(@TaskID, @EmployeeID) = 0
			BEGIN
				RAISERROR('#taskassignmentnotfound', 18, -1)
				RETURN 1
			END
			IF EXISTS(SELECT * FROM [TaskAssignment] 
						WHERE [TaskID] = @TaskID AND [AssignmentID] = @AssignmentID AND [TaskAssignment].[MsAvailable] = 0)
			BEGIN
				RAISERROR('#taskassignmentnotfound', 18, -1)
				RETURN 1
			END			
		END
		
		SET @Rate = dbo.fnPjm5GetEmployeeRate(@EmployeeID, @ProjectID, @Overtime, CASE @DocumentClass WHEN dbo.adfGetClassByName('Pjm5.ServiceAssignment') THEN @DocumentID ELSE NULL END, 0)
		IF @ActivityTypeID IS NULL 
		BEGIN
			EXEC adfParameterGet 'ActivityTypeIsMandatory', 'Pjm5', @value OUTPUT
			SET @ActivityTypeIsMandatory = CAST(ISNULL(@value, 1) as BIT)
			IF @ActivityTypeIsMandatory = 1
				SET @ActivityTypeID = dbo.fnPjm5GetDefaultActivity(@ProjectID, @EmployeeID)
		END
	END
	ELSE
	BEGIN
		DECLARE @RoundInterval int, @RoundingMode int
		EXEC adfParameterGet @Name='RoundInterval', @Group='Pjm5', @Value = @value OUTPUT
		SET @RoundInterval = CAST(@value as int)
		EXEC adfParameterGet @Name='RoundingMode', @Group='Pjm5', @Value = @value OUTPUT
		SET @RoundingMode = CAST(@value as int)

		EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
		SET @CurrencyCode = CAST(@value AS varchar(3))

		SET @RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, @RoundInterval, @RoundingMode)
		SET @Rate = 0
		SET @TaskID = NULL
	END
	
	IF @DocumentID IS NULL SET @DocumentClass = NULL
	
	SET @VATRate = dbo.fnPjm5GetVATRate()
	SELECT @DivisionID = [DivisionID] FROM [Employee] WHERE [ID] = @EmployeeID
	INSERT INTO [TimeEntry]
		([Flag], [State], [FileAs], [ActivityTypeID], [EmployeeID], [AssignmentID], [ProjectID], [DocumentClass], [DocumentID], [TaskID], 
		[StartTime], [Duration], [RoundedDuration], [Billable], 
		[Overtime], [Rate], [CurrencyCode], [VATRate], [Color],
		[Comments], [DivisionID])
	VALUES
		(0, @State, @FileAs, @ActivityTypeID, @EmployeeID, @AssignmentID, @ProjectID,
		@DocumentClass, @DocumentID, @TaskID, 
		@StartTime, @Duration, @RoundedDuration, @Billable, 
		 @Overtime, @Rate, @CurrencyCode, @VATRate, @Color,
		 @Comments, @DivisionID)
			
	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()

	DECLARE @TimeEntryClass TClass
	SET @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')	
	
	IF @RecurrenceID IS NOT NULL
	BEGIN
		UPDATE
			[Document]
		SET
			[RecurrencePatternID] = @RecurrenceID
		WHERE
			[Class] = @TimeEntryClass AND [ID] = @ID
		IF @@ERROR != 0
		BEGIN
			RETURN 1
		END
	END
	IF @ProjectID IS NOT NULL
	BEGIN
		EXEC @rv = pjm5TimeEntryAutoApprove @ID
		IF @rv != 0
			RETURN @rv
	END
	RETURN 0
GO

GRANT EXECUTE ON pjm5TimeEntryCreateInternal TO PUBLIC
GO
  